@@ -525,7 +525,7 @@ class AntGrammar implements GrammarQuery {
         List<GrammarResult> list = new ArrayList<GrammarResult>();
         for (String choice : choices) {
             if (choice.startsWith(prefix)) {
-                list.add (new MyText(choice, choice));
+                list.add (new MyText(choice, choice, -1));
             }
         }
 
@@ -561,29 +561,55 @@ class AntGrammar implements GrammarQuery {
         assert content.length() > 0;
         String header;
         String propPrefix;
-        if (content.charAt(content.length() - 1) == '$') {
+        String wholeText = ctx.getNodeValue();
+        int replaceLen;
+        String suffix = "";
+        
+        if (content.charAt(content.length() - 1) == '$') { // NOI18N
             header = content + '{';
             propPrefix = "";
+            // no closing brace, since even opening brace is missing
+            replaceLen = 1;
         } else {
-            int idx = content.lastIndexOf("${");
+            int idx = content.lastIndexOf("${"); // NOI18N
             assert idx != -1;
             header = content.substring(0, idx + 2);
             propPrefix = content.substring(idx + 2);
+            
+            int closingBrace = wholeText.indexOf('}', content.length()); // NOI18N
+            if (closingBrace == -1) {
+                replaceLen = content.length();
+                suffix = wholeText.substring(replaceLen);
+            } else {
+                // only delete the text up to the closing brace
+                replaceLen = closingBrace + 1;
+            }
         }
         String[] props = likelyPropertyNames(ctx);
         // completion on text works differently from attrs:
         // the context should not be returned (#38342)
         boolean shortHeader = ctx.getNodeType() == Node.TEXT_NODE;
         List<GrammarResult> list = new ArrayList<GrammarResult>();
+        int pl = propPrefix.length();
         for (int i = 0; i < props.length; i++) {
             if (props[i].startsWith(propPrefix)) {
                 String text = header + props[i] + '}';
                 String all = "${" + props[i] + "}";
+                int l = 0;
                 if (shortHeader) {
                     assert text.startsWith(content) : "text=" + text + " content=" + content;
                     text = text.substring(content.length());
                 }
-                list.add(new MyText(text, all));
+                for (; l < suffix.length() && l + pl < props[i].length(); l++) {
+                    if (suffix.charAt(l) != props[i].charAt(l + pl)) {
+                        break;
+                    }
+                }
+                if (shortHeader && (content.length() <= replaceLen)) {
+                    l = -content.length();
+                }
+                replaceLen += l;
+                list.add(new MyText(text, all, replaceLen));
             }
         }
         LOG.log(Level.FINE, "completeProperties({0}) -> {1}", new Object[] {content, list});
@@ -902,10 +928,12 @@ class AntGrammar implements GrammarQuery {
 
         private final String data;
         private final String displayName;
-
-        MyText(String data, String displayName) {
+        private final int    replace;
+        
+        MyText(String data, String displayName, int replace) {
             this.data = data;
             this.displayName = displayName;
+            this.replace = replace;
         }
 
 
@@ -922,7 +950,11 @@ class AntGrammar implements GrammarQuery {
         }
 
         public @Override int getLength() {
-            return data == null ? -1 : data.length();
+//            if (replace != -1) {
+//                return replace;
+//            }
+//            return data == null ? -1 : data.length();
+            return replace;
         }
 
         public @Override String toString() {
