@@ -45,15 +45,17 @@
 package org.netbeans.api.debugger;
 
 import java.beans.*;
+import java.lang.reflect.Field;
 import java.util.*;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import javax.swing.SwingUtilities;
 
+import org.netbeans.debugger.registry.ContextAwareServicePath;
 import org.netbeans.spi.debugger.ActionsProvider;
 import org.netbeans.spi.debugger.ActionsProviderListener;
 import org.openide.util.Cancellable;
+import org.openide.util.Mutex;
 import org.openide.util.RequestProcessor;
 import org.openide.util.Task;
 
@@ -205,7 +207,7 @@ public final class ActionsManager {
         synchronized (actionProvidersLock) {
             inited = (actionProviders != null);
         }
-        if (!inited && SwingUtilities.isEventDispatchThread()) {
+        if (!inited && Mutex.EVENT.isReadAccess()) { // is EDT
             return postActionWithLazyInit(action);
         }
         ArrayList<ActionsProvider> l = getActionProvidersForActionWithInit(action);
@@ -244,6 +246,11 @@ public final class ActionsManager {
                         }
                     }
                 };
+                if (postedActions.size() > 1) {
+                    // We have more than one action provider for a single action.
+                    // Check their paths and choose the most specific one:
+                    postedActions = selectTheMostSpecific(postedActions);
+                }
                 count[0] = k = postedActions.size();
                 fireActionToBeRun(action);
                 for (i = 0; i < k; i++) {
@@ -260,7 +267,7 @@ public final class ActionsManager {
         }
         return task;
     }
-    
+
     private Task postActionWithLazyInit(final Object action) {
         final AsynchActionTask task = new AsynchActionTask(Collections.emptyList());
         new RequestProcessor(ActionsManager.class).post(new Runnable() {
@@ -275,7 +282,94 @@ public final class ActionsManager {
         });
         return task;
     }
-                                                                                
+    
+    private static List<ActionsProvider> selectTheMostSpecific(List<ActionsProvider> aps) {
+        Iterator<ActionsProvider> it = aps.iterator();
+        ActionsProvider ap = it.next();
+        String path = getPath(ap);
+        if (path == null) {
+            return aps;
+        }
+        /*
+        Map<String, ActionsProvider> providersByPath = new LinkedHashMap<String, ActionsProvider>();
+        providersByPath.put(path, ap);
+        while(it.hasNext()) {
+            ap = it.next();
+            path = getPath(ap);
+            if (path == null) {
+                return aps;
+            } else {
+                providersByPath.put(path, ap);
+            }
+        }
+        for (String p1 : providersByPath.keySet()) {
+            
+        }*/
+        int n = aps.size();
+        String[] paths = new String[n];
+        ActionsProvider[] apArr = new ActionsProvider[n];
+        int i = 0;
+        paths[i] = path;
+        apArr[i] = ap;
+        while(it.hasNext()) {
+            ap = it.next();
+            path = getPath(ap);
+            if (path == null) {
+                return aps;
+            } else {
+                i++;
+                paths[i] = path;
+                apArr[i] = ap;
+            }
+        }
+        
+        for (i = 0; i < n; i++) {
+            String p1 = paths[i];
+            for (int j = 0; j < n; j++) {
+                if (i == j) {
+                    continue;
+                }
+                String p2 = paths[j];
+                if (p1.startsWith(p2)) {
+                    // p1 is more specific than p2, abandon p2
+                    String[] newPaths = new String[n-1];
+                    ActionsProvider[] newApArr = new ActionsProvider[n-1];
+                    if (j > 0) {
+                        System.arraycopy(paths, 0, newPaths, 0, j);
+                        System.arraycopy(apArr, 0, newApArr, 0, j);
+                    }
+                    if (j < (n-1)) {
+                        System.arraycopy(paths, j+1, newPaths, j, n-1-j);
+                        System.arraycopy(apArr, j+1, newApArr, j, n-1-j);
+                    }
+                    paths = newPaths;
+                    apArr = newApArr;
+                    i--;
+                    n--;
+                    break;
+                }
+            }
+        }
+        if (n < aps.size()) {
+            aps = Arrays.asList(apArr);
+        }
+        return aps;
+    }
+    
+    private static String getPath(ActionsProvider ap) {
+        if (ap instanceof ContextAwareServicePath) {
+            String path = ((ContextAwareServicePath) ap).getServicePath();
+            int i = path.lastIndexOf('/');
+            if (i > 0) {
+                return path.substring(0, i);
+            } else {
+                return "";
+            }
+        } else {
+            return null;
+        }
+    }
+
     /**
      * Returns true if given action can be performed on this DebuggerEngine.
      * 
@@ -292,7 +386,7 @@ public final class ActionsManager {
             }
         }
         if (doInit) {
-            if (SwingUtilities.isEventDispatchThread()) {
+            if (Mutex.EVENT.isReadAccess()) { // SwingUtilities.isEventDispatchThread()
                 // Need to initialize lazily when called in AWT
                 // A state change will be fired after actions providers are initialized.
                 new RequestProcessor(ActionsManager.class).post(new Runnable() {
@@ -568,23 +662,26 @@ public final class ActionsManager {
     }
 
     private void initActionImpls () {
-        aps = lookup.lookup(null, ActionsProvider.class);
-        providersChangeListener = new PropertyChangeListener() {
-                @Override
-                public void propertyChange(PropertyChangeEvent evt) {
-                    logger.log(Level.FINE, "{0} Providers lookup changed, aps = {1}", new Object[] { this, aps });
-                    synchronized (actionProvidersLock) {
-                        actionProviders.clear();
+        try {
+            aps = lookup.lookup(null, ActionsProvider.class);
+            providersChangeListener = new PropertyChangeListener() {
+                    @Override
+                    public void propertyChange(PropertyChangeEvent evt) {
+                        logger.log(Level.FINE, "{0} Providers lookup changed, aps = {1}", new Object[] { this, aps });
+                        synchronized (actionProvidersLock) {
+                            actionProviders.clear();
+                        }
+                        registerActionsProviders(aps);
                     }
-                    registerActionsProviders(aps);
-                }
-        };
-        logger.log(Level.FINE, "{0}.initActionImpls(): Add ProvidersChangeListener to {1}", new Object[] { this, aps });
-        ((Customizer) aps).addPropertyChangeListener(providersChangeListener);
-        registerActionsProviders(aps);
-        synchronized (actionProvidersInitialized) {
-            actionProvidersInitialized.set(true);
-            actionProvidersInitialized.notifyAll();
+            };
+            logger.log(Level.FINE, "{0}.initActionImpls(): Add ProvidersChangeListener to {1}", new Object[] { this, aps });
+            ((Customizer) aps).addPropertyChangeListener(providersChangeListener);
+            registerActionsProviders(aps);
+        } finally {
+            synchronized (actionProvidersInitialized) {
+                actionProvidersInitialized.set(true);
+                actionProvidersInitialized.notifyAll();
+            }
         }
     }
 
@@ -673,8 +770,9 @@ public final class ActionsManager {
         public boolean cancel() {
             for (Iterator it = postedActions.iterator(); it.hasNext(); ) {
                 Object action = it.next();
-                if (action instanceof Cancellable) {
-                    if (!((Cancellable) action).cancel()) {
+                Cancellable c = getCancellable(action);
+                if (c != null) {
+                    if (!c.cancel()) {
                         return false;
                     }
                 } else {
@@ -683,6 +781,22 @@ public final class ActionsManager {
             }
             return true;
         }
+        
+        private Cancellable getCancellable(Object action) {
+            if (action instanceof Cancellable) {
+                return (Cancellable) action;
+            }
+            try {
+                // Hack because of ActionsProvider$ContextAware:
+                Field delegateField = action.getClass().getDeclaredField("delegate");   // NOI18N
+                delegateField.setAccessible(true);
+                action = delegateField.get(action);
+                if (action instanceof Cancellable) {
+                    return (Cancellable) action;
+                }
+            } catch (Exception ex) {}
+            return null;
+        }
     }
     
     class MyActionListener implements ActionsProviderListener {
