@@ -65,6 +65,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.WeakHashMap;
 import java.util.concurrent.atomic.AtomicReference;
@@ -78,18 +79,20 @@ import org.netbeans.modules.java.classpath.SimplePathResourceImplementation;
 import org.netbeans.spi.java.classpath.ClassPathImplementation;
 import org.netbeans.spi.java.classpath.ClassPathProvider;
 import org.netbeans.spi.java.classpath.FilteringPathResourceImplementation;
+import org.netbeans.spi.java.classpath.FlaggedClassPathImplementation;
 import org.netbeans.spi.java.classpath.PathResourceImplementation;
 import org.netbeans.spi.java.classpath.support.ClassPathSupport;
 import org.openide.filesystems.FileAttributeEvent;
+import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileChangeListener;
 import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileRenameEvent;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.URLMapper;
+import org.openide.util.BaseUtilities;
 import org.openide.util.Lookup;
 import org.openide.util.Parameters;
-import org.openide.util.Utilities;
 import org.openide.util.WeakListeners;
 
 /**
@@ -207,7 +210,13 @@ public final class ClassPath {
      * Name of the "entries" property
      */
     public static final String PROP_ENTRIES = "entries";
-    
+
+    /**
+     * Name of the "flags" property
+     * @since 1.43
+     */
+    public static final String PROP_FLAGS = "flags";
+
     /**
      * Property to be fired when include/exclude set changes.
      * @see FilteringPathResourceImplementation
@@ -297,6 +306,16 @@ public final class ClassPath {
                 URL url = entry.getURL();
                 if ("jar".equals(url.getProtocol())) { //NOI18N
                     url = FileUtil.getArchiveFile(url);
+                    if (url == null) {
+                        LOG.log(
+                            Level.WARNING,
+                            "Invalid classpath root: {0} provided by: {1}", //NOI18N
+                            new Object[]{
+                                entry.getURL(),
+                                impl
+                            });
+                        continue;
+                    }
                 }
                 if (!"file".equals(url.getProtocol())) { // NOI18N
                     // Try to convert nbinst to file
@@ -312,7 +331,7 @@ public final class ClassPath {
                     //todo: Ignore non file urls, we can try to url->fileobject->url
                     //if it becomes a file.
                     if ("file".equals(url.getProtocol())) { //NOI18N
-                        file = FileUtil.normalizeFile(Utilities.toFile(url.toURI()));
+                        file = FileUtil.normalizeFile(BaseUtilities.toFile(url.toURI()));
                     }
                 } catch (IllegalArgumentException e) {
                     LOG.log(Level.WARNING, "Unexpected URL <{0}>: {1}", new Object[] {url, e});
@@ -596,6 +615,25 @@ public final class ClassPath {
         propSupport.removePropertyChangeListener(l);        
     }
 
+    /**
+     * Returns the {@link ClassPath}'s flags.
+     * @return the {@link Flag}s
+     * @since 1.44
+     */
+    @NonNull
+    public Set<Flag> getFlags() {
+        if (impl instanceof FlaggedClassPathImplementation) {
+            final Set<Flag> res = ((FlaggedClassPathImplementation)impl).getFlags();
+            assert res != null : String.format(
+                "ClassPathImplementation %s : %s returned null flags.", //NOI18N
+                impl,
+                impl.getClass());
+            return res;
+        } else {
+            return Collections.<Flag>emptySet();
+        }
+    }
+
     /**
      * Find the classpath of a given type, if any, defined for a given file.
      * <p>This method may return null, if:</p>
@@ -635,11 +673,15 @@ public final class ClassPath {
         for (ClassPathProvider impl  : impls.allInstances()) {
             ClassPath cp = impl.findClassPath(f, id);
             if (cp != null) {
-                LOG.log(Level.FINE, "getClassPath({0}, {1}) -> {2} from {3}", new Object[] {f, id, cp, impl});
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, "getClassPath({0}, {1}) -> {2} from {3}", new Object[] {f, id, cp, impl});
+                }
                 return cp;
             }
         }
-        LOG.log(Level.FINE, "getClassPath({0}, {1}) -> nil", new Object[] {f, id});
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.log(Level.FINE, "getClassPath({0}, {1}) -> nil", new Object[] {f, id});
+        }
         return null;
     }
 
@@ -683,6 +725,18 @@ public final class ClassPath {
         PRINT,
     }
 
+    /**
+     * ClassPath's flags.
+     * @since 1.44
+     */
+    public enum Flag {
+        /**
+         * The incomplete {@link ClassPath} is ignored by language features
+         * unless it's resolved and the {@link INCOMPLETE} flag is removed.
+         */
+        INCOMPLETE
+    }
+
     /**
      * Render this classpath in the conventional format used by the Java launcher.
      * @param conversionMode policy for converting unusual entries
@@ -808,7 +862,7 @@ public final class ClassPath {
                             } else {
                                 String fileState = null;
                                 try {
-                                    final File file = Utilities.toFile(this.url.toURI());
+                                    final File file = BaseUtilities.toFile(this.url.toURI());
                                     final boolean exists = file.exists();
                                     final boolean isDirectory = file.isDirectory();
                                     if (exists && !isDirectory) {
@@ -968,7 +1022,7 @@ public final class ClassPath {
         @Override
         public boolean equals (Object other) {
             if (other instanceof ClassPath.Entry) {
-                return Utilities.compareObjects(((ClassPath.Entry)other).url, this.url);
+                return Objects.equals(((ClassPath.Entry)other).url, this.url);
             }
             return false;
         }
@@ -999,9 +1053,10 @@ public final class ClassPath {
      * Not synchronized, HAS TO be called from the synchronized block!
      */
     private void attachRootsListener () {
+        assert Thread.holdsLock(this);
         if (this.rootsListener == null) {
             assert this.rootsCache == null;
-            this.rootsListener = new RootsListener (this);
+            this.rootsListener = new RootsListener ();
         }
     }
 
@@ -1168,6 +1223,8 @@ public final class ClassPath {
                 if (fire) {
                     firePropertyChange(PROP_INCLUDES, null, null, evt.getPropagationId());
                 }
+            } else if (FlaggedClassPathImplementation.PROP_FLAGS.equals(prop)) {
+                firePropertyChange(PROP_FLAGS, null, null, null);
             }
             if (ClassPathImplementation.PROP_RESOURCES.equals(prop)) {
                 final List<? extends PathResourceImplementation> resources = impl.getResources();
@@ -1198,29 +1255,27 @@ public final class ClassPath {
     }
 
 
-    private static class RootsListener extends WeakReference<ClassPath> implements FileChangeListener, Runnable {
+    private class RootsListener extends FileChangeAdapter {
 
-        private final Set<File> roots;
+        private final Set</*@GuardedBy("this")*/File> roots;
 
-        private RootsListener (ClassPath owner) {
-            super (owner, Utilities.activeReferenceQueue());
+        private RootsListener () {
             roots = new HashSet<> ();
         }
 
         public void addRoots (final Set<? extends File> newRoots) {
             Parameters.notNull("urls",newRoots);    //NOI18N
-
             synchronized (this) {
                 final Set<File> toRemove = new HashSet<>(roots);
                 toRemove.removeAll(newRoots);
                 final Set<File> toAdd = new HashSet<>(newRoots);
                 toAdd.removeAll(roots);
                 for (File root : toRemove) {
-                    safeRemoveListener(root);
+                    safeRemoveFileChangeListener(root);
                     roots.remove(root);
                 }
                 for (File root : toAdd) {
-                    safeAddListener(root);
+                    safeAddFileChangeListener(root);
                     roots.add (root);
                 }
             }
@@ -1231,7 +1286,7 @@ public final class ClassPath {
             for (final Iterator<File> it = roots.iterator(); it.hasNext();) {
                 final File root = it.next();
                 it.remove();
-                FileUtil.removeFileChangeListener(this, root);
+                safeRemoveFileChangeListener(root);
             }
         }
 
@@ -1250,6 +1305,7 @@ public final class ClassPath {
             processEvent(fe);
         }
 
+        @Override
         public void fileDeleted(FileEvent fe) {
             this.processEvent (fe);
         }
@@ -1259,45 +1315,27 @@ public final class ClassPath {
             this.processEvent (fe);
         }
 
-        @Override
-        public void fileAttributeChanged(FileAttributeEvent fe) {
-        }
-
-        @Override
-        public void run() {
-            try {
-                removeAllRoots();
-            } catch (final IllegalArgumentException iae) {
-                //pass - ignore, the FU.removeFileChangeListener holds listeners
-                //in the WeakHashMap and this may be already removed -> IAE.
-            }
-        }
-
         private void processEvent (FileEvent fe) {
-            final ClassPath cp = get();
-            if (cp == null) {
-                return;
+            synchronized (ClassPath.this) {
+                ClassPath.this.rootsCache = null;
+                ClassPath.this.invalidRoots++;
             }
-            synchronized (cp) {
-                cp.rootsCache = null;
-                cp.invalidRoots++;
-            }
-            cp.firePropertyChange(PROP_ROOTS,null,null,null);
+            ClassPath.this.firePropertyChange(PROP_ROOTS,null,null,null);
         }
 
-        private void safeAddListener(@NonNull final File root) {
+        private void safeRemoveFileChangeListener(@NonNull final File file) {
             try {
-                FileUtil.addFileChangeListener(this, root);
+                FileUtil.removeFileChangeListener(this, file);
             } catch (IllegalArgumentException iae) {
-                LOG.warning(iae.getMessage());
+                LOG.log(Level.FINE, iae.getMessage());
             }
         }
 
-        private void safeRemoveListener(@NonNull final File root) {
+        private void safeAddFileChangeListener(@NonNull final File file) {
             try {
-                FileUtil.removeFileChangeListener(this, root);
+                FileUtil.addFileChangeListener(this, file);
             } catch (IllegalArgumentException iae) {
-                LOG.warning(iae.getMessage());
+                LOG.log(Level.FINE, iae.getMessage());
             }
         }
     }
