@@ -110,6 +110,11 @@ public class ResultsOutlineSupport {
             "org/netbeans/modules/search/res/context.gif";              //NOI18N
     private static final int VERTICAL_ROW_SPACE = 2;
 
+    private static final String PROP_HORIZONTAL_SCROLLBAR
+            = "netbeans.search.horizontal.scrollbar";                   //NOI18N
+    private static final int HORIZONTAL_SCROLLBAR_POLICY
+            = getHorizontalScrollbarPolicy();
+
     OutlineView outlineView;
     private boolean replacing;
     private boolean details;
@@ -124,6 +129,7 @@ public class ResultsOutlineSupport {
     private ETableColumnModel columnModel;
     private List<MatchingObjectNode> matchingObjectNodes;
     private boolean closed = false;
+    private volatile boolean expansionListenerEnabled = true;
 
     public ResultsOutlineSupport(boolean replacing, boolean details,
             ResultModel resultModel, BasicComposition basicComposition,
@@ -175,8 +181,7 @@ public class ResultsOutlineSupport {
         FontMetrics fm = outlineView.getOutline().getFontMetrics(font);
         outlineView.getOutline().setRowHeight(
                 Math.max(16, fm.getHeight()) + VERTICAL_ROW_SPACE);
-        outlineView.setTreeHorizontalScrollBarPolicy(
-                OutlineView.HORIZONTAL_SCROLLBAR_AS_NEEDED);
+        outlineView.setTreeHorizontalScrollBarPolicy(HORIZONTAL_SCROLLBAR_POLICY);
         setTooltipHidingBehavior();
     }
 
@@ -338,11 +343,22 @@ public class ResultsOutlineSupport {
         resultsNode.update();
     }
 
+    /**
+     * ExpandingTreeExpansionListener should be enabled only when the nodes are
+     * expanded manually. See bug 248558.
+     */
+    void setExpansionListenerEnabled(boolean enabled) {
+        this.expansionListenerEnabled = enabled;
+    }
+
     private class ExpandingTreeExpansionListener
             implements TreeExpansionListener {
 
         @Override
         public void treeExpanded(TreeExpansionEvent event) {
+            if (!expansionListenerEnabled) {
+                return;
+            }
             Object lpc = event.getPath().getLastPathComponent();
             Node node = Visualizer.findNode(lpc);
             if (node != null) {
@@ -425,10 +441,20 @@ public class ResultsOutlineSupport {
     }
 
     private void expandOnlyChilds(Node parent) {
-        if (parent.getChildren().getNodesCount(true) == 1) {
-            Node onlyChild = parent.getChildren().getNodeAt(0);
-            outlineView.expandNode(onlyChild);
-            expandOnlyChilds(onlyChild);
+        setExpansionListenerEnabled(false);
+        try {
+            Node node = parent;
+            while (node != null) {
+                Children children = node.getChildren();
+                if (children.getNodesCount(true) == 1) {
+                    node = children.getNodeAt(0);
+                    outlineView.expandNode(node);
+                } else {
+                    node = null;
+                }
+            }
+        } finally {
+            setExpansionListenerEnabled(true);
         }
     }
 
@@ -889,4 +915,29 @@ public class ResultsOutlineSupport {
         public void columnSelectionChanged(ListSelectionEvent e) {
         }
     }
+
+    private static int getHorizontalScrollbarPolicy() {
+        try {
+            String prop = System.getProperty(PROP_HORIZONTAL_SCROLLBAR);
+            if (prop == null) {
+                return OutlineView.HORIZONTAL_SCROLLBAR_AS_NEEDED;
+            }
+            switch (prop) {
+                case "on":                                              //NOI18N
+                case "On":                                              //NOI18N
+                case "ON":                                              //NOI18N
+                    return OutlineView.HORIZONTAL_SCROLLBAR_ALWAYS;
+                case "off":                                             //NOI18N
+                case "Off":                                             //NOI18N
+                case "OFF":                                             //NOI18N
+                    return OutlineView.HORIZONTAL_SCROLLBAR_NEVER;
+                default:
+                    return OutlineView.HORIZONTAL_SCROLLBAR_AS_NEEDED;
+            }
+        } catch (Exception e) {
+            Logger.getLogger(ResultsOutlineSupport.class.getName()).log(
+                    Level.INFO, null, e);
+            return OutlineView.HORIZONTAL_SCROLLBAR_AS_NEEDED;
+        }
+    }
 }
