@@ -344,7 +344,10 @@ public class NbModuleProjectGenerator {
         }
         EditableProperties props = new EditableProperties(true);
         props.setProperty("suite.dir", suiteLocation); // NOI18N
-        FileObject suiteProperties = createFileObject(projectDir, suitePropertiesLocation);
+        FileObject suiteProperties = projectDir.getFileObject(suitePropertiesLocation);
+        if (suiteProperties == null || !suiteProperties.isValid()) {
+            suiteProperties = createFileObject(projectDir, suitePropertiesLocation);
+        }
         Util.storeProperties(suiteProperties, props);
     }
     
@@ -467,7 +470,7 @@ public class NbModuleProjectGenerator {
     
     private static void createInitialProperties(FileObject projectDir) throws IOException {
         EditableProperties props = new EditableProperties(false);
-        props.put(SingleModuleProperties.JAVAC_SOURCE, "1.6"); // NOI18N
+        props.put(SingleModuleProperties.JAVAC_SOURCE, "1.7"); // NOI18N
         props.put(SingleModuleProperties.JAVAC_COMPILERARGS, "-Xlint -Xlint:-serial"); // NOI18N
         FileObject f = createFileObject(projectDir, AntProjectHelper.PROJECT_PROPERTIES_PATH);
         Util.storeProperties(f, props);
