@@ -160,6 +160,10 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
     private final String repositoryId;
 
     public IssueTable(String repositoryId, String queryName, QueryController controller, ColumnDescriptor[] descriptors, final boolean isSaved) {
+        this(repositoryId, queryName, controller, descriptors, isSaved, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
+    }
+    
+    public IssueTable(String repositoryId, String queryName, QueryController controller, ColumnDescriptor[] descriptors, final boolean isSaved, int vsbPolicy, int hsbPolicy) {
         assert descriptors != null;
         assert descriptors.length > 0;
 
@@ -185,7 +189,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         sorter.setTableHeader(table.getTableHeader());
         table.setRowHeight(table.getRowHeight() * 6 / 5);
         
-        JScrollPane tableScrollPane = new JScrollPane(table, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
+        JScrollPane tableScrollPane = new JScrollPane(table, vsbPolicy, hsbPolicy);
         tableScrollPane.getViewport().setBackground(table.getBackground());
         Color borderColor = UIManager.getColor("scrollpane_border"); // NOI18N
         if (borderColor == null) borderColor = UIManager.getColor("controlShadow"); // NOI18N
@@ -623,8 +627,11 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
                         }
                     }
                     if(isSaved) {
-                        int w = UIUtils.getColumnWidthInPixels(25, table);
-                        setColumnWidth(getRecentChangesColumnIdx(), w);
+                        int idx = getRecentChangesColumnIdx();
+                        if(idx > -1) {
+                            int w = UIUtils.getColumnWidthInPixels(25, table);
+                            setColumnWidth(getRecentChangesColumnIdx(), w);
+                        }
                     }
                 }
 
@@ -832,13 +839,13 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         });
     }
 
-    private class SeenDescriptor extends ColumnDescriptor<Boolean> {
+    private static class SeenDescriptor extends ColumnDescriptor<Boolean> {
         public SeenDescriptor() {
             super(IssueNode.LABEL_NAME_SEEN, Boolean.class, "", NbBundle.getBundle(IssueTable.class).getString("CTL_Issue_Seen_Desc"), -1, true, true); // NOI18N
         }
     }
 
-    private class RecentChangesDescriptor extends ColumnDescriptor<String> {
+    private static class RecentChangesDescriptor extends ColumnDescriptor<String> {
         public RecentChangesDescriptor() {
             super(IssueNode.LABEL_RECENT_CHANGES, String.class, NbBundle.getBundle(IssueTable.class).getString("CTL_Issue_Recent"), NbBundle.getBundle(IssueTable.class).getString("CTL_Issue_Recent_Desc"), -1, true, true); // NOI18N
         }
