@@ -50,6 +50,7 @@ import java.awt.event.ComponentAdapter;
 import java.awt.event.ComponentEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import java.util.concurrent.TimeUnit;
 import javax.swing.JComponent;
 import javax.swing.Timer;
 import javax.swing.event.DocumentEvent;
@@ -319,6 +320,7 @@ public final class DashboardTopComponent extends TopComponent {
         addTask(new TaskNode(issue, null));
     }
     
+    private boolean openedByUserAction = false;
     public void addTask(TaskNode... taskNodes) {
         final CategoryPicker picker = new CategoryPicker(taskNodes);
         final NotifyDescriptor nd = new NotifyDescriptor(
@@ -339,6 +341,11 @@ public final class DashboardTopComponent extends TopComponent {
         if (DialogDisplayer.getDefault().notify(nd) == NotifyDescriptor.OK_OPTION) {
             Category category = picker.getChosenCategory();
             dashboard.addTaskToCategory(category, taskNodes);
+            
+            if(!openedByUserAction && !isOpened()) {
+                openedByUserAction = true;
+                activate();
+            }
         }
     }
 
@@ -386,16 +393,23 @@ public final class DashboardTopComponent extends TopComponent {
     private class FilterTimerListener implements ActionListener {
 
         private final RequestProcessor RP = new RequestProcessor(FilterTimerListener.class.getName());
+        private boolean wasEmpty = true;
 
         @Override
         public void actionPerformed(ActionEvent e) {
             if (e.getSource() == filterTimer) {
+                final boolean isEmpty = filterPanel.getFilterText().isEmpty();
+                if(wasEmpty && !isEmpty) {
+                    dashboard.saveExpandedState();
+                    wasEmpty = false;
+                } else if(isEmpty) {
+                    wasEmpty = true;
+                }
                 filterTimer.stop();
-                RP.post(new Runnable() {
-
+                RP.schedule(new Runnable() {
                     @Override
                     public void run() {
-                        if (!filterPanel.getFilterText().isEmpty()) {
+                        if (!isEmpty) {
                             DisplayTextTaskFilter newTaskFilter = new DisplayTextTaskFilter(filterPanel.getFilterText());
                             int hits = dashboard.updateTaskFilter(displayTextTaskFilter, newTaskFilter);
                             displayTextTaskFilter = newTaskFilter;
@@ -408,7 +422,7 @@ public final class DashboardTopComponent extends TopComponent {
                             filterPanel.clear();
                         }
                     }
-                });
+                }, 100, TimeUnit.MILLISECONDS);
             }
         }
     }
