@@ -93,6 +93,7 @@ import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.awt.UndoRedo;
 import org.openide.util.Cancellable;
+import org.openide.util.HelpCtx;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -187,6 +188,16 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         } else {
             if(defaultRepository == null) {
                 rs = RepositoryComboSupport.setup(this, repositoryComboBox, false);
+                if(!IssueTopComponent.this.isShowing()) {
+                    try {
+                        // ensure issue exists when TC is opened so 
+                        // that we can notify the issue implementation about issue being opened
+                        IssueTopComponent.this.open();
+                        IssueTopComponent.this.requestActive();
+                    } finally {
+                        UIUtils.setWaitCursor(false);                        
+                    }
+                }
             } else {
                 rs = RepositoryComboSupport.setup(this, repositoryComboBox, defaultRepository.getRepository());
             }
@@ -379,6 +390,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
                 return true;
             }
         };
+        UIUtils.setWaitCursor(true);
         final ProgressHandle handle = ProgressHandleFactory.createHandle(NbBundle.getMessage(IssueTopComponent.class, "CTL_PreparingIssue"), c); // NOI18N
         prepareTask = rp.post(new Runnable() {
             @Override
@@ -393,9 +405,9 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
                     if(issue != null) {
                         if(controller != null) {
                             issuePanelRemove(controller.getComponent());
+                            unregisterListeners();
                             controller.closed();
                         }
-                        unregisterListeners();
                         instanceContent.remove(issue.getIssue());
                     }
                     issue = repo.createNewIssue();
@@ -419,15 +431,22 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
                         public void run() {
                             controller = getController();
                             issuePanel.add(controller.getComponent(), BorderLayout.CENTER);
-                            controller.opened(); // XXX TC wasn't realy opened
                             registerListeners();
                             revalidate();
                             repaint();
 
                             focusFirstEnabledComponent();
+                            
+                            if(!IssueTopComponent.this.isShowing()) {
+                                // ensure issue exists when TC is opened so 
+                                // that we can notify the issue implementation about issue being opened
+                                IssueTopComponent.this.open();
+                                IssueTopComponent.this.requestActive();
+                            }
                         }
                     });
                 } finally {
+                    UIUtils.setWaitCursor(false);
                     setVisible(preparingLabel, false);
                     handle.finish();
                     prepareTask = null;
@@ -621,12 +640,12 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
      * @param issueId
      * @return
      */
-    public static synchronized IssueTopComponent find(String issueId) {
+    static synchronized IssueTopComponent find(String issueId, RepositoryImpl repo) {
         assert issueId != null;
         for (IssueTopComponent tc : openIssues) {
             IssueImpl i = tc.getIssue();
             if(i == null) continue;
-            if (issueId.equals(i.getID())) {
+            if (issueId.equals(i.getID()) && i.getRepositoryImpl().equals(repo)) {
                 return tc;
             }
         }
@@ -653,6 +672,13 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         });
     }
 
+    @Override
+    public HelpCtx getHelpCtx() {
+        return new HelpCtx(issue != null && !issue.isNew()
+                     ? "o.n.m.bugtracking.ui.issue.IssueTopComponent.edit" // NOI18N
+                     : "o.n.m.bugtracking.ui.issue.IssueTopComponent.new"); // NOI18N
+    }
+
     @Override
     public void propertyChange(PropertyChangeEvent evt) {
         if(evt.getPropertyName().equals(IssueImpl.EVENT_ISSUE_DATA_CHANGED)) {
