@@ -99,6 +99,8 @@ import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.awt.Mnemonics;
 import org.openide.util.Cancellable;
+import org.openide.util.Exceptions;
+import org.openide.util.HelpCtx;
 import org.openide.util.Mutex;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -113,7 +115,7 @@ public final class QueryTopComponent extends TopComponent
     private static QueryTopComponent instance;
 
     /** Set of opened {@code QueryTopComponent}s. */
-    private static final Set<QueryTopComponent> openQueries = Collections.synchronizedSet(new HashSet<QueryTopComponent>());
+    private static final Set<QueryTopComponent> openQueries = new HashSet<QueryTopComponent>();
 
     private final RepoSelectorPanel repoPanel;
     private final LinkButton newButton;
@@ -150,8 +152,6 @@ public final class QueryTopComponent extends TopComponent
         GroupLayout layout = (GroupLayout) headerPanel.getLayout();
         leftRepoPanel.setVisible(true);
         layout.replace(leftRepoPanel, repoPanel);
-                
-        addNoContentPanel();
         
         /* texts */
         Mnemonics.setLocalizedText(
@@ -187,10 +187,6 @@ public final class QueryTopComponent extends TopComponent
         LayoutStyle layoutStyle = LayoutStyle.getInstance();
         return layoutStyle.getContainerGap(comp, WEST, null);
     }
-
-    public static Set<QueryTopComponent> getOpenQueries() {
-        return openQueries;
-    }
     
     public QueryImpl getQuery() {
         return query;
@@ -202,6 +198,8 @@ public final class QueryTopComponent extends TopComponent
         addQueryComponent(c);
     }
     
+    @NbBundle.Messages({"LBL_RepositoryInit=<Initializing...>",
+                        "LBL_NoRepositorySelected=<no repository selected>"})
     void init(QueryImpl query, RepositoryImpl defaultRepository, File context, boolean suggestedSelectionOnly, QueryController.QueryMode mode, boolean isNew) {
         this.query = query;
         this.context = context;
@@ -256,18 +254,24 @@ public final class QueryTopComponent extends TopComponent
                     }
                 }
             });
+            
+            NoContentPanel ncp = new NoContentPanel();
             if(defaultRepository == null) {
                 rs = RepositoryComboSupport.setup(this, repositoryComboBox, true);
+                ncp.setText(Bundle.LBL_NoRepositorySelected());
             } else {
                 rs = RepositoryComboSupport.setup(this, repositoryComboBox, defaultRepository.getRepository());
+                ncp.setText(Bundle.LBL_RepositoryInit());
             }
+            queryPanel.add(ncp);
             rs.setLocalRepositoryHidden(true);
             newButton.addFocusListener(this);
             repositoryComboBox.addFocusListener(this);
-        }
+        }                
     }
 
     private void registerListeners() {
+        unregisterListeners(); // avoid duplicates
         query.addPropertyChangeListener(this);
         query.getController().addPropertyChangeListener(this);
         query.getRepositoryImpl().addPropertyChangeListener(this);
@@ -325,7 +329,8 @@ public final class QueryTopComponent extends TopComponent
      * @return top-component that should display the given query.
      */
     public static synchronized QueryTopComponent find(QueryImpl query) {
-        for (QueryTopComponent tc : openQueries) {
+        QueryTopComponent[] tcs = getOpenQueries();
+        for (QueryTopComponent tc : tcs) {
             if (query.equals(tc.getQuery())) {
                 return tc;
             }
@@ -334,7 +339,8 @@ public final class QueryTopComponent extends TopComponent
     }
 
     public static void closeFor(RepositoryImpl repo) {
-        for (QueryTopComponent itc : openQueries) {
+        QueryTopComponent[] tcs = getOpenQueries();
+        for (QueryTopComponent itc : tcs) {
             QueryImpl tcQuery = itc.getQuery(); 
             if(tcQuery == null) {
                 continue;
@@ -348,14 +354,29 @@ public final class QueryTopComponent extends TopComponent
         }
     }
 
+    private static QueryTopComponent[] getOpenQueries() {
+        QueryTopComponent[] tcs;
+        synchronized(openQueries) {
+            tcs = openQueries.toArray(new QueryTopComponent[openQueries.size()]);
+        }
+        return tcs;
+    }
+    
     @Override
     public int getPersistenceType() {
         return TopComponent.PERSISTENCE_NEVER;
     }
 
+    @Override
+    public HelpCtx getHelpCtx() {
+        return new HelpCtx("o.n.m.bugtracking.ui.query.QueryTopComponent"); // NOI18N
+    }
+
     @Override
     public void componentOpened() {
-        openQueries.add(this);
+        synchronized(openQueries) {
+            openQueries.add(this);
+        }
         if(query != null) {
             getController(query).opened();
         }
@@ -369,17 +390,31 @@ public final class QueryTopComponent extends TopComponent
 
     @Override
     public void componentClosed() {
-        openQueries.remove(this);
-        if(query != null) {
-            unregisterListeners();
-            getController(query).closed();
+        synchronized(openQueries) {
+            openQueries.remove(this);
         }
+        RepositoryRegistry.getInstance().removePropertyChangeListener(this);
+
+        if(query != null) {
+            releaseQuery(!isSaved());
+        }
+        
         if(prepareTask != null) {
             prepareTask.cancel();
         }
         BugtrackingManager.LOG.log(Level.FINE, "{0} - {1} closed", new Object[] {this.getClass().getName(), query != null ? query.getDisplayName() : null});  // NOI18N
     }
 
+    private void releaseQuery(boolean remove) {
+        if(query != null) {
+            unregisterListeners();
+            getController(query).closed();
+            if(remove) {
+                query = null;
+            }
+        }
+    }
+
     /** replaces this in object stream */
     @Override
     public Object writeReplace() {
@@ -405,7 +440,7 @@ public final class QueryTopComponent extends TopComponent
                     }    
                 }
                 if(!stillExists) {
-                    closeInAwt();
+                    queryRemoved();
                 }
             }
         } else if(evt.getPropertyName().equals(RepositoryRegistry.EVENT_REPOSITORIES_CHANGED)) {
@@ -416,15 +451,13 @@ public final class QueryTopComponent extends TopComponent
                 {
                     RepositoryImpl thisRepo = query.getRepositoryImpl();
                     if(contains((Collection) cOld, thisRepo)) {
-                        // removed
-                        closeInAwt();
+                        queryRemoved();
                     }
                 } else if(cOld == null) {
                     RepositoryImpl thisRepo = query.getRepositoryImpl();
                     Collection<RepositoryImpl> knownRepos = RepositoryRegistry.getInstance().getKnownRepositories(true);
                     if(!contains((Collection) knownRepos, thisRepo)) {
-                        // removed
-                        closeInAwt();
+                        queryRemoved();
                     }
                 }
             }
@@ -473,6 +506,11 @@ public final class QueryTopComponent extends TopComponent
         } 
     }
 
+    private void queryRemoved() {
+        closeInAwt();
+        releaseQuery(true);
+    }
+
     private void openDashboard() {
         Mutex.EVENT.readAccess(new Runnable() {
             @Override
@@ -589,13 +627,6 @@ public final class QueryTopComponent extends TopComponent
         });
     }
 
-    @NbBundle.Messages("LBL_NoRepositorySelected=<no repository selected>")
-    private void addNoContentPanel() {
-        NoContentPanel ncp = new NoContentPanel();
-        ncp.setText(Bundle.LBL_NoRepositorySelected());
-        queryPanel.add(ncp);
-    }
-
     final static class ResolvableHelper implements Serializable {
 
         private static final long serialVersionUID = 1L;
@@ -641,6 +672,7 @@ public final class QueryTopComponent extends TopComponent
                     if(repo == null) {
                         return;
                     }
+                    repo.removePropertyChangeListener(QueryTopComponent.this);
                     repo.addPropertyChangeListener(QueryTopComponent.this);
 
                     if(query != null) {
