@@ -95,6 +95,7 @@ import org.openide.util.RequestProcessor;
 import org.openide.util.RequestProcessor.Task;
 import org.openide.util.WeakListeners;
 import org.openide.util.WeakSet;
+import org.eclipse.mylyn.tasks.core.IRepositoryQuery;
 
 /**
  *
@@ -119,7 +120,8 @@ public class BugzillaRepository {
     private final Object CACHE_LOCK = new Object();
     private UnsubmittedTasksContainer unsubmittedTasksContainer;
     private PropertyChangeListener unsubmittedTasksListener;
-
+    private boolean queryCleanedup = false;
+    
     public BugzillaRepository() {
         icon = ImageUtilities.loadImage(ICON_PATH, true);
         support = new PropertyChangeSupport(this);
@@ -127,10 +129,10 @@ public class BugzillaRepository {
 
     public BugzillaRepository(RepositoryInfo info) {
         this();
-        this.info = info;
-        String name = info.getDisplayName();
-        String url = info.getUrl();
-        boolean shortLoginEnabled = Boolean.parseBoolean(info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN));
+        this.info = checkAndPatchNetbeansUrl(info);
+        String name = this.info.getDisplayName();
+        String url = this.info.getUrl();
+        boolean shortLoginEnabled = Boolean.parseBoolean(this.info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN));
         taskRepository = setupTaskRepository(name, null, url, "", new char[0], "", new char[0], shortLoginEnabled);
     }
 
@@ -451,6 +453,21 @@ public class BugzillaRepository {
     
     private Set<BugzillaQuery> getQueriesIntern() {
         if(queries == null) {
+            if(!queryCleanedup) {
+                // clean up. we are deleting adhoc queries when closing the query dialog
+                // an eventual crash could have left some stored in MylynSupport
+                queryCleanedup = true;
+                try {
+                    Set<IRepositoryQuery> iqs = MylynSupport.getInstance().getRepositoryQueries(taskRepository);
+                    for (IRepositoryQuery q : iqs) {
+                        if(q.getSummary().startsWith(BugzillaQuery.BUGZILLA_ADHOC_QUERY_PREFIX)) {
+                            MylynSupport.getInstance().deleteQuery(q);
+                        }
+                    }
+                } catch (CoreException ex) { 
+                    Bugzilla.LOG.log(Level.INFO, null, ex);
+                }
+            }
             queries = new HashSet<BugzillaQuery>(10);
             String[] qs = BugzillaConfig.getInstance().getQueries(getID());
             for (String queryName : qs) {
@@ -466,14 +483,14 @@ public class BugzillaRepository {
     }
 
     public synchronized void setInfoValues(String user, char[] password) {
-        setTaskRepository(info.getDisplayName(), info.getUrl(), user, password, null, null, Boolean.parseBoolean(info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN)));
         info = createInfo(info.getID(), info.getUrl(), info.getDisplayName(), user, null, password, null, Boolean.parseBoolean(info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN)));
+        setTaskRepository(info.getDisplayName(), info.getUrl(), user, password, null, null, Boolean.parseBoolean(info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN)));
     }
     
     synchronized void setInfoValues(String name, String url, String user, char[] password, String httpUser, char[] httpPassword, boolean localUserEnabled) {
-        setTaskRepository(name, url, user, password, httpUser, httpPassword, localUserEnabled);
         String id = info != null ? info.getID() : name + System.currentTimeMillis();
         info = createInfo(id, url, name, user, httpUser, password, httpPassword, localUserEnabled);
+        setTaskRepository(name, url, user, password, httpUser, httpPassword, localUserEnabled);
     }
 
     protected RepositoryInfo createInfo(String id, String url, String name, String user, String httpUser, char[] password, char[] httpPassword, boolean localUserEnabled) {
@@ -694,6 +711,25 @@ public class BugzillaRepository {
         }
     }
 
+    private RepositoryInfo checkAndPatchNetbeansUrl(RepositoryInfo info) {
+        if(BugzillaUtil.isNbRepository(info.getUrl()) && info.getUrl().startsWith("http://")) { // NOI18N
+            RepositoryInfo i = new RepositoryInfo(
+                                    info.getID(),
+                                    info.getConnectorId(),
+                                    NBRepositorySupport.NB_BUGZILLA_URL,
+                                    info.getDisplayName(),
+                                    info.getTooltip(),
+                                    info.getUsername(),
+                                    info.getHttpUsername(),
+                                    info.getPassword(), 
+                                    info.getHttpPassword());
+            i.putValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN, info.getValue(IBugzillaConstants.REPOSITORY_SETTING_SHORT_LOGIN));
+            Bugzilla.LOG.warning("Changed NetBeans repository url protocol to https");
+            return i;
+        } 
+        return info;
+    }
+
     private static class TaskMapping extends org.eclipse.mylyn.tasks.core.TaskMapping {
         private final String component;
         private final String product;
