@@ -55,19 +55,18 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.logging.Level;
-import org.netbeans.modules.cnd.apt.structure.APTInclude;
+import org.netbeans.modules.cnd.apt.debug.APTTraceFlags;
 import org.netbeans.modules.cnd.apt.support.APTFileSearch;
 import org.netbeans.modules.cnd.apt.support.APTIncludeHandler;
-import org.netbeans.modules.cnd.apt.support.APTIncludeHandler.IncludeInfo;
 import org.netbeans.modules.cnd.apt.support.APTIncludeResolver;
 import org.netbeans.modules.cnd.apt.support.IncludeDirEntry;
-import org.netbeans.modules.cnd.apt.support.StartEntry;
-import org.netbeans.modules.cnd.apt.utils.APTSerializeUtils;
+import org.netbeans.modules.cnd.apt.support.api.StartEntry;
 import org.netbeans.modules.cnd.apt.utils.APTUtils;
-import org.netbeans.modules.cnd.utils.cache.FilePathCache;
 import org.netbeans.modules.cnd.repository.spi.Persistent;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataInput;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataOutput;
+import org.netbeans.modules.cnd.repository.support.SelfPersistent;
+import org.netbeans.modules.cnd.utils.CndUtils;
 import org.openide.filesystems.FileSystem;
 import org.openide.util.CharSequences;
 import org.openide.util.Parameters;
@@ -105,6 +104,7 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
                                     List<IncludeDirEntry> systemIncludePaths,
                                     List<IncludeDirEntry> userIncludePaths,
                                     List<IncludeDirEntry> userIncludeFilePaths, APTFileSearch fileSearch) {
+        assert !APTTraceFlags.USE_CLANK;
         Parameters.notNull("startFile", startFile);
         this.startFile = startFile;
         this.systemIncludePaths = systemIncludePaths;
@@ -114,8 +114,8 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
     }
 
     @Override
-    public IncludeState pushInclude(CharSequence path, APTInclude aptInclude, int resolvedDirIndex) {
-        return pushIncludeImpl(path, aptInclude.getToken().getLine(), aptInclude.getToken().getOffset(), resolvedDirIndex);
+    public IncludeState pushInclude(FileSystem fs, CharSequence path, int line, int offset, int resolvedDirIndex, int inclDirIndex) {
+        return pushIncludeImpl(fs, path, line, offset, resolvedDirIndex, inclDirIndex);
     }
 
     @Override
@@ -125,7 +125,7 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
     
     @Override
     public APTIncludeResolver getResolver(FileSystem fs, CharSequence path) {
-        return new APTIncludeResolverImpl(fs, path, getCurDirIndex(),
+        return new APTIncludeResolverImpl(fs, path, getCurResolvedDirectoryIndex(),
                 systemIncludePaths, userIncludePaths, fileSearch);
     }
     
@@ -140,10 +140,10 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
         return info.getIncludedPath();
     }
     
-    private int getCurDirIndex() {
+    private int getCurResolvedDirectoryIndex() {
         if (inclStack != null && !inclStack.isEmpty()) {
             IncludeInfo info = inclStack.getLast();
-            return info.getIncludedDirIndex();
+            return info.getResolvedDirectoryIndex();
         } else {
             return 0;
         }
@@ -159,8 +159,8 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
     @Override
     public void setState(State state) {
         if (state instanceof StateImpl) {
-	    StateImpl stateImpl = ((StateImpl)state);
-	    assert ! stateImpl.isCleaned();
+            StateImpl stateImpl = ((StateImpl)state);
+            assert ! stateImpl.isCleaned();
             stateImpl.restoreTo(this);
         }
     }
@@ -201,6 +201,7 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
         private int hashCode = 0;
         
         protected StateImpl(APTIncludeHandlerImpl handler) {
+            assert !APTTraceFlags.USE_CLANK;
             this.systemIncludePaths = handler.systemIncludePaths;
             this.userIncludePaths = handler.userIncludePaths;
             this.userIncludeFilePaths = handler.userIncludeFilePaths;
@@ -214,6 +215,8 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
         }
         
         private StateImpl(StateImpl other, boolean cleanState) {
+            CndUtils.assertTrueInConsole(cleanState == true, "This constructor is only for creating clean states");
+            assert !APTTraceFlags.USE_CLANK;
             // shared information
             this.startFile = other.startFile;
             
@@ -264,32 +267,14 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
             return APTIncludeHandlerImpl.toString(startFile.getStartFile(), systemIncludePaths, userIncludePaths, userIncludeFilePaths, Arrays.asList(inclStack));
         }
         
-        public void write(RepositoryDataOutput output, int unitIndex) throws IOException {
+        public void write(RepositoryDataOutput output) throws IOException {
             assert output != null;
-            startFile.write(output, unitIndex);
+            CndUtils.assertTrueInConsole(isCleaned(), "we expect only clean states to be written in storage");
+            startFile.write(output);
             
-            assert systemIncludePaths != null;
-            assert userIncludePaths != null;
-            
-            int size = systemIncludePaths.size();
-            output.writeInt(size);
-            for (int i = 0; i < size; i++) {
-                APTSerializeUtils.writeFileNameIndex(systemIncludePaths.get(i).getAsSharedCharSequence(), output, unitIndex);
-            }
-            
-            size = userIncludePaths.size();
-            output.writeInt(size);
-            
-            for (int i = 0; i < size; i++) {
-                APTSerializeUtils.writeFileNameIndex(userIncludePaths.get(i).getAsSharedCharSequence(), output, unitIndex);
-            }
-            
-            size = userIncludeFilePaths.size();
-            output.writeInt(size);
-            
-            for (int i = 0; i < size; i++) {
-                APTSerializeUtils.writeFileNameIndex(userIncludeFilePaths.get(i).getAsSharedCharSequence(), output, unitIndex);
-            }
+            assert systemIncludePaths == CLEANED_MARKER;
+            assert userIncludePaths == CLEANED_MARKER;
+            assert userIncludeFilePaths == CLEANED_MARKER;
 
             output.writeInt(inclStack.length);
             for (IncludeInfo inclInfo : inclStack) {
@@ -299,50 +284,34 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
                     inclInfoImpl = (IncludeInfoImpl) inclInfo;
                 } else {
                     inclInfoImpl = new IncludeInfoImpl(
+                            inclInfo.getFileSystem(),
                             inclInfo.getIncludedPath(),
                             inclInfo.getIncludeDirectiveLine(),
                             inclInfo.getIncludeDirectiveOffset(),
-                            inclInfo.getIncludedDirIndex());
+                            inclInfo.getResolvedDirectoryIndex(),
+                            inclInfo.getIncludeDirectiveIndex());
                 }
                 assert inclInfoImpl != null;
-                inclInfoImpl.write(output, unitIndex);
+                inclInfoImpl.write(output);
             }
         }
         
-        public StateImpl(FileSystem fs, final RepositoryDataInput input, int unitIndex) throws IOException {
+        public StateImpl(final RepositoryDataInput input) throws IOException {
             assert input != null;
             
-            startFile = new StartEntry(fs, input, unitIndex);
+            startFile = new StartEntry(input);
+            systemIncludePaths = CLEANED_MARKER;
+            userIncludePaths = CLEANED_MARKER;
+            userIncludeFilePaths = CLEANED_MARKER;
 
             int size = input.readInt();
-            systemIncludePaths = new ArrayList<IncludeDirEntry>(size);
-            for (int i = 0; i < size; i++) {
-                IncludeDirEntry path = IncludeDirEntry.get(fs, APTSerializeUtils.readFileNameIndex(input, unitIndex).toString());
-                systemIncludePaths.add(i, path);
-            }
-            
-            size = input.readInt();
-            userIncludePaths = new ArrayList<IncludeDirEntry>(size);
-            for (int i = 0; i < size; i++) {
-                IncludeDirEntry path = IncludeDirEntry.get(fs, APTSerializeUtils.readFileNameIndex(input, unitIndex).toString());
-                userIncludePaths.add(i, path);                
-            }
-
-            size = input.readInt();
-            userIncludeFilePaths = new ArrayList<IncludeDirEntry>(size);
-            for (int i = 0; i < size; i++) {
-                IncludeDirEntry path = IncludeDirEntry.get(fs, APTSerializeUtils.readFileNameIndex(input, unitIndex).toString());
-                userIncludeFilePaths.add(i, path);
-            }
-            
-            size = input.readInt();
             
             if (size == 0) {
                 inclStack = EMPTY_STACK;
             } else {
                 inclStack = new IncludeInfo[size];
                 for (int i = 0; i < size; i++) {
-                    final IncludeInfo impl = new IncludeInfoImpl(input, unitIndex);
+                    final IncludeInfo impl = new IncludeInfoImpl(input);
                     assert impl != null;
                     inclStack[i] = impl;
                 }
@@ -400,8 +369,13 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
             return this.userIncludeFilePaths == CLEANED_MARKER; // was created as clean state
         }
         
-        /*package*/ APTIncludeHandler.State copy(boolean cleanState) {
-            return new StateImpl(this, cleanState);
+        /*package*/ APTIncludeHandler.State copyCleaned() {
+            return new StateImpl(this, true);
+        }
+
+        /*package*/ APTIncludeHandler.State prepareCachesIfPossible() {
+            // this state is already cache-ready
+            return this;
         }
         
         /*package*/ List<IncludeDirEntry> getSysIncludePaths() {
@@ -420,7 +394,7 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
     ////////////////////////////////////////////////////////////////////////////
     // implementation details
 
-    private IncludeState pushIncludeImpl(CharSequence path, int directiveLine, int directiveOffset, int resolvedDirIndex) {
+    private IncludeState pushIncludeImpl(FileSystem fs, CharSequence path, int directiveLine, int directiveOffset, int resolvedDirIndex, int inclDirIndex) {
         assert CharSequences.isCompact(path) : "must be char sequence key " + path; // NOI18N
         boolean okToPush = true;
         if (CHECK_INCLUDE_DEPTH > 0) {
@@ -458,7 +432,7 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
             }
         }
         if (okToPush) {
-            inclStack.addLast(new IncludeInfoImpl(path, directiveLine, directiveOffset, resolvedDirIndex));
+            inclStack.addLast(new IncludeInfoImpl(fs, path, directiveLine, directiveOffset, resolvedDirIndex, inclDirIndex));
             return IncludeState.Success;
         } else {
             APTUtils.LOG.log(Level.WARNING, "RECURSIVE inclusion:\n\t{0}\n\tin {1}\n", new Object[] { path , getCurPath() }); // NOI18N
@@ -466,32 +440,41 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
         }
     }    
 
-    // Not SelfPersistent any more since I have to pass unitIndex into write method
-    // It is private, so I don't think it's a problem. VK.
-    private static final class IncludeInfoImpl implements IncludeInfo, Persistent {
+    private static final class IncludeInfoImpl implements IncludeInfo, SelfPersistent {
+        private final FileSystem fs;
         private final CharSequence path;
         private final int directiveLine;
         private final int directiveOffset;
-        private final int resolvedDirIndex;
+        private final int resolvedDirectoryIndex;
+        private final int includeDirectiveIndex;
         
-        public IncludeInfoImpl(CharSequence path, int directiveLine, int directiveOffset, int resolvedDirIndex) {
+        public IncludeInfoImpl(FileSystem fs, CharSequence path, int directiveLine, int directiveOffset, int resolvedDirectoryIndex, int includedDirFileIndex) {
             assert path != null;
+            this.fs = fs;
             this.path = path;
             // in case of -include file we have negative line/offset
             assert directiveLine >= 0 || (directiveLine < 0 && directiveOffset < 0);
             this.directiveLine = directiveLine;
             this.directiveOffset = directiveOffset;
-            this.resolvedDirIndex = resolvedDirIndex;
+            this.resolvedDirectoryIndex = resolvedDirectoryIndex;
+            this.includeDirectiveIndex = includedDirFileIndex;
         }
         
-        public IncludeInfoImpl(final RepositoryDataInput input, int unitIndex) throws IOException {
+        public IncludeInfoImpl(final RepositoryDataInput input) throws IOException {
             assert input != null;
-            this.path = APTSerializeUtils.readFileNameIndex(input, FilePathCache.getManager(), unitIndex);
+            this.fs = input.readFileSystem();
+            this.path = input.readFilePathForFileSystem(fs);
             directiveLine = input.readInt();
             directiveOffset = input.readInt();
-            resolvedDirIndex = input.readInt();
+            resolvedDirectoryIndex = input.readInt();
+            includeDirectiveIndex = input.readInt();
         }
 
+        @Override
+        public FileSystem getFileSystem() {
+            return fs;
+        }
+        
         @Override
         public CharSequence getIncludedPath() {
             return path;
@@ -510,9 +493,9 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
         @Override
         public String toString() {
             String retValue;
-            
+
             retValue = "(" + getIncludeDirectiveLine() + "/" + getIncludeDirectiveOffset() + ": " + // NOI18N
-                    getIncludedPath() + ":" + getIncludedDirIndex() + ")"; // NOI18N
+                    getIncludedPath() + ":" + getResolvedDirectoryIndex() + ";#" + getIncludeDirectiveIndex() + ")"; // NOI18N
             return retValue;
         }
 
@@ -522,33 +505,39 @@ public class APTIncludeHandlerImpl implements APTIncludeHandler {
                 return false;
             }
             IncludeInfoImpl other = (IncludeInfoImpl)obj;
-            return this.directiveLine == other.directiveLine && this.directiveOffset == other.directiveOffset &&
-                    this.path.equals(other.path) && (resolvedDirIndex == other.resolvedDirIndex);
+            return (resolvedDirectoryIndex == other.resolvedDirectoryIndex) && (this.includeDirectiveIndex == other.includeDirectiveIndex) &&
+                    this.path.equals(other.path);
         }
 
         @Override
         public int hashCode() {
             int hash = 3;
             hash = 73 * hash + (this.path != null ? this.path.hashCode() : 0);
-            hash = 73 * hash + this.directiveLine;
-            hash = 73 * hash + this.directiveOffset;
-            hash = 73 * hash + this.resolvedDirIndex;
+            hash = 73 * hash + this.resolvedDirectoryIndex;
+            hash = 73 * hash + this.includeDirectiveIndex;
             return hash;
         }
 
-        public void write(final RepositoryDataOutput output, int unitIndex) throws IOException {
+        public void write(final RepositoryDataOutput output) throws IOException {
             assert output != null;
-            
-            APTSerializeUtils.writeFileNameIndex(path, output, unitIndex);
+            output.writeFileSystem(fs);
+            output.writeFilePathForFileSystem(fs, path);
             output.writeInt(directiveLine);
             output.writeInt(directiveOffset);
-            output.writeInt(resolvedDirIndex);
+            output.writeInt(resolvedDirectoryIndex);
+            output.writeInt(includeDirectiveIndex);
         }
 
         @Override
-        public int getIncludedDirIndex() {
-            return this.resolvedDirIndex;
+        public int getResolvedDirectoryIndex() {
+            return this.resolvedDirectoryIndex;
         }
+
+        @Override
+        public int getIncludeDirectiveIndex() {
+            return includeDirectiveIndex;
+        }
+        
     }
       
     private CharSequence popIncludeImpl() {
