@@ -48,6 +48,7 @@ import org.netbeans.modules.cnd.antlr.Token;
 import org.netbeans.modules.cnd.antlr.TokenStream;
 import org.netbeans.modules.cnd.antlr.TokenStreamException;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.LinkedList;
@@ -67,6 +68,7 @@ import org.netbeans.modules.cnd.apt.impl.support.APTLiteLiteralToken;
 import org.netbeans.modules.cnd.apt.impl.support.APTMacroParamExpansion;
 import org.netbeans.modules.cnd.apt.impl.support.APTTestToken;
 import org.netbeans.modules.cnd.apt.impl.support.MacroExpandedToken;
+import org.netbeans.modules.cnd.apt.impl.support.clank.ClankDriverImpl;
 import org.netbeans.modules.cnd.apt.impl.support.generated.APTExprParser;
 import org.netbeans.modules.cnd.apt.support.lang.APTBaseLanguageFilter;
 import org.netbeans.modules.cnd.apt.support.APTTokenTypes;
@@ -378,6 +380,19 @@ public class APTUtils {
         return retValue;
     }
     
+    public static String macros2String(Collection<? extends CharSequence> macros) {
+        StringBuilder retValue = new StringBuilder();
+        retValue.append("MACROS (sorted ").append(macros.size()).append("):\n"); // NOI18N
+        List<CharSequence> macrosSorted = new ArrayList<CharSequence>(macros);
+        Collections.sort(macrosSorted, CharSequences.comparator());
+        for (CharSequence macro : macrosSorted) {
+            assert(macro != null);
+            retValue.append(macro);
+            retValue.append("'\n"); // NOI18N
+        }
+        return retValue.toString();
+    }
+
     public static String macros2String(Map<CharSequence/*getTokenTextKey(token)*/, APTMacro> macros) {
         StringBuilder retValue = new StringBuilder();
         retValue.append("MACROS (sorted ").append(macros.size()).append("):\n"); // NOI18N
@@ -640,18 +655,22 @@ public class APTUtils {
     }
 
     public static List<APTToken> toList(TokenStream ts) {
-        LinkedList<APTToken> tokens = new LinkedList<APTToken>();
-        try {
-            APTToken token = (APTToken) ts.nextToken();
-            while (!isEOF(token)) {
-                assert(token != null) : "list of tokens must not have 'null' elements"; // NOI18N
-                tokens.add(token);
-                token = (APTToken) ts.nextToken();
+        if (ts instanceof ClankDriverImpl.ArrayBasedAPTTokenStream) {
+            return ((ClankDriverImpl.ArrayBasedAPTTokenStream) ts).toList();
+        } else {
+            LinkedList<APTToken> tokens = new LinkedList<APTToken>();
+            try {
+                APTToken token = (APTToken) ts.nextToken();
+                while (!isEOF(token)) {
+                    assert (token != null) : "list of tokens must not have 'null' elements"; // NOI18N
+                    tokens.add(token);
+                    token = (APTToken) ts.nextToken();
+                }
+            } catch (TokenStreamException ex) {
+                LOG.log(Level.INFO, "error on converting token stream to list", ex.getMessage()); // NOI18N
             }
-        } catch (TokenStreamException ex) {
-            LOG.log(Level.INFO, "error on converting token stream to list", ex.getMessage()); // NOI18N
+            return tokens;
         }
-        return tokens;
     }
     
     public static Object getTextKey(String text) {
