@@ -80,6 +80,7 @@ import org.netbeans.modules.cnd.callgraph.api.ui.CallGraphUI;
 import org.netbeans.modules.cnd.callgraph.api.ui.Catalog;
 import org.netbeans.modules.cnd.callgraph.api.ui.CallGraphActionEDTRunnable;
 import org.netbeans.modules.cnd.callgraph.impl.CallGraphScene.LayoutKind;
+import org.netbeans.modules.cnd.callgraph.support.ExportXmlAction;
 import org.openide.awt.Mnemonics;
 import org.openide.awt.StatusDisplayer;
 import org.openide.explorer.ExplorerManager;
@@ -90,6 +91,8 @@ import org.openide.nodes.Children;
 import org.openide.nodes.Node;
 import org.openide.util.Cancellable;
 import org.openide.util.HelpCtx;
+import org.openide.util.ImageUtilities;
+import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
 import org.openide.util.RequestProcessor;
 import org.openide.util.actions.Presenter;
@@ -150,8 +153,11 @@ public class CallGraphPanel extends JPanel implements ExplorerManager.Provider,
         if (showGraph) {
             scene = new CallGraphScene();
             ExportAction exportAction = new ExportAction(scene, this);
+            ExportXmlAction exportXmlAction = new ExportXmlAction(scene, this);
             actions.add(exportAction);
+            actions.add(exportXmlAction);
             scene.setExportAction(exportAction);
+            scene.setExportXmlAction(exportXmlAction);
         }
         actions.add(null);
         actions.add(new ExpandAction());
@@ -266,10 +272,7 @@ public class CallGraphPanel extends JPanel implements ExplorerManager.Provider,
         refresh.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/netbeans/modules/cnd/callgraph/resources/refresh.png"))); // NOI18N
         refresh.setToolTipText(getMessage("RefreshActionTooltip"));
         refresh.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
-        refresh.setMaximumSize(new java.awt.Dimension(28, 28));
-        refresh.setMinimumSize(new java.awt.Dimension(28, 28));
         refresh.setName("refresh"); // NOI18N
-        refresh.setPreferredSize(new java.awt.Dimension(28, 28));
         refresh.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
         refresh.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
@@ -281,10 +284,7 @@ public class CallGraphPanel extends JPanel implements ExplorerManager.Provider,
         focusOn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/netbeans/modules/cnd/callgraph/resources/focus_on.png"))); // NOI18N
         focusOn.setToolTipText(getMessage("FocusOnActionTooltip"));
         focusOn.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
-        focusOn.setMaximumSize(new java.awt.Dimension(28, 28));
-        focusOn.setMinimumSize(new java.awt.Dimension(28, 28));
         focusOn.setName("focusOn"); // NOI18N
-        focusOn.setPreferredSize(new java.awt.Dimension(28, 28));
         focusOn.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
         focusOn.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
@@ -355,8 +355,8 @@ public class CallGraphPanel extends JPanel implements ExplorerManager.Provider,
         graphView.setFocusable(false);
         graphView.setName(""); // NOI18N
         jSplitPane1.setRightComponent(graphView);
-        graphView.getAccessibleContext().setAccessibleName(null);
-        graphView.getAccessibleContext().setAccessibleDescription(null);
+        graphView.getAccessibleContext().setAccessibleName("getMessage(\"pictorial.part\")");
+        graphView.getAccessibleContext().setAccessibleDescription("getMessage(\"pictorial.part\")");
 
         jSplitPane2.setDividerLocation(-10);
         jSplitPane2.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);
@@ -369,7 +369,9 @@ public class CallGraphPanel extends JPanel implements ExplorerManager.Provider,
         treeView.getAccessibleContext().setAccessibleName(getMessage("CGP_TreeView_AN"));
         treeView.getAccessibleContext().setAccessibleDescription(getMessage("CGP_TreeView_AD"));
 
+        contextPanel.setMinimumSize(new java.awt.Dimension(10, 35));
         contextPanel.setName("contextPanel"); // NOI18N
+        contextPanel.setPreferredSize(new java.awt.Dimension(10, 35));
         jSplitPane2.setRightComponent(contextPanel);
         contextPanel.getAccessibleContext().setAccessibleName(getMessage("CGP_ListView_AM"));
         contextPanel.getAccessibleContext().setAccessibleDescription(getMessage("CGP_ListView_AD"));
@@ -467,9 +469,16 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
 
     public void setModel(CallModel model) {
         this.model = model;
+        if (!model.getRoot().kind().equals(Function.Kind.FUNCTION)) {
+            isCalls = false;
+        }
         updateButtons();
         update();
     }
+    
+    public CallModel getModel() {
+        return model;
+    }
            
     private synchronized void update() {
         final CallGraphState state = new CallGraphState(model, scene, actions);
@@ -905,7 +914,7 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
             //allow implementator to implement call as a node
             initDefaultView();
             Collection<Node> list = new ArrayList<Node>(1);
-            list.add(new CallContext(new LoadingNode()));
+            list.add(new CallContext(new LoadingOccurencesNode()));
             Node root  = new CallContextRoot(new ContextList(list));
             getExplorerManager().setRootContext(root);
             revalidate();
@@ -919,8 +928,8 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
                         list = Collections.<Node>emptyList();
                         root  = new CallContextRoot(new ContextList(list));
                     } else {
-                        list = new ArrayList<Node>(1);
                         Call call = node.getCall();
+                        list = new ArrayList<Node>(call.getOccurrences().size());
                         final JPanel contextPanel = graphUI == null ? null : graphUI.getContextPanel(call);
                         if (contextPanel != null) {
                             SwingUtilities.invokeLater(new Runnable() {
@@ -940,7 +949,9 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
                                 root = (Node)call;
 
                             } else {
-                                list.add(new CallContext(call));
+                                for (Call.Occurrence occurrence : call.getOccurrences()) {
+                                    list.add(new CallContext(occurrence));
+                                }
                                 root  = new CallContextRoot(new ContextList(list));
                             }
                         }
@@ -973,27 +984,27 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
         }
 
         public static class CallContext extends AbstractNode {
-            private final Call call;
-            public CallContext(Call element) {
+            private final Call.Occurrence occurrence;
+            public CallContext(Call.Occurrence element) {
                 super( Children.LEAF);
-                call = element;
+                occurrence = element;
             }
 
             @Override
             public String getHtmlDisplayName() {
-                if (call != null) {
-                    return call.getHtmlDisplayName();
+                if (occurrence != null) {
+                    return occurrence.getHtmlDisplayName();
                 }
                 return super.getHtmlDisplayName();
             }
             @Override
             public Action getPreferredAction() {
-                return null;
+                return new GoToOccurrenceAction(occurrence);
             }
 
             @Override
             public String getShortDescription() {
-                String ret = call.getDescription();
+                String ret = occurrence.getDescription();
                 if (ret != null){
                     return ret;
                 }
@@ -1007,8 +1018,8 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
 
             @Override
             public Image getIcon(int type) {
-                if (call instanceof Node) {
-                    return ((Node)call).getIcon(type);
+                if (occurrence instanceof Node) {
+                    return ((Node)occurrence).getIcon(type);
                 }
                 return super.getIcon(type);
             }
@@ -1090,4 +1101,50 @@ private void overridingActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FI
             return null;
         }
     }
+    
+    private static class LoadingOccurencesNode extends AbstractNode implements Call.Occurrence {
+        public LoadingOccurencesNode() {
+            super(Children.LEAF);
+            setName("dummy"); // NOI18N
+            setDisplayName(NbBundle.getMessage(getClass(), "Loading")); // NOI18N
+        }
+
+        @Override
+        public Image getIcon(int param) {
+            return ImageUtilities.loadImage("org/netbeans/modules/cnd/callgraph/resources/waitNode.gif"); // NOI18N
+        }
+
+        @Override
+        public void open() {
+        }
+        
+        @Override
+        public String getHtmlDisplayName() {
+            return getDescription();
+        }
+        
+        @Override
+        public String getDisplayName() {
+            return NbBundle.getMessage(getClass(), "Loading");
+        }
+
+        @Override
+        public String getDescription() {
+            return  getDisplayName();
+        }
+
+        @Override
+        public int hashCode() {
+            int hash = 5;
+            return hash;
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (obj instanceof LoadingNode) {
+                return this == obj;
+            }
+            return false;
+        }
+    }
 }
