@@ -55,15 +55,20 @@ import java.util.Collections;
 import java.util.Iterator;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import org.netbeans.cnd.api.lexer.CndLexerUtilities;
 
 import org.netbeans.modules.cnd.api.model.CsmClassifier;
+import org.netbeans.modules.cnd.api.model.CsmClosureClassifier;
+import org.netbeans.modules.cnd.api.model.CsmClosureType;
 import org.netbeans.modules.cnd.api.model.CsmConstructor;
 import org.netbeans.modules.cnd.api.model.CsmField;
 import org.netbeans.modules.cnd.api.model.CsmScopeElement;
 import org.netbeans.modules.cnd.api.model.CsmType;
 import org.netbeans.modules.cnd.api.model.CsmFile;
 import org.netbeans.modules.cnd.api.model.CsmFunction;
+import org.netbeans.modules.cnd.api.model.CsmFunctionDefinition;
 import org.netbeans.modules.cnd.api.model.CsmMethod;
 import org.netbeans.modules.cnd.api.model.CsmNamespace;
 import org.netbeans.modules.cnd.api.model.CsmObject;
@@ -71,8 +76,6 @@ import org.netbeans.modules.cnd.api.model.CsmOffsetable;
 import org.netbeans.modules.cnd.api.model.CsmProject;
 import org.netbeans.modules.cnd.api.model.CsmSpecializationParameter;
 import org.netbeans.modules.cnd.api.model.CsmTemplate;
-import org.netbeans.modules.cnd.api.model.CsmTypeAlias;
-import org.netbeans.modules.cnd.api.model.CsmTypedef;
 import org.netbeans.modules.cnd.api.model.CsmVariable;
 import org.netbeans.modules.cnd.api.model.services.CsmInstantiationProvider;
 import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
@@ -86,6 +89,8 @@ import org.netbeans.modules.cnd.utils.CndUtils;
  * @version 1.00
  */
 abstract public class CsmCompletion {
+    
+    private static final Logger LOG = Logger.getLogger(CsmCompletion.class.getSimpleName());
 
     public static final int PUBLIC_LEVEL = 3;
     public static final int PROTECTED_LEVEL = 2;
@@ -100,6 +105,7 @@ abstract public class CsmCompletion {
     public static final SimpleClass LONG_CLASS = new SimpleClass("long", ""); // NOI18N
     public static final SimpleClass SHORT_CLASS = new SimpleClass("short", ""); // NOI18N
     public static final SimpleClass VOID_CLASS = new SimpleClass("void", ""); // NOI18N
+    public static final SimpleClass NULLPTR_CLASS = new SimpleClass("nullptr", ""); // NOI18N
     public static final SimpleClass UNSIGNED_CHAR_CLASS = new SimpleClass("unsigned char", ""); // NOI18N
     public static final SimpleClass UNSIGNED_INT_CLASS = new SimpleClass("unsigned int", ""); // NOI18N
     public static final SimpleClass UNSIGNED_LONG_CLASS = new SimpleClass("unsigned long", ""); // NOI18N
@@ -119,6 +125,7 @@ abstract public class CsmCompletion {
     public static final BaseType UNSIGNED_SHORT_TYPE = new BaseType(UNSIGNED_SHORT_CLASS, 0, 0, 0, false);
     public static final BaseType LONG_DOUBLE_TYPE = new BaseType(LONG_DOUBLE_CLASS, 0, 0, 0, false);
     public static final BaseType VOID_TYPE = new BaseType(VOID_CLASS, 0, 0, 0, false);
+    public static final BaseType NULLPTR_TYPE = new BaseType(NULLPTR_CLASS, 1, 0, 0, false);
     public static final SimpleClass INVALID_CLASS = new SimpleClass("", ""); // NOI18N
     public static final BaseType INVALID_TYPE = new BaseType(INVALID_CLASS, 0, 0, 0, false);
     public static final SimpleClass NULL_CLASS = new SimpleClass("null", ""); // NOI18N
@@ -157,7 +164,7 @@ abstract public class CsmCompletion {
         // initialize primitive types cache
         BaseType[] types = new BaseType[]{
             BOOLEAN_TYPE, BYTE_TYPE, CHAR_TYPE, DOUBLE_TYPE, FLOAT_TYPE,
-            INT_TYPE, LONG_TYPE, SHORT_TYPE, VOID_TYPE,
+            INT_TYPE, LONG_TYPE, SHORT_TYPE, VOID_TYPE, NULLPTR_TYPE,
             UNSIGNED_CHAR_TYPE, UNSIGNED_INT_TYPE, UNSIGNED_LONG_TYPE, UNSIGNED_SHORT_TYPE,
             LONG_DOUBLE_TYPE
         };
@@ -172,7 +179,7 @@ abstract public class CsmCompletion {
         types = new BaseType[]{
                     NULL_TYPE, OBJECT_TYPE_ARRAY, OBJECT_TYPE, CLASS_TYPE, STRING_TYPE, CONST_STRING_TYPE,
                     CONST_BOOLEAN_TYPE, CONST_BYTE_TYPE, CONST_CHAR_TYPE, CONST_DOUBLE_TYPE, CONST_FLOAT_TYPE,
-                    CONST_INT_TYPE, CONST_LONG_TYPE, CONST_SHORT_TYPE, CONST_VOID_TYPE                    
+                    CONST_INT_TYPE, CONST_LONG_TYPE, CONST_SHORT_TYPE, CONST_VOID_TYPE
                  };
 
         for (int i = types.length - 1; i >= 0; i--) {
@@ -224,6 +231,14 @@ abstract public class CsmCompletion {
 //               && isPrimitiveClassName(c.getName());
         return isPrimitiveClassName(c.getName().toString());
     }
+    
+    public static boolean safeIsPrimitiveClass(CsmType type, CsmClassifier c) {
+        if (c != null) {
+            return isPrimitiveClass(c);
+        }
+        LOG.log(Level.WARNING, "Type {0} ({1}) doesn''t have classifier!", new Object[]{type, type.getClass().getName()});
+        return false;
+    }
 //
 //    public static CsmClassifier getPrimitiveClass(String s) {
 //        return str2PrimitiveClass.get(s);
@@ -241,9 +256,9 @@ abstract public class CsmCompletion {
         if (baseType != null) {
             // wrap with correct offsetable information
             return new OffsetableType(
-                    baseType, 
-                    containingFile, 
-                    start, 
+                    baseType,
+                    containingFile,
+                    start,
                     end,
                     item.getTokenCount() > 0 ? "0".equals(item.getTokenText(0)) : false // NOI18N
             );
@@ -252,7 +267,7 @@ abstract public class CsmCompletion {
         }
     }
 
-    public static Iterator getPrimitiveClassIterator() {
+    public static Iterator<CsmClassifier> getPrimitiveClassIterator() {
         return str2PrimitiveClass.values().iterator();
     }
 
@@ -310,10 +325,23 @@ abstract public class CsmCompletion {
      * be garbage collected.
      */
     public static CsmType createType(CsmClassifier cls, int ptrDepth, int refDepth, int arrayDepth, boolean _const) {
+        return createType(cls, ptrDepth, refDepth, arrayDepth, _const, CsmKindUtilities.isTemplateParameter(cls));
+    }
+    
+    /** Create new type or get the existing one from the cache. The cache holds
+     * the arrays with the increasing array depth for the particular class
+     * as the members. Simple class is used for the caching to make it independent
+     * on the real completion classes that can become obsolete and thus should
+     * be garbage collected.
+     */
+    public static CsmType createType(CsmClassifier cls, int ptrDepth, int refDepth, int arrayDepth, boolean _const, boolean templateBased) {
         if (cls == null) {
             return null;
         }
-        return new BaseType(cls, ptrDepth, refDepth, arrayDepth, _const);
+        if (CsmKindUtilities.isClosureClassifier(cls)) {
+            return new CompletionClosureType(((CsmClosureClassifier) cls).getLambda(), refDepth, _const);
+        }
+        return new BaseType(cls, ptrDepth, refDepth, arrayDepth, _const, templateBased);
     }
 
     public static CsmNamespace getProjectNamespace(CsmProject project, CsmNamespace ns) {
@@ -328,7 +356,7 @@ abstract public class CsmCompletion {
         }
         return new SimpleNamespace(project, ns);
     }
-    
+
     private static final class SimpleNamespace implements CsmNamespace {
         private final CsmNamespace wrapped;
         private final CsmProject project;
@@ -337,7 +365,7 @@ abstract public class CsmCompletion {
             this.project = owner;
             this.wrapped = ns;
         }
-        
+
         @Override
         public CsmNamespace getParent() {
             CsmNamespace p = wrapped.getParent();
@@ -377,7 +405,7 @@ abstract public class CsmCompletion {
         public boolean isInline() {
             return wrapped.isInline();
         }
-        
+
         @Override
         public CsmProject getProject() {
             return project;
@@ -429,7 +457,7 @@ abstract public class CsmCompletion {
             return "SimpleNamespace{" + "wrapped=" + wrapped + ", project=" + project + '}'; // NOI18N
         }
     }
-    
+
     public static class SimpleClass implements CsmClassifier {
 
         protected CharSequence name;
@@ -557,7 +585,7 @@ abstract public class CsmCompletion {
             }
             return order;
         }
-        
+
         @Override
         public int hashCode() {
             return name.hashCode() ^ packageName.hashCode();
@@ -617,8 +645,13 @@ abstract public class CsmCompletion {
         protected int pointerDepth;
         protected int reference; // nothing, & or && as in C++11
         protected boolean _const;
-
+        protected boolean templateBased;
+        
         private BaseType(CsmClassifier clazz, int pointerDepth, int reference, int arrayDepth, boolean _const) {
+            this(clazz, pointerDepth, reference, arrayDepth, _const, CsmKindUtilities.isTemplateParameter(clazz));
+        }
+
+        private BaseType(CsmClassifier clazz, int pointerDepth, int reference, int arrayDepth, boolean _const, boolean templateBased) {
             this.clazz = clazz;
             this.arrayDepth = arrayDepth;
             this.pointerDepth = pointerDepth;
@@ -628,6 +661,7 @@ abstract public class CsmCompletion {
             }
             this.reference = reference;
             this._const = _const;
+            this.templateBased = templateBased;
             if (arrayDepth < 0) {
                 throw new IllegalArgumentException("Array depth " + arrayDepth + " < 0."); // NOI18N
             }
@@ -635,7 +669,7 @@ abstract public class CsmCompletion {
 
         BaseType() {
         }
-        
+
         @Override
         public int getArrayDepth() {
             return arrayDepth;
@@ -716,6 +750,7 @@ abstract public class CsmCompletion {
             if (clazz instanceof SimpleClass) {
                 return ((SimpleClass) clazz).clazz == null ? clazz : ((SimpleClass) clazz).clazz;
             } else {
+                assert clazz != null;
                 return clazz;
             }
         }
@@ -737,7 +772,7 @@ abstract public class CsmCompletion {
 
         @Override
         public boolean isTemplateBased() {
-            return CsmKindUtilities.isTemplateParameter(clazz);
+            return templateBased;
         }
 
         @Override
@@ -764,7 +799,7 @@ abstract public class CsmCompletion {
         public boolean isRValueReference() {
             return reference == 2;
         }
-        
+
         @Override
         public boolean isConst() {
             return _const;
@@ -913,7 +948,7 @@ abstract public class CsmCompletion {
         public boolean isRValueReference() {
             return delegate.isRValueReference();
         }
-        
+
         @Override
         public boolean isConst() {
             return delegate.isConst();
@@ -960,6 +995,82 @@ abstract public class CsmCompletion {
         }
     }
 
+    public static class CompletionClosureClassifier implements CsmClosureClassifier {
+
+        private final CsmFunctionDefinition lambda;
+
+        public CompletionClosureClassifier(CsmFunctionDefinition lambda) {
+            this.lambda = lambda;
+        }
+
+        @Override
+        public CsmFunctionDefinition getLambda() {
+            return lambda;
+        }
+
+        @Override
+        public Kind getKind() {
+            return CsmDeclaration.Kind.FUNCTION_TYPE;
+        }
+
+        @Override
+        public CsmScope getScope() {
+            return lambda.getScope();
+        }
+
+        @Override
+        public CharSequence getUniqueName() {
+            return lambda.getUniqueName();
+        }
+
+        @Override
+        public CharSequence getQualifiedName() {
+            return lambda.getQualifiedName();
+        }
+
+        @Override
+        public CsmType getReturnType() {
+            return lambda.getReturnType();
+        }
+
+        @Override
+        public Collection<CsmParameter> getParameters() {
+            return lambda.getParameters();
+        }
+
+        @Override
+        public CharSequence getSignature() {
+            return lambda.getSignature();
+        }
+
+        @Override
+        public CharSequence getName() {
+            return lambda.getName();
+        }
+
+        @Override
+        public boolean isValid() {
+            return lambda.isValid();
+        }
+    }
+
+    public static class CompletionClosureType extends BaseType implements CsmClosureType {
+
+        public CompletionClosureType(CsmFunctionDefinition lambda, int reference, boolean _const) {
+            super(new CompletionClosureClassifier(lambda), 0, reference, 0, _const);
+        }
+
+        @Override
+        public CsmFunctionDefinition getLambda() {
+            return ((CsmClosureClassifier) clazz).getLambda();
+        }
+
+        @Override
+        public CsmScope getScope() {
+            return ((CsmClosureClassifier) clazz).getScope();
+        }
+    }
+
     public static int getDebugMode() {
         return debugMode;
     }
