@@ -63,12 +63,10 @@ import org.netbeans.modules.cnd.api.model.services.CsmCacheManager;
 import org.netbeans.modules.cnd.api.model.services.CsmFileInfoQuery;
 import org.netbeans.modules.cnd.api.model.services.CsmFileReferences;
 import org.netbeans.modules.cnd.api.model.services.CsmReferenceContext;
-import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
 import org.netbeans.modules.cnd.api.model.util.CsmKindUtilities;
 import org.netbeans.modules.cnd.api.model.xref.CsmReference;
 import org.netbeans.modules.cnd.api.model.xref.CsmReferenceKind;
 import org.netbeans.modules.cnd.api.model.xref.CsmReferenceRepository;
-import org.netbeans.modules.cnd.apt.support.lang.APTLanguageSupport;
 import org.netbeans.modules.cnd.completion.cplusplus.ext.CsmExpandedTokenProcessor;
 import org.netbeans.modules.cnd.support.Interrupter;
 
@@ -376,7 +374,7 @@ public final class FileReferencesImpl extends CsmFileReferences  {
                         break;
                     case LBRACKET:
                         if (afterBracket) {                            
-                            if (APTLanguageSupport.FLAVOR_CPP11.equals(CsmBaseUtilities.getFileLanguageFlavor(csmFile))) {
+                            if (CsmFileInfoQuery.getDefault().isCpp11OrLater(csmFile)) {
                                 blockConsumer = new BlockConsumer(CppTokenId.LBRACKET, CppTokenId.RBRACKET);
                                 derefToken = null;
                                 break;
