@@ -53,6 +53,8 @@ import java.util.List;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
+import org.netbeans.api.editor.document.LineDocument;
+import org.netbeans.api.editor.document.LineDocumentUtils;
 import org.netbeans.api.lexer.TokenId;
 import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.cnd.api.lexer.CndLexerUtilities;
@@ -109,6 +111,7 @@ import static org.netbeans.modules.cnd.completion.impl.xref.Bundle.*;
 import org.netbeans.modules.cnd.debug.CndDiagnosticProvider;
 import org.netbeans.modules.cnd.modelutil.CsmUtilities;
 import org.netbeans.modules.cnd.support.Interrupter;
+import org.netbeans.modules.cnd.utils.CndUtils;
 import org.netbeans.modules.editor.NbEditorUtilities;
 import org.openide.text.CloneableEditorSupport;
 import org.openide.util.CharSequences;
@@ -150,21 +153,21 @@ public final class ReferencesSupport {
      * the start of document is (1,1)
      */
     public static int getDocumentOffset(BaseDocument doc, int lineIndex, int colIndex) {
-        return Utilities.getRowStartFromLineOffset(doc, lineIndex - 1) + (colIndex - 1);
+        return LineDocumentUtils.getLineStartFromIndex(doc, lineIndex - 1) + (colIndex - 1);
     }
 
     public CsmObject findReferencedObject(CsmFile csmFile, BaseDocument doc, int offset) {
         return findReferencedObject(csmFile, doc, offset, null, null);
     }
 
-    /*package*/ static CsmObject findOwnerObject(CsmFile csmFile, int offset, TokenItem<TokenId> token, 
+    /*package*/ static CsmObject findOwnerObject(CsmFile csmFile, int offset, TokenItem<TokenId> token,
             FileReferencesContext fileReferencesContext) {
         CsmContext context = CsmOffsetResolver.findContext(csmFile, offset, fileReferencesContext);
         CsmObject out = context.getLastObject();
         return out;
     }
 
-    /*package*/ static CsmObject findClosestTopLevelObject(CsmFile csmFile, int offset, TokenItem<TokenId> token, 
+    /*package*/ static CsmObject findClosestTopLevelObject(CsmFile csmFile, int offset, TokenItem<TokenId> token,
             FileReferencesContext fileReferencesContext) {
         CsmContext context = CsmOffsetResolver.findContext(csmFile, offset, fileReferencesContext);
         CsmObject out = context.getLastObject();
@@ -173,7 +176,7 @@ public final class ReferencesSupport {
         }
         return out;
     }
-    
+
     /*package*/ CsmObject findReferencedObject(CsmFile csmFile, final BaseDocument doc,
             final int offset, TokenItem<TokenId> jumpToken, FileReferencesContext fileReferencesContext) {
         long fileVersionOnStartResolving = CsmFileInfoQuery.getDefault().getFileVersion(csmFile);
@@ -233,7 +236,7 @@ public final class ReferencesSupport {
         }
         return csmItem;
     }
-    
+
     public static CsmObject findDefine(Document doc, CsmFile csmFile, TokenItem<TokenId> tokenUnderOffset, int offset) {
         assert (csmFile != null);
         assert (doc != null);
@@ -246,13 +249,13 @@ public final class ReferencesSupport {
             }
         }
         return null;
-    }    
+    }
 
     public static CsmErrorDirective findErrorDirective(CsmFile csmFile, int offset) {
         assert (csmFile != null);
         return CsmOffsetUtilities.findObject(csmFile.getErrors(), null, offset);
     }
-    
+
     public static CsmInclude findInclude(CsmFile csmFile, int offset) {
         assert (csmFile != null);
         return CsmOffsetUtilities.findObject(csmFile.getIncludes(), null, offset);
@@ -265,154 +268,177 @@ public final class ReferencesSupport {
 
     private static CsmObject findDeclaration(final CsmFile csmFile, final Document doc,
             TokenItem<TokenId> tokenUnderOffset, final int offset, FileReferencesContext fileReferencesContext) {
-
-        // fast check, if possible
-        // macros have max priority in file
-        List<CsmReference> macroUsages = CsmFileInfoQuery.getDefault().getMacroUsages(csmFile, Interrupter.DUMMY);
-        CsmObject csmItem = findMacro(macroUsages, offset);
-        if (csmItem != null) {
-            return csmItem;
-        }
-        CsmObject objUnderOffset = CsmOffsetResolver.findObject(csmFile, offset, fileReferencesContext);
-        // TODO: it would be great to check position in named element, but we don't
-        // support this information yet, so
-
-        // fast check for enumerators
-        if (CsmKindUtilities.isEnumerator(objUnderOffset)) {
-            CsmEnumerator enmrtr = (CsmEnumerator) objUnderOffset;
-            if (enmrtr.getExplicitValue() == null) {
-                csmItem = enmrtr;
-            }
-        } else if (CsmKindUtilities.isLabel(objUnderOffset)) {
-            csmItem = objUnderOffset;
-        } else if (CsmKindUtilities.isGotoStatement(objUnderOffset)) {
-            CsmGotoStatement csmGoto = (CsmGotoStatement) objUnderOffset;
-            CsmScope scope = csmGoto.getScope();
-            while (scope != null && CsmKindUtilities.isScopeElement(scope) && !CsmKindUtilities.isFunctionDefinition(scope)) {
-                scope = ((CsmScopeElement) scope).getScope();
-            }
-            if (CsmKindUtilities.isFunctionDefinition(scope)) {
-                Collection<CsmReference> labels = CsmLabelResolver.getDefault().getLabels(
-                        (CsmFunctionDefinition) scope, csmGoto.getLabel(),
-                        EnumSet.of(CsmLabelResolver.LabelKind.Definiton));
-                if (!labels.isEmpty()) {
-                    csmItem = labels.iterator().next().getReferencedObject();
-                }
-            }
-// Commented because goto statements could be expression based. 
-// In such case there are inner identifiers
-//            if (csmItem == null) {
-//                // Exit now, don't look for variables, types and etc.
-//                return null;
-//            }
-        } else if (CsmKindUtilities.isVariable(objUnderOffset) || CsmKindUtilities.isTypedef(objUnderOffset) || CsmKindUtilities.isTypeAlias(objUnderOffset)) {
-            CsmType type = CsmKindUtilities.isVariable(objUnderOffset) ? ((CsmVariable) objUnderOffset).getType() : ((CsmTypedef) objUnderOffset).getType();
-            CsmParameter parameter = null;
-            boolean repeat;
-            do {
-                repeat = false;
-                if (CsmOffsetUtilities.isInObject(type, offset)) {
-                    parameter = null;
-                }
-                if (CsmKindUtilities.isFunctionPointerType(type)) {
-                    CsmParameter deeperParameter = CsmOffsetUtilities.findObject(
-                            ((CsmFunctionPointerType) type).getParameters(), null, offset);
-                    if (deeperParameter != null) {
-                        parameter = deeperParameter;
-                        type = deeperParameter.getType();
-                        repeat = true;
+        final String oldName = Thread.currentThread().getName();
+        try {
+            // Add resolve position to the thread name for logging purposes
+            if (csmFile != null) {
+                try {
+                    String position = "[" + offset + "]"; // NOI18N
+                    if (CndUtils.isDebugMode() && doc instanceof LineDocument) {
+                        LineDocument lineDoc = (LineDocument) doc;
+                        position = "[" + (LineDocumentUtils.getLineIndex(lineDoc, offset) + 1) + "," // NOI18N
+                                   + (offset - LineDocumentUtils.getLineStart(lineDoc, offset) + 1) + "]"; // NOI18N
                     }
-                } 
-                if (type != null && !type.getInstantiationParams().isEmpty()) {
-                    CsmSpecializationParameter param = CsmOffsetUtilities.findObject(type.getInstantiationParams(), null, offset);
-                    if (param != null && !CsmOffsetUtilities.sameOffsets(type, param)) {
-                        if (CsmKindUtilities.isTypeBasedSpecalizationParameter(param)) {
-                            type = ((CsmTypeBasedSpecializationParameter) param).getType();
+                    Thread.currentThread().setName(
+                        oldName + " (find declaration at "  // NOI18N
+                        + csmFile.getAbsolutePath() + position
+                        + ", token \"" + (tokenUnderOffset != null ? tokenUnderOffset.text() : "<unknown>") + "\")" // NOI18N
+                    );
+                } catch (BadLocationException ex) {
+                    // Just ignore it
+                }
+            }
+
+            // fast check, if possible
+            // macros have max priority in file
+            List<CsmReference> macroUsages = CsmFileInfoQuery.getDefault().getMacroUsages(csmFile, Interrupter.DUMMY);
+            CsmObject csmItem = findMacro(macroUsages, offset);
+            if (csmItem != null) {
+                return csmItem;
+            }
+            CsmObject objUnderOffset = CsmOffsetResolver.findObject(csmFile, offset, fileReferencesContext);
+            // TODO: it would be great to check position in named element, but we don't
+            // support this information yet, so
+
+            // fast check for enumerators
+            if (CsmKindUtilities.isEnumerator(objUnderOffset)) {
+                CsmEnumerator enmrtr = (CsmEnumerator) objUnderOffset;
+                if (enmrtr.getExplicitValue() == null) {
+                    csmItem = enmrtr;
+                }
+            } else if (CsmKindUtilities.isLabel(objUnderOffset)) {
+                csmItem = objUnderOffset;
+            } else if (CsmKindUtilities.isGotoStatement(objUnderOffset)) {
+                CsmGotoStatement csmGoto = (CsmGotoStatement) objUnderOffset;
+                CsmScope scope = csmGoto.getScope();
+                while (scope != null && CsmKindUtilities.isScopeElement(scope) && !CsmKindUtilities.isFunctionDefinition(scope)) {
+                    scope = ((CsmScopeElement) scope).getScope();
+                }
+                if (CsmKindUtilities.isFunctionDefinition(scope)) {
+                    Collection<CsmReference> labels = CsmLabelResolver.getDefault().getLabels(
+                            (CsmFunctionDefinition) scope, csmGoto.getLabel(),
+                            EnumSet.of(CsmLabelResolver.LabelKind.Definiton));
+                    if (!labels.isEmpty()) {
+                        csmItem = labels.iterator().next().getReferencedObject();
+                    }
+                }
+    // Commented because goto statements could be expression based.
+    // In such case there are inner identifiers
+    //            if (csmItem == null) {
+    //                // Exit now, don't look for variables, types and etc.
+    //                return null;
+    //            }
+            } else if (CsmKindUtilities.isVariable(objUnderOffset) || CsmKindUtilities.isTypedef(objUnderOffset) || CsmKindUtilities.isTypeAlias(objUnderOffset)) {
+                CsmType type = CsmKindUtilities.isVariable(objUnderOffset) ? ((CsmVariable) objUnderOffset).getType() : ((CsmTypedef) objUnderOffset).getType();
+                CsmParameter parameter = null;
+                boolean repeat;
+                do {
+                    repeat = false;
+                    if (CsmOffsetUtilities.isInObject(type, offset)) {
+                        parameter = null;
+                    }
+                    if (CsmKindUtilities.isFunctionPointerType(type)) {
+                        CsmParameter deeperParameter = CsmOffsetUtilities.findObject(
+                                ((CsmFunctionPointerType) type).getParameters(), null, offset);
+                        if (deeperParameter != null) {
+                            parameter = deeperParameter;
+                            type = deeperParameter.getType();
                             repeat = true;
                         }
                     }
-                }
-            } while (repeat);
-            csmItem = parameter;
-            
-            if (csmItem == null && CsmKindUtilities.isVariableDeclaration(objUnderOffset)) {
-                if (tokenUnderOffset == null && doc instanceof AbstractDocument) {
-                    ((AbstractDocument) doc).readLock();
-                    try {
-                        tokenUnderOffset = CndTokenUtilities.getTokenCheckPrev(doc, offset);
-                    } finally {
-                        ((AbstractDocument) doc).readUnlock();
+                    if (type != null && !type.getInstantiationParams().isEmpty()) {
+                        CsmSpecializationParameter param = CsmOffsetUtilities.findObject(type.getInstantiationParams(), null, offset);
+                        if (param != null && !CsmOffsetUtilities.sameOffsets(type, param)) {
+                            if (CsmKindUtilities.isTypeBasedSpecalizationParameter(param)) {
+                                type = ((CsmTypeBasedSpecializationParameter) param).getType();
+                                repeat = true;
+                            }
+                        }
                     }
-                }
-                if (tokenUnderOffset != null) {
-                    // turned off, due to the problems like
-                    // Cpu MyCpu(type, 0, amount);
-                    // initialization part is part of variable => we need info about name position exactly
-                    CsmVariable var = (CsmVariable) objUnderOffset;
-                    CharSequence name = var.getName();
-                    if (name != null) {
-                        if (name.length() > 0 && tokenUnderOffset.text().toString().equals(name.toString()) && !var.isExtern()) {
-                            // not work yet for arrays declarations IZ#130678
-                            // not work yet for elements with init value IZ#130684
-                            if ((var.getInitialValue() == null) && (var.getType() != null) && (var.getType().getArrayDepth() == 0)) {
-                                csmItem = var;
+                } while (repeat);
+                csmItem = parameter;
+
+                if (csmItem == null && CsmKindUtilities.isVariableDeclaration(objUnderOffset)) {
+                    if (tokenUnderOffset == null && doc instanceof AbstractDocument) {
+                        ((AbstractDocument) doc).readLock();
+                        try {
+                            tokenUnderOffset = CndTokenUtilities.getTokenCheckPrev(doc, offset);
+                        } finally {
+                            ((AbstractDocument) doc).readUnlock();
+                        }
+                    }
+                    if (tokenUnderOffset != null) {
+                        // turned off, due to the problems like
+                        // Cpu MyCpu(type, 0, amount);
+                        // initialization part is part of variable => we need info about name position exactly
+                        CsmVariable var = (CsmVariable) objUnderOffset;
+                        CharSequence name = var.getName();
+                        if (name != null) {
+                            if (name.length() > 0 && tokenUnderOffset.text().toString().equals(name.toString()) && !var.isExtern()) {
+                                // not work yet for arrays declarations IZ#130678
+                                // not work yet for elements with init value IZ#130684
+                                if ((var.getInitialValue() == null) && (var.getType() != null) && (var.getType().getArrayDepth() == 0)) {
+                                    csmItem = var;
+                                }
                             }
                         }
                     }
                 }
-            }
-        } else if (CsmKindUtilities.isType(objUnderOffset)) {
-            CsmType type = (CsmType)objUnderOffset;
-            CsmParameter parameter = null;
-            boolean repeat;
-            do {
-                repeat = false;
-                if (CsmOffsetUtilities.isInObject(type, offset)) {
-                    parameter = null;
-                }
-                if (CsmKindUtilities.isFunctionPointerType(type)) {
-                    CsmParameter deeperParameter = CsmOffsetUtilities.findObject(
-                            ((CsmFunctionPointerType) type).getParameters(), null, offset);
-                    if (deeperParameter != null) {
-                        parameter = deeperParameter;
-                        type = deeperParameter.getType();
-                        repeat = true;
+            } else if (CsmKindUtilities.isType(objUnderOffset)) {
+                CsmType type = (CsmType)objUnderOffset;
+                CsmParameter parameter = null;
+                boolean repeat;
+                do {
+                    repeat = false;
+                    if (CsmOffsetUtilities.isInObject(type, offset)) {
+                        parameter = null;
                     }
-                } 
-                if (!type.getInstantiationParams().isEmpty()) {
-                    CsmSpecializationParameter param = CsmOffsetUtilities.findObject(type.getInstantiationParams(), null, offset);
-                    if (param != null && !CsmOffsetUtilities.sameOffsets(type, param)) {
-                        if (CsmKindUtilities.isTypeBasedSpecalizationParameter(param)) {
-                            type = ((CsmTypeBasedSpecializationParameter) param).getType();
+                    if (CsmKindUtilities.isFunctionPointerType(type)) {
+                        CsmParameter deeperParameter = CsmOffsetUtilities.findObject(
+                                ((CsmFunctionPointerType) type).getParameters(), null, offset);
+                        if (deeperParameter != null) {
+                            parameter = deeperParameter;
+                            type = deeperParameter.getType();
                             repeat = true;
                         }
                     }
+                    if (!type.getInstantiationParams().isEmpty()) {
+                        CsmSpecializationParameter param = CsmOffsetUtilities.findObject(type.getInstantiationParams(), null, offset);
+                        if (param != null && !CsmOffsetUtilities.sameOffsets(type, param)) {
+                            if (CsmKindUtilities.isTypeBasedSpecalizationParameter(param)) {
+                                type = ((CsmTypeBasedSpecializationParameter) param).getType();
+                                repeat = true;
+                            }
+                        }
+                    }
+                } while (repeat);
+                csmItem = parameter;
+            }
+            if (csmItem == null) {
+                int[] idFunBlk = null;
+                try {
+                    if (doc instanceof BaseDocument) {
+                        idFunBlk = NbEditorUtilities.getIdentifierAndMethodBlock((BaseDocument) doc, offset);
+                    }
+                } catch (BadLocationException ex) {
+                    // skip it
                 }
-            } while (repeat);
-            csmItem = parameter;            
-        }
-        if (csmItem == null) {
-            int[] idFunBlk = null;
-            try {
-                if (doc instanceof BaseDocument) {
-                    idFunBlk = NbEditorUtilities.getIdentifierAndMethodBlock((BaseDocument) doc, offset);
+                // check but not for function call
+                if (idFunBlk != null && idFunBlk.length != 3) {
+                    csmItem = findDeclaration(csmFile, doc, tokenUnderOffset, offset, QueryScope.SMART_QUERY, fileReferencesContext);
                 }
-            } catch (BadLocationException ex) {
-                // skip it
             }
-            // check but not for function call
-            if (idFunBlk != null && idFunBlk.length != 3) {
-                csmItem = findDeclaration(csmFile, doc, tokenUnderOffset, offset, QueryScope.SMART_QUERY, fileReferencesContext);
+            if (csmItem == null || !CsmIncludeResolver.getDefault().isObjectVisible(csmFile, csmItem)) {
+                // then full check
+                CsmObject other = findDeclaration(csmFile, doc, tokenUnderOffset, offset, QueryScope.GLOBAL_QUERY, fileReferencesContext);
+                if (other != null) {
+                    csmItem = other;
+                }
             }
+            return csmItem;
+        } finally {
+            Thread.currentThread().setName(oldName);
         }
-        if (csmItem == null || !CsmIncludeResolver.getDefault().isObjectVisible(csmFile, csmItem)) {
-            // then full check 
-            CsmObject other = findDeclaration(csmFile, doc, tokenUnderOffset, offset, QueryScope.GLOBAL_QUERY, fileReferencesContext);
-            if (other != null) {
-                csmItem = other;
-            }
-        }
-        return csmItem;
     }
 
     private static CsmObject findDeclaration(final CsmFile csmFile, final Document doc,
@@ -456,7 +482,7 @@ public final class ReferencesSupport {
                 CsmType varType = var.getType();
                 if (varType != null) {
                     CsmClassifier varClassifier = (varType != null) ? varType.getClassifier() : null;
-                    
+
                 }
             }
         }*/
@@ -486,7 +512,7 @@ public final class ReferencesSupport {
         }
         return out;
     }
-    
+
     /*package*/ static ReferenceImpl createReferenceImpl(final CsmFile file, final BaseDocument doc, final int offset) {
         ReferenceImpl ref = null;
         doc.readLock();
@@ -513,8 +539,8 @@ public final class ReferencesSupport {
 
     private static boolean isSupportedToken(TokenItem<TokenId> token) {
         return token != null &&
-                (CsmIncludeHyperlinkProvider.isSupportedToken(token, HyperlinkType.GO_TO_DECLARATION) || 
-                CsmHyperlinkProvider.isSupportedToken(token, HyperlinkType.GO_TO_DECLARATION) || 
+                (CsmIncludeHyperlinkProvider.isSupportedToken(token, HyperlinkType.GO_TO_DECLARATION) ||
+                CsmHyperlinkProvider.isSupportedToken(token, HyperlinkType.GO_TO_DECLARATION) ||
                 CsmDefineHyperlinkProvider.isSupportedToken(token, HyperlinkType.GO_TO_DECLARATION));
     }
 
@@ -652,7 +678,7 @@ public final class ReferencesSupport {
     /**
      * Searches for macro.
      *
-     * @param macroUsages - list of macros
+     * @param macroUsages - SORTED (!) list of macros
      * @param offset - macro offset
      * @return macro
      */
@@ -677,7 +703,9 @@ public final class ReferencesSupport {
         if (index >= 0) {
             CsmReference macroRef = macroUsages.get(index);
             CsmObject csmItem = macroRef.getReferencedObject();
-            assert csmItem != null : "referenced macro is null. ref " + macroRef + ", file " + macroRef.getContainingFile() + ", name " + macroRef.getText();
+            if (csmItem == null) {
+                CndUtils.assertTrueInConsole(false, "referenced macro is null. ref " + macroRef + ", file " + macroRef.getContainingFile() + ", name " + macroRef.getText());
+            }
             return csmItem;
         }
         return null;
@@ -738,10 +766,10 @@ public final class ReferencesSupport {
 
         @Override
         public CsmObject getClosestTopLevelObject() {
-            throw new UnsupportedOperationException("Not supported.");// NOI18N 
+            throw new UnsupportedOperationException("Not supported.");// NOI18N
         }
     }
-    
+
     @ServiceProvider(service=CndDiagnosticProvider.class, position=2000)
     public static final class RefSupportDiagnostic implements CndDiagnosticProvider {
 
@@ -757,11 +785,11 @@ public final class ReferencesSupport {
             inst.cache.dumpInfo(printOut);
         }
     }
-    
+
     private static DefineImpl getDefine(final Document doc, final CsmFile file, final int offset) {
-        
+
         final DefineTarget dt = new DefineTarget();
-        
+
         if (doc instanceof BaseDocument) {
             ((BaseDocument)doc).render(new Runnable() {
                 @Override
@@ -833,14 +861,14 @@ public final class ReferencesSupport {
                         }
                         int end = ts.offset();
                         dt.setDefine(new DefineImpl(name, params, file, start, offset));
-                    }                    
-                    
+                    }
+
                 }
             });
-        }        
+        }
         return dt.getDefine();
     }
-    
+
     private static int getDefineStartOffset(TokenSequence<TokenId> ts, int offset) {
         if (!ts.moveNext()) {
             return -1;
@@ -858,7 +886,7 @@ public final class ReferencesSupport {
         }
         return lastDefineOffset;
     }
-    
+
 
     private static class DefineParameterImpl implements CsmOffsetable, CsmNamedElement {
         private final CharSequence name;
@@ -870,12 +898,12 @@ public final class ReferencesSupport {
             this.file = file;
             this.startOffset = startOffset;
         }
-     
+
         @Override
         public CharSequence getName() {
             return name;
         }
-        
+
         @Override
         public CsmFile getContainingFile() {
             return file;
@@ -937,7 +965,7 @@ public final class ReferencesSupport {
         }
 
     }
-    
+
     private static class DefineTarget {
         private DefineImpl define;
 
@@ -949,7 +977,7 @@ public final class ReferencesSupport {
             this.define = define;
         }
     }
-    
+
     private static class DefineImpl implements CsmOffsetable {
         private final int startOffset;
         private final int endOffset;
@@ -964,7 +992,7 @@ public final class ReferencesSupport {
             this.endOffset = endOffset;
             this.params = params;
         }
-        
+
         @Override
         public CsmFile getContainingFile() {
             return file;
@@ -998,10 +1026,10 @@ public final class ReferencesSupport {
         public List<DefineParameterImpl> getParams() {
             return params;
         }
-        
-        
+
+
     }
-    
+
     private static final CsmOffsetable.Position DUMMY_POSITION = new CsmOffsetable.Position() {
 
         @Override
@@ -1018,6 +1046,6 @@ public final class ReferencesSupport {
         public int getColumn() {
             return -1;
         }
-    };    
-    
+    };
+
 }
