@@ -1166,6 +1166,25 @@ public class ClassMembersHyperlinkTestCase extends HyperlinkBaseTestCase {
         performTest("bug244524.cpp", 37, 18, "bug244524.cpp", 7, 9);        
     }
     
+    public void testBug235102_3() throws Exception {
+        // Bug 235102 - 5% inaccuracy in LLVM
+        performTest("bug235102_3_AAA.cpp", 8, 12, "bug235102_3_AAA.cpp", 3, 5);
+        performTest("bug235102_3_BBB.cpp", 8, 12, "bug235102_3_BBB.cpp", 3, 5);
+    }
+    
+    public void testBug252581() throws Exception {
+        // Bug 252581 - Methods declared by 'using' statement in a public section are not listed
+        performTest("bug252581.cpp", 21, 16, "bug252581.cpp", 6, 9);
+    }
+    
+    public void testBug255328() throws Exception {
+        // Bug 255328 - inaccuracy tests: C struct initialization
+        performTest("bug255328.cpp", 15, 39, "bug255328.cpp", 6, 4);
+        performTest("bug255328.cpp", 16, 25, "bug255328.cpp", 6, 4);
+        performTest("bug255328.cpp", 17, 42, "bug255328.cpp", 6, 4);
+        performTest("bug255328.cpp", 17, 27, "bug255328.cpp", 2, 5);
+    }
+    
     public static class Failed extends HyperlinkBaseTestCase {
 
         @Override
