@@ -61,6 +61,8 @@ import java.awt.event.ActionListener;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Set;
+import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 import javax.swing.SwingUtilities;
 import org.netbeans.modules.cnd.spi.remote.RemoteSyncFactory;
 
@@ -128,17 +130,17 @@ import org.openide.util.actions.SystemAction;
 public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointProvider {
 
     private final BreakpointManager bm;
+    protected volatile boolean breakpointsActivated = true;
 
-    protected ContextProvider ctxProvider;	// for lookup
-    protected DebuggerEngine debuggerEngine;	// corresponding engine
-    protected NativeSession session;	// corresponding (our) session object
-    protected DebuggerSettingsBridge profileBridge;
+    protected final ContextProvider ctxProvider;	// for lookup
+    protected final DebuggerEngine debuggerEngine;	// corresponding engine
+    protected final NativeSession session;	// corresponding (our) session object
 
     // turned on when postKill is called
-    protected boolean postedKill = false;
+    protected volatile boolean postedKill = false;
 
     // turned on when killEngine is issued
-    protected boolean postedKillEngine = false;
+    protected volatile boolean postedKillEngine = false;
 
     protected volatile Location visitedLocation = null;
 
@@ -217,16 +219,19 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     }
 
     // interface NativeDebugger
+    @Override
     public final NativeSession session() {
         return session;
     }
 
     // interface NativeDebugger
+    @Override
     public final NativeDebuggerManager manager() {
         return NativeDebuggerManager.get();
     }
 
     // interface NativeDebugger
+    @Override
     public final BreakpointManager bm() {
 	return bm;
     }
@@ -236,16 +241,21 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      */
 
     // interface NativeDebugger
+    @Override
     public boolean isCurrent() {
         return manager().currentNativeDebugger() == this;
     }
 
-
-    // interface NativeDebugger
-    public DebuggerSettingsBridge profileBridge() {
-        return profileBridge;
+    @Override
+    public boolean areBreakpointsActivated() {
+        return breakpointsActivated;
     }
 
+    // interface NativeDebugger
+    @Override
+    public abstract DebuggerSettingsBridge profileBridge();
+
+    @Override
     public Context context() {
         final String executable = session().getTarget();
         final String hostname = session().getSessionHost();
@@ -268,6 +278,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         return executor.getExecutionEnvironment();
     }
 
+    @Override
     public Host getHost() {
         if (host == null) {
             host = Host.byName(getNDI().getHostName());
@@ -298,6 +309,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         return (syncFactory == null) ? null : syncFactory.getPathMap(ee);
     }
 
+    @Override
     public final String localToRemote(String who, String path) {
 	String mapped;
 	if (path == null) {
@@ -324,6 +336,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 	return mapped;
     }
 
+    @Override
     public final String remoteToLocal(String who, String path) {
 	String mapped;
 	if (path == null) {
@@ -376,6 +389,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      */
 
     // interface NativeDebugger
+    @Override
     public void invalidateSessionData() {
         if (session != null) // FIXUP: Ivan, check this....
         {
@@ -401,6 +415,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      *   for us so all the accomodation and worries about that are gone.
      */
     protected final List<StateListener> actions = new LinkedList<StateListener>();
+    protected final ReentrantReadWriteLock actionsLock = new ReentrantReadWriteLock();
     protected javax.swing.Timer runTimer;		// see stateSetRunning()
     protected int runDelay = -1;	// -1 == first time through
 
@@ -411,16 +426,28 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         return NativeDebuggerManager.actionEnabler();
     }
 
+    @Override
     public State state() {
         return state;
     }
 
+    @Override
     public void addStateListener(StateListener sl) {
-        actions.add(sl);
+        actionsLock.writeLock().lock();
+        try {
+            actions.add(sl);
+        } finally {
+            actionsLock.writeLock().unlock();
+        }
     }
 
     protected void removeStateListener(StateListener sl) {
-        actions.remove(sl);
+        actionsLock.writeLock().lock();
+        try {
+            actions.remove(sl);
+        } finally {
+            actionsLock.writeLock().unlock();
+        }
     }
 
     /**
@@ -455,10 +482,16 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      */
     protected void updateActions() {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 // update explicitly registered actions
-                for (StateListener action : actions) {
-                    action.update(state);
+                actionsLock.readLock().lock();
+                try {
+                    for (StateListener action : actions) {
+                        action.update(state);
+                    }
+                } finally {
+                    actionsLock.readLock().unlock();
                 }
 
                 // update actions managed by ActionEnabler
@@ -507,6 +540,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
                 runTimer = new javax.swing.Timer(getRunDelay(),
                         new ActionListener() {
 
+                            @Override
                             public void actionPerformed(ActionEvent evt) {
                                 // set state and update when timer expires
                                 state.isRunning = true;
@@ -528,6 +562,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 
 
     // interface NativeDebugger as well.
+    @Override
     public abstract String debuggerType();
 
 
@@ -655,6 +690,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     }
 
     // interface NativeDebugger
+    @Override
     public WatchVariable[] getWatches() {
         return watches.toArray(new WatchVariable[watches.size()]);
     }
@@ -667,6 +703,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         return manager().watchUpdater();
     }
 
+    @Override
     public void restoreWatches(WatchBag wb) {
         NativeWatch[] watchesToRestore = wb.getWatches();
         for (int i = 0; i < watchesToRestore.length; i++) {
@@ -712,11 +749,13 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         }
     }
 
+    @Override
     public void spreadWatchCreation(NativeWatch w) {
         // very similar to restoreWatches
         restoreWatch(w);
     }
 
+    @Override
     public abstract void replaceWatch(NativeWatch template, String replacewith);
     protected abstract void restoreWatch(NativeWatch template);
 
@@ -746,6 +785,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     protected abstract void postVarContinuation(int rt, VarContinuation vc);
 
     // interface NativeDebugger
+    @Override
     public void postVarContinuation(VarContinuation vc) {
         int rt = RoutingToken.VAR.getUniqueRoutingTokenInt();
         varContinuations.put(rt, vc);
@@ -759,6 +799,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         }
     }
 
+    @Override
     public void setShowAutos(boolean showAutos) {
 	// System.out.printf("NativeDebuggerImpl.setShowAutos(%b)\n", showAutos);
 	this.showAutos = showAutos;
@@ -780,6 +821,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      */
     protected final void deleteMarkLocations() {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 setCurrentLine(null, false, false, ShowMode.NONE, false);
             }
@@ -788,12 +830,14 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 
     protected final void resetCurrentLine() {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 setCurrentLine(null, false, false, ShowMode.NONE, false);
             }
         });
     }
     
+    @Override
     public Location getVisitedLocation() {
         return visitedLocation;
     }
@@ -910,7 +954,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
                             if (andShow) {
                                 showMode = showModeOverride;
                                 NativeBreakpoint breakpoint = loc.getBreakpoint();
-                                if (breakpoint != null) {
+                                if (breakpoint != null && ShowMode.AUTO.equals(showModeOverride)) {
                                     if (breakpoint instanceof InstructionBreakpoint) {
                                         showMode = ShowMode.DIS;
                                     } else {
@@ -961,6 +1005,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 	updateLocation(true, ShowMode.AUTO, false);
     }
 
+    @Override
     public void setSrcOODMessage(String msg) {
         if (msg != null && !srcOOD) {
             // If srcOOD is not set it's quite likley that this is a
@@ -978,6 +1023,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     protected int deliverSignal = -1;
     protected OptionLayers optionLayers = null;
 
+    @Override
     public OptionLayers optionLayersInit() {
         // we don't want to create one, if optionLayers is null
         return optionLayers;
@@ -986,6 +1032,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     protected void addExtraOptions(OptionLayers optionLayers) {
     }
 
+    @Override
     public final OptionLayers optionLayers() {
         // We want to create one, if optionLayers is null
 
@@ -997,8 +1044,8 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
             // See bug 6307423.
             // Probably SHOULD do more work.
             OptionSet profileOptions = null;
-            if (profileBridge.currentDbgProfile() != null) {
-                profileOptions = profileBridge.currentDbgProfile().getOptions();
+            if (profileBridge().currentDbgProfile() != null) {
+                profileOptions = profileBridge().currentDbgProfile().getOptions();
                 assert profileOptions != null : "debug profile must have options";
                 optionLayers.push(profileOptions);
             }
@@ -1009,6 +1056,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     }
 
     // interface NativeDebugger
+    @Override
     public void optionLayersReset() {
         // arrange so we re-create optionLayers
         optionLayers = null;
@@ -1018,6 +1066,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      * Called when this session has been switched to
      * 'redundant' is true when we double-click on the same session.
      */
+    @Override
     public void activate(boolean redundant) {
 
         ioPack.switchTo();
@@ -1075,6 +1124,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
      * Called when this session has been switched away from
      * 'redundant' is true when we double-click on the same session.
      */
+    @Override
     public void deactivate(boolean redundant) {
 
         if (redundant) {
@@ -1103,6 +1153,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         EditorBridge.setStatus(null);
     }
 
+    @Override
     public boolean getVerboseStack() {
         if ("on".equals(DebuggerOption.STACK_VERBOSE.getCurrValue(optionLayers()))) { // NOI18N
             return true;
@@ -1261,30 +1312,35 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 
     protected class DisModelSupport implements DisFragModel {
 
-        private ArrayList<Line> current_addrs = new ArrayList<Line>();
-        private ArrayList<Listener> listeners = new ArrayList<Listener>();
+        private List<Line> current_addrs = new CopyOnWriteArrayList<Line>();
+        private List<Listener> listeners = new CopyOnWriteArrayList<Listener>();
 
         // implement DisFragModel
+        @Override
         public void clear() {
             current_addrs.clear();
         }
 
         // implement DisFragModel
+        @Override
         public Line getItem(int i) {
             return current_addrs.get(i);
         }
 
         // implement DisFragModel
+        @Override
         public int size() {
             return current_addrs.size();
         }
 
         // interface DisFragModel
+        @Override
         public void addListener(Listener listener) {
             listeners.add(listener);
         }
 
         // interface DisFragModel
+        @Override
         public void removeListener(Listener listener) {
             listeners.remove(listener);
         }
@@ -1294,13 +1350,18 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 	    // DisView.addrFromLine is sensitive to this number of spaces
             current_addrs.add(new Line(memaddr, memvalue));
         }
-	
+
+	protected final void addAll(List<Line> lines) {
+            current_addrs.addAll(lines);
+        }
+
 	protected final void update() {
             for (Listener listener : listeners) {
                 listener.fragUpdated();
             }
 	}
 
+        @Override
         public Iterator<Line> iterator() {
             return current_addrs.iterator();
         }
@@ -1311,9 +1372,11 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         private StateListener runToCursorListener = null;
 
         // interface Controller
+        @Override
         abstract public void requestDis(boolean withSource);
 
         // interface Controller
+        @Override
         abstract public void requestDis(String start, int count, boolean withSource);
 
 
@@ -1324,6 +1387,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          */
 
 	// interface Controller
+        @Override
         public void setBreakpoint(String address, boolean add) {
             if (add) {
 		setBreakpointHelp(address);
@@ -1341,6 +1405,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          */
 
 	// interface Controller
+        @Override
         public void toggleBreakpoint(String address) {
 	    long addr = Address.parseAddr(address);
             InstBreakpointModel.Bpt foundBpt = breakpointModel().findBptByAddr(addr);
@@ -1357,6 +1422,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          */
 
         // interface Controller
+        @Override
         public final void enableBreakpoint(long address, NativeBreakpoint bpt,
                 boolean enable) {
 
@@ -1373,6 +1439,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          */
 
         // interface Controller
+        @Override
         public final void updateBreakpoint(long address, NativeBreakpoint bpt,
                 boolean add) {
 
@@ -1390,6 +1457,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         }
 
         // interface Controller
+        @Override
         public final void addStateListenerInst(StateListener sl) {
             if (runToCursorListener == null) {
                 runToCursorListener = sl;
@@ -1398,6 +1466,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         }
 
         // interface Controller
+        @Override
         public final void removeStateListenerInst(StateListener sl) {
             // 6567570
             if (runToCursorListener != null) {
@@ -1407,7 +1476,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         }
     }
 
-    protected final class InstBreakpointModel implements BreakpointModel {
+    protected static final class InstBreakpointModel implements BreakpointModel {
 
         public class Bpt {
 
@@ -1419,18 +1488,20 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
                 bpt = b;
             }
         }
-        private ArrayList<Bpt> breakpoints_List = new ArrayList<Bpt>();
-        private ArrayList<Listener> listeners = new ArrayList<Listener>();
+        private List<Bpt> breakpoints_List = new CopyOnWriteArrayList<Bpt>();
+        private List<Listener> listeners = new CopyOnWriteArrayList<Listener>();
 
 	public InstBreakpointModel() {
 	}
 
         // interface BreakpointModel
+        @Override
         public void addListener(Listener listener) {
             listeners.add(listener);
         }
 
         // interface BreakpointModel
+        @Override
         public void removeListener(Listener listener) {
             listeners.remove(listener);
         }
@@ -1451,6 +1522,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          * Return number of disabled bpts at this address.
          */
         // interface BreakpointModel
+        @Override
         public int findDisabled(long address) {
             int count = 0;
             for (Bpt bpt : breakpoints_List) {
@@ -1465,6 +1537,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
          * Return number of bpts at this address.
          */
         // interface BreakpointModel
+        @Override
         public int find(long address) {
             int count = 0;
             for (Bpt bpt : breakpoints_List) {
@@ -1501,6 +1574,7 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
             }
         }
 
+        @Override
         public NativeBreakpoint[] getBreakpoints() {
             NativeBreakpoint[] res = new NativeBreakpoint[breakpoints_List.size()];
             int idx = 0;
@@ -1517,48 +1591,56 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 
         private HashMap<Long, Integer> addrHashMap;
 
-        private final ArrayList<Listener> listeners = new ArrayList<Listener>();
+        private final List<Listener> listeners = new CopyOnWriteArrayList<Listener>();
 
 	public StateModelAdaptor() {
 	}
 
         // interface StateModel
+        @Override
         public void addListener(Listener listener) {
             listeners.add(listener);
         }
 
         // interface StateModel
+        @Override
         public void removeListener(Listener listener) {
             listeners.remove(listener);
         }
 
         // interface StateModel
+        @Override
         public void setAddrHashMap(HashMap<Long, Integer> hashmap) {
             addrHashMap = hashmap;
         }
 
 
         // interface StateModel
+        @Override
         public boolean isVisited() {
             return location.visited();
         }
 
         // interface StateModel
+        @Override
         public long getPC() {
             return location.pc();
         }
 
         // interface StateModel
+        @Override
         public String getFunction() {
             return location.func();
         }
 
         // interface StateModel
+        @Override
         public String getFile() {
             return location.src();
         }
 
         // interface StateModel
+        @Override
         public int getLine() {
             return location.line();
         }
@@ -1592,21 +1674,25 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
     }
 
     // interface NativeDebugger
+    @Override
     public final void InstBptEnabled(long addr, NativeBreakpoint bpt) {
 	disController().enableBreakpoint(addr, bpt, true);
     }
 
     // interface NativeDebugger
+    @Override
     public final void InstBptDisabled(long addr, NativeBreakpoint bpt) {
 	disController().enableBreakpoint(addr, bpt, false);
     }
 
     // interface NativeDebugger
+    @Override
     public final void InstBptAdded(long addr, NativeBreakpoint bpt) {
 	disController().updateBreakpoint(addr, bpt, true);
     }
 
     // interface NativeDebugger
+    @Override
     public final void InstBptRemoved(long addr, NativeBreakpoint bpt) {
 	disController().updateBreakpoint(addr, bpt, false);
     }
@@ -1676,14 +1762,21 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
         if (bt.initBuildTools(model, new ArrayList<String>(), cs)) {
             conf.getCompilerSet().setValue(model.getSelectedCompilerSetName());
             cs = CompilerSetManager.get(exEnv).getCompilerSet(model.getSelectedCompilerSetName());
-            return cs.getTool(PredefinedToolKind.DebuggerTool).getPath();
+            if (cs != null) {
+                debuggerTool = cs.getTool(PredefinedToolKind.DebuggerTool);
+                if (debuggerTool != null) {
+                    return debuggerTool.getPath();
+                }
+            }
         }
         return null;
     }
     
+    @Override
     public void registerMemoryWindow(MemoryWindow w) {
     }
 
+    @Override
     public Set<String> requestAutos() {
 	autos.clear();
 
@@ -1700,15 +1793,18 @@ public abstract class NativeDebuggerImpl implements NativeDebugger, BreakpointPr
 	return Autos.get(EditorBridge.documentFor(location.src(), this), location.line()-1);
     }
     
+    @Override
     public int getAutosCount() {
 	return autos.size();
     }
     
+    @Override
     public Variable[] getAutos() {
         Variable array[] = autos.toArray(new Variable[autos.size()]);
 	return array;
     }
 
+    @Override
     public void copyStack() {
         if (guiStackFrames == null)
 	    return;
