@@ -126,12 +126,17 @@ import javax.swing.JTextArea;
 import javax.swing.ProgressMonitor;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
+import org.netbeans.modules.cnd.api.remote.PathMap;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
 import org.netbeans.modules.cnd.api.toolchain.PredefinedToolKind;
 import org.netbeans.modules.cnd.api.toolchain.ToolchainManager.DebuggerDescriptor;
 import org.netbeans.modules.cnd.debugger.common2.DbgActionHandler;
+import org.netbeans.modules.cnd.debugger.common2.debugger.options.DbgProfile;
 import org.netbeans.modules.cnd.debugger.common2.debugger.remote.Platform;
 import org.netbeans.modules.cnd.makeproject.api.runprofiles.RunProfile;
+import org.netbeans.modules.cnd.spi.remote.RemoteSyncFactory;
+import org.netbeans.modules.cnd.utils.CndPathUtilities;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
@@ -165,7 +170,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
     private final static boolean standalone = "on".equals(System.getProperty("spro.dbxtool")); // NOI18N
     private static final boolean pl = "on".equals(System.getProperty("PL_MODE")); // NOI18N;
 
-    private NativeDebugger currentDebugger;
+    private volatile NativeDebugger currentDebugger;
     private InputOutput io;
 
     // Keep a strong reference to 'changeListener' so it doesn't get GC'ed
@@ -445,6 +450,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
 
         changeListener = new ChangeListener() {
 
+            @Override
             public void stateChanged(ChangeEvent evt) {
 		Object source = evt.getSource();
 		if (source instanceof Set<?>) {
@@ -604,6 +610,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         if (od != null) {
             SwingUtilities.invokeLater(new Runnable() {
 
+                @Override
                 public void run() {
                     od.deactivate(redundant);
                 }
@@ -613,6 +620,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         if (nd != null) {
             SwingUtilities.invokeLater(new Runnable() {
 
+                @Override
                 public void run() {
                     nd.activate(redundant);
                 }
@@ -991,6 +999,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         if (isAsyncStart()) {
             getRequestProcessor().post(new Runnable() {
 
+                @Override
                 public void run() {
                     delegate().startDebugging(di);
                 }
@@ -1065,6 +1074,10 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
                 ndi.setAction(this.getAction());
             }
         }
+        
+        String symbolFile = DebuggerOption.SYMBOL_FILE.getCurrValue(ndi.getDbgProfile().getOptions());
+        symbolFile = ((MakeConfiguration) conf).expandMacros(symbolFile);
+        ndi.setSymbolFile(symbolFile);
 
         if (isStandalone()) {
             startDebugger(getExistingDebugger(ndi), ndi);
@@ -1185,7 +1198,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
     /**
      * Start debugging by loading program.
      */
-    public NativeDebuggerInfo debug(String executable, Configuration configuration, String host,
+    public NativeDebuggerInfo debug(String executable, String symbolFile, Configuration configuration, String host,
             InputOutput io, DbgActionHandler dah, RunProfile profile) {
         NativeDebuggerInfo ndi = makeNativeDebuggerInfo(debuggerType(configuration));
         ndi.setTarget(executable);
@@ -1200,11 +1213,22 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
             ndi.setAction(this.getAction());
         }
         
+        DbgProfile dbgProfile = ndi.getDbgProfile();
         // override executable if needed
-        String debugExecutable = ndi.getDbgProfile().getExecutable();
+        String debugExecutable = dbgProfile.getExecutable();
         if (debugExecutable != null && !debugExecutable.isEmpty()) {
             ndi.setTarget(debugExecutable);
         }
+        if (symbolFile == null || symbolFile.isEmpty()) {
+            symbolFile = DebuggerOption.SYMBOL_FILE.getCurrValue(dbgProfile.getOptions());
+            symbolFile = ((MakeConfiguration) configuration).expandMacros(symbolFile);
+            if (!CndPathUtilities.isPathAbsolute(symbolFile)) {
+                symbolFile = ((MakeConfiguration) configuration).getBaseDir() + "/" + symbolFile; // NOI18N
+                symbolFile = CndPathUtilities.normalizeSlashes(symbolFile);
+                symbolFile = CndPathUtilities.normalizeUnixPath(symbolFile);
+            }
+        }
+        ndi.setSymbolFile(symbolFile);
 
         startDebugger(Start.NEW, ndi);
         return ndi;
@@ -1214,7 +1238,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
      * Start debugging by attaching to pid.
      */
     public void attach(DebugTarget dt) {
-        Configuration conf = dt.getConfig();
+        final Configuration conf = dt.getConfig();
 
         NativeDebuggerInfo ndi = makeNativeDebuggerInfo(dt.getEngine());
         ndi.setDebugTarget(dt);
@@ -1229,11 +1253,13 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
 	    ndi.setTarget("-"); //NOI18N
         } else {
             String execPath = ndi.getTarget();
-            if (host.getPlatform() != Platform.Windows_x86 && host.getPlatform() != Platform.MacOSX_x86) {
-                execPath = executor.readlink(dt.getPid());
-            } else {
+            if (host.getPlatform() == Platform.MacOSX_x86) {
+                execPath = executor.readlsof(dt.getPid());
+            } else if (host.getPlatform() == Platform.Windows_x86) {
                 // omit arguments (IZ 230518)
-                execPath = execPath.split(" ")[0]; // NOI18N
+                //execPath = execPath.split(" ")[0]; // NOI18N
+            } else {
+                execPath = executor.readlink(dt.getPid());
             }
             ndi.setTarget(execPath);
         }
@@ -1248,7 +1274,37 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         ndi.setHostName(dt.getHostName());
         ndi.setAction(ATTACH);
         ndi.setCaptureInfo(dt.getCaptureInfo());
-
+        
+        if (dt.getProjectMode() == DebugTarget.ProjectMode.OLD_PROJECT) {
+            String symbolFile = DebuggerOption.SYMBOL_FILE.getCurrValue(ndi.getDbgProfile().getOptions());
+            symbolFile = ((MakeConfiguration) conf).expandMacros(symbolFile);
+            if (!CndPathUtilities.isPathAbsolute(symbolFile)) {
+                symbolFile = ((MakeConfiguration) conf).getBaseDir() + "/" + symbolFile; // NOI18N
+                symbolFile = CndPathUtilities.normalizeSlashes(symbolFile);
+                symbolFile = CndPathUtilities.normalizeUnixPath(symbolFile);
+                // The below is a partial fix of the issue #252827 - Remote Attach doesn't work
+                // The changesets 6ec8ff163ad7 and a459d48725b5 don't seem correct,
+                // but their motivation need to be thoroughly investigated for the new fix not to break old ones.
+                // In any case, if the path is not absolute, then project will return LOCAL path,
+                // so we need to map it to remote one
+                MakeConfiguration makeConf = (MakeConfiguration) conf;
+                ExecutionEnvironment execEnv = makeConf.getDevelopmentHost().getExecutionEnvironment();
+                if (execEnv.isRemote()) {
+                    RemoteSyncFactory syncFactory = makeConf.getRemoteSyncFactory();
+                    if (syncFactory != null) {
+                        PathMap pathMap = syncFactory.getPathMap(execEnv);
+                        if (pathMap != null) {
+                            String remoteSymbolFile = pathMap.getRemotePath(symbolFile, false);
+                            if (remoteSymbolFile != null) {
+                                symbolFile = remoteSymbolFile;
+                            }
+                        }
+                    }
+                }
+                // end of the partial fix of the issue #252827
+            }
+            ndi.setTarget(symbolFile);
+        }
         if (isStandalone()) {
             startDebugger(getExistingDebugger(ndi), ndi);
         } else {
@@ -1269,7 +1325,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         ndi.setCorefile(dt.getCorefile());
         ndi.setConfiguration(conf);
         ndi.setAction(CORE);
-
+        
         if (isStandalone()) {
             startDebugger(getExistingDebugger(ndi), ndi);
         } else {
@@ -1661,6 +1717,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
 
         if (!handled && (error.maxSeverity() == Error.Severity.ERROR)) {
             SwingUtilities.invokeLater(new Runnable() {
+                @Override
                 public void run() {
                     IpeUtils.postError(error.text());
                 }
@@ -1809,20 +1866,11 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         }
     }
 
-    /*
-     * Status display mgmt
-     */
-
-    private static StatusDisplayer statusDisplayer;
-
     /*
      * Put the given text into the status area
      */
     public void setStatusText(String text) {
-        if (statusDisplayer == null) {
-            statusDisplayer = StatusDisplayer.getDefault();
-        }
-        statusDisplayer.setStatusText(text, 1);
+        StatusDisplayer.getDefault().setStatusText(text);
     }
 
     /*
@@ -1855,6 +1903,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         } else {
             SwingUtilities.invokeLater(new Runnable() {
 
+                @Override
                 public void run() {
                     updateProgressSameThread(message, note, progress);
                 }
@@ -1905,6 +1954,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
         } else {
             SwingUtilities.invokeLater(new Runnable() {
 
+                @Override
                 public void run() {
                     cancelProgressSameThread();
                 }
@@ -2155,6 +2205,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
 
         if (!SwingUtilities.isEventDispatchThread()) {
                 SwingUtilities.invokeLater(new Runnable() {
+                    @Override
                     public void run() {
                         enableConsoleWindow();
                     }
@@ -2178,6 +2229,7 @@ public final class NativeDebuggerManager extends DebuggerManagerAdapter {
 
         if (!SwingUtilities.isEventDispatchThread()) {
 	    SwingUtilities.invokeLater(new Runnable() {
+                @Override
 		public void run() {
 		    enablePioWindow();
 		}
