@@ -219,6 +219,7 @@ public final class AttachPanel extends TopComponent {
             if (hostlist != null) {
                 hostlist.addRecordListListener(new RecordListListener() {
 
+                    @Override
                     public void contentsChanged(RecordListEvent e) {
                         updateRemoteHostList();
                         String hostName = e.getHostName();
@@ -258,6 +259,7 @@ public final class AttachPanel extends TopComponent {
         }
 
         // interface TableCellRenderer
+        @Override
         public Component getTableCellRendererComponent(JTable table,
                 Object value,
                 boolean isSelected,
@@ -297,6 +299,7 @@ public final class AttachPanel extends TopComponent {
 
         allProcessesCheckBox.addActionListener(new ActionListener() {
 
+            @Override
             public void actionPerformed(ActionEvent evt) {
                 refreshProcesses(null, true);
             }
@@ -312,6 +315,7 @@ public final class AttachPanel extends TopComponent {
         Catalog.setAccessibleDescription(refreshButton, "ACSD_Refresh"); // NOI18N
         refreshButton.addActionListener(new ActionListener() {
 
+            @Override
             public void actionPerformed(ActionEvent evt) {
                 refreshProcesses(null, true);
             }
@@ -327,6 +331,7 @@ public final class AttachPanel extends TopComponent {
         
         final JTextComponent cbEditor = (JTextComponent) filterCombo.getEditor().getEditorComponent();
         cbEditor.getDocument().addDocumentListener(new AnyChangeDocumentListener() {
+            @Override
             public void documentChanged(DocumentEvent e) {
                 refreshProcesses(null, false);
             }
@@ -340,6 +345,7 @@ public final class AttachPanel extends TopComponent {
         hostCombo.setToolTipText(Catalog.get("HostName")); //NOI18N
         hostCombo.addActionListener(new ActionListener() {
 
+            @Override
             public void actionPerformed(ActionEvent evt) {
                 String ac = evt.getActionCommand();
                 if ((ac != null) && ac.equals("comboBoxChanged")) { // NOI18N
@@ -363,6 +369,7 @@ public final class AttachPanel extends TopComponent {
                 "ACSD_EditHosts");		// NOI18N
         hostsButton.addActionListener(new java.awt.event.ActionListener() {
 
+            @Override
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 hostsButtonActionPerformed(evt);
             }
@@ -497,6 +504,7 @@ public final class AttachPanel extends TopComponent {
         ListSelectionModel sm = procTable.getSelectionModel();
         sm.addListSelectionListener(new ListSelectionListener() {
 
+            @Override
             public void valueChanged(ListSelectionEvent e) {
                 if (e.getValueIsAdjusting() || isTableInfoShown()) {
                     return;
@@ -627,6 +635,7 @@ public final class AttachPanel extends TopComponent {
     
     private void tableInfo(final String infoKey, final boolean enabled) {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 procTable.clearSelection();
                 setUIEnabled(enabled);
@@ -672,12 +681,7 @@ public final class AttachPanel extends TopComponent {
         // compile and validate 'regexp' into 're'
         Pattern re = null;
         try {
-            // 6646694
-            String regexp2 = regexp;
-            if (regexp.equals("")) {
-                regexp2 = ".*";		// NOI18N
-            }
-            re = Pattern.compile(regexp2);
+            re = Pattern.compile(regexp, Pattern.LITERAL);
         } catch (PatternSyntaxException e) {
             if (e.getLocalizedMessage() != null) {
                 StatusDisplayer.getDefault().setStatusText(e.getLocalizedMessage());
@@ -735,12 +739,14 @@ public final class AttachPanel extends TopComponent {
 
     private void requestProcesses(final Pattern re, final String hostname, final boolean getAll) {
         Runnable asycData = new Runnable() {
+            @Override
 	    public void run() {
                 final Host selectedHost = Host.byName(hostname);
                 PsProvider psProvider = PsProvider.getDefault(selectedHost);
                 if (psProvider == null) {
                     // "clear" the table
                     SwingUtilities.invokeLater(new Runnable() {
+                        @Override
                         public void run() {
                             processModel.setRowCount(0);
                         }
@@ -752,6 +758,7 @@ public final class AttachPanel extends TopComponent {
 		setPsData(data);
 		try {
 		    javax.swing.SwingUtilities.invokeAndWait(new Runnable() {
+                        @Override
                         public void run() {
                             filterProcesses(re);
                         }
@@ -775,7 +782,7 @@ public final class AttachPanel extends TopComponent {
     private final static RequestProcessor getPcRP =  
 				new RequestProcessor("processes"); // throughput 1 // NOI18N
 
-    private PsProvider.PsData psData = null;
+    private volatile PsProvider.PsData psData = null;
 
     private void setPsData (PsProvider.PsData data) {
 	psData = data;
@@ -796,6 +803,7 @@ public final class AttachPanel extends TopComponent {
 
         SwingUtilities.invokeLater(new Runnable() {
 
+            @Override
             public void run() {
                 processModel.setDataVector(psData.processes(re), psData.header());
                 setUIEnabled(true);
@@ -894,14 +902,17 @@ public final class AttachPanel extends TopComponent {
     public static abstract class AnyChangeDocumentListener implements DocumentListener {
         protected abstract void documentChanged(DocumentEvent e);
 
+        @Override
         public void changedUpdate(DocumentEvent e) {
             documentChanged(e);
         }
 
+        @Override
         public void insertUpdate(DocumentEvent e) {
             documentChanged(e);
         }
 
+        @Override
         public void removeUpdate(DocumentEvent e) {
             documentChanged(e);
         }
@@ -920,15 +931,23 @@ public final class AttachPanel extends TopComponent {
         private String loadedPID = null;
 
         // interface Controller
+        @Override
         final public boolean isValid() {
 	    if (!ckMatch())
 		return false;
-
+            
+            if (isTableInfoShown()) {
+                return false;
+            }
+            
             if (loadedPID == null) {
                 int selectedRow = procTable.getSelectedRow();
                 if (selectedRow == -1) {
                     return false;
                 }
+                if (processModel.getRowCount() <= selectedRow) {
+                    return false;
+                }
                 Object pidobj = processModel.getValueAt(selectedRow, 1);
                 if (!(pidobj instanceof String)) {
                     return false;
@@ -938,6 +957,7 @@ public final class AttachPanel extends TopComponent {
         }
 
         // interface Controller
+        @Override
         final public boolean ok() {
             //System.out.println("AttachPanel.ok");
             
@@ -1005,16 +1025,19 @@ public final class AttachPanel extends TopComponent {
         }
 
         // interface Controller
+        @Override
         final public boolean cancel() {
             return true;
         }
 
         // interface Controller
+        @Override
         final public void addPropertyChangeListener(PropertyChangeListener l) {
             pcs.addPropertyChangeListener(l);
         }
 
         // interface Controller
+        @Override
         final public void removePropertyChangeListener(PropertyChangeListener l) {
             pcs.removePropertyChangeListener(l);
         }
@@ -1032,7 +1055,11 @@ public final class AttachPanel extends TopComponent {
 
         @Override
         public boolean load(Properties props) {
-            Vector<Vector<String>> processes = psData.processes(Pattern.compile(props.getString(COMMAND_PROP, NO_EXISTING_PROCESS)));
+            if (psData == null) {
+                NativeDebuggerManager.warning(Catalog.get("MSG_Uninitialized_Process_Table"));
+                return false;
+            }
+            Vector<Vector<String>> processes = psData.processes(Pattern.compile(props.getString(COMMAND_PROP, NO_EXISTING_PROCESS), Pattern.LITERAL));
             if (processes.isEmpty()) {
                 return false;
             }
