@@ -74,7 +74,6 @@ import org.netbeans.modules.cnd.debugger.common2.debugger.api.EngineTypeManager;
 import org.netbeans.modules.cnd.debugger.common2.debugger.remote.Host;
 import org.netbeans.modules.cnd.debugger.common2.debugger.remote.CustomizableHostList;
 import org.netbeans.modules.cnd.debugger.common2.debugger.remote.HostListEditor;
-import org.netbeans.modules.cnd.debugger.common2.debugger.remote.CndRemote;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
 import java.util.Collection;
@@ -87,6 +86,8 @@ import javax.swing.SwingUtilities;
 import org.netbeans.api.project.ProjectInformation;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.modules.cnd.api.picklist.DefaultPicklistModel;
+import org.netbeans.modules.cnd.api.remote.ServerList;
+import org.netbeans.modules.cnd.api.remote.ServerRecord;
 import org.netbeans.modules.cnd.debugger.common2.APIAccessor;
 import org.netbeans.modules.cnd.debugger.common2.debugger.actions.ExecutableProjectPanel.ProjectCBItem;
 import org.netbeans.modules.cnd.makeproject.api.configurations.ConfigurationSupport;
@@ -94,6 +95,7 @@ import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.FileFilterFactory;
 import org.netbeans.modules.cnd.utils.MIMENames;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
 import org.netbeans.modules.remote.api.ui.FileChooserBuilder;
@@ -159,12 +161,14 @@ final class DebugCorePanel extends javax.swing.JPanel {
 	executableComboBox.setModel(new DefaultComboBoxModel(executablePickList.getElementsDisplayName()));
 	((JTextField)executableComboBox.getEditor().getEditorComponent()).getDocument().addDocumentListener(validationWorker);
 
-        if (host != null) {
-            lastHostChoice = host;
+        if (lastHostChoice == null) {
+            ServerRecord defaultHost = ServerList.getDefaultRecord();
+            if (defaultHost != null) {
+                lastHostChoice = ExecutionEnvironmentFactory.toUniqueID(defaultHost.getExecutionEnvironment());
+            }
         }
 	initRemoteHost();
 	initEngine();
-	lastHostChoice = null;
 	adjustAutoCore();
 
         projectComboBox.addItemListener(validationWorker);
@@ -177,6 +181,7 @@ final class DebugCorePanel extends javax.swing.JPanel {
                 lastSelectedProject = getSelectedProject();
                 lastSelectedEngine = getEngine();
                 lastSelectedCorefile = getCorefilePath();
+                lastHostChoice = getHostName();
                 
                 executablePickList.addElement(getExecutablePath());
                 corefilePickList.addElement(getCorefilePath());
@@ -271,6 +276,7 @@ final class DebugCorePanel extends javax.swing.JPanel {
 	    // listen to host host list model
 	    if (hostlist != null) {
 		hostlist.addRecordListListener(new RecordListListener() {
+                    @Override
 		    public void contentsChanged(RecordListEvent e) {
 			if (e.getHostName() != null)
 			    lastHostChoice = e.getHostName();
@@ -406,6 +412,7 @@ final class DebugCorePanel extends javax.swing.JPanel {
                 "ACSD_EditHosts"); // NOI18N
 
         hostsButton.addActionListener(new java.awt.event.ActionListener() {
+            @Override
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 hostsButtonActionPerformed(evt);
             }
@@ -467,6 +474,7 @@ final class DebugCorePanel extends javax.swing.JPanel {
         corefileBrowseButton.setMnemonic(java.util.ResourceBundle.getBundle("org/netbeans/modules/cnd/debugger/common2/debugger/actions/Bundle").getString("LOADCORE_COREFILEBROWSE_BUTTON_MN").charAt(0));
         corefileBrowseButton.setText(java.util.ResourceBundle.getBundle("org/netbeans/modules/cnd/debugger/common2/debugger/actions/Bundle").getString("BROWSE_BUTTON_TXT"));
         corefileBrowseButton.addActionListener(new java.awt.event.ActionListener() {
+            @Override
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 corefileBrowseButtonActionPerformed(evt);
             }
@@ -507,6 +515,7 @@ final class DebugCorePanel extends javax.swing.JPanel {
         executableBrowseButton.setMnemonic(java.util.ResourceBundle.getBundle("org/netbeans/modules/cnd/debugger/common2/debugger/actions/Bundle").getString("EXECUTABLEBROWSE_BUTTON_MN").charAt(0));
         executableBrowseButton.setText(java.util.ResourceBundle.getBundle("org/netbeans/modules/cnd/debugger/common2/debugger/actions/Bundle").getString("BROWSE_BUTTON_TXT"));
         executableBrowseButton.addActionListener(new java.awt.event.ActionListener() {
+            @Override
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 executableBrowseButtonActionPerformed(evt);
             }
