@@ -91,6 +91,7 @@ import org.openide.util.RequestProcessor;
 public final class ExecutableProjectPanel extends javax.swing.JPanel {
 
 //    private DocumentListener executableValidateListener = null;
+    private static final RequestProcessor RP = new RequestProcessor("ExecutableProjectPanel", 1); //NOI18N
     private final JButton actionButton;
     private boolean noproject;
     private final EngineDescriptor debuggerType;
@@ -462,15 +463,18 @@ public final class ExecutableProjectPanel extends javax.swing.JPanel {
     // ModifiedDocumentListener
     public class ExecutableValidateListener implements DocumentListener {
 
+        @Override
         public void changedUpdate(javax.swing.event.DocumentEvent documentEvent) {
         }
 
+        @Override
         public void insertUpdate(javax.swing.event.DocumentEvent documentEvent) {
             if (validateExecutablePath()) {
                 // ;
             }
         }
 
+        @Override
         public void removeUpdate(javax.swing.event.DocumentEvent documentEvent) {
             if (validateExecutablePath()) {
                 // ;
@@ -502,7 +506,7 @@ public final class ExecutableProjectPanel extends javax.swing.JPanel {
  
         projectComboBox.setEnabled(false);
         
-        RequestProcessor.getDefault().post(new Runnable() {
+        RP.post(new Runnable() {
             @Override
             public void run() {
                 final ProjectCBItem prj = getProjectByPath(hostName, path);
