@@ -63,6 +63,7 @@ import java.util.Iterator;
 import java.util.Set;
 import java.util.Date;
 import java.util.HashSet;
+import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.logging.Level;
 import javax.swing.SwingUtilities;
 import org.netbeans.api.debugger.DebuggerEngine;
@@ -226,7 +227,7 @@ public abstract class NativeBreakpoint
 
 	// create one for children too so getChildren() naturally
 	// returns a 0-sized array
-	children = new ArrayList<NativeBreakpoint>(1);
+	children = new CopyOnWriteArrayList<NativeBreakpoint>();
 
 	if (!isRestored())
 	    updateTimestamp();	// record creation date
@@ -296,6 +297,7 @@ public abstract class NativeBreakpoint
     }
 
     // interface org.netbeans.api.debugger.Breakpoint
+    @Override
     public void enable() {
 	if (NativeDebuggerManager.isPerTargetBpts()) {
 	    NativeBreakpoint current = findCurrent();
@@ -307,6 +309,7 @@ public abstract class NativeBreakpoint
     }
 
     // interface org.netbeans.api.debugger.Breakpoint
+    @Override
     public void disable() {
 	if (NativeDebuggerManager.isPerTargetBpts()) {
 	    NativeBreakpoint current = findCurrent();
@@ -334,6 +337,7 @@ public abstract class NativeBreakpoint
 	// 6706848
 	if (!SwingUtilities.isEventDispatchThread()) {
 	    SwingUtilities.invokeLater(new Runnable() {
+                @Override
 		public void run() {
 		    dispose();
 		}
@@ -421,7 +425,7 @@ public abstract class NativeBreakpoint
 	*/
     }
 
-    private final ArrayList<NativeBreakpoint> children;
+    private final CopyOnWriteArrayList<NativeBreakpoint> children;
 
     private NativeBreakpoint parent;
 
@@ -491,10 +495,11 @@ public abstract class NativeBreakpoint
 
     private int findByBreakpoint(NativeBreakpoint subBpt) {
 	// Vector.indexOf uses equals() which is overkill for us
-	for (int bx = 0; bx < children.size(); bx++) {
-	    NativeBreakpoint candidate = children.get(bx);
+        int bx = 0;
+	for (NativeBreakpoint candidate : children) {
 	    if (candidate == subBpt)
 		return bx;
+            bx++;
 	}
 	return -1;
     }
@@ -665,9 +670,7 @@ public abstract class NativeBreakpoint
 
 
     public final NativeBreakpoint[] getChildren() {
-	NativeBreakpoint array[] = new NativeBreakpoint[children.size()];
-	children.toArray(array);
-	return array;
+	return children.toArray(new NativeBreakpoint[0]);
     }
 
     /**
@@ -836,6 +839,7 @@ public abstract class NativeBreakpoint
 
 
 	return this.equals(that, new PropertyOwner.Comparator() {
+            @Override
 	    public boolean equals(Property thisP, Property thatP) {
 		if (enableDifferentiates && thisP == enabled) {
 		} else if (ghostBuster && thisP == context) {
@@ -959,6 +963,7 @@ public abstract class NativeBreakpoint
 		"\tthat: " + that.getBreakpointType(); // NOI18N
 
 	return this.equals(that, new PropertyOwner.Comparator() {
+            @Override
 	    public boolean equals(Property thisP, Property thatP) {
 		if (enableDifferentiates && thisP == enabled) {
 		} else if (thisP == context) {
@@ -1553,6 +1558,7 @@ public abstract class NativeBreakpoint
 
 
     // interface EditUndoable
+    @Override
     public void undo(String property) {
 	 // re-pull the whole line instead of just the cell.
 	 update();
@@ -1837,6 +1843,7 @@ public abstract class NativeBreakpoint
 
 	DebuggerAnnotation.Listener listener =
 	    new DebuggerAnnotation.Listener() {
+                @Override
 		public void annotationMoved() {
 		    update();
 		    updateTimestamp();
@@ -2141,41 +2148,49 @@ public abstract class NativeBreakpoint
      */
 
     // interface PropertyOwner
+    @Override
     public final void register(Property p) {
 	pos.register(p);
     }
 
     // interface PropertyOwner
+    @Override
     public Property propertyByName(String name) {
 	return pos.propertyByName(name);
     }
 
     // interface PropertyOwner
+    @Override
     public Property propertyByKey(String key) {
 	return pos.propertyByKey(key);
     }
 
     // interface PropertyOwner
+    @Override
     public int size() {
 	return pos.size();
     }
 
     // interface PropertyOwner/Iterable
+    @Override
     public Iterator<Property> iterator() {
 	return pos.iterator();
     }
 
     // interface PropertyOwner
+    @Override
     public boolean isDirty() {
 	return pos.isDirty();
     }
 
     // interface PropertyOwner
+    @Override
     public void clearDirty() {
 	pos.clearDirty();
     }
 
     // interface PropertyOwner
+    @Override
     public boolean equals(PropertyOwner that, Comparator comparator) {
 	return pos.equals(((NativeBreakpoint)that).pos, comparator);
     }
@@ -2229,6 +2244,7 @@ public abstract class NativeBreakpoint
     }
 
     // interface org.netbeans.api.debugger.Breakpoint
+    @Override
     public final boolean isEnabled() {
 	boolean isEnabled = enabled.get();
 	if (Log.Bpt.enabling) {
@@ -2928,7 +2944,7 @@ public abstract class NativeBreakpoint
 
     private static final String icon_dir =
 	"org/netbeans/modules/cnd/debugger/common2/icons";       // NOI18N
-
+    
     public String getIconBase() {
 	// SHOULD merge this with annotation types?
 
@@ -2938,6 +2954,13 @@ public abstract class NativeBreakpoint
 	// StringBuffer name = new StringBuffer("viewBpt");
 
 	// texteditor glyph gutter icons
+        if (debugger != null && !debugger.areBreakpointsActivated()) {
+            if (isEnabled()) {
+                return debugger_icon_dir + "/DeactivatedBreakpoint";       // NOI18N
+            } else {
+                return debugger_icon_dir + "/DeactivatedDisabledBreakpoint";       // NOI18N
+            }
+        }
 	StringBuilder name = new StringBuilder();
         if (!isEnabled()) {
 	    name.append(DebuggerAnnotation.TYPE_BPTX_DISABLED);
