@@ -231,6 +231,7 @@ public final class DebugTarget implements Record {
     }
 
     // interface Record
+    @Override
     public String getKey() {
 	return displayName();
     /*
@@ -241,18 +242,21 @@ public final class DebugTarget implements Record {
     }
 
     // interface Record
+    @Override
     public void setKey(String newKey) {
 	// Cannot for now
 	return;
     }
 
     // interface record
+    @Override
     public boolean matches(String key) {
 	return IpeUtils.sameString(getKey(), key, 120);
     }
 
 
     // interface Record
+    @Override
     public boolean isArchetype() {
 	return false;
     }
@@ -294,6 +298,7 @@ public final class DebugTarget implements Record {
     }
 
     // interface Record
+    @Override
     public DebugTarget cloneRecord() {
 
 	// IZ 134190 is fixed in NB6.1 patch 3
@@ -316,6 +321,7 @@ public final class DebugTarget implements Record {
 	clone.setHostName(this.getHostName());
 	clone.setCorefile(this.getCorefile());
 	clone.setEngine(this.getEngine());
+        clone.setUnparsedArgs(this.getUnparsedArgs());
 
 	return clone;
     }
@@ -330,6 +336,7 @@ public final class DebugTarget implements Record {
     }
     
     // interface Record
+    @Override
     public String displayName() {
 	String exec = configuration.getMakefileConfiguration().
 			getOutput().getValue() ;
@@ -524,6 +531,7 @@ public final class DebugTarget implements Record {
 	    hostName = h;
     }
 
+    @Override
     public String getHostName() {
 	return hostName;
     }
