@@ -50,6 +50,7 @@ import org.netbeans.modules.cnd.debugger.common2.utils.options.CatalogDynamic;
 import org.netbeans.modules.cnd.debugger.common2.utils.options.Option;
 import org.netbeans.modules.cnd.debugger.common2.utils.options.OptionValue;
 import org.netbeans.modules.cnd.debugger.common2.utils.options.Validity;
+import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 
 public class DebuggerOption extends Option {
 
@@ -109,6 +110,7 @@ public class DebuggerOption extends Option {
      */
 
     // interface Option
+    @Override
     public Option getSubOption(String value) {
 
 	if (this == OUTPUT_LOG_FILE && value.equals("custom")) // NOI18N
@@ -125,12 +127,14 @@ public class DebuggerOption extends Option {
 
     /** Hack to fix width rendering */
     // interface Option
+    @Override
     public boolean verticalLayout() {
 	return (this == RUN_IO);
     }
 
     /** Hack to fix width rendering */
     // interface Option
+    @Override
     public boolean overrideHasLabel() {
 	return (this != RUN_IO);
     }
@@ -140,6 +144,7 @@ public class DebuggerOption extends Option {
      * return the sub option if any
      */
     // interface Option
+    @Override
     public Option getSubOption() {
 	if (this == OUTPUT_LOG_FILE)
 	    return OUTPUT_LOG_FILE_NAME;
@@ -156,6 +161,7 @@ public class DebuggerOption extends Option {
      * returns if this is a sub option or not
      */
     // interface Option
+    @Override
     public boolean isSubOption() {
 	if (this == RUN_PTY)
 	    return true;
@@ -167,16 +173,19 @@ public class DebuggerOption extends Option {
     }
 
     // interface Option
+    @Override
     public Validity getValidity(String text) {
 	return Validity.TRUE;
     }
 
     // interface Option
+    @Override
     public boolean isTrim() {
 	return false;
     }
 
     // interface Option
+    @Override
     public boolean persist(OptionValue value) {
 
 	/* LATER?
@@ -341,6 +350,14 @@ public class DebuggerOption extends Option {
 			    "on", //NOI18N // deault value
 			    true, // is engine option
 			    Type.COMBO_BOX, false);  //type , hasToolTip
+    
+    public static final DebuggerOption GDB_REVERSE_DEBUGGING = 
+        new DebuggerOption( // NOI18N
+			    "reverse_debugging", // NOI18N //name
+                            new String[] {"on", "off"},  // NOI18N //values
+                            "off",  // NOI18N // deault value
+			    true, // is engine option
+			    Type.CHECK_BOX, false);  //type , hasToolTip
 
     public static final DebuggerOption OUTPUT_BASE  =
 	new DebuggerOption( // NOI18N
@@ -760,4 +777,11 @@ public class DebuggerOption extends Option {
 			    "", // deault value
 			    false, // is engine option
 			    Type.DIRECTORY, false);  //type , hasToolTip
+    
+    public static final DebuggerOption SYMBOL_FILE = 
+        new DebuggerOption( // NOI18N
+			    "symbol_file", // NOI18N //name
+                            MakeConfiguration.CND_OUTPUT_PATH_MACRO, // deault value
+			    false, // is engine option
+			    Type.FILE, false);  //type , hasToolTip
 }
