@@ -61,8 +61,10 @@ import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.QmakeConfiguration;
 import org.netbeans.modules.cnd.api.toolchain.Tool;
-import org.netbeans.modules.cnd.discovery.api.DiscoveryUtils.Artifacts;
 import org.netbeans.modules.cnd.discovery.wizard.api.support.ProjectBridge;
+import org.netbeans.modules.cnd.dwarfdump.source.Artifacts;
+import org.netbeans.modules.cnd.dwarfdump.source.CompileLineOrigin;
+import org.netbeans.modules.cnd.dwarfdump.source.Driver;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.HostInfo;
@@ -124,10 +126,11 @@ public abstract class QtInfoProvider {
                                     String key = lines[0].trim();
                                     vars.put(lines[0].trim(), lines[1].trim());
                                     if (key.equals(CXXFLAGS)) {
-                                        Artifacts artifacts = new Artifacts();
-                                        DiscoveryUtils.gatherCompilerLine(getActualVarValue(vars, CXXFLAGS), DiscoveryUtils.LogOrigin.BuildLog, artifacts, new ProjectBridge(project), true);
-                                        List<String> result = new ArrayList<>(artifacts.userMacros.size());
-                                        for (Map.Entry<String, String> pair : artifacts.userMacros.entrySet()) {
+                                        ProjectBridge projectBridge = new ProjectBridge(project);
+                                        Driver driver = DriverFactory.getDriver(projectBridge.getCompilerSet());
+                                        Artifacts artifacts = driver.gatherCompilerLine(getActualVarValue(vars, CXXFLAGS), CompileLineOrigin.BuildLog, true);
+                                        List<String> result = new ArrayList<>(artifacts.getUserMacros().size());
+                                        for (Map.Entry<String, String> pair : artifacts.getUserMacros().entrySet()) {
                                             if (pair.getValue() == null) {
                                                 result.add(pair.getKey());
                                             } else {
@@ -144,7 +147,7 @@ public abstract class QtInfoProvider {
                     Exceptions.printStackTrace(ex);
                 }
             }
-            return java.util.Collections.EMPTY_LIST;
+            return java.util.Collections.emptyList();
         }
 
         private String getActualVarValue(Map<String, String> vars, String var) {
@@ -154,7 +157,7 @@ public abstract class QtInfoProvider {
             }
             return result;
         }
-        
+
         /**
          * Finds Qt include directories for given project configuration.
          *
@@ -324,8 +327,7 @@ public abstract class QtInfoProvider {
                         cache.put(cacheKey, baseDir);
                     } else {
                         String baseInc = guessBaseQtIncludeDir(qmakePath);
-                        String baseLib = null;
-                        baseDir = Pair.of(baseInc, baseLib);
+                        baseDir = Pair.of(baseInc, null);
                         // do not cache this result, so that we can
                         // really query qmake once connection is up
                     }
