@@ -57,10 +57,13 @@ import org.netbeans.api.project.Project;
 import org.netbeans.modules.cnd.api.remote.*;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSetManager;
+import org.netbeans.modules.cnd.api.toolchain.CompilerSetUtils;
 import org.netbeans.modules.cnd.api.toolchain.PredefinedToolKind;
 import org.netbeans.modules.cnd.api.toolchain.Tool;
 import org.netbeans.modules.cnd.api.utils.PlatformInfo;
 import org.netbeans.modules.cnd.discovery.api.BuildTraceSupport;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport;
 import org.netbeans.modules.cnd.spi.toolchain.CompilerLineConvertor;
 import org.netbeans.modules.cnd.spi.toolchain.ToolchainProject;
 import org.netbeans.modules.cnd.utils.CndUtils;
@@ -71,7 +74,6 @@ import org.netbeans.modules.nativeexecution.api.execution.PostMessageDisplayer;
 import org.netbeans.modules.nativeexecution.api.util.*;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager.CancellationException;
 import org.openide.util.Exceptions;
-import org.openide.util.NbBundle;
 import org.openide.windows.IOProvider;
 import org.openide.windows.InputOutput;
 
@@ -83,17 +85,26 @@ public class ExecuteCommand {
 
     private final String runDir;
     private String command;
+    private String cmdLine;
     private final Project project;
     private final ExecutionEnvironment execEnv;
+    private String name;
+    private String displayName;
 
     public ExecuteCommand(Project project, String runDir, String command) {
         this.runDir = runDir;
         this.command = command;
+        this.cmdLine = command;
         this.project = project;
         this.execEnv = getExecutionEnvironment();
 
     }
-    
+
+    public void setName(String name, String displayName) {
+        this.name = name;
+        this.displayName = displayName;
+    }
+
     public Future<Integer> performAction(ExecutionListener listener, Writer outputListener, List<String> additionalEnvironment) {
         NativeExecutionService es = prepare(listener, outputListener, additionalEnvironment);
         if (es != null) {
@@ -115,49 +126,30 @@ public class ExecuteCommand {
         }
         // Executable
         String executable = hostInfo.getShell();
-        if (command.contains("${MAKE}")) { //NOI18N
-            String make = "make"; //NOI18N
-            CompilerSet compilerSet = getCompilerSet();
-            if (compilerSet != null) {
-                Tool findTool = compilerSet.findTool(PredefinedToolKind.MakeTool);
-                if (findTool != null && findTool.getPath() != null && findTool.getPath().length() > 0) {
-                    make = findTool.getPath();
-                    if (hostInfo.getOSFamily() == HostInfo.OSFamily.WINDOWS) {
-                        String aMake = WindowsSupport.getInstance().convertToShellPath(make);
-                        if (aMake != null && aMake.length() > 0) {
-                            make = aMake;
-                        }
-                    }
-                }
-            }
-            command = command.replace("${MAKE}", make); //NOI18N
-        }
+        expandMacros(hostInfo, BuildSupport.MAKE_MACRO, PredefinedToolKind.MakeTool, "make"); //NOI18N
+        expandMacros(hostInfo, PreBuildSupport.C_COMPILER_MACRO, PredefinedToolKind.CCompiler, "gcc"); //NOI18N
+        expandMacros(hostInfo, PreBuildSupport.CPP_COMPILER_MACRO, PredefinedToolKind.CCCompiler, "g++"); //NOI18N
         // Arguments
         String[] args = new String[]{"-c", command}; // NOI18N
         // Build directory
         String buildDir = convertToRemoteIfNeeded(runDir);
         if (buildDir == null) {
-            ImportProject.logger.log(Level.INFO, "Run folder folder is null"); //NOI18N
+            ImportProject.logger.log(Level.INFO, "Run folder is null"); //NOI18N
             return null;
         }
         Map<String, String> envMap = getEnv(additionalEnvironment);
         if (isSunStudio()) {
             envMap.put("SPRO_EXPAND_ERRORS", ""); // NOI18N
         }
-        InputOutput inputOutput = null;
-        if (inputOutput == null) {
-            // Tab Name
-            String tabName = execEnv.isLocal() ? NbBundle.getMessage(ExecuteCommand.class, "MAKE_LABEL", command) : // NOI18N
-                                                 NbBundle.getMessage(ExecuteCommand.class, "MAKE_REMOTE_LABEL", command, execEnv.getDisplayName()); // NOI18N
-            InputOutput _tab = IOProvider.getDefault().getIO(tabName, false); // This will (sometimes!) find an existing one.
-            _tab.closeInputOutput(); // Close it...
-            InputOutput tab = IOProvider.getDefault().getIO(tabName, true); // Create a new ...
-            try {
-                tab.getOut().reset();
-            } catch (IOException ioe) {
-            }
-            inputOutput = tab;
+
+        InputOutput _tab = IOProvider.getDefault().getIO(displayName, false); // This will (sometimes!) find an existing one.
+        _tab.closeInputOutput(); // Close it...
+        InputOutput inputOutput = IOProvider.getDefault().getIO(displayName, true); // Create a new ...
+        try {
+            inputOutput.getOut().reset();
+        } catch (IOException ioe) {
         }
+
         RemoteSyncWorker syncWorker = RemoteSyncSupport.createSyncWorker(project, inputOutput.getOut(), inputOutput.getErr());
         if (syncWorker != null) {
             if (!syncWorker.startup(envMap)) {
@@ -192,7 +184,7 @@ public class ExecuteCommand {
         }
         traceExecutable(executable, buildDir, args, execEnv.toString(), mm.toMap());
         ProcessChangeListener processChangeListener = new ProcessChangeListener(listener, outputListener,
-                new CompilerLineConvertor(project, getCompilerSet(), execEnv, RemoteFileUtil.getFileObject(buildDir, execEnv)), syncWorker); // NOI18N
+                new CompilerLineConvertor(project, getCompilerSet(), execEnv, RemoteFileUtil.getFileObject(buildDir, execEnv), inputOutput), syncWorker); // NOI18N
 
         NativeProcessBuilder npb = NativeProcessBuilder.newProcessBuilder(execEnv).
                 setExecutable(executable).
@@ -211,13 +203,41 @@ public class ExecuteCommand {
                 inputOutput(inputOutput).
                 outLineBased(true).
                 postExecution(processChangeListener).
-                postMessageDisplayer(new PostMessageDisplayer.Default("Make")). // NOI18N
+                postMessageDisplayer(new PostMessageDisplayer.Default(name)).
                 errConvertorFactory(processChangeListener).
                 outConvertorFactory(processChangeListener);
 
-        return NativeExecutionService.newService(npb, descr, "make"); // NOI18N
+        descr.noReset(true);
+
+        String cdLine = "cd '" + buildDir + "'"; //NOI18N
+
+        inputOutput.getOut().println(cdLine);
+        inputOutput.getOut().println(cmdLine);
+
+        return NativeExecutionService.newService(npb, descr, name);
     }
-    
+
+    private void expandMacros(HostInfo hostInfo, String macro, PredefinedToolKind tool, String defaultValue) {
+        if (command.contains(macro)) {
+            String path = defaultValue;
+            CompilerSet compilerSet = getCompilerSet();
+            if (compilerSet != null) {
+                Tool findTool = compilerSet.findTool(tool);
+                if (findTool != null && findTool.getPath() != null && findTool.getPath().length() > 0) {
+                    path = findTool.getPath();
+                    cmdLine = cmdLine.replace(macro, path);
+                    if (hostInfo.getOSFamily() == HostInfo.OSFamily.WINDOWS) {
+                        String aPath = WindowsSupport.getInstance().convertToShellPath(path);
+                        if (aPath != null && aPath.length() > 0) {
+                            path = aPath;
+                        }
+                    }
+                }
+            }
+            command = command.replace(macro, path);
+        }
+    }
+
     private CompilerSet getCompilerSet() {
         CompilerSet set = null;
         ToolchainProject toolchain = project.getLookup().lookup(ToolchainProject.class);
@@ -247,7 +267,7 @@ public class ExecuteCommand {
         }
     }
 
-    private ExecutionEnvironment getExecutionEnvironment() {
+    public final ExecutionEnvironment getExecutionEnvironment() {
         RemoteProject info = project.getLookup().lookup(RemoteProject.class);
         if (info != null) {
             return info.getDevelopmentHost();
@@ -342,7 +362,7 @@ public class ExecuteCommand {
             return envMap;
         }
     }
-    
+
     private Map<String, String> getDefaultEnvironment() {
         PlatformInfo pi = PlatformInfo.getDefault(execEnv);
         String defaultPath = pi.getPathAsString();
@@ -350,7 +370,7 @@ public class ExecuteCommand {
         if (cs != null) {
             defaultPath = cs.getDirectory() + pi.pathSeparator() + defaultPath;
             // TODO Provide platform info
-            String cmdDir = cs.getCompilerFlavor().getCommandFolder(pi.getPlatform());
+            String cmdDir = CompilerSetUtils.getCommandFolder(cs);
             if (cmdDir != null && 0 < cmdDir.length()) {
                 // Also add msys to path. Thet's where sh, mkdir, ... are.
                 defaultPath = cmdDir + pi.pathSeparator() + defaultPath;
@@ -358,8 +378,8 @@ public class ExecuteCommand {
         }
         return Collections.singletonMap(pi.getPathName(), defaultPath);
     }
-    
-    
+
+
     private static final class ProcessChangeListener implements ChangeListener, Runnable, LineConvertorFactory {
 
         private final AtomicReference<NativeProcess> processRef = new AtomicReference<>();
@@ -448,4 +468,4 @@ public class ExecuteCommand {
             return null;
         }
     }
-}
+}
\ No newline at end of file
