@@ -44,11 +44,9 @@ package org.netbeans.modules.cnd.discovery.projectimport;
 
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -99,6 +97,7 @@ import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.remote.spi.FileSystemProvider;
 import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
 import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
@@ -122,6 +121,7 @@ public class ImportExecutable implements PropertyChangeListener {
     private List<String> dependencies;
     private CsmModel model;
     private IteratorExtension extension;
+    private FileSystem sourceFileSystem;
 
     public ImportExecutable(Map<String, Object> map, Project lastSelectedProject, ProjectKind projectKind) {
         this.map = map;
@@ -133,6 +133,12 @@ public class ImportExecutable implements PropertyChangeListener {
         } else {
             addSourceRoot = true;
             createProjectMode = false;
+            try {
+                sourceFileSystem = lastSelectedProject.getProjectDirectory().getFileSystem();
+            } catch (FileStateInvalidException ex) {
+                ex.printStackTrace(System.err);
+            }
+            extension = Lookup.getDefault().lookup(IteratorExtension.class);
         }
     }
 
@@ -156,17 +162,37 @@ public class ImportExecutable implements PropertyChangeListener {
 
     @SuppressWarnings("unchecked")
     private void createProject() {
-        String binaryPath = (String) map.get(WizardConstants.PROPERTY_BUILD_RESULT);
-        sourcesPath = (String) map.get(WizardConstants.PROPERTY_SOURCE_FOLDER_PATH);
-        FSPath projectFolder = (FSPath) map.get(WizardConstants.PROPERTY_PROJECT_FOLDER);
-        String projectName = (String) map.get(WizardConstants.PROPERTY_NAME);
-        dependencies = (List<String>) map.get(WizardConstants.PROPERTY_DEPENDENCIES);
+        String binaryPath = WizardConstants.PROPERTY_BUILD_RESULT.fromMap(map);
+        List<String> libs = new ArrayList<>();
+        {
+            String firstBinary = null;
+            for(String s : binaryPath.split(";")) { //NOI18N
+                String path = s.trim();
+                if (path.isEmpty()) {
+                    continue;
+                }
+                if (firstBinary == null) {
+                    firstBinary = path;
+                } else {
+                    libs.add(s);
+                }
+            }
+            binaryPath = firstBinary;
+        }
+        ExecutionEnvironment fullRemoteEnv = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.fromMap(map);
+        FileSystem fullRemotefileSystem = null;
+        if (fullRemoteEnv != null) {
+            fullRemotefileSystem = FileSystemProvider.getFileSystem(fullRemoteEnv);
+        }
+        sourcesPath = WizardConstants.PROPERTY_SOURCE_FOLDER_PATH.fromMap(map);
+        FSPath projectFolder = WizardConstants.PROPERTY_PROJECT_FOLDER.fromMap(map);
+        String projectName = WizardConstants.PROPERTY_NAME.fromMap(map);
+        dependencies = WizardConstants.PROPERTY_DEPENDENCIES.fromMap(map);
         String baseDir;
-        FileSystem fileSystem;
         if (projectFolder != null) {
             projectFolder = new FSPath(projectFolder.getFileSystem(), RemoteFileUtil.normalizeAbsolutePath(projectFolder.getPath(), FileSystemProvider.getExecutionEnvironment(projectFolder.getFileSystem())));
             baseDir = projectFolder.getPath();
-            fileSystem = projectFolder.getFileSystem();
+            sourceFileSystem = projectFolder.getFileSystem();
             if (projectName == null) {
                 projectName = CndPathUtilities.getBaseName(baseDir);
             }
@@ -176,35 +202,55 @@ public class ImportExecutable implements PropertyChangeListener {
                 projectName = ProjectGenerator.getValidProjectName(projectParentFolder, CndPathUtilities.getBaseName(binaryPath));
             }
             ExecutionEnvironment ee = ExecutionEnvironmentFactory.getLocal();
-            baseDir = projectParentFolder + File.separator + projectName;
-            fileSystem = FileSystemProvider.getFileSystem(ee);
-            projectFolder = new FSPath(fileSystem, RemoteFileUtil.normalizeAbsolutePath(baseDir, ee));
+            sourceFileSystem = FileSystemProvider.getFileSystem(ee);
+            baseDir = projectParentFolder + CndFileUtils.getFileSeparatorChar(sourceFileSystem) + projectName;
+            projectFolder = new FSPath(sourceFileSystem, RemoteFileUtil.normalizeAbsolutePath(baseDir, ee));
         }
-        String hostUID = (String) map.get(WizardConstants.PROPERTY_HOST_UID);
-        CompilerSet toolchain = (CompilerSet) map.get(WizardConstants.PROPERTY_TOOLCHAIN);
-        boolean defaultToolchain = Boolean.TRUE.equals(map.get(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT));
+        String hostUID = WizardConstants.PROPERTY_HOST_UID.fromMap(map);
+        CompilerSet toolchain = WizardConstants.PROPERTY_TOOLCHAIN.fromMap(map);
+        boolean defaultToolchain = Boolean.TRUE.equals(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.fromMap(map));
         MakeConfiguration conf = MakeConfiguration.createMakefileConfiguration(projectFolder, "Default",  hostUID, toolchain, defaultToolchain); // NOI18N
-        String workingDirRel = ProjectSupport.toProperPath(new FSPath(fileSystem, baseDir),  sourcesPath, MakeProjectOptions.getPathMode()); // it's better to pass project source mode here (once full remote is supprted here)
-        workingDirRel = CndPathUtilities.naturalizeSlashes(fileSystem, workingDirRel);
+        String workingDirRel = ProjectSupport.toProperPath(new FSPath(sourceFileSystem, baseDir),  sourcesPath, MakeProjectOptions.getPathMode()); // it's better to pass project source mode here (once full remote is supprted here)
+        workingDirRel = CndPathUtilities.naturalizeSlashes(sourceFileSystem, workingDirRel);
         conf.getMakefileConfiguration().getBuildCommandWorkingDir().setValue(workingDirRel);
         // Executable
         String exe = binaryPath;
-        exe = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(baseDir), exe);
-        exe = CndPathUtilities.normalizeSlashes(exe);
+        if (fullRemotefileSystem != null) {
+            exe = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(fullRemotefileSystem, baseDir), exe);
+            exe = CndPathUtilities.normalizeSlashes(exe);
+        } else {
+            exe = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(baseDir), exe);
+            exe = CndPathUtilities.normalizeSlashes(exe);
+        }
         conf.getMakefileConfiguration().getOutput().setValue(exe);
-        String exePath = new File(binaryPath).getParentFile().getAbsolutePath();
-        exePath = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(baseDir), exePath);
-        exePath = CndPathUtilities.normalizeSlashes(exePath);
+        String exePath = CndPathUtilities.getDirName(binaryPath);
+        if (fullRemotefileSystem != null) {
+            exePath = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(fullRemotefileSystem, baseDir), exePath);
+            exePath = CndPathUtilities.normalizeSlashes(exePath);
+        } else {
+            exePath = CndPathUtilities.toRelativePath(CndPathUtilities.naturalizeSlashes(baseDir), exePath);
+            exePath = CndPathUtilities.normalizeSlashes(exePath);
+        }
         conf.getProfile().setRunDirectory(exePath);
         conf.getProfile().setBuildFirst(false);
 
+        ArrayList<String> importantBinaries = new ArrayList<>();
+        importantBinaries.add(binaryPath);
+        importantBinaries.addAll(libs);
+        {
+            String launcher = projectFolder.getPath()+"/nbproject/private/launcher.properties"; //NOI18N
+            launcher = ProjectSupport.toProperPath(projectFolder, CndPathUtilities.naturalizeSlashes(sourceFileSystem, launcher), MakeProjectOptions.getPathMode());
+            launcher = CndPathUtilities.normalizeSlashes(launcher);
+            importantBinaries.add(launcher);
+        }
+
         ProjectGenerator.ProjectParameters prjParams = new ProjectGenerator.ProjectParameters(projectName, projectFolder);
         prjParams.setOpenFlag(false)
                  .setConfiguration(conf)
-                 .setImportantFiles(Collections.<String>singletonList(binaryPath).iterator())
+                 .setImportantFiles(importantBinaries.iterator())
                  .setMakefileName(""); //NOI18N
-        Boolean trueSourceRoot = (Boolean) map.get(WizardConstants.PROPERTY_TRUE_SOURCE_ROOT);
-        if (trueSourceRoot != null && trueSourceRoot.booleanValue()) {
+        Boolean trueSourceRoot = WizardConstants.PROPERTY_TRUE_SOURCE_ROOT.fromMap(map);
+        if (trueSourceRoot != null && trueSourceRoot) {
             List<SourceFolderInfo> list = new ArrayList<>();
             list.add(new SourceFolderInfo() {
 
@@ -231,12 +277,25 @@ public class ImportExecutable implements PropertyChangeListener {
         try {
             lastSelectedProject = ProjectGenerator.createProject(prjParams);
             OpenProjects.getDefault().addPropertyChangeListener(this);
-            map.put(DiscoveryWizardDescriptor.BUILD_RESULT, binaryPath);
-            map.put(DiscoveryWizardDescriptor.RESOLVE_SYMBOLIC_LINKS, CommonUtilities.resolveSymbolicLinks());
+            DiscoveryWizardDescriptor.BUILD_RESULT.toMap(map, binaryPath);
+            if (fullRemotefileSystem != null) {
+                DiscoveryWizardDescriptor.FILE_SYSTEM.toMap(map, fullRemotefileSystem);
+            }
+            DiscoveryWizardDescriptor.RESOLVE_SYMBOLIC_LINKS.toMap(map, CommonUtilities.resolveSymbolicLinks());
             if (sourcesPath != null && sourcesPath.length()>1) {
-                 map.put(DiscoveryWizardDescriptor.ROOT_FOLDER, sourcesPath);
+                DiscoveryWizardDescriptor.ROOT_FOLDER.toMap(map, sourcesPath);
             } else {
-                map.put(DiscoveryWizardDescriptor.ROOT_FOLDER, lastSelectedProject.getProjectDirectory().getPath());
+                 DiscoveryWizardDescriptor.ROOT_FOLDER.toMap(map, lastSelectedProject.getProjectDirectory().getPath());
+            }
+            if (libs.size() > 0) {
+                StringBuilder buf = new StringBuilder();
+                for(String lib : libs) {
+                    if (buf.length()>0) {
+                        buf.append(';');
+                    }
+                    buf.append(lib);
+                }
+                DiscoveryWizardDescriptor.ADDITIONAL_LIBRARIES.toMap(map, buf.toString());
             }
             model = CsmModelAccessor.getModel();
             switchModel(model, false, lastSelectedProject);
@@ -293,18 +352,23 @@ public class ImportExecutable implements PropertyChangeListener {
                             }
                             if (addSourceRoot && sourcesPath != null && sourcesPath.length()>1) {
                                 configurationDescriptor.addSourceRoot(sourcesPath);
-                                map.put(DiscoveryWizardDescriptor.ROOT_FOLDER, sourcesPath);
+                                 DiscoveryWizardDescriptor.ROOT_FOLDER.toMap(map, sourcesPath);
                             }
                             configurationDescriptor.getActiveConfiguration().getCodeAssistanceConfiguration().getResolveSymbolicLinks().setValue(CommonUtilities.resolveSymbolicLinks());
                             if (!createProjectMode) {
                                 resetCompilerSet(configurationDescriptor.getActiveConfiguration(), applicable);
                             }
-                            String additionalDependencies = null;
                             if (projectKind == ProjectKind.IncludeDependencies) {
-                                additionalDependencies = additionalDependencies(applicable, configurationDescriptor.getActiveConfiguration(),
+                                String additionalDependencies = DiscoveryWizardDescriptor.ADDITIONAL_LIBRARIES.fromMap(map);
+                                String ad = additionalDependencies(applicable, configurationDescriptor.getActiveConfiguration(),
                                         DiscoveryWizardDescriptor.adaptee(map).getBuildResult());
-                                if (additionalDependencies != null && !additionalDependencies.isEmpty()) {
-                                    map.put(DiscoveryWizardDescriptor.ADDITIONAL_LIBRARIES, additionalDependencies);
+                                if (ad != null && !ad.isEmpty()) {
+                                    if (additionalDependencies == null) {
+                                        DiscoveryWizardDescriptor.ADDITIONAL_LIBRARIES.toMap(map, ad);
+                                        additionalDependencies = ad;
+                                    } else {
+                                        DiscoveryWizardDescriptor.ADDITIONAL_LIBRARIES.toMap(map, additionalDependencies+";"+ad); //NOI18N
+                                    }
                                 }
                             }
                             if (extension.canApply(map, lastSelectedProject, null)) {
@@ -312,8 +376,8 @@ public class ImportExecutable implements PropertyChangeListener {
                                     extension.apply(map, lastSelectedProject, null);
                                     discoverScripts(lastSelectedProject, DiscoveryWizardDescriptor.adaptee(map).getBuildResult());
                                     DiscoveryProjectGenerator.saveMakeConfigurationDescriptor(lastSelectedProject, null);
-                                    if (projectKind == ProjectKind.CreateDependencies && (additionalDependencies == null || additionalDependencies.isEmpty())) {
-                                        cd = new CreateDependencies(lastSelectedProject, DiscoveryWizardDescriptor.adaptee(map).getDependencies(), dependencies,
+                                    if (projectKind == ProjectKind.CreateDependencies) {
+                                        cd = new CreateDependencies(lastSelectedProject, sourceFileSystem, DiscoveryWizardDescriptor.adaptee(map).getDependencies(), dependencies,
                                                 DiscoveryWizardDescriptor.adaptee(map).getSearchPaths(), DiscoveryWizardDescriptor.adaptee(map).getBuildResult());
                                     }
                                 } catch (IOException ex) {
@@ -357,7 +421,7 @@ public class ImportExecutable implements PropertyChangeListener {
                                 }
                             }
                         }
-                        FileObject toFileObject = CndFileUtils.toFileObject(mainFilePath); // should it be normalized?
+                        FileObject toFileObject = CndFileUtils.toFileObject(sourceFileSystem, mainFilePath); // should it be normalized?
                         if (toFileObject != null && toFileObject.isValid()) {
                             if (CsmUtilities.openSource(toFileObject, mainFunction.getLine(), 0)) {
                                 open = false;
@@ -375,7 +439,7 @@ public class ImportExecutable implements PropertyChangeListener {
         };
         RP.post(run);
     }
-    
+
     private int commonEnd(String mainFilePath, String candidate) {
         int len = mainFilePath.length() - 1;
         for(int i = candidate.length()-1; i >= 0; i--) {
@@ -396,7 +460,7 @@ public class ImportExecutable implements PropertyChangeListener {
         return len;
     }
 
-    private static void discoverScripts(Project project, String binary) {
+    private void discoverScripts(Project project, String binary) {
         ConfigurationDescriptorProvider provider = project.getLookup().lookup(ConfigurationDescriptorProvider.class);
         if (provider == null) {
             return;
@@ -413,10 +477,13 @@ public class ImportExecutable implements PropertyChangeListener {
         if (root == null) {
             return;
         }
-        File rootFile = new File(root);
+        FileObject rootFile = sourceFileSystem.findResource(root);
+        if (rootFile == null || !rootFile.isValid()) {
+            return;
+        }
         DiscoveredConfigure configure = scanFolder(rootFile);
         if (configure.script == null || configure.makefile == null) {
-            File parentFile = rootFile.getParentFile();
+            FileObject parentFile = rootFile.getParent();
             DiscoveredConfigure parentConfigure = scanFolder(parentFile);
             if (parentConfigure.script != null && parentConfigure.makefile != null) {
                 if (configure.scriptWeight < parentConfigure.scriptWeight) {
@@ -429,16 +496,16 @@ public class ImportExecutable implements PropertyChangeListener {
             if (binaryName.indexOf('.') > 0 ) {
                 binaryName = binaryName.substring(0, binaryName.lastIndexOf('.'));
             }
-            File[] listFiles = rootFile.listFiles();
+            FileObject[] listFiles = rootFile.getChildren();
             if (listFiles != null) {
-                for(File file : listFiles) {
-                    if (file.isDirectory()) {
+                for(FileObject file : listFiles) {
+                    if (file != null && file.isValid() && file.isFolder()) {
                         DiscoveredConfigure childConfigure = scanFolder(file);
                         if (childConfigure.script != null && childConfigure.makefile != null) {
                             if (configure.scriptWeight < childConfigure.scriptWeight) {
                                 configure = childConfigure;
                             }
-                        } else if (childConfigure.makefile != null && configure.makefile == null && binaryName.equals(file.getName())) {
+                        } else if (childConfigure.makefile != null && configure.makefile == null && binaryName.equals(file.getNameExt())) {
                             configure.setMakefile(childConfigure.makefile, childConfigure.makefileWeight);
                         }
                     }
@@ -446,7 +513,7 @@ public class ImportExecutable implements PropertyChangeListener {
             }
         }
         if (configure.makefile != null) {
-            activeConfiguration.getMakefileConfiguration().getBuildCommandWorkingDir().setValue(configure.makefile.getParentFile().getAbsolutePath());
+            activeConfiguration.getMakefileConfiguration().getBuildCommandWorkingDir().setValue(configure.makefile.getParent().getPath());
             activeConfiguration.getMakefileConfiguration().getBuildCommand().setValue("${MAKE} -f "+configure.makefile.getName()); // NOI18N
             activeConfiguration.getMakefileConfiguration().getCleanCommand().setValue("${MAKE} -f "+configure.makefile.getName()+" clean"); // NOI18N
             Folder externalItemFolder = configurationDescriptor.getExternalItemFolder();
@@ -456,35 +523,37 @@ public class ImportExecutable implements PropertyChangeListener {
                     break;
                 }
             }
-            externalItemFolder.addItem(Item.createInFileSystem(configurationDescriptor.getBaseDirFileSystem(), configure.makefile.getAbsolutePath()));
+            externalItemFolder.addItem(Item.createInFileSystem(configurationDescriptor.getBaseDirFileSystem(), configure.makefile.getPath()));
             if (configure.script != null) {
-                externalItemFolder.addItem(Item.createInFileSystem(configurationDescriptor.getBaseDirFileSystem(), configure.script.getAbsolutePath()));
+                externalItemFolder.addItem(Item.createInFileSystem(configurationDescriptor.getBaseDirFileSystem(), configure.script.getPath()));
             }
         }
     }
 
 
-    private static DiscoveredConfigure scanFolder(File rootFile) {
+    private static DiscoveredConfigure scanFolder(FileObject rootFile) {
         DiscoveredConfigure configure = new DiscoveredConfigure();
-        File[] listFiles = rootFile.listFiles();
-        if (listFiles != null) {
-            for(File file : listFiles) {
-                if (file.isFile()) {
-                    String name = file.getName();
-                    if ("CMakeLists.txt".equals(name)) { // NOI18N
-                        configure.setScript(file, 3);
-                    } else if (name.endsWith(".pro")) { // NOI18N
-                        configure.setScript(file, 4);
-                    } else if ("configure".equals(name) || "configure.exe".equals(name)) { // NOI18N
-                        configure.setScript(file, 5);
-                    } else if ("Makefile".equals(name)) { // NOI18N
-                        configure.setMakefile(file, 5);
-                    } else if ("makefile".equals(name)) { // NOI18N
-                        configure.setMakefile(file, 4);
-                    } else if ("GNUmakefile".equals(name)) { // NOI18N
-                        configure.setMakefile(file, 3);
-                    } else if (name.endsWith(".mk")) { // NOI18N
-                        configure.setMakefile(file, 2);
+        if (rootFile != null && rootFile.isValid()) {
+            FileObject[] listFiles = rootFile.getChildren();
+            if (listFiles != null) {
+                for(FileObject file : listFiles) {
+                    if (file != null && file.isValid() && file.isData()) {
+                        String name = file.getName();
+                        if ("CMakeLists.txt".equals(name)) { // NOI18N
+                            configure.setScript(file, 3);
+                        } else if (name.endsWith(".pro")) { // NOI18N
+                            configure.setScript(file, 4);
+                        } else if ("configure".equals(name) || "configure.exe".equals(name)) { // NOI18N
+                            configure.setScript(file, 5);
+                        } else if ("Makefile".equals(name)) { // NOI18N
+                            configure.setMakefile(file, 5);
+                        } else if ("makefile".equals(name)) { // NOI18N
+                            configure.setMakefile(file, 4);
+                        } else if ("GNUmakefile".equals(name)) { // NOI18N
+                            configure.setMakefile(file, 3);
+                        } else if (name.endsWith(".mk")) { // NOI18N
+                            configure.setMakefile(file, 2);
+                        }
                     }
                 }
             }
@@ -493,17 +562,17 @@ public class ImportExecutable implements PropertyChangeListener {
     }
 
     private static final class DiscoveredConfigure {
-        private File script;
+        private FileObject script;
         private int scriptWeight;
-        private File makefile;
+        private FileObject makefile;
         private int makefileWeight;
-        private void setScript(File script, int weight) {
+        private void setScript(FileObject script, int weight) {
             if (this.script == null || scriptWeight < weight) {
                 this.script = script;
                 scriptWeight = weight;
             }
         }
-        private void setMakefile(File makefile, int weight) {
+        private void setMakefile(FileObject makefile, int weight) {
             if (this.makefile == null || makefileWeight < weight) {
                 this.makefile = makefile;
                 makefileWeight = weight;
@@ -511,76 +580,83 @@ public class ImportExecutable implements PropertyChangeListener {
         }
     }
 
-    private String additionalDependencies(Applicable applicable, MakeConfiguration activeConfiguration, String binary) {
+    private String additionalDependencies(Applicable applicable, MakeConfiguration activeConfiguration, String binariesPath) {
         if (dependencies == null) {
-            String root = sourcesPath;
-            if (root == null || root.length()==0) {
-                root = applicable.getSourceRoot();
-            }
-            if (root == null || root.length() == 0) {
-                return null;
-            }
-            if (applicable.getDependencies() == null || applicable.getDependencies().isEmpty()) {
-                return null;
+            List<String> binaries = new ArrayList<>();
+            for(String path : binariesPath.split(";")) { //NOI18N
+                if (!path.trim().isEmpty()) {
+                    binaries.add(path.trim());
+                }
             }
             Set<String> checkedDll = new HashSet<>();
-            checkedDll.add(binary);
             Map<String,String> dllPaths = new HashMap<>();
-            String ldLibPath = CommonUtilities.getLdLibraryPath(activeConfiguration);
-            ldLibPath = CommonUtilities.addSearchPaths(ldLibPath, applicable.getSearchPaths(), binary);
-            for(String dll : applicable.getDependencies()) {
-                dllPaths.put(dll, findLocation(dll, ldLibPath));
-            }
-            while(true) {
-                List<String> secondary = new ArrayList<>();
-                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
-                    if (entry.getValue() != null) {
-                        if (!checkedDll.contains(entry.getValue())) {
-                            checkedDll.add(entry.getValue());
-                            final Map<String, Object> extMap = new HashMap<>();
-                            extMap.put(DiscoveryWizardDescriptor.BUILD_RESULT, entry.getValue());
-                            if (extension != null) {
-                                extension.discoverArtifacts(extMap);
-                                @SuppressWarnings("unchecked")
-                                List<String> dlls = (List<String>) extMap.get(DiscoveryWizardDescriptor.DEPENDENCIES);
-                                if (dlls != null) {
-                                    for(String so : dlls) {
-                                        if (!dllPaths.containsKey(so)) {
-                                            secondary.add(so);
+            String root = sourcesPath;
+            for(String binary : binaries) {
+                if (root == null || root.length()==0) {
+                    root = applicable.getSourceRoot();
+                }
+                if (root == null || root.length() == 0) {
+                    return null;
+                }
+                if (applicable.getDependencies() == null || applicable.getDependencies().isEmpty()) {
+                    return null;
+                }
+                checkedDll.add(binary);
+                String ldLibPath = CommonUtilities.getLdLibraryPath(activeConfiguration);
+                ldLibPath = CommonUtilities.addSearchPaths(ldLibPath, applicable.getSearchPaths(), binary);
+                for(String dll : applicable.getDependencies()) {
+                    dllPaths.put(dll, findLocation(sourceFileSystem, dll, ldLibPath));
+                }
+                while(true) {
+                    List<String> secondary = new ArrayList<>();
+                    for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                        if (entry.getValue() != null) {
+                            if (!checkedDll.contains(entry.getValue())) {
+                                checkedDll.add(entry.getValue());
+                                final Map<String, Object> extMap = new HashMap<>();
+                                DiscoveryWizardDescriptor.BUILD_RESULT.toMap(extMap, entry.getValue());
+                                if (extension != null) {
+                                    extension.discoverArtifacts(extMap);
+                                    List<String> dlls = DiscoveryWizardDescriptor.DEPENDENCIES.fromMap(extMap);
+                                    if (dlls != null) {
+                                        for(String so : dlls) {
+                                            if (!dllPaths.containsKey(so)) {
+                                                secondary.add(so);
+                                            }
                                         }
                                     }
-                                    //@SuppressWarnings("unchecked")
-                                    //List<String> searchPaths = (List<String>) map.get("DW:searchPaths"); // NOI18N
                                 }
                             }
                         }
                     }
-                }
-                for(String so : secondary) {
-                    dllPaths.put(so, findLocation(so, ldLibPath));
-                }
-                int search = 0;
-                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
-                    if (entry.getValue() == null) {
-                        search++;
+                    for(String so : secondary) {
+                        dllPaths.put(so, findLocation(sourceFileSystem, so, ldLibPath));
                     }
-                }
-                if (search > 0 && root.length() > 1) {
-                    gatherSubFolders(new File(root), new HashSet<String>(), dllPaths);
-                }
-                int newSearch = 0;
-                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
-                    if (entry.getValue() == null) {
-                        newSearch++;
+                    int search = 0;
+                    for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                        if (entry.getValue() == null) {
+                            search++;
+                        }
+                    }
+                    if (search > 0 && root.length() > 1) {
+                        FileObject rootFO = sourceFileSystem.findResource(root);
+                        if (rootFO != null && rootFO.isValid()) {
+                            gatherSubFolders(rootFO, new HashSet<String>(), dllPaths);
+                        }
+                    }
+                    int newSearch = 0;
+                    for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                        if (entry.getValue() == null) {
+                            newSearch++;
+                        }
+                    }
+                    if (newSearch == search && secondary.isEmpty()) {
+                        break;
                     }
-                }
-                if (newSearch == search && secondary.isEmpty()) {
-                    break;
                 }
             }
-            
             StringBuilder buf = new StringBuilder();
-            String binaryDir = CndPathUtilities.getDirName(binary);
+            String binaryDir = CndPathUtilities.getDirName(binaries.get(0));
             for(Map.Entry<String, String> entry : dllPaths.entrySet()) {
                 if (entry.getValue() != null) {
                     if (isMyDll(entry.getValue(), root) || isMyDll(entry.getValue(), binaryDir)) {
@@ -723,16 +799,16 @@ public class ImportExecutable implements PropertyChangeListener {
         return false;
     }
 
-    static String findLocation(String dll, String ldPath){
+    static String findLocation(FileSystem fs, String dll, String ldPath){
         if (ldPath != null) {
             String separator = ":";  // NOI18N
             if (ldPath.indexOf(';') > 0) {
                 separator = ";";  // NOI18N
             }
             for(String search : ldPath.split(separator)) {  // NOI18N
-                File file = new File(search, dll);
-                if (file.isFile() && file.exists()) {
-                    String path = file.getAbsolutePath();
+                FileObject file = fs.findResource(search+"/"+dll);
+                if (file != null && file.isValid()) {
+                    String path = file.getPath();
                     return path.replace('\\', '/');
                 }
             }
@@ -740,36 +816,36 @@ public class ImportExecutable implements PropertyChangeListener {
         return null;
     }
 
-    static void gatherSubFolders(File startFolder, HashSet<String> set, Map<String,String> result){
+    static void gatherSubFolders(FileObject startFolder, HashSet<String> set, Map<String,String> result){
         if (!DLL_FILE_SEARCH) {
             return;
         }
-        List<File> down = new ArrayList<>();
+        List<FileObject> down = new ArrayList<>();
         down.add(startFolder);
         while(!down.isEmpty()) {
-            ArrayList<File> next = new ArrayList<>();
-            for (File file : down) {
-                if (CndPathUtilities.isIgnoredFolder(file)){
+            ArrayList<FileObject> next = new ArrayList<>();
+            for (FileObject file : down) {
+                if (CndPathUtilities.isIgnoredFolder(file.getNameExt())){
                     continue;
                 }
-                if (file.exists() && file.isDirectory() && file.canRead()){
+                if (file.isValid() && file.isFolder() && file.canRead()){
                     String canPath;
                     try {
-                        canPath = file.getCanonicalPath();
+                        canPath = CndFileUtils.getCanonicalPath(file);
                     } catch (IOException ex) {
                         continue;
                     }
                     if (!set.contains(canPath)){
                         set.add(canPath);
-                        File[] fileList = file.listFiles();
+                        FileObject[] fileList = file.getChildren();
                         if (fileList != null) {
                             for (int i = 0; i < fileList.length; i++) {
-                                if (fileList[i].isDirectory()) {
+                                if (fileList[i].isFolder()) {
                                     next.add(fileList[i]);
                                 } else {
                                     String name = fileList[i].getName();
                                     if (result.containsKey(name)) {
-                                       result.put(name, fileList[i].getAbsolutePath());
+                                       result.put(name, fileList[i].getPath());
                                        boolean finished = true;
                                        for(String path : result.values()) {
                                            if (path == null || path.isEmpty()) {
