@@ -67,7 +67,7 @@ import org.netbeans.modules.cnd.discovery.api.DiscoveryProviderFactory;
 import org.netbeans.modules.cnd.discovery.api.Progress;
 import org.netbeans.modules.cnd.discovery.api.ProjectProperties;
 import org.netbeans.modules.cnd.discovery.api.ProjectProxy;
-import org.netbeans.modules.cnd.discovery.api.ProviderProperty;
+import org.netbeans.modules.cnd.discovery.api.ProviderPropertyType;
 import org.netbeans.modules.cnd.discovery.api.SourceFileProperties;
 import org.netbeans.modules.cnd.discovery.projectimport.ImportExecutable;
 import org.netbeans.modules.cnd.discovery.projectimport.ImportProject;
@@ -94,7 +94,12 @@ import org.openide.util.NbBundle;
  */
 @org.openide.util.lookup.ServiceProvider(service=org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension.class)
 public class DiscoveryExtension implements IteratorExtension, DiscoveryExtensionInterface {
-    
+    public static final String DWARF_PROVIDER = "dwarf-executable";// NOI18N
+    public static final String FOLDER_PROVIDER = "dwarf-folder"; // NOI18N
+    public static final String MAKE_LOG_PROVIDER = "make-log"; // NOI18N
+    public static final String EXEC_LOG_PROVIDER = "exec-log"; // NOI18N
+    public static final String MODEL_FOLDER_PROVIDER = "model-folder"; // NOI18N
+
     /** Creates a new instance of DiscoveryExtension */
     public DiscoveryExtension() {
     }
@@ -103,19 +108,17 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
     public void discoverArtifacts(Map<String, Object> map) {
         DiscoveryDescriptor descriptor = DiscoveryWizardDescriptor.adaptee(map);
         Applicable applicable = isApplicable(descriptor, null, false);
-        if (applicable != null) {
-            if (applicable.isApplicable()) {
-                descriptor.setCompilerName(applicable.getCompilerName());
-                descriptor.setDependencies(applicable.getDependencies());
-                descriptor.setSearchPaths(applicable.getSearchPaths());
-                descriptor.setRootFolder(applicable.getSourceRoot());
-                descriptor.setErrors(applicable.getErrors());
-            } else {
-                descriptor.setErrors(applicable.getErrors());
-            }
+        if (applicable.isApplicable()) {
+            descriptor.setCompilerName(applicable.getCompilerName());
+            descriptor.setDependencies(applicable.getDependencies());
+            descriptor.setSearchPaths(applicable.getSearchPaths());
+            descriptor.setRootFolder(applicable.getSourceRoot());
+            descriptor.setErrors(applicable.getErrors());
+        } else {
+            descriptor.setErrors(applicable.getErrors());
         }
     }
-    
+
     @Override
     public Set<FileObject> createProject(WizardDescriptor wizard) throws IOException{
         return new ImportProject(wizard).create();
@@ -125,7 +128,7 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
     public void apply(Map<String, Object> map, Project project) throws IOException {
         apply(map, project, null);
     }
-    
+
     @Override
     public void apply(Map<String, Object> map, Project project, Interrupter interrupter) throws IOException {
         DiscoveryDescriptor descriptor = DiscoveryWizardDescriptor.adaptee(map);
@@ -174,7 +177,7 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
             progress.done();
         }
     }
-    
+
     private DiscoveryExtensionInterface.Applicable isApplicableDwarfExecutable(DiscoveryDescriptor descriptor, boolean findMain){
         String selectedExecutable = descriptor.getBuildResult();
         if (selectedExecutable == null) {
@@ -189,19 +192,17 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
             return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "NotFoundExecutable",selectedExecutable))); // NOI18N
         }
         ProjectProxy proxy = new ProjectProxyImpl(descriptor);
-        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider("dwarf-executable"); // NOI18N
+        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider(DiscoveryExtension.DWARF_PROVIDER);
         if (provider != null && provider.isApplicable(proxy)){
-            provider.getProperty("executable").setValue(selectedExecutable); // NOI18N
-            provider.getProperty("libraries").setValue(new String[0]); // NOI18N
-            provider.getProperty("filesystem").setValue(descriptor.getFileSystem()); // NOI18N
-            ProviderProperty property = provider.getProperty("find_main");
-            if (property != null) {
-                if (findMain) {
-                    property.setValue(Boolean.TRUE);
-                } else {
-                    property.setValue(Boolean.FALSE);
-                }
+            ProviderPropertyType.ExecutablePropertyType.setProperty(provider, selectedExecutable);
+            String aditionalLibraries = descriptor.getAditionalLibraries();
+            if (aditionalLibraries == null || aditionalLibraries.isEmpty()) {
+                ProviderPropertyType.LibrariesPropertyType.setProperty(provider, new String[0]);
+            } else {
+                ProviderPropertyType.LibrariesPropertyType.setProperty(provider, aditionalLibraries.split(";")); //NOI18N
             }
+            ProviderPropertyType.BinaryFileSystemPropertyType.setProperty(provider, descriptor.getFileSystem());
+            ProviderPropertyType.FindMainPropertyType.setProperty(provider, findMain);
             Applicable canAnalyze = provider.canAnalyze(proxy, null);
             if (canAnalyze.isApplicable()){
                 descriptor.setProvider(provider);
@@ -216,16 +217,19 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
         }
         return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "NotFoundDiscoveryProvider"))); // NOI18N
     }
-    
+
     private DiscoveryExtensionInterface.Applicable  isApplicableDwarfFolder(DiscoveryDescriptor descriptor, Interrupter interrupter){
-        String rootFolder = descriptor.getRootFolder();
-        if (rootFolder == null) {
+        String buildFolder = descriptor.getBuildFolder();
+        if (buildFolder == null) {
+            buildFolder = descriptor.getRootFolder();
+        }
+        if (buildFolder == null) {
             return ApplicableImpl.getNotApplicable(null);
         }
         ProjectProxy proxy = new ProjectProxyImpl(descriptor);
-        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider("dwarf-folder"); // NOI18N
+        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider(DiscoveryExtension.FOLDER_PROVIDER);
         if (provider != null && provider.isApplicable(proxy)){
-            provider.getProperty("folder").setValue(rootFolder); // NOI18N
+            ProviderPropertyType.ExecutableFolderPropertyType.setProperty(provider, buildFolder);
             Applicable canAnalyze = provider.canAnalyze(proxy, interrupter);
             if (canAnalyze.isApplicable()){
                 descriptor.setProvider(provider);
@@ -234,7 +238,7 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
                 if (canAnalyze.getErrors().size() > 0) {
                     return ApplicableImpl.getNotApplicable(canAnalyze.getErrors());
                 } else {
-                    return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "CannotAnalyzeFolder",rootFolder))); // NOI18N
+                    return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "CannotAnalyzeFolder",buildFolder))); // NOI18N
                 }
             }
         }
@@ -248,9 +252,9 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
         }
         String logFile = descriptor.getBuildLog();
         ProjectProxy proxy = new ProjectProxyImpl(descriptor);
-        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider("make-log"); // NOI18N
+        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider(DiscoveryExtension.MAKE_LOG_PROVIDER);
         if (provider != null && provider.isApplicable(proxy)){
-            provider.getProperty("make-log-file").setValue(logFile); // NOI18N
+            ProviderPropertyType.MakeLogPropertyType.setProperty(provider, logFile);
             Applicable canAnalyze = provider.canAnalyze(proxy, null);
             if (canAnalyze.isApplicable()){
                 descriptor.setProvider(provider);
@@ -265,17 +269,20 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
         }
         return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "NotFoundDiscoveryProvider"))); // NOI18N
     }
-    
+
     private DiscoveryExtensionInterface.Applicable  isApplicableExecLog(DiscoveryDescriptor descriptor){
         String rootFolder = descriptor.getRootFolder();
         if (rootFolder == null) {
             return ApplicableImpl.getNotApplicable(null);
         }
         String logFile = descriptor.getExecLog();
+        if (logFile == null) {
+            logFile = descriptor.getBuildLog();
+        }
         ProjectProxy proxy = new ProjectProxyImpl(descriptor);
-        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider("exec-log"); // NOI18N
+        DiscoveryProvider provider = DiscoveryProviderFactory.findProvider(DiscoveryExtension.EXEC_LOG_PROVIDER);
         if (provider != null) {
-            provider.getProperty("exec-log-file").setValue(logFile); // NOI18N
+            ProviderPropertyType.ExecLogPropertyType.setProperty(provider, logFile);
             if (provider.isApplicable(proxy)){
                 Applicable canAnalyze = provider.canAnalyze(proxy, null);
                 if (canAnalyze.isApplicable()){
@@ -292,12 +299,12 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
         }
         return ApplicableImpl.getNotApplicable(Collections.singletonList(NbBundle.getMessage(DiscoveryExtension.class, "NotFoundDiscoveryProvider"))); // NOI18N
     }
-    
+
     public DiscoveryExtensionInterface.Applicable isApplicable(Map<String,Object> map, Project project, boolean findMain) {
         DiscoveryDescriptor descriptor = DiscoveryWizardDescriptor.adaptee(map);
         return isApplicable(descriptor, null, findMain);
     }
-    
+
     boolean canApply(DiscoveryDescriptor descriptor, Interrupter interrupter) {
         if (!isApplicable(descriptor, interrupter, false).isApplicable()){
             return false;
@@ -306,33 +313,29 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
         if (provider == null){
             return false;
         }
-        if ("dwarf-executable".equals(provider.getID())){ // NOI18N
+        if (DiscoveryExtension.DWARF_PROVIDER.equals(provider.getID())){
             String selectedExecutable = descriptor.getBuildResult();
             String additional = descriptor.getAditionalLibraries();
-            provider.getProperty("executable").setValue(selectedExecutable); // NOI18N
-            ProviderProperty property = provider.getProperty("find_main");
-            if (property != null) {
-                property.setValue(Boolean.TRUE);
-            }
+            ProviderPropertyType.ExecutablePropertyType.setProperty(provider, selectedExecutable);
+            ProviderPropertyType.FindMainPropertyType.setProperty(provider, Boolean.TRUE);
             if (additional != null && additional.length()>0){
                 List<String> list = new ArrayList<>();
                 StringTokenizer st = new StringTokenizer(additional,";");  // NOI18N
                 while(st.hasMoreTokens()){
                     list.add(st.nextToken());
                 }
-                provider.getProperty("libraries").setValue(list.toArray(new String[list.size()])); // NOI18N
+                ProviderPropertyType.LibrariesPropertyType.setProperty(provider, list.toArray(new String[list.size()]));
             } else {
-                provider.getProperty("libraries").setValue(new String[0]); // NOI18N
+                ProviderPropertyType.LibrariesPropertyType.setProperty(provider, new String[0]);
             }
-        } else if ("dwarf-folder".equals(provider.getID())){ // NOI18N
-            String rootFolder = descriptor.getRootFolder();
-            provider.getProperty("folder").setValue(rootFolder); // NOI18N
-        } else if ("make-log".equals(provider.getID())){ // NOI18N
-            //String rootFolder = descriptor.getRootFolder();
-            //provider.getProperty("folder").setValue(rootFolder); // NOI18N
-        } else if ("exec-log".equals(provider.getID())){ // NOI18N
-            //String rootFolder = descriptor.getRootFolder();
-            //provider.getProperty("folder").setValue(rootFolder); // NOI18N
+        } else if (DiscoveryExtension.FOLDER_PROVIDER.equals(provider.getID())){
+            String buildFolder = descriptor.getBuildFolder();
+            if (buildFolder == null) {
+                buildFolder = descriptor.getRootFolder();
+            }
+            ProviderPropertyType.ExecutableFolderPropertyType.setProperty(provider, buildFolder);
+        } else if (DiscoveryExtension.MAKE_LOG_PROVIDER.equals(provider.getID())){
+        } else if (DiscoveryExtension.EXEC_LOG_PROVIDER.equals(provider.getID())){
         } else {
             return false;
         }
@@ -344,7 +347,7 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
             && descriptor.getConfigurations() != null && descriptor.getConfigurations().size() > 0
             && descriptor.getIncludedFiles() != null;
     }
-    
+
     public static void buildModel(final DiscoveryDescriptor wizardDescriptor, Interrupter interrupter){
         String rootFolder = wizardDescriptor.getRootFolder();
         DiscoveryProvider provider = wizardDescriptor.getProvider();
@@ -387,7 +390,7 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
             public boolean resolveSymbolicLinks() {
                 return wizardDescriptor.isResolveSymbolicLinks();
             }
-            
+
         }, new MyProgress(NbBundle.getMessage(DiscoveryExtension.class, "AnalyzingProjectProgress")), interrupter);
         if (interrupter != null && interrupter.cancelled()) {
             return;
@@ -450,14 +453,14 @@ public class DiscoveryExtension implements IteratorExtension, DiscoveryExtension
     public boolean canApply(Map<String, Object> map, Project project) {
         return canApply(map, project, null);
     }
-    
+
     @Override
     public boolean canApply(Map<String, Object> map, Project project, Interrupter interrupter) {
         DiscoveryDescriptor descriptor = DiscoveryWizardDescriptor.adaptee(map);
         descriptor.setProject(project);
         return canApply(descriptor, interrupter);
     }
-    
+
     @Override
     public void discoverProject(final Map<String, Object> map, final Project lastSelectedProject, ProjectKind projectKind) {
         ImportExecutable importer = new ImportExecutable(map, lastSelectedProject, projectKind);
