@@ -60,15 +60,22 @@ import javax.swing.JPanel;
 import javax.swing.event.ChangeListener;
 import javax.swing.filechooser.FileFilter;
 import org.netbeans.api.project.ProjectUtils;
+import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.discovery.api.ProviderProperty;
-import org.netbeans.modules.cnd.discovery.api.ProviderProperty.PropertyKind;
+import org.netbeans.modules.cnd.discovery.api.ProviderPropertyType.PropertyKind;
 import org.netbeans.modules.cnd.discovery.wizard.api.DiscoveryDescriptor;
+import org.netbeans.modules.cnd.spi.utils.CndFileSystemProvider;
+import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.cnd.utils.FileFilterFactory;
+import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.cnd.utils.ui.EditableComboBox;
-import org.netbeans.modules.cnd.utils.ui.FileChooser;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.remote.spi.FileSystemProvider;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.awt.Mnemonics;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
@@ -78,30 +85,34 @@ import org.openide.util.Utilities;
  *
  * @author Alexander Simon
  */
-public class ProviderControl {
+public class ProviderControl<T> {
     private final ProviderProperty property;
     private final String propertyKey;
     private final DiscoveryDescriptor wizardDescriptor;
     private final JPanel panel;
     private final ChangeListener listener;
-    private String description;
+    private FileSystem projectFileSystem;
     private JLabel label;
     private EditableComboBox field;
     private JButton button;
     private int chooserMode = 0;
     private static final String LIST_LIST_DELIMITER = ";"; // NOI18N
     
-    public ProviderControl(String key, ProviderProperty property, DiscoveryDescriptor wizardDescriptor,
+    public ProviderControl(String key, ProviderProperty<T> property, DiscoveryDescriptor wizardDescriptor,
             JPanel panel, ChangeListener listener){
         this.propertyKey = key;
         this.property = property;
         this.panel = panel;
         this.listener = listener;
         this.wizardDescriptor = wizardDescriptor;
-        description = property.getDescription();
+        try {
+            projectFileSystem = wizardDescriptor.getProject().getProjectDirectory().getFileSystem();
+        } catch (FileStateInvalidException ex) {
+            projectFileSystem = CndFileSystemProvider.getLocalFileSystem();
+        }
         label = new JLabel();
         Mnemonics.setLocalizedText(label, property.getName());
-        switch(property.getKind()) {
+        switch(property.getPropertyType().kind()) {
             case MakeLogFile:
                 field = new EditableComboBox();
                 field.setEditable(true);
@@ -113,7 +124,7 @@ public class ProviderControl {
                 button.addActionListener(new ActionListener() {
                     @Override
                     public void actionPerformed(ActionEvent evt) {
-                        rootFolderButtonActionPerformed(evt, ProviderControl.this.property.getKind()==PropertyKind.BinaryFile,
+                        rootFolderButtonActionPerformed(evt, ProviderControl.this.property.getPropertyType().kind()==PropertyKind.BinaryFile,
                                                         getString("LOG_FILE_CHOOSER_TITLE_TXT"));
                     }
                 });
@@ -130,7 +141,7 @@ public class ProviderControl {
                 button.addActionListener(new ActionListener() {
                     @Override
                     public void actionPerformed(ActionEvent evt) {
-                        rootFolderButtonActionPerformed(evt, ProviderControl.this.property.getKind()==PropertyKind.BinaryFile,
+                        rootFolderButtonActionPerformed(evt, ProviderControl.this.property.getPropertyType().kind()==PropertyKind.BinaryFile,
                                                         getString("BINARY_FILE_CHOOSER_TITLE_TXT"));
                     }
                 });
@@ -246,7 +257,7 @@ public class ProviderControl {
     }
     
     public void store(){
-        switch(property.getKind()) {
+        switch(property.getPropertyType().kind()) {
             case MakeLogFile:
             case Folder:
             case BinaryFile:
@@ -283,37 +294,49 @@ public class ProviderControl {
 
     public boolean valid() {
         String path = getComboBoxText();
-        File file;
-        switch(property.getKind()) {
-            case Folder:
+        //ProviderControlFolderError="{0}" is not a folder
+        //ProviderControlFileError=File "{0}" not found
+        switch(property.getPropertyType().kind()) {
+            case Folder: {
                 if (path.length() == 0) {
+                    wizardDescriptor.setMessage(getString("ProviderControlFolderError", path)); // NOI18N
                     return false;
                 }
-                file = new File(path);
-                if (file.exists() && file.isDirectory()) {
-                    return true;
+                FSPath file = new FSPath(projectFileSystem, path);
+                FileObject fo = file.getFileObject();
+                if (fo == null || !fo.isValid() || !fo.isFolder()) {
+                    wizardDescriptor.setMessage(getString("ProviderControlFolderError", path)); // NOI18N
+                    return false;
                 }
-                break;
+                return true;
+            }
             case MakeLogFile:
-            case BinaryFile:
+            case BinaryFile: {
                 if (path.length() == 0) {
+                    wizardDescriptor.setMessage(getString("ProviderControlFileError", path)); // NOI18N
                     return false;
                 }
-                file = new File(path);
-                if (file.exists() && file.isFile()) {
-                    return true;
+                FSPath file = new FSPath(projectFileSystem, path);
+                FileObject fo = file.getFileObject();
+                if (fo == null || !fo.isValid() || !fo.isData()) {
+                    wizardDescriptor.setMessage(getString("ProviderControlFileError", path)); // NOI18N
+                    return false;
                 }
-                break;
+                return true;
+            }
             case BinaryFiles:
                 String text = getComboBoxText();
                 StringTokenizer st = new StringTokenizer(text,LIST_LIST_DELIMITER); // NOI18N
                 while(st.hasMoreTokens()){
                     path = st.nextToken();
                     if (path.length() == 0) {
+                        wizardDescriptor.setMessage(getString("ProviderControlFileError", path)); // NOI18N
                         return false;
                     }
-                    file = new File(path);
-                    if (!(file.exists() && file.isFile())) {
+                    FSPath file = new FSPath(projectFileSystem, path);
+                    FileObject fo = file.getFileObject();
+                    if (fo == null || !fo.isValid() || !fo.isData()) {
+                        wizardDescriptor.setMessage(getString("ProviderControlFileError", path)); // NOI18N
                         return false;
                     }
                 }
@@ -390,8 +413,8 @@ public class ProviderControl {
                 filters = new FileFilter[]{new LogFileFilter()};
             }
         }
-        
-        JFileChooser fileChooser = new FileChooser(
+        ExecutionEnvironment execEnv = FileSystemProvider.getExecutionEnvironment(projectFileSystem);
+        JFileChooser fileChooser = RemoteFileUtil.createFileChooser(execEnv,
                 title,
                 getString("ROOT_DIR_BUTTON_TXT"), // NOI18N
                 chooserMode,
@@ -416,17 +439,17 @@ public class ProviderControl {
         if (path == null) {
             initComboBox(""); // NOI18N
         } else {
-            if (Utilities.isWindows()) {
-                path = path.replace('/', File.separatorChar);
+            if (CndFileUtils.isLocalFileSystem(projectFileSystem) && Utilities.isWindows()) {
+                path = path.replace('/', CndFileUtils.getFileSeparatorChar(projectFileSystem));
             }
             initComboBox(path);
         }
     }
     
-    private String getString(String key) {
-        return NbBundle.getMessage(ProviderControl.class, key);
+    private String getString(String key, String ... params) {
+        return NbBundle.getMessage(ProviderControl.class, key, params);
     }
-    
+
     private class LogFileFilter extends javax.swing.filechooser.FileFilter {
         public LogFileFilter() {
         }
@@ -440,7 +463,8 @@ public class ProviderControl {
                 if (f.isDirectory()) {
                     return true;
                 }
-                return f.getName().endsWith(".log"); // NOI18N
+                String name = f.getName();
+                return name.endsWith(".log") || name.endsWith(".json"); // NOI18N
             }
             return false;
         }
