@@ -46,7 +46,6 @@ package org.netbeans.modules.cnd.discovery.wizard;
 import java.awt.Component;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.io.File;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -63,14 +62,22 @@ import org.netbeans.modules.cnd.api.model.CsmListeners;
 import org.netbeans.modules.cnd.api.model.CsmModelAccessor;
 import org.netbeans.modules.cnd.api.model.CsmProgressListener;
 import org.netbeans.modules.cnd.api.model.CsmProject;
+import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.discovery.api.DiscoveryProvider;
 import org.netbeans.modules.cnd.discovery.api.DiscoveryProviderFactory;
 import org.netbeans.modules.cnd.discovery.api.ProjectProxy;
 import org.netbeans.modules.cnd.discovery.api.ProviderProperty;
+import org.netbeans.modules.cnd.discovery.api.ProviderPropertyType;
 import org.netbeans.modules.cnd.discovery.wizard.api.DiscoveryDescriptor;
+import org.netbeans.modules.cnd.utils.FSPath;
+import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.cnd.utils.ui.EditableComboBox;
-import org.netbeans.modules.cnd.utils.ui.FileChooser;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.remote.spi.FileSystemProvider;
 import org.openide.WizardDescriptor;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileStateInvalidException;
+import org.openide.filesystems.FileSystem;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
 import org.openide.util.Utilities;
@@ -253,7 +260,7 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
             ProviderItem provider = (ProviderItem)item;
             instructionsTextArea.setText(provider.getDescription());
             wizard.stateChanged(null);
-            if ("make-log".equals(provider.getID())) {// NOI18N
+            if (DiscoveryExtension.MAKE_LOG_PROVIDER.equals(provider.getID())) {
                 restrictCompile.setSelected(true);
             } else {
                 restrictCompile.setSelected(false);
@@ -266,12 +273,13 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
     }
     
     private void rootFolderButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_rootFolderButtonActionPerformed
-        JFileChooser fileChooser = new FileChooser(
+        FileObject projectDirectory = wizard.getWizardDescriptor().getProject().getProjectDirectory();
+        ExecutionEnvironment execEnv = FileSystemProvider.getExecutionEnvironment(projectDirectory);
+        JFileChooser fileChooser = RemoteFileUtil.createFileChooser(execEnv,
                 getString("ROOT_DIR_CHOOSER_TITLE_TXT"), // NOI18N
                 getString("ROOT_DIR_BUTTON_TXT"), // NOI18N
                 JFileChooser.DIRECTORIES_ONLY,
-                null,
-                getRootText(),
+                null, getRootText(),
                 false
                 );
         int ret = fileChooser.showOpenDialog(this);
@@ -360,8 +368,12 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
             prividersComboBox.setSelectedItem(def);
         }
         String path = wizardDescriptor.getRootFolder();
-        if (Utilities.isWindows()) {
-            path = path.replace('/', File.separatorChar);
+        try {
+            FileSystem fileSystem = wizard.getWizardDescriptor().getProject().getProjectDirectory().getFileSystem();
+            if (CndFileUtils.isLocalFileSystem(fileSystem) && Utilities.isWindows()) {
+                path = path.replace('/', CndFileUtils.getFileSeparatorChar(fileSystem));
+            }
+        } catch (FileStateInvalidException ex) {
         }
         Preferences preferences;
         if (USE_PROJECT_PROPERTIES) {
@@ -399,20 +411,20 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
         }
         ((EditableComboBox)rootFolder).setStorage(ROOT_PROPERTY_KEY, preferences);
         ((EditableComboBox)rootFolder).store();
-        ProviderProperty p = provider.getProvider().getProperty("restrict_source_root"); // NOI18N
+        ProviderProperty p = provider.getProvider().getProperty(ProviderPropertyType.RestrictSourceRootPropertyType.key());
         if (p != null) {
             if (restrictSources.isSelected()){
-                p.setValue(getRootText());
+                ProviderPropertyType.RestrictSourceRootPropertyType.setProperty(provider.getProvider(), getRootText());
             } else {
-                p.setValue(""); // NOI18N
+                ProviderPropertyType.RestrictSourceRootPropertyType.setProperty(provider.getProvider(), ""); // NOI18N
             }
         }
-        p = provider.getProvider().getProperty("restrict_compile_root"); // NOI18N
+        p = provider.getProvider().getProperty(ProviderPropertyType.RestrictCompileRootPropertyType.key()); // NOI18N
         if (p != null) {
             if (restrictCompile.isSelected()){
-                p.setValue(getRootText());
+                ProviderPropertyType.RestrictCompileRootPropertyType.setProperty(provider.getProvider(), getRootText());
             } else {
-                p.setValue(""); // NOI18N
+                ProviderPropertyType.RestrictCompileRootPropertyType.setProperty(provider.getProvider(), ""); // NOI18N
             }
         }
     }
@@ -421,14 +433,23 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
   	wizardDescriptor.setMessage(null);
         String path = getRootText();
         if (path == null){
+      	    wizardDescriptor.setMessage(getString("SelectModeRootFolderError", path)); // NOI18N
             return false;
         }
-        File file = new File(path);
-        if (!(file.exists() && file.isDirectory())) {
+        FSPath file;
+        try {
+            file = new FSPath(wizard.getWizardDescriptor().getProject().getProjectDirectory().getFileSystem(), path);
+        } catch (FileStateInvalidException ex) {
+      	    wizardDescriptor.setMessage(getString("SelectModeRootFolderError", path)); // NOI18N
+            return false;
+        }
+        FileObject fo = file.getFileObject();
+        if (fo == null || !fo.isValid() || !fo.isFolder()) {
+      	    wizardDescriptor.setMessage(getString("SelectModeRootFolderError", path)); // NOI18N
             return false;
         }
         ProviderItem provider = (ProviderItem)prividersComboBox.getSelectedItem();
-        if ("model-folder".equals(provider.getID())){ // NOI18N
+        if (DiscoveryExtension.MODEL_FOLDER_PROVIDER.equals(provider.getID())){ // NOI18N
             Project project = wizardDescriptor.getProject();
             if (project != null){
                 CsmProject langProject = CsmModelAccessor.getModel().getProject(project);
@@ -448,8 +469,8 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
     }
 
 
-    private String getString(String key) {
-        return NbBundle.getMessage(SelectProviderPanel.class, key);
+    private String getString(String key, String ... params) {
+        return NbBundle.getMessage(SelectProviderPanel.class, key, params);
     }
 
     @Override
@@ -495,6 +516,10 @@ public final class SelectProviderPanel extends JPanel implements CsmProgressList
     public void parserIdle() {
     }
 
+    @Override
+    public void fileRemoved(CsmFile file) {
+    }
+
     static class ProviderItem implements Comparable<ProviderItem> {
         private final DiscoveryProvider provider;
         ProviderItem(DiscoveryProvider provider){
