@@ -46,8 +46,8 @@ package org.netbeans.modules.cnd.dwarfdiscovery.provider;
 
 import java.io.BufferedReader;
 import java.io.File;
-import java.io.FileReader;
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
@@ -62,20 +62,27 @@ import java.util.StringTokenizer;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.modules.cnd.discovery.api.DiscoveryUtils;
-import org.netbeans.modules.cnd.discovery.api.DiscoveryUtils.Artifacts;
+import org.netbeans.modules.cnd.discovery.api.DriverFactory;
 import org.netbeans.modules.cnd.discovery.api.ItemProperties;
 import org.netbeans.modules.cnd.discovery.api.SourceFileProperties;
 import org.netbeans.modules.cnd.dwarfdiscovery.provider.BaseDwarfProvider.GrepEntry;
 import org.netbeans.modules.cnd.dwarfdump.CompilationUnit;
 import org.netbeans.modules.cnd.dwarfdump.CompilationUnitInterface;
+import org.netbeans.modules.cnd.dwarfdump.source.SourceFile;
 import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfMacinfoEntry;
 import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfMacinfoTable;
 import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfStatementList;
 import org.netbeans.modules.cnd.dwarfdump.dwarfconsts.MACINFO;
+import org.netbeans.modules.cnd.dwarfdump.section.FileEntry;
+import org.netbeans.modules.cnd.dwarfdump.source.Artifacts;
+import org.netbeans.modules.cnd.dwarfdump.source.CompileLineOrigin;
 import org.netbeans.modules.cnd.makeproject.api.configurations.ConfigurationDescriptorProvider;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
+import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.dlight.libs.common.PathUtilities;
 import org.netbeans.modules.nativeexecution.api.util.LinkSupport;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileSystem;
 import org.openide.util.Exceptions;
 import org.openide.util.Utilities;
 
@@ -92,24 +99,23 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     private static final String CYG_DRIVE_WIN = "\\cygdrive\\"; // NOI18N
     private static final String CYGWIN_PATH = ":/cygwin"; // NOI18N
     private String cygwinPath;
-    
+
     private String sourceName;
     private final ItemProperties.LanguageKind language;
-    private final ItemProperties.LanguageStandard standard;
+    private ItemProperties.LanguageStandard standard;
     private List<String> systemIncludes;
     private boolean haveSystemIncludes;
     private Map<String, String> userMacros;
     private List<String> undefinedMacros;
     private Map<String, String> systemMacros;
     private boolean haveSystemMacros;
-    private CompilerSettings normilizeProvider;
     private final Map<String,GrepEntry> grepBase;
     private String compilerName;
     private final CompileLineStorage storage;
     private int handler = -1;
     private final CompilerSettings compilerSettings;
     private String importantFlags;
-    
+
     DwarfSource(CompilationUnitInterface cu, ItemProperties.LanguageKind lang, ItemProperties.LanguageStandard standard, CompilerSettings compilerSettings, Map<String,GrepEntry> grepBase, CompileLineStorage storage) throws IOException{
         this(lang, standard, grepBase, storage, compilerSettings);
         initCompilerSettings(compilerSettings, lang);
@@ -131,7 +137,6 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         original.userIncludes = new ArrayList(derived.userIncludes);
         original.userFiles = new ArrayList(derived.userFiles);
         original.includedFiles = new HashSet(derived.includedFiles);
-        original.normilizeProvider = derived.normilizeProvider;
         original.sourceName = PathUtilities.getBaseName(originalFile);
         original.systemIncludes = new ArrayList(derived.systemIncludes);
         original.haveSystemIncludes = derived.haveSystemIncludes;
@@ -144,14 +149,14 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         original.importantFlags = derived.importantFlags;
         return original;
     }
-    
+
     private void countFileName(CompilationUnitInterface cu) throws IOException {
         fullName = cu.getSourceFileAbsolutePath();
         fullName = fixFileName(fullName);
         //File file = new File(fullName);
         fullName = compilerSettings.getNormalizedPath(fullName);
         fullName = linkSupport(fullName);
-        if (fullName != null && normilizeProvider.isWindows()) {
+        if (fullName != null && compilerSettings.isWindows() && compilerSettings.isLocalFileSystem()) {
             fullName = fullName.replace('/', '\\');
         }
         fullName = PathCache.getString(fullName);
@@ -180,20 +185,18 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
                        for(String path:list){
                            int i = path.toLowerCase().indexOf(CYGWIN_PATH);
                            if (i > 0) {
-                               if (cygwinPath == null) {
-                                   cygwinPath = "" + Character.toUpperCase(path.charAt(0)) + CYGWIN_PATH; // NOI18N
-                                   for(i = i + CYGWIN_PATH.length();i < path.length();i++){
-                                       char c = path.charAt(i);
-                                       if (c == '\\'){
-                                           break;
-                                       }
-                                       cygwinPath+=""+c;
-                                   }
-                                   if (DwarfSource.LOG.isLoggable(Level.FINE)) {
-                                       DwarfSource.LOG.log(Level.FINE, "Detect cygwinPath:{0}", cygwinPath); // NOI18N
-                                   }
-                                   break;
-                               }
+                                cygwinPath = "" + Character.toUpperCase(path.charAt(0)) + CYGWIN_PATH; // NOI18N
+                                for(i = i + CYGWIN_PATH.length();i < path.length();i++){
+                                    char c = path.charAt(i);
+                                    if (c == '\\'){
+                                        break;
+                                    }
+                                    cygwinPath+=""+c;
+                                }
+                                if (DwarfSource.LOG.isLoggable(Level.FINE)) {
+                                    DwarfSource.LOG.log(Level.FINE, "Detect cygwinPath:{0}", cygwinPath); // NOI18N
+                                }
+                                break;
                            }
                        }
                    }
@@ -210,9 +213,8 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             systemMacros = new HashMap<String,String>();
         }
         haveSystemMacros = systemMacros.size() > 0;
-        normilizeProvider = compilerSettings;
     }
-    
+
     @Override
     public String getCompilePath() {
         return compilePath;
@@ -225,7 +227,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         return null;
     }
-    
+
     @Override
     public String getItemPath() {
         return fullName;
@@ -235,7 +237,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     public String getItemName() {
         return sourceName;
     }
-    
+
     @Override
     public List<String> getUserInludePaths() {
         return userIncludes;
@@ -245,19 +247,19 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     public List<String> getUserInludeFiles() {
         return userFiles;
     }
-    
+
     @Override
     public List<String> getSystemInludePaths() {
         return systemIncludes;
     }
-    
+
     public Set<String> getIncludedFiles() {
         if (false && ConfigurationDescriptorProvider.VCS_WRITE) {
             return Collections.emptySet();
         }
         return includedFiles;
     }
-    
+
     @Override
     public Map<String, String> getUserMacros() {
         return userMacros;
@@ -267,12 +269,12 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     public List<String> getUndefinedMacros() {
         return undefinedMacros;
     }
-    
+
     @Override
     public Map<String, String> getSystemMacros() {
         return systemMacros;
     }
-    
+
     @Override
     public ItemProperties.LanguageKind getLanguageKind() {
         return language;
@@ -287,7 +289,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     public String getCompilerName() {
         return compilerName;
     }
-    
+
     @Override
     public String getImportantFlags() {
         return importantFlags;
@@ -297,7 +299,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         if (fileName == null){
             return fileName;
         }
-        if (normilizeProvider.isWindows()) {
+        if (compilerSettings.isWindows() && compilerSettings.isLocalFileSystem()) {
             //replace /cygdrive/<something> prefix with <something>:/ prefix:
             if (DwarfSource.LOG.isLoggable(Level.FINE)) {
                 DwarfSource.LOG.log(Level.FINE, "Try to fix win name:{0}", fileName); // NOI18N
@@ -347,9 +349,9 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         return fileName;
     }
-    
+
     private String linkSupport(String name){
-        if (normilizeProvider.isWindows()) {
+        if (compilerSettings.isWindows() &&  compilerSettings.isLocalFileSystem()) {
             if (!new File(name).exists()){
                 String link = name+".lnk"; // NOI18N
                 if (new File(link).exists()){
@@ -389,7 +391,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         return name;
     }
-    
+
 
     static String extractCompilerName(CompilationUnitInterface cui, ItemProperties.LanguageKind lang) throws IOException {
         String compilerName = null;
@@ -441,7 +443,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         compilerName = PathCache.getString(extractCompilerName(cu, lang));
         compilePath = PathCache.getString(fixFileName(cu.getCompilationDir()));
         sourceName = PathCache.getString(cu.getSourceFileName());
-        
+
         if (compilePath == null && sourceName.lastIndexOf('/')>0) {
             int i = sourceName.lastIndexOf('/');
             compilePath = sourceName.substring(0,i);
@@ -460,12 +462,12 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             }
         }
     }
-    
+
     public void process(CompilationUnitInterface cu) throws IOException{
         String line = cu.getCommandLine();
         if (line != null && line.length()>0){
             if (storage != null) {
-                List<String> args = DiscoveryUtils.scanCommandLine(line, DiscoveryUtils.LogOrigin.DwarfCompileLine);
+                List<String> args = compilerSettings.getDriver().splitCommandLine(line, CompileLineOrigin.DwarfCompileLine);
                 //List<String> args = ImportUtils.parseArgs(line);
                 StringBuilder buf = new StringBuilder();
                 for (int i = 0; i < args.size(); i++) {
@@ -503,7 +505,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
                     }
                     buf.append(s);
                 }
-                
+
                 handler = storage.putCompileLine(buf.toString());
             }
             gatherLine(line);
@@ -514,6 +516,29 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             if (cu instanceof CompilationUnit) {
                 gatherMacros((CompilationUnit)cu);
                 gatherIncludes((CompilationUnit)cu);
+                if (compilerName != null && compilerName.indexOf(" -") > 0) { // NOI18N
+                    // Since 4.7 GNU write flags in the producer attribute
+                    // Example:
+                    // #g++ main.cpp -o .object/debug/main.o -g3 -Wall -std=c++11 -c -I./.object/debug -DDEBUG   -I./include -I./   -O3  -ldl
+                    // DW_AT_producer [DW_FORM_string] GNU C++ 4.8.2 -mtune=generic -march=pentium4 -g3 -O3 -std=c++11
+                    // importantFlags = "-mtune=generic -march=pentium4 -O3 -std=c++11"
+                    if (language == LanguageKind.C) {
+                        Artifacts artifacts = compilerSettings.getDriver().gatherCompilerLine(compilerName, CompileLineOrigin.DwarfCompileLine, false);
+                        if (!artifacts.getImportantFlags().isEmpty()) {
+                            importantFlags = DriverFactory.importantFlagsToString(artifacts);
+                        }
+                    } else if (language == LanguageKind.CPP) {
+                        Artifacts artifacts = compilerSettings.getDriver().gatherCompilerLine(compilerName, CompileLineOrigin.DwarfCompileLine, true);
+                        if (!artifacts.getImportantFlags().isEmpty()) {
+                            importantFlags = DriverFactory.importantFlagsToString(artifacts);
+                        }
+                        standard = DriverFactory.getLanguageStandard(standard, artifacts);
+                    }
+                }
+            } else if (cu instanceof SourceFile) {
+                processPseudoDwarf((SourceFile) cu);
+            }
+            if (importantFlags == null || importantFlags.isEmpty()) {
                 switch(standard) {
                     case C89:
                         importantFlags = "-std=c89";// NOI18N
@@ -525,7 +550,76 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             }
         }
     }
-    
+
+    private void processPseudoDwarf(SourceFile sf) {
+        final String line = sf.getDwarfDump();
+        if (line == null || line.isEmpty()) {
+            return;
+        }
+        DwarfStatementList emulateDwarf = new DwarfStatementList(0);
+        List<String> dirs = emulateDwarf.getIncludeDirectories();
+        List<FileEntry> files = emulateDwarf.getFileEntries();
+        List<String> options = compilerSettings.getDriver().splitCommandLine(line, CompileLineOrigin.DwarfCompileLine);
+        for(String option : options) {
+            if (option.startsWith("-d")) { // NOI18N
+                //buf.append(" -d").append("'").append(dir).append("'"); // NOI18N
+                dirs.add(DiscoveryUtils.removeQuotes(option.substring(2)));
+            } else if (option.startsWith("-f:")) { // NOI18N
+                //buf.append(" -f:").append(""+fileEntry.dirIndex).append(":'").append(fileEntry.fileName).append("'"); // NOI18N
+                String s = option.substring(3);
+                int i = s.indexOf(':'); // NOI18N
+                if (i <= 0) {
+                    // broken format
+                    return;
+                }
+                int dirNumber = Integer.parseInt(s.substring(0,i));
+                String name = DiscoveryUtils.removeQuotes(s.substring(i+1));
+                files.add(new FileEntry(name, dirNumber, -1, -1));
+            } else if (option.startsWith("-include")) { // NOI18N
+                //buf.append(" -include").append("'").append(includedSource).append("'"); // NOI18N
+                String s = DiscoveryUtils.removeQuotes(option.substring(8));
+                undefinedMacros.add(PathCache.getString(s));
+            } else if (option.startsWith("-D")) { // NOI18N
+                //buf.append(" -D").append(def.substring(0,i)).append("='").append(def.substring(i+1).trim()).append("'"); // NOI18N
+                String s = option.substring(2);
+                int i = s.indexOf('='); // NOI18N
+                String name;
+                String value;
+                if (i >= 0) {
+                    name = s.substring(0,i);
+                    value = DiscoveryUtils.removeQuotes(s.substring(i+1));
+                } else {
+                    name = s;
+                    value = null;
+                }
+                if (haveSystemMacros && systemMacros.containsKey(name)){
+                    String sysValue = systemMacros.get(name);
+                    if (equalValues(sysValue, value)) {
+                        continue;
+                    }
+                }
+                userMacros.put(PathCache.getString(name), PathCache.getString(value));
+            } else if (option.startsWith("-U")) { // NOI18N
+                //buf.append(" -D").append(def.substring(0,i)); // NOI18N
+                String s = option.substring(2);
+                undefinedMacros.add(PathCache.getString(s));
+            }
+        }
+        for (Iterator<String> it = emulateDwarf.getIncludeDirectories().iterator(); it.hasNext();) {
+            addpath(it.next());
+        }
+        List<String> list = grepSourceFile(fullName).includes;
+        for(String path : list){
+            cutFolderPrefix(path, emulateDwarf);
+        }
+        for(String path : emulateDwarf.getFilePaths()){
+            processPath(path, emulateDwarf, true);
+        }
+        if (DwarfSource.LOG.isLoggable(Level.FINE)) {
+            DwarfSource.LOG.log(Level.FINE, "Include paths:{0}", userIncludes); // NOI18N
+        }
+    }
+
     private void addUserIncludePath(String path){
         if (!userIncludes.contains(path)) {
             userIncludes.add(path);
@@ -537,22 +631,22 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         if (DwarfSource.LOG.isLoggable(Level.FINE)) {
             DwarfSource.LOG.log(Level.FINE, "Process command line {0}", line); // NOI18N
         }
-        Artifacts artifacts = new Artifacts();
-        DiscoveryUtils.gatherCompilerLine(line, DiscoveryUtils.LogOrigin.DwarfCompileLine, artifacts, compilerSettings.getProjectBridge(), this.language == LanguageKind.CPP);
-        for(String s : artifacts.userIncludes) {
+        Artifacts artifacts = compilerSettings.getDriver().gatherCompilerLine(line, CompileLineOrigin.DwarfCompileLine, this.language == LanguageKind.CPP);
+        for(String s : artifacts.getUserIncludes()) {
             String include = PathCache.getString(s);
             addUserIncludePath(include);
         }
-        userFiles.addAll(artifacts.userFiles);
-        for(String s : artifacts.undefinedMacros) {
+        userFiles.addAll(artifacts.getUserFiles());
+        for(String s : artifacts.getUserUndefinedMacros()) {
             undefinedMacros.add(PathCache.getString(s));
         }
-        for(Map.Entry<String, String> entry : artifacts.userMacros.entrySet()) {
+        for(Map.Entry<String, String> entry : artifacts.getUserMacros().entrySet()) {
             userMacros.put(PathCache.getString(entry.getKey()), entry.getValue());
         }
-        importantFlags = artifacts.getImportantFlags();
+        importantFlags = DriverFactory.importantFlagsToString(artifacts);
+        standard = DriverFactory.getLanguageStandard(standard, artifacts);
     }
-    
+
     private String fixCygwinPath(String path){
         if (cygwinPath != null) {
             if (path.startsWith("/usr/lib/")){// NOI18N
@@ -564,12 +658,12 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         if (path.startsWith(CYG_DRIVE_UNIX)){
             path = fixFileName(path);
         }
-        if (normilizeProvider.isWindows()) {
+        if (compilerSettings.isWindows()) {
             path = path.replace('\\', '/');
         }
         return path;
     }
-    
+
     private boolean isSystemPath(String path){
         path = fixCygwinPath(path);
         path = normalizePath(path);
@@ -599,7 +693,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         return false;
     }
-    
+
     private void addpath(String path){
         if (haveSystemIncludes) {
             if (!isSystemPath(path)){
@@ -631,16 +725,15 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             }
         }
     }
-    
+
     private String normalizePath(String path){
         if (path.startsWith("/") || // NOI18N
                 path.length()>2 && path.charAt(1)==':') {
-            return normilizeProvider.getNormalizedPath(path);
+            return compilerSettings.getNormalizedPath(path);
         }
         return path;
     }
-    
-    
+
     private void gatherIncludes(final CompilationUnit cu) throws IOException {
         if (!ourGatherIncludes) {
             return;
@@ -666,27 +759,26 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             for(int i : commandLineIncludedFiles) {
                 String includedSource = processPath(dwarfTable.getFilePath(i));
                 if (!fullName.replace('\\', '/').equals(includedSource)) {
-                    processPath(dwarfTable.getFilePath(i), list, dwarfTable, false);
+                    processPath(dwarfTable.getFilePath(i), dwarfTable, false);
                 }
             }
         }
         for(String path : dwarfIncludedFiles){
-            processPath(path, list, dwarfTable, true);
+            processPath(path, dwarfTable, true);
         }
         if (DwarfSource.LOG.isLoggable(Level.FINE)) {
             DwarfSource.LOG.log(Level.FINE, "Include paths:{0}", userIncludes); // NOI18N
         }
     }
 
-    private void processPath(String path, List<String> list, DwarfStatementList dwarfTable, boolean isPath) {
+    private void processPath(String path, DwarfStatementList dwarfTable, boolean isPath) {
         String includeFullName = processPath(path);
         if (isPath) {
             int i = includeFullName.lastIndexOf('/'); // NOI18N
             if (i > 0) {
                 String userPath = includeFullName.substring(0, i);
                 if (!isSystemPath(userPath)) {
-                    list = grepSourceFile(includeFullName).includes;
-                    for (String included : list) {
+                    for (String included : grepSourceFile(includeFullName).includes) {
                         cutFolderPrefix(included, dwarfTable);
                     }
                     addpath(userPath);
@@ -710,13 +802,13 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         if (path.startsWith("./")) { // NOI18N
             includeFullName = compilePath + path.substring(1);
         } else if (path.startsWith("../")) { // NOI18N
-            includeFullName = compilePath + File.separator + path;
+            includeFullName = compilePath + "/" + path; // NOI18N
         } else if (!(path.startsWith("/") || path.length()>2 && path.charAt(1)==':')) { // NOI18N
-            includeFullName = compilePath + File.separator + path;
+            includeFullName = compilePath + "/" + path; // NOI18N
         } else {
             includeFullName = fixCygwinPath(path);
         }
-        if (normilizeProvider.isWindows()) {
+        if (compilerSettings.isWindows()) {
             includeFullName = includeFullName.replace('\\', '/'); // NOI18N
         }
         includeFullName = normalizePath(includeFullName);
@@ -724,7 +816,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
     }
 
     private void cutFolderPrefix(String path, final DwarfStatementList dwarfTable) {
-        if (normilizeProvider.isWindows()) {
+        if (compilerSettings.isWindows()) {
             path = path.replace('\\', '/'); // NOI18N
         }
         if (path.indexOf('/')>0){ // NOI18N
@@ -780,7 +872,7 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             }
         }
     }
-    
+
     private void gatherIncludedFiles(final CompilationUnit cu) throws IOException {
         if (!ourGatherIncludes) {
             return;
@@ -794,13 +886,13 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
             if (path.startsWith("./")) { // NOI18N
                 includeFullName = compilePath+path.substring(1);
             } else if (path.startsWith("../")) { // NOI18N
-                includeFullName = compilePath+File.separator+path;
+                includeFullName = compilePath + "/" + path; // NOI18N
             }
             includeFullName = normalizePath(includeFullName);
             includedFiles.add(PathCache.getString(includeFullName));
         }
     }
-    
+
     private void gatherMacros(final CompilationUnit cu) throws IOException {
         if (!ourGatherMacros){
             return;
@@ -841,6 +933,11 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
                     }
                 }
                 userMacros.put(macro,value);
+            } else if ((entry.type == MACINFO.DW_MACINFO_undef ||
+                 entry.type == MACINFO.DW_MACRO_undef_indirect) &&
+                 entry.definition != null) {
+                String def = PathCache.getString(entry.definition);
+                undefinedMacros.add(def);
             }
         }
         if (DwarfSource.LOG.isLoggable(Level.FINE)) {
@@ -857,22 +954,23 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         return value.equals(sysValue); // NOI18N
     }
-  
+
     private GrepEntry grepSystemFolder(String path) {
         GrepEntry res = grepBase.get(path);
         if (res != null) {
             return res;
         }
+        FileSystem fs = compilerSettings.getFileSystem();
         res = new GrepEntry();
-        File folder = new File(path);
-        if (folder.exists() && folder.canRead() && folder.isDirectory()) {
-            File[] ff = folder.listFiles();
+        FileObject folder = fs.findResource(path);
+        if (folder != null && folder.isValid() && folder.canRead() && folder.isFolder()) {
+            FileObject[] ff = folder.getChildren();
             if (ff != null) {
-                for(File f: ff){
-                    if (f.exists() && f.canRead() && !f.isDirectory()){
-                        List<String> l = grepSourceFile(f.getAbsolutePath()).includes;
+                for(FileObject f: ff){
+                    if (f != null && f.isValid() && f.canRead() && f.isData()){
+                        List<String> l = grepSourceFile(f.getPath()).includes;
                         for (String i : l){
-                            if (i.indexOf("..")>0 || i.startsWith("/") || i.indexOf(":")>0) { // NOI18N
+                            if (i.indexOf("..")>0 || i.startsWith("/") || i.indexOf(':')>0) { // NOI18N
                                 continue;
                             }
                             if (i.indexOf('/')>0){ // NOI18N
@@ -890,15 +988,18 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         }
         List<String> secondLevel = new ArrayList<String>();
         for(String sub : res.includes) {
-            File subFolder = new File(path+sub);
-            try {
-                if (subFolder.getCanonicalFile().getAbsolutePath().startsWith(path + sub)) {
-                    for (String s : grepSystemFolder(path + sub).includes) {
-                        secondLevel.add(s);
+            FileObject subFolder = fs.findResource(path+sub);
+            if (subFolder != null && subFolder.isValid() && subFolder.canRead() && subFolder.isFolder()) {
+                try {
+                    String canonicalPath = CndFileUtils.getCanonicalPath(subFolder);
+                    if (canonicalPath != null && canonicalPath.startsWith(path + sub)) {
+                        for (String s : grepSystemFolder(path + sub).includes) {
+                            secondLevel.add(s);
+                        }
                     }
+                } catch (IOException ex) {
+                    Exceptions.printStackTrace(ex);
                 }
-            } catch (IOException ex) {
-                Exceptions.printStackTrace(ex);
             }
         }
         for(String s: secondLevel){
@@ -909,17 +1010,41 @@ public class DwarfSource extends RelocatableImpl implements SourceFileProperties
         grepBase.put(PathCache.getString(path), res);
         return res;
     }
-    
+
     private GrepEntry grepSourceFile(String fileName){
+        FileSystem fs = compilerSettings.getFileSystem();
         GrepEntry res = grepBase.get(fileName);
         if (res != null) {
             return res;
         }
         res = new GrepEntry();
-        File file = new File(fileName);
-        if (file.exists() && file.canRead() && !file.isDirectory()){
+        String dirName = CndPathUtilities.getDirName(fileName);
+        if (dirName != null) {
+            GrepEntry dirInfo = grepBase.get(dirName);
+            if (dirInfo != null && !dirInfo.exists) {
+                grepBase.put(fileName,res);
+                return res;
+            }
+        }
+        FileObject file = fs.findResource(fileName);
+        if (file == null || !file.isValid()) {
+            if (dirName != null) {
+                FileObject dir = fs.findResource(dirName);
+                if (dir != null && dir.isValid()) {
+                    GrepEntry dirInfo = new GrepEntry();
+                    dirInfo.exists = true;
+                    grepBase.put(dirName, dirInfo);
+                } else {
+                    GrepEntry dirInfo = new GrepEntry();
+                    dirInfo.exists = false;
+                    grepBase.put(dirName, dirInfo);
+                }
+            }
+        }
+        if (file != null && file.isValid() && file.canRead() && file.isData()){
+            res.exists = true;
             try {
-                BufferedReader in = new BufferedReader(new FileReader(file));
+                BufferedReader in = new BufferedReader(new InputStreamReader(file.getInputStream()));
                 int lineNo = 0;
                 int size;
                 String line;
