@@ -60,7 +60,7 @@ import org.netbeans.modules.cnd.discovery.api.ProjectProxy;
 import org.netbeans.modules.cnd.dwarfdiscovery.provider.BaseDwarfProvider.GrepEntry;
 import org.netbeans.modules.cnd.dwarfdump.CompilationUnitInterface;
 import org.netbeans.modules.cnd.dwarfdump.CompileLineService;
-import org.netbeans.modules.cnd.dwarfdump.CompileLineService.SourceFile;
+import org.netbeans.modules.cnd.dwarfdump.source.SourceFile;
 import org.netbeans.modules.cnd.dwarfdump.Dwarf;
 import org.netbeans.modules.cnd.dwarfdump.Dwarf.CompilationUnitIterator;
 import org.netbeans.modules.cnd.dwarfdump.exception.WrongFileFormatException;
@@ -396,21 +396,21 @@ public class DwarfSourceReaderTest extends NbTestCase {
         assertTrue(source.getUserInludePaths().size()==1);
         assertEquals(source.getUserInludePaths().get(0), "/export1/sside/pomona/java_cp/wsb131/proto/root_i386/usr/include");
         printInclidePaths(source);
-        List<SourceFile> list = CompileLineService.getSourceFileProperties(getDataDir().getAbsolutePath()+"/org/netbeans/modules/cnd/dwarfdiscovery/provider/echo");
+        List<SourceFile> list = CompileLineService.getSourceFileProperties(getDataDir().getAbsolutePath()+"/org/netbeans/modules/cnd/dwarfdiscovery/provider/echo", false);
         assertEquals(1, list.size());
         SourceFile sf = list.get(0);
-        assertEquals(sf.getCompileDir(), "/export1/sside/pomona/java_cp/wsb131/usr/src/cmd/echo");
-        assertEquals(sf.getSource(), "echo.c");
+        assertEquals(sf.getCompilationDir(), "/export1/sside/pomona/java_cp/wsb131/usr/src/cmd/echo");
+        assertEquals(sf.getSourceFileName(), "echo.c");
 //      /export/opt/sunstudio/12ml/SUNWspro/prod/bin/cc -O -xspace -Xa -xildoff -errtags=yes -errwarn=%all -erroff=E_EMPTY_TRANSLATION_UNIT -erroff=E_STATEMENT_NOT_REACHED -xc99=%none -W0,-xglobalstatic -v -D_iBCS2 -DTEXT_DOMAIN='"SUNW_OST_OSCMD"' -D_TS_ERRNO -I/export1/sside/pomona/java_cp/wsb131/proto/root_i386/usr/include -Bdirect -M/export1/sside/pomona/java_cp/wsb131/usr/src/common/mapfiles/common/map.noexstk -M/export1/sside/pomona/java_cp/wsb131/usr/src/common/mapfiles/i386/map.pagealign -M/export1/sside/pomona/java_cp/wsb131/usr/src/common/mapfiles/i386/map.noexdata -L/export1/sside/pomona/java_cp/wsb131/proto/root_i386/lib -L/export1/sside/pomona/java_cp/wsb131/proto/root_i386/usr/lib -c  echo.c
         //System.err.println(sf.getCompileLine());
         map = new TreeMap<String, String>(sf.getUserMacros());
         assertTrue(compareMap(map, golden));
         assertEquals(sf.getUserPaths().get(0), "/export1/sside/pomona/java_cp/wsb131/proto/root_i386/usr/include");
-        list = CompileLineService.getSourceFolderProperties(getDataDir().getAbsolutePath());
+        list = CompileLineService.getSourceFolderProperties(getDataDir().getAbsolutePath(), false);
         //assertEquals(8, list.size());
         int i = 0;
         for(SourceFile file : list){
-            if (!file.getCompileLine().isEmpty()) {
+            if (!file.getCommandLine().isEmpty()) {
                 i++;
             }
         }
