@@ -130,7 +130,12 @@ public class Dwarf {
     }
 
     public SharedLibraries readPubNames() throws IOException {
-	return dwarfReader.readPubNames();
+        if (dwarfReader != null) {
+            return dwarfReader.readPubNames();
+        } else {
+            // archive does not have PubNames
+            return new SharedLibraries();
+        }
     }
     
     public String getFileName() {
@@ -447,7 +452,7 @@ public class Dwarf {
         CompilationUnitInterface next() throws IOException;
     }
     
-    private class JoinIterator implements  CompilationUnitIterator {
+    private static class JoinIterator implements  CompilationUnitIterator {
 
         private final CompilationUnitIterator[] delegates;
         private int curr;
