@@ -231,9 +231,11 @@ final class CppFoldManager extends CppFoldManagerBase
             }
             return null;
         }
-
-        CppFile cpf = CppMetaModel.getDefault().
-                get(doc.getProperty(Document.TitleProperty).toString());
+        Object titleProperty = doc.getProperty(Document.TitleProperty);
+        if (titleProperty == null) {
+            return null;
+        }
+        CppFile cpf = CppMetaModel.getDefault().get(titleProperty.toString());
         if (cpf == null) {
             return null;
         }
@@ -382,8 +384,8 @@ final class CppFoldManager extends CppFoldManagerBase
                 if (prefs != null) {
                     foldInitialCommentsPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_INITIAL_COMMENT, false);
                     foldIncludesPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_IMPORT, false);
-                    foldCodeBlocksPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_METHOD, false);
-                    foldCommentPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_JAVADOC, false);
+                    foldCodeBlocksPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_CODE_BLOCK, false);
+                    foldCommentPreset = prefs.getBoolean(CODE_FOLDING_COLLAPSE_COMMENT, false);
                 }
             }
         }
@@ -553,6 +555,7 @@ final class CppFoldManager extends CppFoldManagerBase
                 case CppFoldRecord.CONSTRUCTOR_FOLD:
                 case CppFoldRecord.DESTRUCTOR_FOLD:
                 case CppFoldRecord.CLASS_FOLD:
+                case CppFoldRecord.COMPOUND_BLOCK_FOLD:
                 case CppFoldRecord.NAMESPACE_FOLD:
                     template = CODE_BLOCK_FOLD_TEMPLATE;
                     collapse = foldCodeBlocksPreset;
@@ -655,7 +658,7 @@ final class CppFoldManager extends CppFoldManagerBase
 
     private static final class WeakParsingListener implements ParsingListener {
 
-        private WeakReference<ParsingListener> ref;
+        private final WeakReference<ParsingListener> ref;
 
         WeakParsingListener(ParsingListener listener) {
             ref = new WeakReference<ParsingListener>(listener);
