@@ -97,6 +97,7 @@ import org.netbeans.modules.cnd.makeproject.api.configurations.ConfigurationDesc
 import org.netbeans.modules.cnd.makeproject.api.configurations.DevelopmentHostConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.Folder;
 import org.netbeans.modules.cnd.makeproject.api.configurations.Folder.FileObjectNameMatcher;
+import org.netbeans.modules.cnd.makeproject.api.configurations.Item;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfigurationDescriptor;
 import org.netbeans.modules.cnd.makeproject.api.support.MakeProjectEvent;
@@ -142,7 +143,6 @@ import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.URLMapper;
-import org.openide.loaders.DataLoaderPool;
 import org.openide.modules.Places;
 import org.openide.util.Cancellable;
 import org.openide.util.Exceptions;
@@ -222,7 +222,7 @@ public final class MakeProject implements Project, MakeProjectListener {
 
         synchronized(MakeProject.class) {
             if (templateListener == null) {
-                DataLoaderPool.getDefault().addOperationListener(templateListener = new MakeTemplateListener());
+                templateListener = MakeTemplateListener.createInstance();
             }
         }
         LOGGER.log(Level.FINE, "End of creation MakeProject@{0} {1}", new Object[]{System.identityHashCode(MakeProject.this), helper.getProjectDirectory()}); // NOI18N
@@ -275,6 +275,7 @@ public final class MakeProject implements Project, MakeProjectListener {
         Info info = new Info(this);
         MakeProjectConfigurationProvider makeProjectConfigurationProvider = new MakeProjectConfigurationProvider(this, projectDescriptorProvider, info);
         final RemoteProjectImpl remoteProject = new RemoteProjectImpl(this);
+        final MakeProjectEncodingQueryImpl encodingQuery = new MakeProjectEncodingQueryImpl(this);
         Object[] lookups = new Object[] {
                     info,
                     aux,
@@ -294,11 +295,13 @@ public final class MakeProject implements Project, MakeProjectListener {
                     new MakeProjectOperations(this),
                     new MakeProjectSearchInfo(projectDescriptorProvider),
                     kind,
-                    new MakeProjectEncodingQueryImpl(this), remoteProject,
+                    encodingQuery,
+                    remoteProject,
                     new ToolchainProjectImpl(this),
                     new CacheDirectoryProviderImpl(helper.getProjectDirectory()),
                     BrokenReferencesSupport.createPlatformVersionProblemProvider(this, helper, projectDescriptorProvider, makeProjectConfigurationProvider),
                     new CndDocumentCodeStyleProviderImpl(),
+                    new TemplateAttributesProviderImpl(this, encodingQuery),
                     this
                 };
         
@@ -369,6 +372,33 @@ public final class MakeProject implements Project, MakeProjectListener {
         return (T[]) newLookups.toArray();
     }
 
+    public Properties getProjectProperties(boolean shared) {
+        Properties props = new Properties();
+        FileObject propsFO;
+        if (shared) {
+            propsFO = helper.getProjectDirectory().getFileObject(MakeProjectHelper.PROJECT_PROPERTIES_PATH);
+        } else {
+            propsFO = helper.getProjectDirectory().getFileObject(MakeProjectHelper.PRIVATE_PROPERTIES_PATH);
+        }
+        if (propsFO != null && propsFO.isValid()) {
+            InputStream is = null;
+            try {
+                is = propsFO.getInputStream();
+                props.load(is);
+            } catch (IOException ex) {
+                ex.printStackTrace(System.err);
+            } finally {
+                if (is != null) {
+                    try {
+                        is.close();
+                    } catch (IOException ex) {
+                    }
+                }
+            }
+        }
+        return props;
+    }
+
     /**
      * Tries getting cache path from project.properties -
      * first private, then public
@@ -918,7 +948,7 @@ public final class MakeProject implements Project, MakeProjectListener {
             if (typeNode != null) {
                 String type = typeNode.getNodeValue();
                 try {
-                    return new Integer(type);
+                    return Integer.parseInt(type);
                 } catch (NumberFormatException nfe) {
                 }
             }
@@ -935,7 +965,10 @@ public final class MakeProject implements Project, MakeProjectListener {
         if (nodeList != null && nodeList.getLength() > 0) {
             for (int i = 0; i < nodeList.getLength(); i++) {
                 Node node = nodeList.item(i);
-                return new Integer(node.getTextContent());
+                try {
+                    return Integer.parseInt(node.getTextContent());
+                } catch (NumberFormatException nfe) {
+                }
             }
         }
         return -1;
@@ -952,7 +985,10 @@ public final class MakeProject implements Project, MakeProjectListener {
         if (nodeList != null && nodeList.getLength() > 0) {
             for (int i = 0; i < nodeList.getLength(); i++) {
                 Node node = nodeList.item(i);
-                return new Integer(node.getTextContent());
+                try {
+                    return Integer.parseInt(node.getTextContent());
+                } catch (NumberFormatException nfe) {
+                }
             }
         }
 
@@ -1645,6 +1681,14 @@ public final class MakeProject implements Project, MakeProjectListener {
                     Folder rootFolder = configurationDescriptor.getLogicalFolders();
                     Set<FileObject> res = rootFolder.getAllItemsAsFileObjectSet(false, matcher);
                     FileObject baseDirFileObject = projectDescriptorProvider.getConfigurationDescriptor().getBaseDirFileObject();
+
+                    final Item[] projectItems = projectDescriptorProvider.getConfigurationDescriptor().getProjectItems();
+                    for(Item item : projectItems) {
+                        FileObject fo = item.getFileObject();
+                        if (fo != null && (matcher == null || matcher.pathMatches(fo))) {
+                            res.add(fo);
+                        }
+                    }
                     addFolder(res, baseDirFileObject.getFileObject(MakeConfiguration.NBPROJECT_FOLDER), matcher);
                     addFolder(res, baseDirFileObject.getFileObject(MakeConfiguration.NBPROJECT_PRIVATE_FOLDER), matcher);
                     return res.iterator();
