@@ -516,7 +516,7 @@ public class MakeProjectFileProviderFactory implements FileProviderFactory {
         @Override
         public final String getProjectName() {
             MakeProject.InfoInterface info = (MakeProject.InfoInterface) project.getLookup().lookup(ProjectInformation.class);
-            return info.getName();
+            return info.getDisplayName();
         }   
         
         @Override
