@@ -62,7 +62,9 @@ import org.netbeans.api.extexecution.print.LineConvertor;
 import org.netbeans.api.project.Project;
 import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.api.remote.ServerList;
+import org.netbeans.modules.cnd.api.toolchain.CompilerFlavor;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
+import org.netbeans.modules.cnd.api.toolchain.CompilerSetUtils;
 import org.netbeans.modules.cnd.api.toolchain.PredefinedToolKind;
 import org.netbeans.modules.cnd.api.utils.PlatformInfo;
 import org.netbeans.modules.cnd.makeproject.MakeProject;
@@ -72,6 +74,7 @@ import org.netbeans.modules.cnd.makeproject.api.ProjectActionEvent.Type;
 import org.netbeans.modules.cnd.makeproject.api.configurations.CompileConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.runprofiles.RunProfile;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport;
 import org.netbeans.modules.cnd.makeproject.configurations.CppUtils;
 import org.netbeans.modules.cnd.spi.toolchain.CompilerLineConvertor;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
@@ -161,6 +164,7 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
         final Type actionType = pae.getType();
 
         if (actionType != ProjectActionEvent.PredefinedType.RUN
+                && actionType != ProjectActionEvent.PredefinedType.PRE_BUILD
                 && actionType != ProjectActionEvent.PredefinedType.BUILD
                 && actionType != ProjectActionEvent.PredefinedType.COMPILE_SINGLE
                 && actionType != ProjectActionEvent.PredefinedType.CLEAN
@@ -168,14 +172,14 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
                 && actionType != ProjectActionEvent.PredefinedType.TEST) {
             assert false;
         }
-
+        
         final String origRunDir = pae.getProfile().getRunDir();
         boolean preventRunPathConvertion = origRunDir.startsWith("///"); // NOI18N
         final String runDirectory = RemoteFileUtil.normalizeAbsolutePath(pae.getProfile().getRunDirectory(), pae.getProject());
         final MakeConfiguration conf = pae.getConfiguration();
         final PlatformInfo pi = conf.getPlatformInfo();
         final ExecutionEnvironment execEnv = conf.getDevelopmentHost().getExecutionEnvironment();
-
+        
         Map<String, String> env = pae.getProfile().getEnvironment().getenvAsMap();
         boolean showInput = actionType == ProjectActionEvent.PredefinedType.RUN;
         boolean unbuffer = false;
@@ -184,7 +188,7 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
         boolean statusEx = false;
         String commandLine = null;
         CompilerSet cs;
-
+        
         int consoleType = pae.getProfile().getConsoleType().getValue();
         ArrayList<String> args = null;
         // Used if not RUN. Also in case of QMake args are tweaked...
@@ -227,7 +231,7 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             cs = conf.getCompilerSet().getCompilerSet();
             if (cs != null) {
                 String csdirs = cs.getDirectory();
-                String commands = cs.getCompilerFlavor().getCommandFolder(conf.getDevelopmentHost().getBuildPlatform());
+                String commands = CompilerSetUtils.getCommandFolder(cs);
                 if (commands != null && commands.length() > 0) {
                     // Also add msys to path. Thet's where sh, mkdir, ... are.
                     csdirs = csdirs + pi.pathSeparator() + commands;
@@ -246,7 +250,7 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             // Build or Clean
             cs = conf.getCompilerSet().getCompilerSet();
             String csdirs = cs.getDirectory();
-            String commands = cs.getCompilerFlavor().getCommandFolder(conf.getDevelopmentHost().getBuildPlatform());
+            String commands = CompilerSetUtils.getCommandFolder(cs);
             if (commands != null && commands.length() > 0) {
                 // Also add msys to path. Thet's where sh, mkdir, ... are.
                 csdirs = csdirs + pi.pathSeparator() + commands;
@@ -257,6 +261,10 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             } else {
                 path = csdirs + pi.pathSeparator() + path;
             }
+            String baseMinGW = CompilerSetUtils.getMinGWBaseFolder(cs);
+            if (baseMinGW != null) {
+                path = path + pi.pathSeparator() + baseMinGW;
+            }
             env.put(pi.getPathName(), path);
             // Pass QMAKE from compiler set to the Makefile (IZ 174731)
             if (conf.isQmakeConfiguration()) {
@@ -270,9 +278,9 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             }
 
             // See bug #228730
-            if (conf.getDevelopmentHost().isLocalhost() && Utilities.isWindows()
-                    && cs.getCompilerFlavor().isMinGWCompiler()
-                    && pae.getExecutable().contains("make")) { // NOI18N
+            if (conf.getDevelopmentHost().isLocalhost() && Utilities.isWindows() 
+                    && pae.getExecutable().contains("make") // NOI18N
+                    && CompilerSetUtils.isMsysBased(cs)) {
                 env.put("MAKE", WindowsSupport.getInstance().convertToMSysPath(pae.getExecutable())); // NOI18N
             }
         }
@@ -284,19 +292,19 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             actionType == ProjectActionEvent.PredefinedType.BUILD_TESTS) {
             converter = new CompilerLineConvertor(
                     pae.getProject(), conf.getCompilerSet().getCompilerSet(),
-                    execEnv, RemoteFileUtil.getFileObject(runDirectory, pae.getProject()));
+                    execEnv, RemoteFileUtil.getFileObject(runDirectory, pae.getProject()), io);
         }
 
         // TODO: this is actual only for sun studio compiler
         env.put("SPRO_EXPAND_ERRORS", ""); // NOI18N
-
+        
         String workingDirectory = preventRunPathConvertion ? runDirectory : ProjectSupport.convertWorkingDirToRemoteIfNeeded(pae, runDirectory);
-
+        
         if (workingDirectory == null) {
             // TODO: fix me
             // return null;
         }
-
+        
         WriterRedirector writer = null;
         if (outputHandlers != null && outputHandlers.size() > 0) {
             writer = new WriterRedirector(outputHandlers);
@@ -315,10 +323,25 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             buf.append(commandLine);
             npb.setCommandLine(commandLine);
         } else {
-            String exe = pae.getExecutable();
+            String exe = getExecutable(cs);
+            
             if (args == null) {
                 args = pae.getArguments();
             }
+            if (actionType == ProjectActionEvent.PredefinedType.PRE_BUILD) {
+                ArrayList<String> expandedArgs = new ArrayList<>();
+                if (isCygwinCompilerSet(cs)) {
+                    for(String s :args) {
+                        expandedArgs.add(PreBuildSupport.expandMacrosCygwin(s, cs));
+                    }
+                } else {
+                    for(String s :args) {
+                        expandedArgs.add(PreBuildSupport.expandMacros(s, cs));
+                    }
+                }
+                args = expandedArgs;
+            }
+
             npb.setExecutable(exe).setArguments(args.toArray(new String[args.size()]));
             buf.append(exe);
             for(String a : args) {
@@ -327,7 +350,8 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             }
         }
         
-        if (actionType == ProjectActionEvent.PredefinedType.BUILD ||
+        if (actionType == ProjectActionEvent.PredefinedType.PRE_BUILD ||
+            actionType == ProjectActionEvent.PredefinedType.BUILD ||
             actionType == ProjectActionEvent.PredefinedType.BUILD_TESTS) {
             npb.redirectError();
         }
@@ -372,7 +396,8 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
                 outConvertorFactory(processChangeListener).
                 keepInputOutputOnFinish();
 
-        if (actionType == PredefinedType.BUILD ||
+        if (actionType == PredefinedType.PRE_BUILD ||
+            actionType == PredefinedType.BUILD ||
             actionType == PredefinedType.COMPILE_SINGLE ||
             actionType == PredefinedType.CLEAN) {
             descr.noReset(true);
@@ -388,7 +413,12 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
             }
         }
         
-        if (actionType == PredefinedType.COMPILE_SINGLE) {
+        if (actionType == PredefinedType.PRE_BUILD ||
+            actionType == PredefinedType.COMPILE_SINGLE ||
+            actionType == PredefinedType.BUILD ||
+            actionType == PredefinedType.CLEAN) {
+            // CR 19816163
+            io.getOut().println("cd '"+workingDirectory+"'"); //NOI18N
             io.getOut().println(buf.toString());
         }
 
@@ -399,6 +429,15 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
 
         executorTask = es.run();
     }
+    
+    private String getExecutable(CompilerSet cs) {
+        if (pae.getExecutable().contains("cmake")) { // NOI18N
+            if (isCygwinCompilerSet(cs)) {
+                return PreBuildSupport.getCmakePath(cs);
+            }
+        }
+        return pae.getExecutable();
+    }
 
     @Override
     public void addExecutionListener(ExecutionListener l) {
@@ -439,7 +478,13 @@ public class DefaultProjectActionHandler implements ProjectActionHandler {
     protected static String getString(String key, String... a1) {
         return NbBundle.getMessage(DefaultProjectActionHandler.class, key, a1);
     }
-
+    
+    private static boolean isCygwinCompilerSet(CompilerSet compilerSet) {
+        CompilerFlavor flavor = compilerSet.getCompilerFlavor();
+        if (flavor.isCygwinCompiler()) return true;
+        else return false;
+    }
+    
     private static final class ProcessChangeListener implements ChangeListener, Runnable, LineConvertorFactory {
 
         private final AtomicReference<NativeProcess> processRef = new AtomicReference<>();
