@@ -78,6 +78,7 @@ import org.netbeans.modules.cnd.makeproject.api.runprofiles.Env;
 import org.netbeans.modules.cnd.makeproject.api.runprofiles.RunProfile;
 import org.netbeans.modules.cnd.makeproject.api.wizards.CommonUtilities;
 import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension;
+import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import org.netbeans.modules.cnd.makeproject.ui.wizards.PanelProjectLocationVisual;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.FSPath;
@@ -1133,10 +1134,9 @@ public final class RunDialogPanel extends javax.swing.JPanel implements Property
             IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
             if (extension != null) {
                 Map<String, Object> map = new HashMap<>();
-                map.put("DW:buildResult", getExecutablePath()); // NOI18N
-                map.put("DW:resolveLinks", CommonUtilities.resolveSymbolicLinks()); // NOI18N
-                map.put("DW:consolidationLevel", "file"); // NOI18N
-                map.put("DW:rootFolder", lastSelectedProject.getProjectDirectory().getPath()); // NOI18N
+                WizardConstants.DISCOVERY_BUILD_RESULT.toMap(map, getExecutablePath());
+                WizardConstants.DISCOVERY_RESOLVE_LINKS.toMap(map, CommonUtilities.resolveSymbolicLinks());
+                WizardConstants.DISCOVERY_ROOT_FOLDER.toMap(map, lastSelectedProject.getProjectDirectory().getPath());
                 IteratorExtension.ProjectKind kind = ((ProjectKindItem)projectKind.getSelectedItem()).kind;
                 extension.discoverProject(map, lastSelectedProject, kind); // NOI18N
             }
@@ -1180,6 +1180,10 @@ public final class RunDialogPanel extends javax.swing.JPanel implements Property
         return executableTextField.getText();
     }
     
+    public String getArguments() {
+        return argumentTextField.getText();
+    }
+    
     private void setErrorMsg(String msg) {
         errorLabel.setText(msg);
     }
