@@ -236,7 +236,7 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
 
     public String getAbsPath() {
         String retPath = null;
-        if (CndPathUtilities.isPathAbsolute(getPath())) {// UNIX path
+        if (CndPathUtilities.isPathAbsolute(fileSystem, getPath())) {// UNIX path
             retPath = getPath();
         } else if (getFolder() != null) {
             retPath = getFolder().getConfigurationDescriptor().getBaseDir() + '/' + getPath(); // UNIX path
@@ -330,7 +330,7 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
             if (getFolder() != null) {
                 FileObject fo = (FileObject) evt.getNewValue();
                 String newPath = fo.getPath();
-                if (!CndPathUtilities.isPathAbsolute(getPath())) {
+                if (!CndPathUtilities.isPathAbsolute(fileSystem, getPath())) {
                     newPath = CndPathUtilities.toRelativePath(getFolder().getConfigurationDescriptor().getBaseDirFileObject(), newPath);
                 }
                 newPath = CndPathUtilities.normalizeSlashes(newPath);
@@ -474,7 +474,7 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
                     // don't know file system, fall back to the default one
                     // but do not cache file object
                     String p = getPath();
-                    if (CndPathUtilities.isPathAbsolute(p)) {// UNIX path
+                    if (CndPathUtilities.isPathAbsolute(fileSystem, p)) {// UNIX path
                         p = FileSystemProvider.normalizeAbsolutePath(p, fileSystem);                        
                         fileObject = fileSystem.findResource(p);
                     }
@@ -521,7 +521,9 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
     
     private void attachTo(DataObject dataObject) {
         if (dataObject != null) {
-            LOG.log(Level.FINEST, "attaching {0} to {1}", new Object[]{System.identityHashCode(this), dataObject});
+            if (LOG.isLoggable(Level.FINEST)) {
+                LOG.log(Level.FINEST, "attaching {0} to {1}", new Object[]{System.identityHashCode(this), dataObject});
+            }
             dataObject.removePropertyChangeListener(this);
             dataObject.addPropertyChangeListener(this);
             NativeFileItemSet set = dataObject.getLookup().lookup(NativeFileItemSet.class);
@@ -541,7 +543,9 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
     
     private void detachFrom(DataObject dao) {
         if (dao != null) {
-            LOG.log(Level.FINEST, "detaching {0} from {1}", new Object[]{System.identityHashCode(this), dao});
+            if (LOG.isLoggable(Level.FINEST)) {
+                LOG.log(Level.FINEST, "detaching {0} from {1}", new Object[]{System.identityHashCode(this), dao});
+            }
             dao.removePropertyChangeListener(this);
             NativeFileItemSet set = dao.getLookup().lookup(NativeFileItemSet.class);
             if (set != null) {
@@ -714,7 +718,7 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
                     }
                     p = macroConverter.expand(p);
                 }
-                if (CndPathUtilities.isPathAbsolute(p)) {
+                if (CndPathUtilities.isPathAbsolute(fileSystem, p)) {
                     result.add(new FSPath(compilerFS, p));
                 } else {
                     String absPath = CndPathUtilities.toAbsolutePath(getFolder().getConfigurationDescriptor().getBaseDirFileObject(), p);
@@ -1027,8 +1031,8 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
                     switch (itemConfiguration.getCCCompilerConfiguration().getInheritedCppStandard()) {
                         case CCCompilerConfiguration.STANDARD_CPP11:
                             return LanguageFlavor.CPP11;
-                        //case CCCompilerConfiguration.STANDARD_CPP14:
-                        //    return LanguageFlavor.CPP14;
+                        case CCCompilerConfiguration.STANDARD_CPP14:
+                            return LanguageFlavor.CPP14;
                         case CCCompilerConfiguration.STANDARD_CPP98:
                         case CCCompilerConfiguration.STANDARD_DEFAULT:
                             return LanguageFlavor.CPP;
@@ -1044,8 +1048,8 @@ public final class Item implements NativeFileItem, PropertyChangeListener {
                     switch (ccCompilerConfiguration.getInheritedCppStandard()) {
                         case CCCompilerConfiguration.STANDARD_CPP11:
                             return LanguageFlavor.CPP11;
-                        //case CCCompilerConfiguration.STANDARD_CPP14:
-                        //    return LanguageFlavor.CPP14;
+                        case CCCompilerConfiguration.STANDARD_CPP14:
+                            return LanguageFlavor.CPP14;
                 }
                 }
             }
