@@ -69,6 +69,7 @@ import org.netbeans.modules.cnd.makeproject.configurations.ConfigurationMakefile
 import org.netbeans.modules.cnd.makeproject.configurations.CppUtils;
 import org.netbeans.modules.cnd.makeproject.configurations.ui.CompilerSetNodeProp;
 import org.netbeans.modules.cnd.makeproject.configurations.ui.DevelopmentHostNodeProp;
+import org.netbeans.modules.cnd.makeproject.configurations.ui.PlatformSpecificProp;
 import org.netbeans.modules.cnd.makeproject.configurations.ui.RemoteSyncFactoryNodeProp;
 import org.netbeans.modules.cnd.makeproject.configurations.ui.RequiredProjectsNodeProp;
 import org.netbeans.modules.cnd.makeproject.platform.Platforms;
@@ -106,6 +107,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
     public static final String CND_BUILDDIR_MACRO = "${CND_BUILDDIR}"; // NOI18N
     public static final String CND_DLIB_EXT_MACRO = "${CND_DLIB_EXT}"; // NOI18N
     public static final String CND_OUTPUT_PATH_MACRO = "${OUTPUT_PATH}"; // NOI18N
+    public static final String PROJECTDIR_MACRO = "${PROJECT_DIR}"; // NOI18N
     // Project Types
     private static String[] TYPE_NAMES_UNMANAGED = {
         getString("MakefileName")
@@ -138,6 +140,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
     
     // Configurations
     private IntConfiguration configurationType;
+    private PreBuildConfiguration preBuildConfiguration;
     private MakefileConfiguration makefileConfiguration;
     private CompileConfiguration compileConfiguration;
     private CompilerSet2Configuration compilerSet;
@@ -161,43 +164,16 @@ public final class MakeConfiguration extends Configuration implements Cloneable
     private boolean languagesDirty = true;
     private RemoteSyncFactory fixedRemoteSyncFactory;
     private CodeAssistanceConfiguration codeAssistanceConfiguration;
+    private BooleanConfiguration platformSpecificConfiguration;
     private static final Logger LOGGER = Logger.getLogger("org.netbeans.modules.cnd.makeproject"); // NOI18N
     
     private String customizerId = null;
 
-//    //XXX:fullRemote:fileSystem - should be removed (replaced with FSPath)
-//    public MakeConfiguration(String baseDir, String name, int configurationTypeValue) {
-//        this(baseDir, name, configurationTypeValue, null);
-//    }
-//
-//    //XXX:fullRemote:fileSystem - should be removed (replaced with FSPath)
-//    public MakeConfiguration(String baseDir, String name, int configurationTypeValue, String hostUID) {
-//        this(baseDir, name, configurationTypeValue, hostUID, null, true);
-//    }
-//
-//    public MakeConfiguration(String baseDir, String name, int configurationTypeValue, String hostUID, CompilerSet hostCS, boolean defaultToolCollection) {
-//        this(new FSPath(CndFileUtils.getLocalFileSystem(), baseDir), name, configurationTypeValue, null, hostUID, hostCS, defaultToolCollection);
-//    }
-//    
-//    public MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue) {
-//        this(fsPath, name, configurationTypeValue, null);
-//    }
-//
-//    public MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue, String hostUID) {
-//        this(fsPath, name, configurationTypeValue, null, hostUID, null, true);
-//    }
-    
-    private MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue, String customizerId, String hostUID) {
-        this(fsPath, name, configurationTypeValue, customizerId, hostUID, null, true);
-    }
-    private MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue, String hostUID, CompilerSet hostCS, boolean defaultToolCollection) {
-        this(fsPath, name, configurationTypeValue, null, hostUID,  hostCS, defaultToolCollection);
-    }
-        
-
-    private MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue, String customizerId, String hostUID, CompilerSet hostCS, boolean defaultToolCollection) {
+    private MakeConfiguration(FSPath fsPath, String name, int configurationTypeValue,
+            String customizerId, String hostUID, CompilerSet hostCS,
+            boolean defaultToolCollection, boolean platformSpecific) {
         super(fsPath, name);
-        hostUID = (hostUID == null) ? CppUtils.getDefaultDevelopmentHost() : hostUID;
+        hostUID = (hostUID == null) ? CppUtils.getDefaultDevelopmentHost(fsPath.getFileSystem()) : hostUID;
         if (configurationTypeValue == TYPE_MAKEFILE) {
             configurationType = new IntConfiguration(null, configurationTypeValue, TYPE_NAMES_UNMANAGED, null);
         } else if (configurationTypeValue == TYPE_APPLICATION || configurationTypeValue == TYPE_DYNAMIC_LIB || configurationTypeValue == TYPE_STATIC_LIB) {
@@ -223,6 +199,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         cppRequired = new LanguageBooleanConfiguration();
         fortranRequired = new LanguageBooleanConfiguration();
         assemblerRequired = new LanguageBooleanConfiguration();
+        preBuildConfiguration = new PreBuildConfiguration(this);
         makefileConfiguration = new MakefileConfiguration(this);
         compileConfiguration = new CompileConfiguration(this);
         if (isMakefileConfiguration()) {
@@ -249,6 +226,8 @@ public final class MakeConfiguration extends Configuration implements Cloneable
 
         developmentHost.addPropertyChangeListener(compilerSet);
         codeAssistanceConfiguration = new CodeAssistanceConfiguration(this);
+        platformSpecificConfiguration = new BooleanConfiguration(false);
+        platformSpecificConfiguration.setValue(platformSpecific);
         initAuxObjects();
     }
     
@@ -261,28 +240,57 @@ public final class MakeConfiguration extends Configuration implements Cloneable
      * @return the MakeConfiguration
      */
     public static MakeConfiguration createDefaultHostMakefileConfiguration(String baseDir, String name) {
-        return new MakeConfiguration(new FSPath(CndFileUtils.getLocalFileSystem(), baseDir), name, MakeConfiguration.TYPE_MAKEFILE, null, null);
+        return new MakeConfiguration(new FSPath(CndFileUtils.getLocalFileSystem(), baseDir), name, MakeConfiguration.TYPE_MAKEFILE,
+                null, null, null,
+                true ,false);
     }
-    
     public static MakeConfiguration createMakefileConfiguration(FSPath baseDir, String name, String hostID) {
-        return new MakeConfiguration(baseDir, name, MakeConfiguration.TYPE_MAKEFILE, null, hostID);
+        return new MakeConfiguration(baseDir, name, MakeConfiguration.TYPE_MAKEFILE,
+                null, hostID, null,
+                true, false);
     }
     
-    public static MakeConfiguration createMakefileConfiguration(FSPath baseDir, String name, String hostID, CompilerSet hostCS, boolean defaultToolCollection) {
-        return new MakeConfiguration(baseDir, name, MakeConfiguration.TYPE_MAKEFILE, null, hostID, hostCS, defaultToolCollection);
+    public static MakeConfiguration createMakefileConfiguration(FSPath baseDir, String name,
+            String hostID, CompilerSet hostCS,
+            boolean defaultToolCollection) {
+        return new MakeConfiguration(baseDir, name, MakeConfiguration.TYPE_MAKEFILE,
+                null, hostID, hostCS,
+                defaultToolCollection, false);
     }
     
     
-    public static MakeConfiguration createConfiguration(FSPath baseDir, String name, int configurationType, String customizerID, String hostID) {
-        return new MakeConfiguration(baseDir, name, configurationType, customizerID, hostID);
+    public static MakeConfiguration createConfiguration(FSPath baseDir, String name, int configurationType,
+            String customizerID, String hostID) {
+        return new MakeConfiguration(baseDir, name, configurationType,
+                customizerID, hostID, null,
+                true, false);
     }    
+
+    public static MakeConfiguration createConfiguration(FSPath baseDir, String name, int configurationType,
+            String customizerID, String hostID,
+            boolean platformSpecific) {
+        return new MakeConfiguration(baseDir, name, configurationType,
+                customizerID, hostID, null,
+                true, platformSpecific);
+    }
     
-    public static MakeConfiguration createConfiguration(FSPath baseDir, String name, 
-            int configurationType, String customizerID, String hostID, CompilerSet hostCS, boolean defaultToolCollection) {
-        return new MakeConfiguration(baseDir, 
-                name, configurationType, customizerID, hostID, hostCS, defaultToolCollection);
+    public static MakeConfiguration createConfiguration(FSPath baseDir, String name, int configurationType,
+            String customizerID, String hostID, CompilerSet hostCS,
+            boolean defaultToolCollection) {
+        return new MakeConfiguration(baseDir, name, configurationType,
+                customizerID, hostID, hostCS,
+                defaultToolCollection, false);
     }        
 
+    public void setPreBuildConfiguration(PreBuildConfiguration makefileConfiguration) {
+        this.preBuildConfiguration = makefileConfiguration;
+        this.preBuildConfiguration.setMakeConfiguration(this);
+    }
+
+    public PreBuildConfiguration getPreBuildConfiguration() {
+        return preBuildConfiguration;
+    }
+
     public void setMakefileConfiguration(MakefileConfiguration makefileConfiguration) {
         this.makefileConfiguration = makefileConfiguration;
         this.makefileConfiguration.setMakeConfiguration(this);
@@ -365,6 +373,14 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         this.assemblerRequired = assemblerRequired;
     }
 
+    public BooleanConfiguration getPlatformSpecific() {
+        return platformSpecificConfiguration;
+    }
+
+    public void setPlatformSpecificConfiguration(BooleanConfiguration platformSpecificConfiguration) {
+        this.platformSpecificConfiguration = platformSpecificConfiguration;
+    }
+
     public PlatformInfo getPlatformInfo() {
         PlatformInfo platformInfo = PlatformInfo.getDefault(getDevelopmentHost().getExecutionEnvironment());
 //        assert platformInfo.getPlatform() == getPlatform().getValue();
@@ -601,6 +617,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         getDependencyChecking().assign(makeConf.getDependencyChecking());
         getRebuildPropChanged().assign(makeConf.getRebuildPropChanged());
 
+        getPreBuildConfiguration().assign(makeConf.getPreBuildConfiguration());
         getMakefileConfiguration().assign(makeConf.getMakefileConfiguration());
         getCompileConfiguration().assign(makeConf.getCompileConfiguration());
         getCCompilerConfiguration().assign(makeConf.getCCompilerConfiguration());
@@ -616,6 +633,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         getDebuggerChooserConfiguration().assign(makeConf.getDebuggerChooserConfiguration());
         getQmakeConfiguration().assign(makeConf.getQmakeConfiguration());
         getCodeAssistanceConfiguration().assign(makeConf.getCodeAssistanceConfiguration());
+        getPlatformSpecific().assign(makeConf.getPlatformSpecific());
 
         // do assign on all aux objects
         ConfigurationAuxObject[] auxs = getAuxObjects(); // from this profile
@@ -736,7 +754,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
     @Override
     public MakeConfiguration clone() {
         MakeConfiguration clone = new MakeConfiguration(getBaseFSPath(), getName(),
-                getConfigurationType().getValue(), getCustomizerId(), getDevelopmentHost().getHostKey());
+                getConfigurationType().getValue(), getCustomizerId(), getDevelopmentHost().getHostKey(), null, true, getPlatformSpecific().getValue());
         super.cloneConf(clone);
         clone.setCloneOf(this);
 
@@ -751,6 +769,7 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         clone.setCppRequired(getCppRequired().clone());
         clone.setFortranRequired(getFortranRequired().clone());
         clone.setAssemblerRequired(getAssemblerRequired().clone());
+        clone.setPreBuildConfiguration(getPreBuildConfiguration().clone());
         clone.setMakefileConfiguration(getMakefileConfiguration().clone());
         clone.setCompileConfiguration(getCompileConfiguration().clone());
         clone.setDependencyChecking(getDependencyChecking().clone());
@@ -807,12 +826,13 @@ public final class MakeConfiguration extends Configuration implements Cloneable
         set.put(new IntNodeProp(getConfigurationType(), true, "ConfigurationType", getString("ConfigurationTypeTxt"), getString("ConfigurationTypeHint"))); // NOI18N
         sheet.put(set);
 
+        set = Sheet.createExpertSet();
         if (isCompileConfiguration()) {
-            set = Sheet.createExpertSet();
             set.put(new BooleanNodeProp(getDependencyChecking(), true, "DependencyChecking", getString("DependencyCheckingTxt"), getString("DependencyCheckingHint"))); // NOI18N
             set.put(new BooleanNodeProp(getRebuildPropChanged(), true, "RebuildPropChanged", getString("RebuildPropChangedTxt"), getString("RebuildPropChangedHint"))); // NOI18N
-            sheet.put(set);
         }
+        set.put(new PlatformSpecificProp(this, getPlatformSpecific(), true, "PlatformSpecific", getString("PlatformSpecificTxt"), getString("PlatformSpecificHint"))); // NOI18N
+        sheet.put(set);
 
         return sheet;
     }
@@ -1134,16 +1154,17 @@ public final class MakeConfiguration extends Configuration implements Cloneable
     
     public String expandMacros(String val) {
         // Substitute macros
-        val = CndPathUtilities.expandMacro(val, "${TESTDIR}", MakeConfiguration.CND_BUILDDIR_MACRO + '/' + MakeConfiguration.CND_CONF_MACRO + '/' + MakeConfiguration.CND_PLATFORM_MACRO + "/" + "tests"); // NOI18N
-        val = CndPathUtilities.expandMacro(val, "${OUTPUT_PATH}", getOutputValue()); // NOI18N
-        val = CndPathUtilities.expandMacro(val, "${OUTPUT_BASENAME}", CndPathUtilities.getBaseName(getOutputValue())); // NOI18N
-        val = CndPathUtilities.expandMacro(val, "${PLATFORM}", getVariant()); // Backward compatibility // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.OBJECTDIR_MACRO, ConfigurationMakefileWriter.getObjectDir(this)); // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.CND_PLATFORM_MACRO, getVariant()); // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.CND_CONF_MACRO, getName()); // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.CND_DISTDIR_MACRO, MakeConfiguration.DIST_FOLDER); // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.CND_BUILDDIR_MACRO, MakeConfiguration.BUILD_FOLDER); // NOI18N
-        val = CndPathUtilities.expandMacro(val, MakeConfiguration.CND_DLIB_EXT_MACRO, getLibraryExtension()); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, "${TESTDIR}", MakeConfiguration.CND_BUILDDIR_MACRO + '/' + MakeConfiguration.CND_CONF_MACRO + '/' + MakeConfiguration.CND_PLATFORM_MACRO + "/" + "tests"); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_OUTPUT_PATH_MACRO, getOutputValue());
+        val = CndPathUtilities.expandAllMacroses(val, "${OUTPUT_BASENAME}", CndPathUtilities.getBaseName(getOutputValue())); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, "${PLATFORM}", getVariant()); // Backward compatibility // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.OBJECTDIR_MACRO, ConfigurationMakefileWriter.getObjectDir(this)); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_PLATFORM_MACRO, getVariant()); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_CONF_MACRO, getName()); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_DISTDIR_MACRO, MakeConfiguration.DIST_FOLDER); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_BUILDDIR_MACRO, MakeConfiguration.BUILD_FOLDER); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.CND_DLIB_EXT_MACRO, getLibraryExtension()); // NOI18N
+        val = CndPathUtilities.expandAllMacroses(val, MakeConfiguration.PROJECTDIR_MACRO, getBaseDir());
         return val;
     }
 
