@@ -100,6 +100,13 @@ import org.openide.util.Exceptions;
  * 
  * Change History:
  * 
+ * V97 - NB 8.1
+ *    Store target platform in public configurations.xml
+ *    if configuration is marked as platform specific.
+ *    It prevent treat all configuration's platforms as current platform.
+ *    By default configuration is not platform specific.
+ * V96 - NB 8.1
+ *    Introduce pre-build step
  * V95 - NB 8.0.1
  *    Introduce resolving symbolic links (RESOLVE_SYMBOLIC_LINKS)
  * V94 - NB 8.0
@@ -291,7 +298,7 @@ public abstract class CommonConfigurationXMLCodec
         implements XMLEncoder {
     
     public final static int VERSION_WITH_INVERTED_SERIALIZATION = 88;
-    public final static int CURRENT_VERSION = 95;
+    public final static int CURRENT_VERSION = 97;
     // Generic
     protected final static String PROJECT_DESCRIPTOR_ELEMENT = "projectDescriptor"; // NOI18N
     protected final static String DEBUGGING_ELEMENT = "justfordebugging"; // NOI18N
@@ -341,6 +348,11 @@ public abstract class CommonConfigurationXMLCodec
     protected final static String DICTIONARY_ELEMENT = "element"; // NOI18N
     protected final static String DICTIONARY_ELEMENT_ATR_ID = "flagsID"; // NOI18N
     protected final static String DICTIONARY_ELEMENT_ATR_VALUE = "commonFlags"; // NOI18N
+    //PreBuild
+    protected final static String PRE_BUILD_ELEMENT = "preBuild"; // NOI18N
+    protected final static String PRE_BUILD_WORKING_DIR_ELEMENT = "preBuildCommandWorkingDir"; // NOI18N
+    protected final static String PRE_BUILD_COMMAND_ELEMENT = "preBuildCommand"; // NOI18N
+    protected final static String PRE_BUILD_FIRST_ELEMENT = "preBuildFirst"; // NOI18N
     // Compile
     protected static final String COMPILE_ID = "compile"; // NOI18N
     protected final static String COMPILE_DIR_ELEMENT = "compiledir"; // NOI18N
@@ -445,6 +457,7 @@ public abstract class CommonConfigurationXMLCodec
     protected final static String ARCHIVERTOOL_SUPRESS_ELEMENT = "archiverSupress"; // NOI18N
     public final static String VERSION_ATTR = "version"; // NOI18N
     protected final static String TYPE_ATTR = "type"; // NOI18N
+    protected final static String PLATFORM_SPECIFIC_ATTR = "platformSpecific"; // NOI18N
     protected final static String CUSTOMIZERID_ATTR = "customizerid"; // NOI18N
     protected final static String KIND_ATTR = "kind"; // NOI18N
     protected final static String NAME_ATTR = "name"; // NOI18N
@@ -531,12 +544,20 @@ public abstract class CommonConfigurationXMLCodec
                             new AttrValuePair(CUSTOMIZERID_ATTR, "" + makeConfiguration.getCustomizerId()), // NOI18N
                         });
             } else {
-                xes.elementOpen(CONF_ELEMENT,
-                        new AttrValuePair[]{
-                            new AttrValuePair(NAME_ATTR, "" + makeConfiguration.getName()), // NOI18N
-                            new AttrValuePair(TYPE_ATTR, "" + makeConfiguration.getConfigurationType().getValue()), // NOI18N
-                        });
-
+                if (makeConfiguration.getPlatformSpecific().getValue()) {
+                    xes.elementOpen(CONF_ELEMENT,
+                            new AttrValuePair[]{
+                                new AttrValuePair(NAME_ATTR, "" + makeConfiguration.getName()), // NOI18N
+                                new AttrValuePair(TYPE_ATTR, "" + makeConfiguration.getConfigurationType().getValue()), // NOI18N
+                                new AttrValuePair(PLATFORM_SPECIFIC_ATTR, "" + makeConfiguration.getPlatformSpecific().getValue()), // NOI18N
+                            });
+                } else {
+                    xes.elementOpen(CONF_ELEMENT,
+                            new AttrValuePair[]{
+                                new AttrValuePair(NAME_ATTR, "" + makeConfiguration.getName()), // NOI18N
+                                new AttrValuePair(TYPE_ATTR, "" + makeConfiguration.getConfigurationType().getValue()), // NOI18N
+                            });
+                }
             }
 
             writeToolsSetBlock(xes, makeConfiguration);
@@ -719,6 +740,13 @@ public abstract class CommonConfigurationXMLCodec
         //if (makeConfiguration.getLinkerConfiguration() != null)
         //    writeLinkerConfiguration(xes, makeConfiguration.getLinkerConfiguration());
         xes.elementClose(MAKETOOL_ELEMENT);
+        xes.elementOpen(PRE_BUILD_ELEMENT);
+        xes.element(PRE_BUILD_WORKING_DIR_ELEMENT, makeConfiguration.getPreBuildConfiguration().getPreBuildCommandWorkingDir().getValue());
+        xes.element(PRE_BUILD_COMMAND_ELEMENT, makeConfiguration.getPreBuildConfiguration().getPreBuildCommand().getValue());
+        if (makeConfiguration.getPreBuildConfiguration().getPreBuildFirst().getValue()) {
+            xes.element(PRE_BUILD_FIRST_ELEMENT, "true"); //NOI18N
+        }
+        xes.elementClose(PRE_BUILD_ELEMENT);
         writeRequiredProjects(xes, makeConfiguration.getRequiredProjectsConfiguration());
         xes.elementClose(MAKEFILE_TYPE_ELEMENT);
     }
@@ -1492,7 +1520,7 @@ public abstract class CommonConfigurationXMLCodec
             xes.element(BUILD_ANALAZYER_ELEMENT, "" + codeAssistanceConfiguration.getBuildAnalyzer().getValue()); // NOI18N
         }
         if (codeAssistanceConfiguration.getResolveSymbolicLinks().getModified()) {
-            xes.element(RESOLVE_SYMBOLIC_LINKS, "" + codeAssistanceConfiguration.getBuildAnalyzer().getValue()); // NOI18N
+            xes.element(RESOLVE_SYMBOLIC_LINKS, "" + codeAssistanceConfiguration.getResolveSymbolicLinks().getValue()); // NOI18N
         }
         if (codeAssistanceConfiguration.getIncludeInCA().getModified()) {
             xes.element(CODE_ASSISTANCE_INCLUDE_ADDITIONAL, "" + codeAssistanceConfiguration.getIncludeInCA().getValue()); // NOI18N
