@@ -43,6 +43,7 @@
  */
 package org.netbeans.modules.cnd.makeproject.ui.wizards;
 
+import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import java.awt.Component;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -69,10 +70,8 @@ import org.netbeans.modules.cnd.makeproject.api.configurations.ConfigurationDesc
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.QmakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension;
-import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension.ProjectKind;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels.NamedPanel;
-import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import org.netbeans.modules.cnd.makeproject.spi.DatabaseProjectProvider;
 import org.netbeans.modules.cnd.utils.CndUtils;
 import org.netbeans.modules.cnd.utils.FSPath;
@@ -84,6 +83,7 @@ import org.openide.WizardDescriptor;
 import org.openide.filesystems.FileObject;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.Pair;
 
 /**
  * Wizard to create a new Make project.
@@ -141,7 +141,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
 
     public static List<WizardDescriptor.Panel<WizardDescriptor>> getPanels(int wizardtype, String name, String wizardTitle, String wizardACSD, boolean fullRemote) {
         List<WizardDescriptor.Panel<WizardDescriptor>> out = new ArrayList<>();
-        out.add(new MakefileOrConfigureDescriptorPanel());
+        out.add(new PreBuildActionDescriptorPanel());
         out.add(new BuildActionsDescriptorPanel());
         out.add(new SourceFoldersDescriptorPanel());
         out.add(new ParserConfigurationDescriptorPanel());
@@ -364,23 +364,23 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     @Override
     public Set<FileObject> instantiate() throws IOException {
         Set<FileObject> resultSet = new HashSet<>();
-        FSPath dirF = (FSPath) wiz.getProperty(WizardConstants.PROPERTY_PROJECT_FOLDER);
-        String hostUID = (String) wiz.getProperty(WizardConstants.PROPERTY_HOST_UID);
-        CompilerSet toolchain = (CompilerSet) wiz.getProperty(WizardConstants.PROPERTY_TOOLCHAIN);
-        boolean defaultToolchain = Boolean.TRUE.equals(wiz.getProperty(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT));
+        FSPath dirF = WizardConstants.PROPERTY_PROJECT_FOLDER.get(wiz);
+        String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wiz);
+        CompilerSet toolchain = WizardConstants.PROPERTY_TOOLCHAIN.get(wiz);
+        boolean defaultToolchain = Boolean.TRUE.equals(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.get(wiz));
         if (dirF != null) {
-            ExecutionEnvironment ee = (ExecutionEnvironment) wiz.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV);
+            ExecutionEnvironment ee = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wiz);
             if (ee == null) {
                 ee = ExecutionEnvironmentFactory.getLocal();
             }
             dirF = new FSPath(dirF.getFileSystem(), RemoteFileUtil.normalizeAbsolutePath(dirF.getPath(), ee));
         }
-        String projectName = (String) wiz.getProperty(WizardConstants.PROPERTY_NAME);
-        String makefileName = (String) wiz.getProperty(WizardConstants.PROPERTY_GENERATED_MAKEFILE_NAME);
+        String projectName = WizardConstants.PROPERTY_NAME.get(wiz);
+        String makefileName = WizardConstants.PROPERTY_GENERATED_MAKEFILE_NAME.get(wiz);
         if (isSimple()) {
             IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
             if (extension != null) {
-                resultSet.addAll(extension.createProject(getSelectModePanel().getWizardStorage().getAdapter()));
+                resultSet.addAll(extension.createProject(wiz));
             } else {
                 String message = NbBundle.getMessage(NewMakeProjectWizardIterator.class, "SERVICE_NOT_AVALIABLE"); // NOI18N
                 if (CndUtils.isStandalone() || CndUtils.isUnitTestMode()) {
@@ -404,7 +404,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
         } else if (wizardtype == TYPE_BINARY) {
             IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
             if (extension != null) {
-                IteratorExtension.ProjectKind kind = (ProjectKind) wiz.getProperty(WizardConstants.PROPERTY_DEPENDENCY_KIND);
+                IteratorExtension.ProjectKind kind = WizardConstants.PROPERTY_DEPENDENCY_KIND.get(wiz);
                 if (kind == null) {
                     kind = IteratorExtension.ProjectKind.IncludeDependencies;
                 }
@@ -436,17 +436,21 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
                 conftype = MakeConfiguration.TYPE_DB_APPLICATION;
             }
             String mainFile = null;
-            if (((Boolean) wiz.getProperty("createMainFile"))) { // NOI18N
-                String fname = (String) wiz.getProperty("mainFileName"); // NOI18N
-                String template = (String) wiz.getProperty("mainFileTemplate"); // NOI18N
+            if (WizardConstants.PROPERTY_CREATE_MAIN_FILE.get(wiz)) { // NOI18N
+                WizardConstants.PROPERTY_MAIN_FILE_NAME.get(wiz);
+                String fname = WizardConstants.PROPERTY_MAIN_FILE_NAME.get(wiz);
+                String template = WizardConstants.PROPERTY_MAIN_TEMPLATE_NAME.get(wiz);
                 mainFile = fname + "|" + template; // NOI18N
             }
+            String langStandard = WizardConstants.PROPERTY_LANGUAGE_STANDARD.get(wiz);
+
             MakeConfiguration debug = MakeConfiguration.createConfiguration(dirF, "Debug", conftype, null, hostUID, toolchain, defaultToolchain); // NOI18N
             debug.getCCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getCCCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getFortranCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getAssemblerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getQmakeConfiguration().getBuildMode().setValue(QmakeConfiguration.DEBUG_MODE);
+            setupLanguageStandard(debug, langStandard);
             if (wizardtype == TYPE_DB_APPLICATION) {
                 DatabaseProjectProvider provider = Lookup.getDefault().lookup(DatabaseProjectProvider.class);
                 if(provider != null) {
@@ -459,6 +463,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
             release.getFortranCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_RELEASE);
             release.getAssemblerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_RELEASE);
             release.getQmakeConfiguration().getBuildMode().setValue(QmakeConfiguration.RELEASE_MODE);
+            setupLanguageStandard(release, langStandard);
             if (wizardtype == TYPE_DB_APPLICATION) {
                 DatabaseProjectProvider provider = Lookup.getDefault().lookup(DatabaseProjectProvider.class);
                 if(provider != null) {
@@ -492,19 +497,32 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     private transient List<WizardDescriptor.Panel<WizardDescriptor>> panels;
     private transient WizardDescriptor wiz;
 
+    private void setupLanguageStandard(MakeConfiguration conf, String langStandard) {
+        Pair<String, Integer> languageStandard = PanelProjectLocationVisual.getLanguageStandard(langStandard);
+        if (languageStandard != null) {
+            if (PanelProjectLocationVisual.C[0].equals(languageStandard.first())) {
+                conf.getCCompilerConfiguration().getCStandard().setValue(languageStandard.second());
+            } else if (PanelProjectLocationVisual.CPP[0].equals(languageStandard.first())) {
+                conf.getCCCompilerConfiguration().getCppStandard().setValue(languageStandard.second());
+            } else if (PanelProjectLocationVisual.FORTRAN[0].equals(languageStandard.first())) {
+                //conf.getFortranCompilerConfiguration().getFortranStandard().setValue(languageStandard.second());
+            } 
+        }
+    }
+    
     @Override
     public void initialize(WizardDescriptor wiz) {
         this.wiz = wiz;
-        wiz.putProperty(WizardConstants.PROPERTY_SOURCE_HOST_ENV, NewProjectWizardUtils.getDefaultSourceEnvironment());
+        WizardConstants.PROPERTY_SOURCE_HOST_ENV.put(wiz, NewProjectWizardUtils.getDefaultSourceEnvironment());
         index = 0;
         setupPanelsAndStepsIfNeed();
     }
 
     @Override
     public void uninitialize(WizardDescriptor wiz) {
-        this.wiz.putProperty(WizardConstants.PROPERTY_PROJECT_FOLDER, null);
-        this.wiz.putProperty(WizardConstants.PROPERTY_NAME, null);
-        this.wiz.putProperty(WizardConstants.MAIN_CLASS, null); // NOI18N
+        WizardConstants.PROPERTY_PROJECT_FOLDER.put(this.wiz, null);
+        WizardConstants.PROPERTY_NAME.put(this.wiz, null);
+        WizardConstants.MAIN_CLASS.put(this.wiz, null); // NOI18N
         if (wizardtype == TYPE_MAKEFILE) {
             this.wiz.putProperty("sourceRoot", null); // NOI18N
         }
@@ -518,7 +536,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     }
 
     private boolean isSimple() {
-        return wizardtype == TYPE_MAKEFILE && wiz != null && Boolean.TRUE.equals(wiz.getProperty(WizardConstants.PROPERTY_SIMPLE_MODE));
+        return wizardtype == TYPE_MAKEFILE && wiz != null && Boolean.TRUE.equals(WizardConstants.PROPERTY_SIMPLE_MODE.get(wiz));
     }
 
     @Override
