@@ -48,9 +48,11 @@
 
 package org.netbeans.modules.cnd.makeproject.ui.wizards;
 
+import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
+import java.awt.Dialog;
 import java.awt.Dimension;
 import java.awt.Point;
 import java.awt.Rectangle;
@@ -100,7 +102,6 @@ import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSetManager;
 import org.netbeans.modules.cnd.makeproject.api.wizards.CommonUtilities;
 import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension;
-import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.cnd.utils.FileFilterFactory;
@@ -110,9 +111,9 @@ import org.netbeans.modules.cnd.utils.ui.DocumentAdapter;
 import org.netbeans.modules.cnd.utils.ui.EditableComboBox;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
-import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
-import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
 import org.netbeans.modules.remote.spi.FileSystemProvider;
+import org.openide.DialogDescriptor;
+import org.openide.DialogDisplayer;
 import org.openide.WizardDescriptor;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileSystem;
@@ -160,7 +161,7 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
             @Override
             public void actionPerformed(ActionEvent e) {
                 String path = ((EditableComboBox)binaryField).getText().trim();
-                controller.getWizardStorage().setBinaryPath(new FSPath(fileSystem, path));
+                controller.getWizardStorage().setBinaryPath(fileSystem, path);
                 updateRoot();
             }
         });
@@ -198,19 +199,6 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         controller.getWizardStorage().validate();
     }
 
-    private FileObject findProjectCreator() {
-        for(CompilerSet set : CompilerSetManager.get(env).getCompilerSets()) {
-            if (set.getCompilerFlavor().isSunStudioCompiler()) {
-                String directory = set.getDirectory();
-                FileObject creator = fileSystem.findResource(directory+"/../lib/ide_project/bin/ide_project");
-                if (creator != null && creator.isValid()) {
-                    return creator;
-                }
-            }
-        }
-        return null;
-    }
-
     private void updateRoot(){
         sourcesField.setEnabled(false);
         sourcesButton.setEnabled(false);
@@ -218,19 +206,33 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         viewComboBox.setEnabled(false);
         table.setModel(new DefaultTableModel(0, 0));
         if (validBinary()) {
-            if (env.isRemote() && findProjectCreator() == null) {
-                controller.getWizardDescriptor().putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, getString("ERROR_FIND_PROJECT_CREATOR", env.getDisplayName()));  // NOI18N
-                return;
+            if (env.isRemote()) {
+                // TODO check java on remote host
+                //controller.getWizardDescriptor().putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, getString("ERROR_FIND_PROJECT_CREATOR", env.getDisplayName()));  // NOI18N
+                //return;
             }
             controller.getWizardDescriptor().putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, "");
             checking.incrementAndGet();
             validateController();
             final IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
             final Map<String, Object> map = new HashMap<>();
-            map.put("DW:buildResult", controller.getWizardStorage().getBinaryPath().getPath()); // NOI18N
-            map.put("DW:resolveLinks", CommonUtilities.resolveSymbolicLinks()); // NOI18N
+            List<FSPath> binaries = controller.getWizardStorage().getBinaryPath();
+            if (binaries.size() == 1) {
+                WizardConstants.DISCOVERY_BUILD_RESULT.toMap(map, binaries.get(0).getPath());
+            } else {
+                WizardConstants.DISCOVERY_BUILD_RESULT.toMap(map, binaries.get(0).getPath());
+                StringBuilder buf = new StringBuilder();
+                for(int i = 1; i < binaries.size(); i++) {
+                    if (buf.length() > 0) {
+                        buf.append(';');
+                    }
+                    buf.append(binaries.get(i).getPath());
+                }
+                WizardConstants.DISCOVERY_LIBRARIES.toMap(map, buf.toString());
+            }
+            WizardConstants.DISCOVERY_RESOLVE_LINKS.toMap(map, CommonUtilities.resolveSymbolicLinks());
             if (env.isRemote()) {
-                map.put("DW:fileSystem", fileSystem); // NOI18N
+                WizardConstants.DISCOVERY_BINARY_FILESYSTEM.toMap(map, fileSystem);
             }
             if (extension != null) {
                 RP.post(new Runnable() {
@@ -238,14 +240,12 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
                     @Override
                     public void run() {
                         extension.discoverArtifacts(map);
-                        @SuppressWarnings("unchecked")
-                        List<String> dlls = (List<String>) map.get("DW:dependencies"); // NOI18N
-                        String root = (String) map.get("DW:rootFolder"); // NOI18N
+                        List<String> dlls = WizardConstants.DISCOVERY_BINARY_DEPENDENCIES.fromMap(map);
+                        String root = WizardConstants.DISCOVERY_ROOT_FOLDER.fromMap(map);
                         if (root == null) {
                             root = "";
                         }
-                        @SuppressWarnings("unchecked")
-                        List<String> searchPaths = (List<String>) map.get("DW:searchPaths"); // NOI18N
+                        List<String> searchPaths = WizardConstants.DISCOVERY_BINARY_SEARCH_PATH.fromMap(map);
                         final Map<String, String> resolvedDlls = searchingTable(dlls);
                         updateArtifacts(root, map, resolvedDlls);
                         checkDll(resolvedDlls, root, searchPaths, controller.getWizardStorage().getBinaryPath());
@@ -275,26 +275,26 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
             @Override
             public void run() {
                 if (env.isLocal()) {
-                    CompilerSet compiler = detectCompilerSet((String) map.get("DW:compiler")); // NOI18N
+                    CompilerSet compiler = detectCompilerSet(WizardConstants.DISCOVERY_COMPILER.fromMap(map));
                     if (compiler != null) {
-                        controller.getWizardDescriptor().putProperty(WizardConstants.PROPERTY_TOOLCHAIN, compiler);
-                        controller.getWizardDescriptor().putProperty(WizardConstants.PROPERTY_HOST_UID, ExecutionEnvironmentFactory.getLocal().getHost());
+                        WizardConstants.PROPERTY_TOOLCHAIN.put(controller.getWizardDescriptor(), compiler);
+                        WizardConstants.PROPERTY_HOST_UID.put(controller.getWizardDescriptor(), ExecutionEnvironmentFactory.getLocal().getHost());
                         // allow user to select right tool collection if discovery detected wrong one
-                        controller.getWizardDescriptor().putProperty(WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN, Boolean.FALSE);
+                        WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN.put(controller.getWizardDescriptor(), Boolean.FALSE);
                     } else {
-                        controller.getWizardDescriptor().putProperty(WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN, Boolean.FALSE);
+                        WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN.put(controller.getWizardDescriptor(), Boolean.FALSE);
                     }
                     sourcesField.setText(root);
                     int i = checking.decrementAndGet();
                     if (i == 0) {
                         boolean validBinary = validBinary();
-                        String validBinaryPath = getValidBinaryPath();
+                        List<FSPath> validBinaryPath = getValidBinaryPath();
                         sourcesField.setEnabled(validBinary);
                         sourcesButton.setEnabled(validBinary);
                         dependeciesComboBox.setEnabled(validBinary);
                         viewComboBox.setEnabled(validBinary);
                         if (validBinary && validBinaryPath != null) {
-                            String binaryRoot = CndPathUtilities.getDirName(validBinaryPath);
+                            String binaryRoot = CndPathUtilities.getDirName(validBinaryPath.get(0).getPath());
                             if (binaryRoot != null) {
                                 if (binaryRoot.startsWith(root) || root.startsWith(binaryRoot)) {
                                     binaryRoot = null;
@@ -305,8 +305,7 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
                             updateTableModel(Collections.<String, String>emptyMap(), root, null, true);
                         }
                     }
-                    @SuppressWarnings("unchecked")
-                    List<String> errors = (List<String>) map.get("DW:errors"); // NOI18N
+                    List<String> errors = WizardConstants.DISCOVERY_ERRORS.fromMap(map);
                     if (errors != null && errors.size() > 0) {
                         controller.getWizardDescriptor().putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, errors.get(0));
                     } else {
@@ -317,13 +316,13 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
                     int i = checking.decrementAndGet();
                     if (i == 0) {
                         boolean validBinary = validBinary();
-                        String validBinaryPath = getValidBinaryPath();
+                        List<FSPath> validBinaryPath = getValidBinaryPath();
                         sourcesField.setEnabled(validBinary);
                         sourcesButton.setEnabled(validBinary);
-                        dependeciesComboBox.setEnabled(false);
+                        dependeciesComboBox.setEnabled(true);
                         viewComboBox.setEnabled(validBinary);
                         if (validBinary && validBinaryPath != null) {
-                            String binaryRoot = CndPathUtilities.getDirName(validBinaryPath);
+                            String binaryRoot = CndPathUtilities.getDirName(validBinaryPath.get(0).getPath());
                             if (binaryRoot != null) {
                                 if (binaryRoot.startsWith(root) || root.startsWith(binaryRoot)) {
                                     binaryRoot = null;
@@ -349,9 +348,9 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
                 int i = checking.get();
                 if (i == 0) {
                     boolean validBinary = validBinary();
-                    String validBinaryPath = getValidBinaryPath();
+                    List<FSPath> validBinaryPath = getValidBinaryPath();
                     if (validBinary && validBinaryPath != null) {
-                        String binaryRoot = CndPathUtilities.getDirName(validBinaryPath);
+                        String binaryRoot = CndPathUtilities.getDirName(validBinaryPath.get(0).getPath());
                         if (binaryRoot != null) {
                             if (binaryRoot.startsWith(root) || root.startsWith(binaryRoot)) {
                                 binaryRoot = null;
@@ -400,7 +399,7 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         return dllPaths; 
     }
 
-    private void checkDll(Map<String, String> dllPaths, String root, List<String> searchPaths, FSPath binary) {
+    private void checkDll(Map<String, String> dllPaths, String root, List<String> searchPaths, List<FSPath> binary) {
         cancelSearch();
         if (validBinary()) {
             searching.set(true);
@@ -435,86 +434,85 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         }
     }
     
-    private void processDlls(List<String> searchPaths, FSPath binary, Map<String, String> dllPaths, final AtomicBoolean cancel, String root) {
+    private void processDlls(List<String> searchPaths, List<FSPath> binaries, Map<String, String> dllPaths, final AtomicBoolean cancel, String root) {
         Set<String> checkedDll = new HashSet<>();
-        checkedDll.add(binary.getPath());
-        String ldLibPath = CommonUtilities.getLdLibraryPath(env);
-        ldLibPath = CommonUtilities.addSearchPaths(ldLibPath, searchPaths, binary.getPath());
-        for(String dll : dllPaths.keySet()) {
-            if (cancel.get()) {
-                break;
-            }
-            String p = findLocation(dll, ldLibPath);
-            if (p != null) {
-                dllPaths.put(dll, p);
-            } else {
-                dllPaths.put(dll, null);
-            }
-        }
-        while(true) {
-            List<String> secondary = new ArrayList<>();
-            for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+        for(FSPath binary : binaries) {
+            checkedDll.add(binary.getPath());
+            String ldLibPath = CommonUtilities.getLdLibraryPath(env);
+            ldLibPath = CommonUtilities.addSearchPaths(ldLibPath, searchPaths, binary.getPath());
+            for(String dll : dllPaths.keySet()) {
                 if (cancel.get()) {
                     break;
                 }
-                if (entry.getValue() != null) {
-                    if (!checkedDll.contains(entry.getValue())) {
-                        checkedDll.add(entry.getValue());
-                        final IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
-                        final Map<String, Object> map = new HashMap<>();
-                        map.put("DW:buildResult", entry.getValue()); // NOI18N
-                        map.put("DW:resolveLinks", Boolean.TRUE); // NOI18N
-                        if (env.isRemote()) {
-                            map.put("DW:fileSystem", fileSystem); // NOI18N
-                        }
-                        if (extension != null) {
-                            extension.discoverArtifacts(map);
-                            @SuppressWarnings("unchecked")
-                            List<String> dlls = (List<String>) map.get("DW:dependencies"); // NOI18N
-                            if (dlls != null) {
-                                for(String so : dlls) {
-                                    if (!dllPaths.containsKey(so)) {
-                                        secondary.add(so);
+                String p = findLocation(dll, ldLibPath);
+                if (p != null) {
+                    dllPaths.put(dll, p);
+                } else {
+                    dllPaths.put(dll, null);
+                }
+            }
+            while(true) {
+                List<String> secondary = new ArrayList<>();
+                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                    if (cancel.get()) {
+                        break;
+                    }
+                    if (entry.getValue() != null) {
+                        if (!checkedDll.contains(entry.getValue())) {
+                            checkedDll.add(entry.getValue());
+                            final IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
+                            final Map<String, Object> map = new HashMap<>();
+                            WizardConstants.DISCOVERY_BUILD_RESULT.toMap(map, entry.getValue());
+                            WizardConstants.DISCOVERY_RESOLVE_LINKS.toMap(map, Boolean.TRUE);
+                            if (env.isRemote()) {
+                                WizardConstants.DISCOVERY_BINARY_FILESYSTEM.toMap(map, fileSystem);
+                            }
+                            if (extension != null) {
+                                extension.discoverArtifacts(map);
+                                List<String> dlls = WizardConstants.DISCOVERY_BINARY_DEPENDENCIES.fromMap(map);
+                                if (dlls != null) {
+                                    for(String so : dlls) {
+                                        if (!dllPaths.containsKey(so)) {
+                                            secondary.add(so);
+                                        }
                                     }
                                 }
-                                //@SuppressWarnings("unchecked")
-                                //List<String> searchPaths = (List<String>) map.get("DW:searchPaths"); // NOI18N
                             }
                         }
                     }
                 }
-            }
-            for(String so : secondary) {
-                if (cancel.get()) {
+                for(String so : secondary) {
+                    if (cancel.get()) {
+                        break;
+                    }
+                    dllPaths.put(so, findLocation(so, ldLibPath));
+                }
+                int search = 0;
+                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                    if (entry.getValue() == null) {
+                        search++;
+                    }
+                }
+                updateDllArtifacts(root, dllPaths, search > 0);
+                if (!cancel.get() && search > 0 && root.length() > 1) {
+                    ProgressHandle progress = ProgressHandleFactory.createHandle(getString("SearchForUnresolvedDLL")); //NOI18N
+                    progress.start();
+                    try {
+                        gatherSubFolders(fileSystem.findResource(root), new HashSet<String>(), dllPaths, cancel);
+                    } finally {
+                        progress.finish();
+                    }
+                    updateDllArtifacts(root, dllPaths, false);
+                }
+                int newSearch = 0;
+                for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
+                    if (entry.getValue() == null) {
+                        newSearch++;
+                    }
+                }
+                if (newSearch == search && secondary.isEmpty()) {
                     break;
                 }
-                dllPaths.put(so, findLocation(so, ldLibPath));
-            }
-            int search = 0;
-            for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
-                if (entry.getValue() == null) {
-                    search++;
-                }
-            }
-            updateDllArtifacts(root, dllPaths, search > 0);
-            if (!cancel.get() && search > 0 && root.length() > 1) {
-                ProgressHandle progress = ProgressHandleFactory.createHandle(getString("SearchForUnresolvedDLL")); //NOI18N
-                progress.start();
-                try {
-                    gatherSubFolders(fileSystem.findResource(root), new HashSet<String>(), dllPaths, cancel);
-                } finally {
-                    progress.finish();
-                }
-                updateDllArtifacts(root, dllPaths, false);
-            }
-            int newSearch = 0;
-            for(Map.Entry<String,String> entry : dllPaths.entrySet()) {
-                if (entry.getValue() == null) {
-                    newSearch++;
-                }
-            }
-            if (newSearch == search && secondary.isEmpty()) {
-                break;
             }
         }
     }
@@ -581,7 +579,7 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
             if (ldPath.indexOf(';')>0) {
                 pathSepararor = ";"; // NOI18N
             }
-            Set<String> visited = new HashSet<String>();
+            Set<String> visited = new HashSet<>();
             for(String search :  ldPath.split(pathSepararor)) {
                 if (visited.contains(search)) {
                     continue;
@@ -794,11 +792,37 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
     }// </editor-fold>//GEN-END:initComponents
 
     private void binaryButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_binaryButtonActionPerformed
-        String path = selectBinaryFile(((EditableComboBox)binaryField).getText());
-        if (path == null) {
-            return;
-        }
-        ((EditableComboBox)binaryField).setText(path);
+        final String oldPath = ((EditableComboBox)binaryField).getText();
+        //if (oldPath.isEmpty()) {
+        //    String path = selectBinaryFile(oldPath, true);
+        //    if (path == null) {
+        //        return;
+        //    }
+        //    ((EditableComboBox)binaryField).setText(path);
+        //} else {
+            FileListEditorPanel panel = new FileListEditorPanel(oldPath, env, fileSystem);
+            JButton jOK = new JButton(NbBundle.getMessage(SelectBinaryPanelVisual.class, "SelectBinaryPanelVisual.Browse.OK.Button")); // NOI18N
+            panel.setPreferredSize(new Dimension(450, 200));
+            DialogDescriptor dd = new DialogDescriptor(panel, getString("SelectBinaryPanelVisual.Browse.Multi.Title"), true, 
+                new Object[] { jOK, DialogDescriptor.CANCEL_OPTION},
+                DialogDescriptor.OK_OPTION, DialogDescriptor.DEFAULT_ALIGN, null, null);
+            Dialog dialog = DialogDisplayer.getDefault().createDialog(dd);
+            try {
+                dialog.setVisible(true);
+            } finally {
+                dialog.dispose();
+            }
+            if (dd.getValue() == jOK) {
+                StringBuilder buf = new StringBuilder();
+                for (String s: panel.getFileList()) {
+                    if (buf.length() > 0) {
+                        buf.append(';');
+                    }
+                    buf.append(s);
+                }
+                ((EditableComboBox)binaryField).setText(buf.toString());
+            }
+        //}
     }//GEN-LAST:event_binaryButtonActionPerformed
 
     private void sourcesButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_sourcesButtonActionPerformed
@@ -823,16 +847,16 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
     }//GEN-LAST:event_sourcesButtonActionPerformed
 
     void read(WizardDescriptor wizardDescriptor) {
-        env = (ExecutionEnvironment) wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV);
+        env = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor);
         if (env == null) {
             env = ExecutionEnvironmentFactory.getLocal();
         } else {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_HOST_UID, ExecutionEnvironmentFactory.toUniqueID(env));
+            WizardConstants.PROPERTY_HOST_UID.put(wizardDescriptor, ExecutionEnvironmentFactory.toUniqueID(env));
         }
         fileSystem = FileSystemProvider.getFileSystem(env);
 
         ((EditableComboBox)binaryField).setStorage(BINARY_FILE_KEY, NbPreferences.forModule(SelectBinaryPanelVisual.class));
-        String binary = (String)wizardDescriptor.getProperty(WizardConstants.PROPERTY_BUILD_RESULT);
+        String binary = WizardConstants.PROPERTY_BUILD_RESULT.get(wizardDescriptor);
         if (binary == null) {
             binary = ""; // NOI18N
         }
@@ -841,21 +865,27 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
 
     void store(WizardDescriptor wizardDescriptor) {
         cancelSearch();
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_BUILD_RESULT,  ((EditableComboBox)binaryField).getText().trim());
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_PREFERED_PROJECT_NAME,   new File(((EditableComboBox)binaryField).getText().trim()).getName());
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_SOURCE_FOLDER_PATH,  sourcesField.getText().trim());
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_DEPENDENCY_KIND,  ((ProjectKindItem)dependeciesComboBox.getSelectedItem()).kind);
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_DEPENDENCIES,  getDlls());
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_TRUE_SOURCE_ROOT,  ((ProjectView)viewComboBox.getSelectedItem()).isSourceRoot);
+        String binary = ((EditableComboBox)binaryField).getText().trim();
+        WizardConstants.PROPERTY_BUILD_RESULT.put(wizardDescriptor, binary);
+        String[] split = binary.split(";"); // NOI18N
+        String aBinary = binary;
+        if (split.length > 0) {
+            aBinary = split[0];
+        }
+        WizardConstants.PROPERTY_PREFERED_PROJECT_NAME.put(wizardDescriptor, CndPathUtilities.getBaseName(aBinary));
+        WizardConstants.PROPERTY_SOURCE_FOLDER_PATH.put(wizardDescriptor,  sourcesField.getText().trim());
+        WizardConstants.PROPERTY_DEPENDENCY_KIND.put(wizardDescriptor, ((ProjectKindItem)dependeciesComboBox.getSelectedItem()).kind);
+        WizardConstants.PROPERTY_DEPENDENCIES.put(wizardDescriptor,  getDlls());
+        WizardConstants.PROPERTY_TRUE_SOURCE_ROOT.put(wizardDescriptor,  ((ProjectView)viewComboBox.getSelectedItem()).isSourceRoot);
         ((EditableComboBox)binaryField).setStorage(BINARY_FILE_KEY, NbPreferences.forModule(SelectBinaryPanelVisual.class));
         ((EditableComboBox)binaryField).store();
-        if (wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV) != null) {
+        if (WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor) != null) {
             // forbid tool collection selection
             // project creator detect real tool collection
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN, Boolean.TRUE);
+            WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN.put(wizardDescriptor, Boolean.TRUE);
         }
         // TODO should be inited
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_USER_MAKEFILE_PATH,  ""); // NOI18N
+        WizardConstants.PROPERTY_USER_MAKEFILE_PATH.put(wizardDescriptor,  ""); // NOI18N
     }
 
     private ArrayList<String> getDlls(){
@@ -875,27 +905,35 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         return !searching.get() && checking.get()==0 && validBinary() && validSourceRoot() && validDlls();
     }
 
-    private String getValidBinaryPath() {
-        String path = ((EditableComboBox) binaryField).getText().trim();
-        if (path.isEmpty()) {
+    private List<FSPath> getValidBinaryPath() {
+        List<FSPath> binaries = controller.getWizardStorage().getBinaryPath();
+        if (binaries == null || binaries.isEmpty()) {
             return null;
         }
-        if (CndPathUtilities.isPathAbsolute(path)) {
-            return CndFileUtils.normalizeAbsolutePath(fileSystem, path);
-        } else {
-            return null;
-        }   
+        List<FSPath> res = new ArrayList<>();
+        for(FSPath path : binaries) {
+            if (!CndPathUtilities.isAbsolute(path.getFileSystem(), path.getPath())) {
+                return null;
+            }
+            res.add(new FSPath(fileSystem, CndFileUtils.normalizeAbsolutePath(path.getFileSystem(), path.getPath())));
+        }
+        return res;
     }
     
     private boolean validBinary() {
-        String validBinaryPath = getValidBinaryPath();
+        List<FSPath> validBinaryPath = getValidBinaryPath();
         if (validBinaryPath != null) {
-            FileObject fo = fileSystem.findResource(validBinaryPath); // can be null
-            if (fo != null && fo.isValid()) {
-                return MIMENames.isBinary(fo.getMIMEType());
+            for(FSPath fsPath : validBinaryPath) {
+                FileObject fo = fsPath.getFileObject();
+                if (fo != null && fo.isValid() && MIMENames.isBinary(fo.getMIMEType())){
+                    continue;
+                } else {
+                    return false;
+                }
             }
+            return true;
         }
-            return false;
+        return false;
     }
 
     private boolean validSourceRoot() {
@@ -941,29 +979,59 @@ public class SelectBinaryPanelVisual extends javax.swing.JPanel {
         }
     }
 
-    private String selectBinaryFile(String path) {
+    private String selectBinaryFile(String path, boolean muliSelection) {
         FileFilter[] filters = FileFilterFactory.getBinaryFilters(fileSystem);
         if (path.isEmpty()) { 
             path = SelectModePanel.getDefaultDirectory(env);
+        } else {
+            if (path.startsWith("\"")) { //NOI18N
+                int i = path.indexOf('"', 0);
+                int j = path.indexOf('"', 1);
+                if (i >= 0 && j > i) {
+                    path = path.substring(i+1, j);
+                }
+            }
         }
+        
         JFileChooser fileChooser = NewProjectWizardUtils.createFileChooser(
                 controller.getWizardDescriptor(),
-                getString("SelectBinaryPanelVisual.Browse.Title"), // NOI18N
-                getString("SelectBinaryPanelVisual.Browse.Select"), // NOI18N
+                muliSelection?getString("SelectBinaryPanelVisual.Browse.Multi.Title"):getString("SelectBinaryPanelVisual.Browse.Title"), // NOI18N
+                muliSelection?getString("SelectBinaryPanelVisual.Browse.Multi.Select"):getString("SelectBinaryPanelVisual.Browse.Select"), // NOI18N
                 JFileChooser.FILES_ONLY,
                 filters,
                 path,
                 false
                 );
+        if (muliSelection) {
+            fileChooser.setMultiSelectionEnabled(true);
+        }
         int ret = fileChooser.showOpenDialog(this);
         if (ret == JFileChooser.CANCEL_OPTION) {
             return null;
         }
-        return fileChooser.getSelectedFile().getPath();
+        if (!muliSelection) {
+            return fileChooser.getSelectedFile().getPath();
+        }
+        File[] selected = fileChooser.getSelectedFiles();
+        if (selected == null || selected.length == 0) {
+            return null;
+        }
+        if (selected.length == 1) {
+            return selected[0].getPath();
+        } else {
+            StringBuilder buf = new StringBuilder();
+            for(File f : selected) {
+                if (buf.length() > 0) {
+                    buf.append(';');
+                }
+                buf.append(f.getPath());
+            }
+            return buf.toString();
+        }
     }
 
     private void tableButtonActionPerformed(int row) {
-        String path = selectBinaryFile((String) table.getModel().getValueAt(row, 2));
+        String path = selectBinaryFile((String) table.getModel().getValueAt(row, 2), false);
         if (path == null) {
             return;
         }
