@@ -43,17 +43,22 @@
  */
 package org.netbeans.modules.cnd.makeproject.ui.wizards;
 
+import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.api.remote.ServerList;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport.BuildFile;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels.NamedPanel;
-import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels.WizardStorage;
-import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport.PreBuildArtifact;
+import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
@@ -133,11 +138,7 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
     }
 
     private void setMode(boolean isSimple) {
-        if (isSimple) {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE, Boolean.TRUE);
-        } else {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE, Boolean.FALSE);
-        }
+        WizardConstants.PROPERTY_SIMPLE_MODE.put(wizardDescriptor, isSimple);
         validate();
     }
 
@@ -183,7 +184,7 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
         String[] res;
         Object o = component.getClientProperty(WizardDescriptor.PROP_CONTENT_DATA);
         String[] names = (String[]) o;
-        if (Boolean.TRUE.equals(wizardDescriptor.getProperty(WizardConstants.PROPERTY_SIMPLE_MODE))){
+        if (Boolean.TRUE.equals(WizardConstants.PROPERTY_SIMPLE_MODE.get(wizardDescriptor))){
             res = new String[]{names[0]};
         } else {
             res = new String[]{names[0], "..."}; // NOI18N
@@ -194,7 +195,7 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
 
     @Override
     public boolean isFinishPanel() {
-        return  Boolean.TRUE.equals(wizardDescriptor.getProperty(WizardConstants.PROPERTY_SIMPLE_MODE));
+        return  Boolean.TRUE.equals(WizardConstants.PROPERTY_SIMPLE_MODE.get(wizardDescriptor));
     }
 
     // You can use a settings object to keep track of state. Normally the
@@ -204,8 +205,8 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
     @Override
     public void readSettings(WizardDescriptor settings) {
         wizardDescriptor = settings;
-        if (wizardDescriptor.getProperty(WizardConstants.PROPERTY_SIMPLE_MODE) == null) {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE, Boolean.TRUE);
+        if (WizardConstants.PROPERTY_SIMPLE_MODE.get(wizardDescriptor) == null) {
+            WizardConstants.PROPERTY_SIMPLE_MODE.put(wizardDescriptor, Boolean.TRUE);
         }
         getComponent().read(wizardDescriptor);
     }
@@ -213,9 +214,11 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
     @Override
     public void storeSettings(WizardDescriptor settings) {
         getComponent().store(settings);
+         if (Boolean.TRUE.equals(WizardConstants.PROPERTY_SIMPLE_MODE.get(settings))) {
+             wizardStorage.finishWizard(wizardDescriptor);
+         }
     }
 
-    @Override
     public WizardStorage getWizardStorage(){
         return wizardStorage;
     }
@@ -225,31 +228,74 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
     }
 
     boolean isFullRemote() {
-        return wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV) != null;
+        return WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor) != null;
     }
 
     private class MyWizardStorage implements WizardStorage {
-        private volatile String projectPath = ""; // NOI18N
-        private volatile FileObject sourceFileObject;
-        private volatile String flags = ""; // NOI18N
-        private volatile boolean setMain = true;
-        private volatile boolean buildProject = true;
-        private volatile CompilerSet cs;
-        private volatile boolean defaultCompilerSet;
-        private volatile ExecutionEnvironment buildEnv;
-        private volatile ExecutionEnvironment sourceEnv;
-        private volatile FileObject makefileFO;
+        volatile String projectPath = ""; // NOI18N
+        volatile FileObject sourceFileObject;
+        volatile String flags = ""; // NOI18N
+        volatile boolean setMain = true;
+        volatile boolean buildProject = true;
+        volatile CompilerSet cs;
+        volatile boolean defaultCompilerSet;
+        volatile ExecutionEnvironment buildEnv;
+        volatile ExecutionEnvironment sourceEnv;
+        volatile ExecutionEnvironment fullRemoteEnv;
+        volatile FileObject makefileFO;
 
         public MyWizardStorage() {
             buildEnv = ServerList.getDefaultRecord().getExecutionEnvironment();
             sourceEnv = NewProjectWizardUtils.getDefaultSourceEnvironment();
         }
 
-        @Override
-        public WizardDescriptor getAdapter() {
-            return new WizardDescriptorAdapter(this);
+        void finishWizard(WizardDescriptor settings) {
+            if (getSourcesFileObject() == null) {
+                // called from WizardDescriptor.resetWizard()
+                return;
+            }
+            WizardConstants.PROPERTY_HOST_UID.put(settings, ExecutionEnvironmentFactory.toUniqueID(getExecutionEnvironment()));
+            WizardConstants.PROPERTY_SOURCE_HOST_ENV.put(settings, getSourceExecutionEnvironment());
+            WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.put(settings, isDefaultCompilerSet());
+            WizardConstants.PROPERTY_TOOLCHAIN.put(settings, getCompilerSet());
+            WizardConstants.PROPERTY_NATIVE_PROJ_DIR.put(settings, getSourcesFileObject().getPath());
+            WizardConstants.PROPERTY_NATIVE_PROJ_FO.put(settings, getSourcesFileObject());
+            WizardConstants.PROPERTY_SIMPLE_MODE.put(settings, Boolean.TRUE);
+            try {
+                WizardConstants.PROPERTY_PROJECT_FOLDER.put(settings, new FSPath(getSourcesFileObject().getFileSystem(), getSourcesFileObject().getPath()));
+            } catch (FileStateInvalidException ex) {
+            }
+            PreBuildArtifact scriptArtifact = getScriptArtifact();
+            BuildFile makeArtifact = null;
+            if (scriptArtifact != null) {
+                WizardConstants.PROPERTY_RUN_CONFIGURE.put(settings, Boolean.TRUE);
+                FileObject script = scriptArtifact.getScript();
+                WizardConstants.PROPERTY_CONFIGURE_RUN_FOLDER.put(settings, script.getParent().getPath());
+                WizardConstants.PROPERTY_CONFIGURE_SCRIPT_PATH.put(settings, script.getPath());
+                String args = scriptArtifact.getArguments(buildEnv, cs, flags);
+                WizardConstants.PROPERTY_CONFIGURE_SCRIPT_ARGS.put(settings, args);
+                String command = scriptArtifact.getCommandLine(args, script.getParent().getPath());
+                WizardConstants.PROPERTY_CONFIGURE_COMMAND.put(settings, command);
+                
+                String makefile = script.getParent().getPath()+"/Makefile"; //NOI18N
+                ExecutionEnvironment env = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor);
+                if (env != null) {
+                    makefile = RemoteFileUtil.normalizeAbsolutePath(makefile, env);
+                }
+                makeArtifact = BuildSupport.scriptToBuildFile(makefile);
+            }
+            if (makeArtifact == null) {
+                makeArtifact = getMakeArtifact();
+            }
+            if (makeArtifact != null) {
+                WizardConstants.PROPERTY_RUN_REBUILD.put(settings, Boolean.TRUE);
+                WizardConstants.PROPERTY_USER_MAKEFILE_PATH.put(settings, makeArtifact.getFile());
+                WizardConstants.PROPERTY_WORKING_DIR.put(settings, CndPathUtilities.getDirName(makeArtifact.getFile()));
+                WizardConstants.PROPERTY_BUILD_COMMAND.put(settings, makeArtifact.getBuildCommandLine(null, CndPathUtilities.getDirName(makeArtifact.getFile())));
+                WizardConstants.PROPERTY_CLEAN_COMMAND.put(settings, makeArtifact.getCleanCommandLine(null, CndPathUtilities.getDirName(makeArtifact.getFile())));
+            }
         }
-
+        
         /**
          * @return the path
          */
@@ -288,24 +334,37 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
 
         @Override
         public String getConfigure(){
-            //if (projectPath.length() == 0) {
-            //    return null;
-            //}
+            PreBuildArtifact scriptArtifact = getScriptArtifact();
+            if (scriptArtifact != null) {
+                return scriptArtifact.getScript().getPath();
+            }
+            return null;
+        }
+
+        private PreBuildArtifact getScriptArtifact(){
             if (sourceFileObject != null) {
-                return ConfigureUtils.findConfigureScript(sourceFileObject);
+                return PreBuildSupport.findArtifactInFolder(sourceFileObject, sourceEnv, cs);
             } else {
                 if (wizardDescriptor != null) {
-                    ExecutionEnvironment env = (ExecutionEnvironment) wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV);
+                    ExecutionEnvironment env = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor);
                     if (env == null) {
                         env = ExecutionEnvironmentFactory.getLocal();
                     }
                     FileSystem fileSystem = FileSystemProvider.getFileSystem(env);
-                    return ConfigureUtils.findConfigureScript(fileSystem.findResource(projectPath));
+                     return PreBuildSupport.findArtifactInFolder(fileSystem.findResource(projectPath), sourceEnv, cs);
                 }
             }
             return null;
         }
 
+        private BuildFile getMakeArtifact() {
+            if (makefileFO != null) {
+                return BuildSupport.scriptToBuildFile(makefileFO.getPath());
+            }
+            return null;
+        }
+
+        
         @Override
         public String getMake(){
             return (makefileFO == null) ? null : makefileFO.getPath();
@@ -324,14 +383,6 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
             return flags;
         }
 
-        /**
-         * @return the flags
-         */
-        @Override
-        public String getRealFlags() {
-            return ConfigureUtils.getConfigureArguments(buildEnv, cs, getConfigure(), flags);
-        }
-
         /**
          * @param flags the flags to set
          */
@@ -341,6 +392,28 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
             validate();
         }
 
+        /**
+         * @return the arguments
+         */
+        @Override
+        public String getRealFlags() {
+            PreBuildArtifact scriptArtifact = getScriptArtifact();
+            if (scriptArtifact != null) {
+                return scriptArtifact.getArguments(buildEnv, cs, flags);
+            }
+            return null;
+        }
+
+        @Override
+        public String getRealCommand() {
+            PreBuildArtifact scriptArtifact = getScriptArtifact();
+            if (scriptArtifact != null) {
+                String args = scriptArtifact.getArguments(buildEnv, cs, flags);
+                return scriptArtifact.getCommandLine(args, scriptArtifact.getScript().getParent().getPath());
+            }
+            return null;
+        }
+
         /**
          * @return the setMain
          */
@@ -414,54 +487,15 @@ public class SelectModeDescriptorPanel implements ProjectWizardPanels.MakeModePa
         public boolean isDefaultCompilerSet() {
             return defaultCompilerSet;
         }
-    }
 
-    private static class WizardDescriptorAdapter extends WizardDescriptor{
-        private final WizardStorage storage;
-        public WizardDescriptorAdapter(WizardStorage storage) {
-            this.storage = storage;
-        }
         @Override
-        public synchronized Object getProperty(String name) {
-            if ("realFlags".equals(name)) { // NOI18N
-                return storage.getRealFlags();
-            } else if ("buildProject".equals(name)) { // NOI18N
-                if (storage.isBuildProject()) {
-                    return Boolean.TRUE;
-                } else {
-                    return Boolean.FALSE;
-                }
-            } else if ("setMain".equals(name)) { // NOI18N
-                if (storage.isSetMain()) {
-                    return Boolean.TRUE;
-                } else {
-                    return Boolean.FALSE;
-                }
-            } else if (WizardConstants.PROPERTY_SIMPLE_MODE.equals(name)) { // NOI18N
-                return Boolean.TRUE;
-            } else if (WizardConstants.PROPERTY_USER_MAKEFILE_PATH.equals(name)) { // NOI18N
-                return storage.getMake();
-            } else if (WizardConstants.PROPERTY_CONFIGURE_SCRIPT_PATH.equals(name)) { // NOI18N
-                return storage.getConfigure();
-            } else if (WizardConstants.PROPERTY_HOST_UID.equals(name)) { // NOI18N
-                return ExecutionEnvironmentFactory.toUniqueID(storage.getExecutionEnvironment());
-            } else if (WizardConstants.PROPERTY_SOURCE_HOST_ENV.equals(name)) {
-                return storage.getSourceExecutionEnvironment();
-            } else if (WizardConstants.PROPERTY_TOOLCHAIN.equals(name)) { // NOI18N
-                return storage.getCompilerSet();
-            } else if (WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.equals(name)) { // NOI18N
-                return storage.isDefaultCompilerSet();
-            } else if (WizardConstants.PROPERTY_NATIVE_PROJ_DIR.equals(name)) { // NOI18N
-                return storage.getSourcesFileObject().getPath();
-            } else if (WizardConstants.PROPERTY_NATIVE_PROJ_FO.equals(name)) { // NOI18N
-                return storage.getSourcesFileObject();
-            } else if (WizardConstants.PROPERTY_PROJECT_FOLDER.equals(name)) { // NOI18N
-                try {
-                    return new FSPath(storage.getSourcesFileObject().getFileSystem(), storage.getSourcesFileObject().getPath());
-                } catch (FileStateInvalidException ex) {
-                }
-            }
-            return super.getProperty(name);
+        public void setFullRemoteEnv(ExecutionEnvironment fullRemoteEnv) {
+            this.fullRemoteEnv = fullRemoteEnv;
+        }
+
+        @Override
+        public ExecutionEnvironment getFullRemoteEnv() {
+            return fullRemoteEnv;
         }
     }
 }
