@@ -43,12 +43,14 @@
  */
 package org.netbeans.modules.cnd.makeproject.ui.wizards;
 
+import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.io.File;
 import java.io.IOException;
 import java.util.Collection;
+import java.util.concurrent.atomic.AtomicBoolean;
 import javax.swing.JFileChooser;
 import javax.swing.SwingUtilities;
 import javax.swing.text.html.HTMLEditorKit;
@@ -58,16 +60,19 @@ import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.api.remote.ServerList;
 import org.netbeans.modules.cnd.api.remote.ServerRecord;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
-import org.netbeans.modules.cnd.api.toolchain.ui.ToolsCacheManager;
 import org.netbeans.modules.cnd.makeproject.MakeBasedProjectFactorySingleton;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.support.MakeProjectHelper;
-import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport.BuildFile;
+import org.netbeans.modules.cnd.makeproject.api.wizards.BuildSupport.BuildFileProvider;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport.PreBuildArtifact;
+import org.netbeans.modules.cnd.makeproject.api.wizards.PreBuildSupport.PreBuildArtifactProvider;
 import org.netbeans.modules.cnd.makeproject.ui.wizards.PanelProjectLocationVisual.DevHostsInitializer;
 import org.netbeans.modules.cnd.makeproject.ui.wizards.PanelProjectLocationVisual.ToolCollectionItem;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.FSPath;
-import org.netbeans.modules.cnd.utils.MIMENames;
 import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.cnd.utils.ui.EditableComboBox;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
@@ -92,6 +97,7 @@ public class SelectModePanel extends javax.swing.JPanel {
 
     private final SelectModeDescriptorPanel controller;
     private volatile boolean initialized = false;
+    private volatile boolean firstTime = true;
     private static final String SOURCES_FILE_KEY = "sourcesField"; // NOI18N
     private ExecutionEnvironment env;
     private FileSystem fileSystem;
@@ -99,6 +105,7 @@ public class SelectModePanel extends javax.swing.JPanel {
     private static final RequestProcessor RP2 = new RequestProcessor("SelectRoot", 1); // NOI18N
     private final RequestProcessor.Task refreshSourceFolderTask;
     private final RefreshRunnable refreshRunnable;
+    private final AtomicBoolean updateHost = new AtomicBoolean(false);
 
     /** Creates new form SelectModePanel */
     public SelectModePanel(SelectModeDescriptorPanel controller) {
@@ -112,15 +119,22 @@ public class SelectModePanel extends javax.swing.JPanel {
         addListeners();
     }
     
-    private void refreshSourceFolder() {
+    private void refreshSourceFolder(boolean refresh) {
         String path = ((EditableComboBox)sourceFolder).getText();
-        FileObject fileObject;
-        if (path.isEmpty()) {
-            fileObject = null;
+        if (refresh) {
+            FileObject fileObject;
+            if (path.isEmpty()) {
+                fileObject = null;
+            } else {
+                fileObject = fileSystem.findResource(path);
+            }
+            controller.getWizardStorage().setSourcesFileObject(fileObject);
         } else {
-            fileObject = fileSystem.findResource(path);
+            FileObject oldFO = controller.getWizardStorage().getSourcesFileObject();
+            if (oldFO == null && !path.isEmpty()) {
+                controller.getWizardStorage().setSourcesFileObject(fileSystem.findResource(path));
+            }
         }
-        controller.getWizardStorage().setSourcesFileObject(fileObject);
     }
     
     private void addListeners(){
@@ -158,7 +172,8 @@ public class SelectModePanel extends javax.swing.JPanel {
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    // <editor-fold defaultstate="collapsed" desc="Generated Code">                          
+    @SuppressWarnings("unchecked")
+    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
     private void initComponents() {
         java.awt.GridBagConstraints gridBagConstraints;
 
@@ -208,7 +223,6 @@ public class SelectModePanel extends javax.swing.JPanel {
         java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("org/netbeans/modules/cnd/makeproject/ui/wizards/Bundle"); // NOI18N
         org.openide.awt.Mnemonics.setLocalizedText(simpleMode, bundle.getString("SimpleModeButtonText")); // NOI18N
         simpleMode.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        simpleMode.setMargin(new java.awt.Insets(0, 0, 0, 0));
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 5;
@@ -220,7 +234,6 @@ public class SelectModePanel extends javax.swing.JPanel {
         buttonGroup1.add(advancedMode);
         org.openide.awt.Mnemonics.setLocalizedText(advancedMode, bundle.getString("AdvancedModeButtonText")); // NOI18N
         advancedMode.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        advancedMode.setMargin(new java.awt.Insets(0, 0, 0, 0));
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 6;
@@ -236,6 +249,12 @@ public class SelectModePanel extends javax.swing.JPanel {
         gridBagConstraints.gridwidth = 3;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
         add(modeLabel, gridBagConstraints);
+
+        toolchainComboBox.addItemListener(new java.awt.event.ItemListener() {
+            public void itemStateChanged(java.awt.event.ItemEvent evt) {
+                toolchainComboBoxItemStateChanged(evt);
+            }
+        });
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 1;
         gridBagConstraints.gridy = 3;
@@ -254,7 +273,6 @@ public class SelectModePanel extends javax.swing.JPanel {
         add(toolchainLabel, gridBagConstraints);
 
         hostComboBox.addItemListener(new java.awt.event.ItemListener() {
-            @Override
             public void itemStateChanged(java.awt.event.ItemEvent evt) {
                 hostComboBoxItemStateChanged(evt);
             }
@@ -287,7 +305,6 @@ public class SelectModePanel extends javax.swing.JPanel {
 
         org.openide.awt.Mnemonics.setLocalizedText(sourceBrowseButton, org.openide.util.NbBundle.getMessage(SelectModePanel.class, "SELECT_MODE_BROWSE_PROJECT_FOLDER")); // NOI18N
         sourceBrowseButton.addActionListener(new java.awt.event.ActionListener() {
-            @Override
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 sourceBrowseButtonActionPerformed(evt);
             }
@@ -306,36 +323,40 @@ public class SelectModePanel extends javax.swing.JPanel {
         gridBagConstraints.weightx = 1.0;
         gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
         add(sourceFolder, gridBagConstraints);
-    }// </editor-fold>                        
+    }// </editor-fold>//GEN-END:initComponents
 
-    private void hostComboBoxItemStateChanged(java.awt.event.ItemEvent evt) {                                              
+    private void toolchainComboBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_toolchainComboBoxItemStateChanged
         if (!initialized) {
             return;
         }
+        if (updateHost.get()) {
+            return;
+        }
         if (evt.getStateChange() == ItemEvent.SELECTED) {
-            ServerRecord newItem = (ServerRecord) evt.getItem();
-            PanelProjectLocationVisual.updateToolchains(toolchainComboBox, newItem);
-            this.controller.fireChangeEvent(); // Notify that the panel changed
+            controller.getWizardStorage().setCompilerSet(getSelectedCompilerSet());
+            refreshInstruction(false);
         }
-    }
-    
-    public static String getDefaultDirectory(ExecutionEnvironment env) {
-        String home;
-        if (env.isLocal()) {
-            home = System.getProperty("user.home"); // NOI18N
-        } else if (!(HostInfoUtils.isHostInfoAvailable(env) && ConnectionManager.getInstance().isConnectedTo(env))) {
-            home = null;
-        } else {
-            try {
-                home = HostInfoUtils.getHostInfo(env).getUserDir();
-            } catch (IOException | ConnectionManager.CancellationException ex) {
-                home = null;
-            }
-        }
-        return home == null ? "" : home; // NOI18N
-    }
+    }//GEN-LAST:event_toolchainComboBoxItemStateChanged
 
-    private void sourceBrowseButtonActionPerformed(java.awt.event.ActionEvent evt) {
+    private void hostComboBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_hostComboBoxItemStateChanged
+        if (!initialized) {
+            return;
+        }
+        try {
+            updateHost.set(true);
+            if (evt.getStateChange() == ItemEvent.SELECTED) {
+                ServerRecord newItem = (ServerRecord) evt.getItem();
+                PanelProjectLocationVisual.updateToolchains(toolchainComboBox, newItem);
+                controller.getWizardStorage().setExecutionEnvironment(getSelectedExecutionEnvironment());
+                controller.getWizardStorage().setCompilerSet(getSelectedCompilerSet());
+                refreshInstruction(false);
+            }
+        } finally {
+            updateHost.set(false);
+        }
+    }//GEN-LAST:event_hostComboBoxItemStateChanged
+
+    private void sourceBrowseButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_sourceBrowseButtonActionPerformed
         String path = ((EditableComboBox)sourceFolder).getText();
         if (path.isEmpty()) { 
             path = SelectModePanel.getDefaultDirectory(env);
@@ -359,26 +380,45 @@ public class SelectModePanel extends javax.swing.JPanel {
             path = selectedFile.getPath();
             ((EditableComboBox)sourceFolder).setText(path);
         }
-    }                                                  
-    
+    }//GEN-LAST:event_sourceBrowseButtonActionPerformed
+
+    public static String getDefaultDirectory(ExecutionEnvironment env) {
+        String home;
+        if (env.isLocal()) {
+            home = System.getProperty("user.home"); // NOI18N
+        } else if (!(HostInfoUtils.isHostInfoAvailable(env) && ConnectionManager.getInstance().isConnectedTo(env))) {
+            home = null;
+        } else {
+            try {
+                home = HostInfoUtils.getHostInfo(env).getUserDir();
+            } catch (IOException | ConnectionManager.CancellationException ex) {
+                home = null;
+            }
+        }
+        return home == null ? "" : home; // NOI18N
+    }
+   
     void read(WizardDescriptor wizardDescriptor) {
         initialized = false;
-        env = (ExecutionEnvironment) wizardDescriptor.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV);
+        env = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor);
         if (env != null) {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_HOST_UID, ExecutionEnvironmentFactory.toUniqueID(env));
+            WizardConstants.PROPERTY_HOST_UID.put(wizardDescriptor, ExecutionEnvironmentFactory.toUniqueID(env));
         } else {
             env = ExecutionEnvironmentFactory.getLocal();
         }
         fileSystem = FileSystemProvider.getFileSystem(env);
         ((EditableComboBox)sourceFolder).setStorage(SOURCES_FILE_KEY, NbPreferences.forModule(SelectModePanel.class));
-        ((EditableComboBox)sourceFolder).read("");
+        if (firstTime) {
+            ((EditableComboBox)sourceFolder).read("");
+        }
         refreshInstruction(false);
+        firstTime = false;
         
-        String hostUID = (String) wizardDescriptor.getProperty(WizardConstants.PROPERTY_HOST_UID);
-        CompilerSet cs = (CompilerSet) wizardDescriptor.getProperty(WizardConstants.PROPERTY_TOOLCHAIN);
-        boolean isDefaultCompilerSet = Boolean.TRUE.equals(wizardDescriptor.getProperty(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT));
+        String hostUID = WizardConstants.PROPERTY_HOST_UID.get(wizardDescriptor);
+        CompilerSet cs = WizardConstants.PROPERTY_TOOLCHAIN.get(wizardDescriptor);
+        boolean isDefaultCompilerSet = Boolean.TRUE.equals(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.get(wizardDescriptor));
         RP.post(new DevHostsInitializer(hostUID, cs, isDefaultCompilerSet, false,
-                (ToolsCacheManager) wizardDescriptor.getProperty(WizardConstants.PROPERTY_TOOLS_CACHE_MANAGER)) { // NOI18N
+                WizardConstants.PROPERTY_TOOLS_CACHE_MANAGER.get(wizardDescriptor)) {
             @Override
             public void updateComponents(Collection<ServerRecord> records, ServerRecord srToSelect, CompilerSet csToSelect, boolean isDefaultCompilerSet, boolean enabled) {
                 boolean enableHost = enabled;
@@ -398,14 +438,19 @@ public class SelectModePanel extends javax.swing.JPanel {
         }
         return ServerList.getDefaultRecord().getExecutionEnvironment();
     }
+    
+    private CompilerSet getSelectedCompilerSet() {
+        Object tc = toolchainComboBox.getSelectedItem();
+        if (tc instanceof ToolCollectionItem) {
+            return ((ToolCollectionItem) tc).getCompilerSet();
+        }
+        return null;
+    }
 
     void store(WizardDescriptor wizardDescriptor) {
-        if (simpleMode.isSelected()) {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE, Boolean.TRUE);
-        } else {
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE, Boolean.FALSE);
-        }
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_SIMPLE_MODE_FOLDER, ((EditableComboBox)sourceFolder).getText().trim());
+        WizardConstants.PROPERTY_SIMPLE_MODE.put(wizardDescriptor, simpleMode.isSelected());
+        controller.getWizardStorage().setFullRemoteEnv(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wizardDescriptor));
+        WizardConstants.PROPERTY_SIMPLE_MODE_FOLDER.put(wizardDescriptor, ((EditableComboBox)sourceFolder).getText().trim());
         ((EditableComboBox)sourceFolder).setStorage(SOURCES_FILE_KEY, NbPreferences.forModule(SelectModePanel.class));
         ((EditableComboBox)sourceFolder).store();
         String folderPath = ((EditableComboBox)sourceFolder).getText().trim();
@@ -415,25 +460,25 @@ public class SelectModePanel extends javax.swing.JPanel {
         if (CndPathUtilities.isPathAbsolute(folderPath)) {
             String normalizeAbsolutePath = RemoteFileUtil.normalizeAbsolutePath(folderPath, env);
             FSPath path = new FSPath(fileSystem, normalizeAbsolutePath);
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_PROJECT_FOLDER, path);
+            WizardConstants.PROPERTY_PROJECT_FOLDER.put(wizardDescriptor, path);
         }
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN, Boolean.TRUE);
+        WizardConstants.PROPERTY_READ_ONLY_TOOLCHAIN.put(wizardDescriptor, Boolean.TRUE);
 
         ExecutionEnvironment ee = getSelectedExecutionEnvironment();
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_HOST_UID, ExecutionEnvironmentFactory.toUniqueID(ee));
+        WizardConstants.PROPERTY_HOST_UID.put(wizardDescriptor, ExecutionEnvironmentFactory.toUniqueID(ee));
         controller.getWizardStorage().setExecutionEnvironment(ee);
 
         Object tc = toolchainComboBox.getSelectedItem();
         if (tc != null && tc instanceof ToolCollectionItem) {
             ToolCollectionItem item = (ToolCollectionItem) tc;
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_TOOLCHAIN, item.getCompilerSet());
-            wizardDescriptor.putProperty(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT, item.isDefaultCompilerSet());
+            WizardConstants.PROPERTY_TOOLCHAIN.put(wizardDescriptor, item.getCompilerSet());
+            WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.put(wizardDescriptor, item.isDefaultCompilerSet());
             controller.getWizardStorage().setCompilerSet(item.getCompilerSet());
             controller.getWizardStorage().setDefaultCompilerSet(item.isDefaultCompilerSet());
         }
         FileObject fo = controller.getWizardStorage().getSourcesFileObject();
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_NATIVE_PROJ_FO, fo);
-        wizardDescriptor.putProperty(WizardConstants.PROPERTY_NATIVE_PROJ_DIR, (fo == null) ? null : fo.getPath()); 
+        WizardConstants.PROPERTY_NATIVE_PROJ_FO.put(wizardDescriptor, fo);
+        WizardConstants.PROPERTY_NATIVE_PROJ_DIR.put(wizardDescriptor, (fo == null) ? null : fo.getPath()); 
         initialized = false;
     }
 
@@ -498,13 +543,25 @@ public class SelectModePanel extends javax.swing.JPanel {
                     Exceptions.printStackTrace(ex);
                 }
             }
-            if (ConfigureUtils.findConfigureScript(controller.getWizardStorage().getSourcesFileObject()) != null) {
+            CompilerSet cs = null;
+            Object tc = toolchainComboBox.getSelectedItem();
+            if (tc != null && tc instanceof ToolCollectionItem) {
+                ToolCollectionItem item = (ToolCollectionItem) tc;
+                cs = item.getCompilerSet();
+            }
+            ExecutionEnvironment ee = getSelectedExecutionEnvironment();
+            FileObject sourcesFileObject = controller.getWizardStorage().getSourcesFileObject();
+            PreBuildArtifact findConfigureScripts = PreBuildSupport.findArtifactInFolder(sourcesFileObject, ee, cs);
+            if (findConfigureScripts != null) {
                 return true;
             }
-            FileObject makeFO = ConfigureUtils.findMakefile(controller.getWizardStorage().getSourcesFileObject());
-            if (makeFO != null){
-                controller.getWizardStorage().setMake(makeFO);
-                return true;
+            BuildFile makeFile = BuildSupport.findBuildFileInFolder(projectDirFO, ee, cs);
+            if (makeFile != null) {
+                FileObject makeFO = new FSPath(projectDirFO.getFileSystem(), makeFile.getFile()).getFileObject();
+                if (makeFO != null && makeFO.isValid()) {
+                    controller.getWizardStorage().setMake(makeFO);
+                    return true;
+                }
             }
             if (simpleMode.isSelected()) {
                 messageKind = notFoundMakeAndConfigure;
@@ -531,7 +588,7 @@ public class SelectModePanel extends javax.swing.JPanel {
         }
     }
         
-    // Variables declaration - do not modify                     
+    // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.JRadioButton advancedMode;
     private javax.swing.ButtonGroup buttonGroup1;
     private javax.swing.JComboBox hostComboBox;
@@ -546,7 +603,7 @@ public class SelectModePanel extends javax.swing.JPanel {
     private javax.swing.JLabel sourceFolderLabel;
     private javax.swing.JComboBox toolchainComboBox;
     private javax.swing.JLabel toolchainLabel;
-    // End of variables declaration                   
+    // End of variables declaration//GEN-END:variables
 
     private void disableHostSensitiveComponents() {
         PanelProjectLocationVisual.disableHostsInfo(this.hostComboBox, this.toolchainComboBox);
@@ -562,7 +619,9 @@ public class SelectModePanel extends javax.swing.JPanel {
         this.simpleMode.setEnabled(true);
         refreshInstruction(false);
         initialized = true;
-        SelectModePanel.this.controller.fireChangeEvent(); // Notify that the panel changed
+        controller.getWizardStorage().setCompilerSet(csToSelect);
+        controller.getWizardStorage().setExecutionEnvironment(env);
+        refreshInstruction(false);
     }
 
 
@@ -594,38 +653,38 @@ public class SelectModePanel extends javax.swing.JPanel {
             }
             boolean simple = simpleMode.isSelected();
             SelectModePanel.this.controller.getWizardStorage().setMode(simple);            
-            if (refresh) {
-                refreshSourceFolder();
-            }
+            refreshSourceFolder(refresh);
             synchronized(lock) {
                 if (startCount < generation) {
                     return;
                 }
             }
             if (simple) {
-                String tool = "Makefile"; // NOI18N
-                String toolsInfo = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionExtraText_Make"); // NOI18N
+                String tool = ""; // NOI18N
+                String toolsInfo = ""; // NOI18N
                 if (SelectModePanel.this.controller.getWizardStorage() != null) {
                     String configure = SelectModePanel.this.controller.getWizardStorage().getConfigure();
                     if (configure != null) {
-                        toolsInfo = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionExtraText_Configure"); // NOI18N
-                        tool = configure;
-                        String normalizedPath = CndFileUtils.normalizeAbsolutePath(configure);
-                        FileObject fo = CndFileUtils.toFileObject(normalizedPath);
+                        String normalizedPath = CndFileUtils.normalizeAbsolutePath(fileSystem, configure);
+                        FileObject fo = CndFileUtils.toFileObject(fileSystem, normalizedPath);
                         if (fo != null && fo.isValid()) {
-                            String mimeType = fo.getMIMEType();
-                            if (MIMENames.CMAKE_MIME_TYPE.equals(mimeType)) {
-                                toolsInfo = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionExtraText_CMake"); // NOI18N
-                                tool = "cmake"; // NOI18N
-                            } else if (MIMENames.QTPROJECT_MIME_TYPE.equals(mimeType)) {
-                                toolsInfo = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionExtraText_QMake"); // NOI18N
-                                tool = "qmake"; // NOI18N
+                            PreBuildArtifact scriptArtifact = PreBuildSupport.scriptToArtifact(fo);
+                            if (scriptArtifact != null) {
+                                PreBuildArtifactProvider preBuildProvider = PreBuildSupport.getPreBuildProvider(scriptArtifact);
+                                toolsInfo = preBuildProvider.getHint();
+                                tool = preBuildProvider.getToolName();
                             }
                         }
                     } else {
                         String makefile = SelectModePanel.this.controller.getWizardStorage().getMake();
                         if (makefile != null) {
-                            tool = makefile;
+                            BuildFile scriptFile = BuildSupport.scriptToBuildFile(makefile);
+                            if (scriptFile != null) {
+                                SelectModePanel.this.controller.getWizardStorage().getProjectPath();
+                                tool = CndPathUtilities.getRelativePath(((EditableComboBox)sourceFolder).getText().trim(), makefile);
+                                BuildFileProvider buildFileProvider = BuildSupport.getBuildFileProvider(scriptFile);
+                                toolsInfo = buildFileProvider.getHint();
+                            }
                         }
                     }
                 }
@@ -634,22 +693,31 @@ public class SelectModePanel extends javax.swing.JPanel {
                         return;
                     }
                 }
-                String modeInfo = NbBundle.getMessage(SelectModePanel.class, "SimpleModeButtonText", tool); // NOI18N
-                final String message1 = modeInfo;
-                final String message2 = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionText", toolsInfo);
-                SwingUtilities.invokeLater(new Runnable() {
-                    @Override
-                    public void run() {
-                        org.openide.awt.Mnemonics.setLocalizedText(simpleMode, message1);
-                        instructions.setText(message2);
-                    }
-                });
+                if (tool == null || tool.isEmpty()) {
+                    SwingUtilities.invokeLater(new Runnable() {
+                        @Override
+                        public void run() {
+                        org.openide.awt.Mnemonics.setLocalizedText(simpleMode, NbBundle.getMessage(SelectModePanel.class, "SimpleModeButtonText")); // NOI18N
+                        instructions.setText(NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionText")); // NOI18N
+                        }
+                    });
+                } else {
+                    final String message1 = NbBundle.getMessage(SelectModePanel.class, "SimpleModeButtonSpecifiedText", tool); // NOI18N
+                    final String message2 = NbBundle.getMessage(SelectModePanel.class, "SelectModeSimpleInstructionSpecifiedText", toolsInfo);
+                    SwingUtilities.invokeLater(new Runnable() {
+                        @Override
+                        public void run() {
+                            org.openide.awt.Mnemonics.setLocalizedText(simpleMode, message1);
+                            instructions.setText(message2);
+                        }
+                    });
+                }
             } else {
-                final String message = NbBundle.getMessage(SelectModePanel.class, "SelectModeAdvancedInstructionText"); // NOI18N
                 SwingUtilities.invokeLater(new Runnable() {
                     @Override
                     public void run() {
-                        instructions.setText(message);
+                        org.openide.awt.Mnemonics.setLocalizedText(simpleMode, NbBundle.getMessage(SelectModePanel.class, "SimpleModeButtonText")); // NOI18N
+                        instructions.setText(NbBundle.getMessage(SelectModePanel.class, "SelectModeAdvancedInstructionText")); // NOI18N
                     }
                 });
             }
