@@ -180,9 +180,9 @@ public class ConfigurationMakefileWriterTest extends CndBaseTestCase {
         System.err.println("name: " + host.getHostDisplayName(true));
         System.err.println("key: " + host.getHostKey());
 
-        System.err.println("DefaultDevelopmentHostID " + CppUtils.getDefaultDevelopmentHost());
+        System.err.println("DefaultDevelopmentHostID " + CppUtils.getDefaultDevelopmentHost(folderBaseFO));
         
-        env = ExecutionEnvironmentFactory.fromUniqueID(CppUtils.getDefaultDevelopmentHost());
+        env = ExecutionEnvironmentFactory.fromUniqueID(CppUtils.getDefaultDevelopmentHost(folderBaseFO));
         System.err.println("DefaultExecutionEnvironment " + env);
         System.err.println("host: " + env.getHost());
         System.err.println("host address: " + env.getHostAddress());
@@ -511,7 +511,7 @@ public class ConfigurationMakefileWriterTest extends CndBaseTestCase {
         golden.append("\t$(COMPILE.cc) -g  -MMD -MP -MF \"$@.d\" -o "+MakeConfiguration.OBJECTDIR_MACRO+"/test.o test.cc\n");
         golden.append("${CND_DISTDIR}/${CND_CONF}/${CND_PLATFORM}/libXxx."+MakeConfiguration.CND_DLIB_EXT_MACRO+": ${OBJECTFILES}\n");
         golden.append("\t${MKDIR} -p ${CND_DISTDIR}/${CND_CONF}/${CND_PLATFORM}\n");
-        golden.append("\t${LINK.cc} -o "+MakeConfiguration.CND_DISTDIR_MACRO+"/"+MakeConfiguration.CND_CONF_MACRO+"/"+MakeConfiguration.CND_PLATFORM_MACRO+"/libXxx." + MakeConfiguration.CND_DLIB_EXT_MACRO + " ${OBJECTFILES} ${LDLIBSOPTIONS} -mno-cygwin -shared\n");
+        golden.append("\t${LINK.cc} -o "+MakeConfiguration.CND_DISTDIR_MACRO+"/"+MakeConfiguration.CND_CONF_MACRO+"/"+MakeConfiguration.CND_PLATFORM_MACRO+"/libXxx." + MakeConfiguration.CND_DLIB_EXT_MACRO + " ${OBJECTFILES} ${LDLIBSOPTIONS} -shared\n");
         testDynamicLibrary("DynLib_Cygwin_Windows", "Cygwin", PlatformTypes.PLATFORM_WINDOWS, golden.toString());
     }
 }
