@@ -61,9 +61,10 @@ import java.util.logging.Logger;
 import org.netbeans.modules.cnd.api.model.CsmFile;
 import org.netbeans.modules.cnd.api.model.CsmUID;
 import org.netbeans.modules.cnd.debug.DebugUtils;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.apt.support.APTHandlersSupport;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler.State;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler.State;
 import org.netbeans.modules.cnd.apt.utils.APTSerializeUtils;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FilePreprocessorConditionState;
@@ -71,11 +72,9 @@ import org.netbeans.modules.cnd.modelimpl.csm.core.PreprocessorStatePair;
 import org.netbeans.modules.cnd.modelimpl.csm.core.ProjectBase;
 import org.netbeans.modules.cnd.modelimpl.csm.core.Utils;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
-import org.netbeans.modules.cnd.utils.cache.APTStringManager;
 import org.netbeans.modules.cnd.utils.cache.FilePathCache;
 import org.netbeans.modules.cnd.modelimpl.debug.TraceFlags;
 import org.netbeans.modules.cnd.modelimpl.repository.FileContainerKey;
-import org.netbeans.modules.cnd.modelimpl.repository.KeyUtilities;
 import org.netbeans.modules.cnd.modelimpl.repository.PersistentUtils;
 import org.netbeans.modules.cnd.modelimpl.repository.RepositoryUtils;
 import org.netbeans.modules.cnd.modelimpl.textcache.DefaultCache;
@@ -83,11 +82,8 @@ import org.netbeans.modules.cnd.modelimpl.uid.KeyBasedUID;
 import org.netbeans.modules.cnd.modelimpl.uid.LazyCsmCollection;
 import org.netbeans.modules.cnd.modelimpl.uid.UIDCsmConverter;
 import org.netbeans.modules.cnd.modelimpl.uid.UIDObjectFactory;
-import org.netbeans.modules.cnd.modelimpl.uid.UIDUtilities;
-import org.netbeans.modules.cnd.repository.spi.Persistent;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataInput;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataOutput;
-import org.netbeans.modules.cnd.repository.support.SelfPersistent;
 import org.netbeans.modules.cnd.spi.utils.CndFileSystemProvider;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.CndUtils;
@@ -99,7 +95,7 @@ import org.openide.filesystems.FileSystem;
  * Storage for files and states. Class was extracted from ProjectBase.
  * @author Alexander Simon
  */
-public class FileContainer extends ProjectComponent implements Persistent, SelfPersistent {
+public class FileContainer extends ProjectComponent {
     private static final boolean TRACE_PP_STATE_OUT = DebugUtils.getBoolean("cnd.dump.preproc.state", false);
     private static final Logger LOG = Logger.getLogger("repository.support.filecreate.logger"); //NOI18N
 
@@ -108,7 +104,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
     private final Map<CharSequence, FileEntry> myFiles = new ConcurrentHashMap<>();
     private final ConcurrentMap<CharSequence, Object/*CharSequence or CharSequence[]*/> canonicFiles = new ConcurrentHashMap</*CharSequence or CharSequence[]*/>();
     private final FileSystem fileSystem;
-            
+
     // empty stub
     private static final FileContainer EMPTY = new FileContainer() {
 
@@ -140,12 +136,12 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         fileSystem = project.getFileSystem();
 	put();
     }
-    
+
     public FileContainer (RepositoryDataInput input) throws IOException {
 	super(input);
         fileSystem = PersistentUtils.readFileSystem(input);
-        readStringToFileEntryMap(fileSystem, getUnitId(), input, myFiles);
-        readStringToStringsArrMap(getUnitId(), input, canonicFiles);
+        readFilePathsForFileSystemToFileEntryMap(fileSystem, input, myFiles);
+        readFilePathsForFileSystemToStringsArrMap(fileSystem, input, canonicFiles);
 	//trace(canonicFiles, "Read in ctor:");
         if (CndUtils.isDebugMode()) {
             checkConsistency();
@@ -163,13 +159,13 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
     }
 
     private void trace(Map<CharSequence, Object/*String or CharSequence[]*/> map, String title) {
-	System.err.printf("%s\n", title);
+	System.err.printf("%s%n", title);
 	for( Map.Entry<CharSequence, Object> entry : map.entrySet() ) {
-	    System.err.printf("%s ->\n%s\n\n", entry.getKey(), entry.getValue());
+	    System.err.printf("%s ->%n%s%n%n", entry.getKey(), entry.getValue());
 	}
     }
 
-    public void putFile(FileImpl impl, APTPreprocHandler.State state) {
+    public void putFile(FileImpl impl, PreprocHandler.State state) {
         if (CndUtils.isDebugMode()) {
             checkConsistency();
         }
@@ -177,7 +173,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         CharSequence canonicalPath = getCanonicalKey(path);
         FileEntry newEntry;
         CsmUID<CsmFile> uid = RepositoryUtils.<CsmFile>put(impl);
-        newEntry = new FileEntry(uid, state, path, canonicalPath);
+        newEntry = new FileEntry(uid, state, path, impl.getFileSystem(), canonicalPath);
         FileEntry old;
 
         old = myFiles.put(path, newEntry);
@@ -202,7 +198,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         if (f != null) {
             removeAlternativeFileKey(f.canonical, path);
         }
-        
+
         if (f != null) {
             if (f.fileNew != null){
                 // clean repository
@@ -242,7 +238,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
         return impl;
     }
-    
+
     public CsmUID<CsmFile> getFileUID(CharSequence absPath, boolean treatSymlinkAsSeparateFile) {
         FileEntry f = getFileEntry(absPath, treatSymlinkAsSeparateFile, false);
         if (f == null) {
@@ -261,21 +257,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
         if (TRACE_PP_STATE_OUT) {
             CharSequence path = getFileKey(absPath, false);
-            System.err.println("\nInvalidated state for file" + path + "\n");
-        }
-    }
-    
-    public void markAsParsingPreprocStates(CharSequence absPath) {
-        FileEntry f = getFileEntry(absPath, false, false);
-        if (f == null) {
-            return;
-        }
-        synchronized (f) {
-            f.markAsParsingPreprocStates();
-        }
-        if (TRACE_PP_STATE_OUT) {
-            CharSequence path = getFileKey(absPath, false);
-            System.err.println("\nmarkAsParsingPreprocStates for file" + path + "\n");
+            System.err.println("%nInvalidated state for file" + path + "%n");
         }
     }
 
@@ -288,7 +270,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         FileEntry f = getFileEntry(absPath, false, false);
         return f == null ? lock : f.getLock();
     }
-    
+
     public void debugClearState(){
         List<FileEntry> files;
         files = new ArrayList<>(myFiles.values());
@@ -299,7 +281,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
 	put();
     }
-    
+
     public Collection<CsmFile> getFiles() {
 	List<CsmUID<CsmFile>> uids = new ArrayList<>(myFiles.values().size());
 	getFiles2(uids);
@@ -311,13 +293,13 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         getFiles2(uids);
         return uids;
     }
-    
+
     public Collection<FileImpl> getFileImpls() {
 	List<CsmUID<CsmFile>> uids = new ArrayList<>(myFiles.values().size());
 	getFiles2(uids);
 	return new LazyCsmCollection<>(uids, TraceFlags.SAFE_UID_ACCESS);
     }
-    
+
     private void getFiles2(List<CsmUID<CsmFile>> res) {
         List<FileEntry> files;
         files = new ArrayList<>(myFiles.values());
@@ -325,18 +307,18 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             res.add(f.fileNew);
         }
     }
-    
+
     public int getSize(){
         return myFiles.size();
     }
-    
+
     @Override
     public void write(RepositoryDataOutput aStream) throws IOException {
 	super.write(aStream);
         PersistentUtils.writeFileSystem(fileSystem, aStream);
 	// maps are concurrent, so we don't need synchronization here
-        writeStringToFileEntryMap(getUnitId(), aStream, myFiles);
-        writeStringToStringsArrMap(getUnitId(), aStream, canonicFiles);
+        writeFilePathsForFileSystemToFileEntryMap(fileSystem, aStream, myFiles);
+        writeFilePathsForFileSystemToStringsArrMap(fileSystem, aStream, canonicFiles);
 	//trace(canonicFiles, "Wrote in write()");
     }
 
@@ -354,14 +336,14 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
         return null;
     }
-    
+
     private FileEntry getFileEntry(CharSequence absPath, boolean treatSymlinkAsSeparateFile, boolean sharedText) {
         return getFileEntryImpl(getFileKey(absPath, sharedText), treatSymlinkAsSeparateFile);
     }
 
     /**
      * NB: path should be got via getFileKey!
-     * to be called only from within getFileEntry 
+     * to be called only from within getFileEntry
      */
     private FileEntry getFileEntryImpl(CharSequence path, boolean treatSymlinkAsSeparateFile) {
         FileEntry f = myFiles.get(path);
@@ -377,7 +359,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
         return f;
     }
-    
+
     private void addAlternativeFileKey(CharSequence primaryKey, CharSequence canonicKey) {
         Object out = canonicFiles.get(canonicKey);
         Object newVal;
@@ -409,9 +391,9 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             } else {
                 System.err.println("entry for " + canonicKey + " while adding " + primaryKey + " is " + newVal);
             }
-        }                
+        }
     }
-    
+
     private void removeAlternativeFileKey(CharSequence canonicKey, CharSequence primaryKey) {
         Object out = canonicFiles.get(canonicKey);
         assert out != null : "no entry for " + canonicKey + " of " + primaryKey;
@@ -476,126 +458,113 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         assert valuesSize == myFiles.size() : "different number of elements " + myFiles.size() + " vs " + valuesSize;
     }
 
-    /*package*/ static void writeStringToFileEntryMap (
-            int unitIndex, final RepositoryDataOutput output, Map<CharSequence, FileEntry> aMap) throws IOException {
+    /*package*/ static void writeFilePathsForFileSystemToFileEntryMap (FileSystem fs,
+            final RepositoryDataOutput output, Map<CharSequence, FileEntry> aMap) throws IOException {
         assert output != null;
         assert aMap != null;
         int size = aMap.size();
-        
+
         //write size
         output.writeInt(size);
-        
+
         // write the map
         final Set<Map.Entry<CharSequence, FileEntry>> entrySet = aMap.entrySet();
         final Iterator <Map.Entry<CharSequence, FileEntry>> setIterator = entrySet.iterator();
         while (setIterator.hasNext()) {
             final Map.Entry<CharSequence, FileEntry> anEntry = setIterator.next();
-            PersistentUtils.writeFileNameIndex(anEntry.getKey(), output, unitIndex);
+            output.writeFilePathForFileSystem(fs, anEntry.getKey());
             // TODO: replace call above by the next line if no failures in following asserts
-            // it allows to eleminate charSeq->fileIndex conversion when fileIndex is 
+            // it allows to eleminate charSeq->fileIndex conversion when fileIndex is
             // known from fileNew UID kept in value's FileEntry
 //            output.writeInt(UIDUtilities.getFileID(anEntry.getValue().fileNew));
             assert anEntry.getValue() != null;
-            // see IncludedFileContainer.getIncludedUnitId
-            if (false && (CndUtils.isDebugMode() || CndUtils.isUnitTestMode())) {
-                int projectIDFromFileEntry = UIDUtilities.getProjectID(anEntry.getValue().fileNew);
-                CndUtils.assertTrueInConsole(projectIDFromFileEntry == unitIndex, anEntry.getValue().fileNew + "is not from unit " + unitIndex + " but from " + projectIDFromFileEntry);
-                int fileIDFromFileEntry = UIDUtilities.getFileID(anEntry.getValue().fileNew);
-                int fileIdByNameFromUnitId = KeyUtilities.getFileIdByName(unitIndex, anEntry.getKey());
-                CndUtils.assertTrueInConsole(fileIDFromFileEntry == fileIdByNameFromUnitId, fileIDFromFileEntry + ":" + projectIDFromFileEntry + " differs from " + fileIdByNameFromUnitId + ":" + unitIndex);
-            }
-            anEntry.getValue().write(output, unitIndex);
+            anEntry.getValue().write(output);
         }
     }
-    
-    /*package*/ static void  readStringToFileEntryMap(
-            FileSystem fs, int unitIndex,
+
+    /*package*/ static void  readFilePathsForFileSystemToFileEntryMap(FileSystem fs,
             RepositoryDataInput input, Map<CharSequence, FileEntry> aMap) throws IOException {
-        
-        assert input != null; 
+
+        assert input != null;
         assert aMap != null;
-        
-        final APTStringManager pathManager = FilePathCache.getManager();
-        
+
         aMap.clear();
         final int size = input.readInt();
-        
+
         for (int i = 0; i < size; i++) {
-            CharSequence key = PersistentUtils.readFileNameIndex(input, pathManager, unitIndex);
-            FileEntry value = new FileEntry(fs, input, unitIndex);
-            
+            CharSequence key = input.readFilePathForFileSystem(fs);
+            FileEntry value = new FileEntry(input);
+
             assert key != null;
             assert value != null;
-            
+
             aMap.put(key, value);
         }
     }
-    
-    private static void writeStringToStringsArrMap (
-            final int unitIndex, final RepositoryDataOutput output,
+
+    private static void writeFilePathsForFileSystemToStringsArrMap (FileSystem fs,
+            final RepositoryDataOutput output,
             final Map<CharSequence, Object/*CharSequence or CharSequence[]*/> aMap) throws IOException {
-        
+
         assert output != null;
         assert aMap != null;
-        
+
         final int size = aMap.size();
         output.writeInt(size);
-        
+
         final Set<Map.Entry<CharSequence, Object>> entrySet = aMap.entrySet();
         final Iterator<Map.Entry<CharSequence, Object>> setIterator = entrySet.iterator();
-        
+
         while (setIterator.hasNext()) {
             final Map.Entry<CharSequence, Object> anEntry = setIterator.next();
             assert anEntry != null;
-            
+
             final CharSequence key = anEntry.getKey();
             final Object value = anEntry.getValue();
             assert key != null;
             assert value != null;
             assert ((value instanceof CharSequence) || (value instanceof CharSequence[]));
-            
-            APTSerializeUtils.writeFileNameIndex(key, output, unitIndex);
-            
+
+            output.writeFilePathForFileSystem(fs, key);
+
             if (value instanceof CharSequence ) {
                 output.writeInt(1);
-                APTSerializeUtils.writeFileNameIndex((CharSequence)value, output, unitIndex);
+                output.writeFilePathForFileSystem(fs, (CharSequence)value);
             } else if (value instanceof CharSequence[]) {
-                
+
                 final CharSequence[] array = (CharSequence[]) value;
-                
+
                 output.writeInt(array.length);
                 for (int j = 0; j < array.length; j++) {
-                    APTSerializeUtils.writeFileNameIndex(array[j], output, unitIndex);
+                    output.writeFilePathForFileSystem(fs, array[j]);
                 }
             }
         }
     }
-    
-    private static void readStringToStringsArrMap(
-            final int unitId, final RepositoryDataInput input, Map<CharSequence,
+
+    private static void readFilePathsForFileSystemToStringsArrMap(FileSystem fs,
+            final RepositoryDataInput input, Map<CharSequence,
                     Object/*CharSequence or CharSequence[]*/> aMap) throws IOException {
         assert input != null;
         assert aMap != null;
 
-        final APTStringManager pathManager = FilePathCache.getManager();
-
         aMap.clear();
 
         final int size = input.readInt();
 
         for (int i = 0; i < size; i++) {
-            CharSequence key = APTSerializeUtils.readFileNameIndex(input, pathManager, unitId);
+            CharSequence key = input.readFilePathForFileSystem(fs);
             assert key != null;
 
             final int arraySize = input.readInt();
             assert arraySize != 0;
 
             if (arraySize == 1) {
-                aMap.put(key, APTSerializeUtils.readFileNameIndex(input, pathManager, unitId));
+                aMap.put(key, input.readFilePathForFileSystem(fs));
             } else {
                 final CharSequence[] value = new CharSequence[arraySize];
                 for (int j = 0; j < arraySize; j++) {
-                    CharSequence path = APTSerializeUtils.readFileNameIndex(input, pathManager, unitId);
+                    CharSequence path = input.readFilePathForFileSystem(fs);
                     assert path != null;
 
                     value[j] = path;
@@ -615,32 +584,34 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         return new TreeMap<>(canonicFiles);
     }
 
-    public static FileEntry createFileEntryForMerge(CharSequence fileKey) {
-        return new FileEntry(null, null, fileKey, fileKey);
+    public static FileEntry createFileEntryForMerge(FileSystem fs, CharSequence fileKey) {
+        return new FileEntry(null, null, fileKey, fs, fileKey);
     }
 
     /*package*/ static FileEntry createFileEntry(FileImpl fileImpl) {
         CharSequence path = getFileKey(fileImpl.getAbsolutePath(), false);
-        return new FileEntry(fileImpl.getUID(), null, path, path);
+        return new FileEntry(fileImpl.getUID(), null, path, fileImpl.getFileSystem(), path);
     }
     private static final boolean TRACE = false;
     public static final class FileEntry {
 
         private final CsmUID<CsmFile> fileNew;
+        private final FileSystem fs;
         private final CharSequence canonical;
         private volatile Object data; // either StatePair or List<StatePair>
         private volatile int modCount;
 
         @SuppressWarnings("unchecked")
-        private FileEntry (FileSystem fs, RepositoryDataInput input, int unitIndex) throws IOException {
+        private FileEntry (RepositoryDataInput input) throws IOException {
             fileNew = UIDObjectFactory.getDefaultFactory().readUID(input);
-            canonical = PersistentUtils.readFileNameIndex(input, FilePathCache.getManager(), unitIndex);
+            fs = input.readFileSystem();
+            canonical = input.readFilePathForFileSystem(fs);
             modCount = input.readInt();
             if (input.readBoolean()) {
                 int cnt = input.readInt();
                 assert cnt > 0;
                 if (cnt == 1) {
-                    PreprocessorStatePair pair = readStatePair(fs, input, unitIndex);
+                    PreprocessorStatePair pair = readStatePair(input);
                     if (TRACE && pair != null && !pair.state.isValid()) {
                         CndUtils.assertTrueInConsole(false, "read INVALID state for ", this.canonical);
                     }
@@ -648,7 +619,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 } else {
                     data = new ArrayList<>(cnt);
                     for (int i = 0; i < cnt; i++) {
-                        PreprocessorStatePair pair = readStatePair(fs, input, unitIndex);
+                        PreprocessorStatePair pair = readStatePair(input);
                         if (TRACE && pair != null && !pair.state.isValid()) {
                             CndUtils.assertTrueInConsole(false, "read INVALID state for ", this.canonical);
                         }
@@ -660,7 +631,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             }
         }
 
-        private FileEntry(CsmUID<CsmFile> fileNew, APTPreprocHandler.State state, CharSequence fileKey, CharSequence canonicalFileKey) {
+        private FileEntry(CsmUID<CsmFile> fileNew, PreprocHandler.State state, CharSequence fileKey, FileSystem fs, CharSequence canonicalFileKey) {
             this.fileNew = fileNew;
             this.data = (state == null) ? null : new PreprocessorStatePair(state, FilePreprocessorConditionState.PARSING);
 //            if (state == null) {
@@ -668,13 +639,15 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
 //                    CndUtils.assertTrueInConsole(false, "creating null based entry for " + fileKey); // NOI18N
 //                }
 //            }
+            this.fs = fs;
             this.canonical = canonicalFileKey;
             this.modCount = 0;
         }
-        
-        private void write(final RepositoryDataOutput output, int unitIndex) throws IOException {
+
+        private void write(final RepositoryDataOutput output) throws IOException {
             UIDObjectFactory.getDefaultFactory().writeUID(fileNew, output);
-            PersistentUtils.writeFileNameIndex(canonical, output, unitIndex);
+            output.writeFileSystem(fs);
+            output.writeFilePathForFileSystem(fs, canonical);
             output.writeInt(modCount);
             Object aData = data;
             output.writeBoolean(aData != null);
@@ -685,7 +658,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                     if (TRACE && !pair.state.isValid()) {
                         CndUtils.assertTrueInConsole(false, "write INVALID state for ", this.canonical);
                     }
-                    writeStatePair(output, pair, unitIndex);
+                    writeStatePair(output, pair);
                 } else {
                     @SuppressWarnings("unchecked")
                     Collection<PreprocessorStatePair> pairs = (Collection<PreprocessorStatePair>)aData;
@@ -694,17 +667,17 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                         if (TRACE && pair != null && !pair.state.isValid()) {
                             CndUtils.assertTrueInConsole(false, "write INVALID state for ", this.canonical);
                         }
-                        writeStatePair(output, pair, unitIndex);
+                        writeStatePair(output, pair);
                     }
                 }
             }
         }
-        
-        private static PreprocessorStatePair readStatePair(FileSystem fs, RepositoryDataInput input, int unitIndex) throws IOException {
+
+        private static PreprocessorStatePair readStatePair(RepositoryDataInput input) throws IOException {
             if (input.readBoolean()) {
-                APTPreprocHandler.State state = null;
+                PreprocHandler.State state = null;
                 if (input.readBoolean()){
-                    state = PersistentUtils.readPreprocState(fs, input, unitIndex);
+                    state = PersistentUtils.readPreprocState(input);
                 }
                 FilePreprocessorConditionState pcState = null;
                 if (input.readBoolean()){
@@ -715,16 +688,16 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 return new PreprocessorStatePair(state, pcState);
             }
             return null;
-            
-            
+
+
         }
 
-        private static void writeStatePair(RepositoryDataOutput output, PreprocessorStatePair pair, int unitIndex) throws IOException {
+        private static void writeStatePair(RepositoryDataOutput output, PreprocessorStatePair pair) throws IOException {
             output.writeBoolean(pair != null);
             if (pair != null) {
                 output.writeBoolean(pair.state != null);
                 if (pair.state != null) {
-                    PersistentUtils.writePreprocState(pair.state, output, unitIndex);
+                    PersistentUtils.writePreprocState(pair.state, output);
                 }
                 output.writeBoolean(pair.pcState != FilePreprocessorConditionState.PARSING);
                 if (pair.pcState != FilePreprocessorConditionState.PARSING) {
@@ -739,7 +712,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
 
         /**
          * @return lock under which all sequances read-decide-modify should be done
-         * get* and replace* methods are synchronize on the same lock 
+         * get* and replace* methods are synchronize on the same lock
          */
         public Object getLock() {
             return this;
@@ -749,11 +722,11 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             data = null;
         }
 
-        /** 
+        /**
          * This should only be called if we are sure this is THE ONLY correct state:
          * e.g., when creating new file, when invalidating state of a *source* (not a header) file, etc
          */
-        public final synchronized void setState(APTPreprocHandler.State state, FilePreprocessorConditionState pcState) {
+        public final synchronized void setState(PreprocHandler.State state, FilePreprocessorConditionState pcState) {
             if (TraceFlags.TRACE_182342_BUG) {
                 new Exception("setState replacing:\n" + toString()).printStackTrace(System.err); //NOI18N
             }
@@ -765,7 +738,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 @SuppressWarnings("unchecked")
                 Collection<PreprocessorStatePair> states = (Collection<PreprocessorStatePair>) data;
                 // check how many good old states are there
-                // and pick a valid one to check that we aren't replacing better state by worse one 
+                // and pick a valid one to check that we aren't replacing better state by worse one
                 int oldGoodStatesCount = 0;
                 for (PreprocessorStatePair pair : states) {
                     if (pair.state != null && pair.state.isValid()) {
@@ -779,7 +752,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                     if (CndUtils.isDebugMode()) {
                         StringBuilder sb = new StringBuilder("Attempt to set state while there are multiple states: " + canonical); // NOI18N
                         for (PreprocessorStatePair pair : states) {
-                            sb.append(String.format("\nvalid: %b context: %b %s", pair.state.isValid(), pair.state.isCompileContext(), pair.pcState)); //NOI18N
+                            sb.append(String.format("%nvalid: %b context: %b %s", pair.state.isValid(), pair.state.isCompileContext(), pair.pcState)); //NOI18N
                         }
                         Utils.LOG.log(Level.SEVERE, sb.toString(), new Exception(sb.toString()));
                     }
@@ -788,9 +761,9 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             } else if(data instanceof PreprocessorStatePair) {
                 oldState = ((PreprocessorStatePair) data).state;
             }
-            
+
             incrementModCount();
-            
+
             if (oldState != null
                     && oldState.isValid()
                     && oldState.isCompileContext()
@@ -801,17 +774,17 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 }
                 return;
             }
-            
+
             if (TRACE_PP_STATE_OUT) {
-                System.err.println("\nPut state for file" + canonical + "\n");
+                System.err.println("%nPut state for file" + canonical + "%n");
                 System.err.println(state);
             }
-            
+
             data = new PreprocessorStatePair(state, pcState);
             if (TraceFlags.TRACE_182342_BUG) {
                 new Exception("setState at the end:\n"+toString()).printStackTrace(System.err); //NOI18N
             }
-        }        
+        }
 
         public synchronized void setStates(Collection<PreprocessorStatePair> pairs, PreprocessorStatePair yetOneMore) {
             if (TraceFlags.TRACE_182342_BUG) {
@@ -903,11 +876,11 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                                     pair.state.isValid(), pair.state.isCompileContext(), pair.pcState));
                         }
                     }
-                    Utils.LOG.log(Level.INFO, sb.toString(), new Exception(sb.toString()));                
+                    Utils.LOG.log(Level.INFO, sb.toString(), new Exception(sb.toString()));
                 }
             }
         }
-        
+
         private synchronized void incrementModCount() {
             modCount = (modCount == Integer.MAX_VALUE) ? 0 : modCount+1;
         }
@@ -930,7 +903,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 new Exception("invalidateStates:\n"+toString()).printStackTrace(System.err); //NOI18N
             }
         }
-        
+
         @SuppressWarnings("unchecked")
         public synchronized void markAsParsingPreprocStates() {
             incrementModCount();
@@ -949,7 +922,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 new Exception("invalidateStates:\n" + toString()).printStackTrace(System.err); //NOI18N
             }
         }
-        
+
         private static PreprocessorStatePair createMarkedAsParsingState(PreprocessorStatePair pair) {
             if (pair == null) {
                 return pair;
@@ -961,7 +934,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 }
             }
         }
-        
+
         private static PreprocessorStatePair createInvalidState(PreprocessorStatePair pair) {
             if (pair == null) {
                 return pair;
@@ -973,7 +946,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
                 }
             }
         }
-            
+
         public synchronized Collection<PreprocessorStatePair> getStatePairs() {
             if (data == null) {
                 return Collections.<PreprocessorStatePair>emptyList();
@@ -986,7 +959,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             }
         }
         
-        public synchronized Collection<APTPreprocHandler.State> getPrerocStates() {
+        public synchronized Collection<PreprocHandler.State> getPrerocStates() {
             if (data == null) {
                 return Collections.emptyList();
             } else if(data instanceof PreprocessorStatePair) {
@@ -994,7 +967,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             } else {
                 @SuppressWarnings("unchecked")
                 Collection<PreprocessorStatePair> pairs = (Collection<PreprocessorStatePair>) data;
-                Collection<APTPreprocHandler.State> result = new ArrayList<>(pairs.size());
+                Collection<PreprocHandler.State> result = new ArrayList<>(pairs.size());
                 for (PreprocessorStatePair pair : pairs) {
                     result.add(pair.state);
                 }
@@ -1020,7 +993,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
         }
 
     }
-    
+
     private CharSequence getCanonicalKey(CharSequence fileKey) {
         try {
             CharSequence res = CndFileSystemProvider.getCanonicalPath(fileSystem, fileKey);
@@ -1034,7 +1007,7 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             return fileKey;
         }
     }
-    
+
     private static CharSequence getCanonicalKey(FileObject fileObject, CharSequence fileKey) {
         try {
             CharSequence res = CndFileUtils.getCanonicalPath(fileObject);
@@ -1048,5 +1021,5 @@ public class FileContainer extends ProjectComponent implements Persistent, SelfP
             return fileKey;
         }
     }
-    
+
 }
