@@ -75,7 +75,7 @@ import org.openide.util.CharSequences;
  * Common ancestor for ClassImpl and EnumImpl
  * @author Vladimir Kvashin
  */
-public abstract class ClassEnumBase<T> extends OffsetableDeclarationBase<T> implements Disposable, CsmCompoundClassifier, CsmMember {
+public abstract class ClassEnumBase<T> extends OffsetableDeclarationBase<T> implements CsmCompoundClassifier, CsmMember {
 
     private final CharSequence name;
     private /*final*/ CharSequence qualifiedName;
@@ -98,7 +98,7 @@ public abstract class ClassEnumBase<T> extends OffsetableDeclarationBase<T> impl
         assert name != null;
         this.name = NameCache.getManager().getString(name.getName());
     }
-    
+
     protected ClassEnumBase(CharSequence name, CharSequence qName, CsmFile file, int startOffset, int endOffset) {
         super(file, startOffset, endOffset);
         enclosingElements = Collections.synchronizedList(new ArrayList<CsmUID<CsmOffsetableDeclaration>>(0));
@@ -207,18 +207,22 @@ public abstract class ClassEnumBase<T> extends OffsetableDeclarationBase<T> impl
     /** Initializes qualified name */
     protected final void initQualifiedName(CsmScope scope) {
         CharSequence qualifiedNamePostfix = getQualifiedNamePostfix();
+        CharSequence qualName;
         if (CsmKindUtilities.isNamespace(scope)) {
-            qualifiedName = Utils.getQualifiedName(qualifiedNamePostfix.toString(), (CsmNamespace) scope);
+            qualName = Utils.getQualifiedName(qualifiedNamePostfix.toString(), (CsmNamespace) scope);
         } else if (CsmKindUtilities.isClass(scope)) {
             int last = CharSequenceUtils.lastIndexOf(qualifiedNamePostfix, "::"); // NOI18N
             if (last >= 0) { // NOI18N
                 qualifiedNamePostfix = qualifiedNamePostfix.toString().substring(last + 2); // NOI18N
             }
-            qualifiedName = CharSequenceUtils.concatenate(((CsmClass) scope).getQualifiedName(), "::", qualifiedNamePostfix); // NOI18N
+            qualName = CharSequenceUtils.concatenate(((CsmClass) scope).getQualifiedName(), "::", qualifiedNamePostfix); // NOI18N
         } else {
-            qualifiedName = qualifiedNamePostfix;
+            qualName = qualifiedNamePostfix;
         }
-        qualifiedName = QualifiedNameCache.getManager().getString(qualifiedName);
+        // substitution of qual name has to be atomic, because this instance can
+        // already be registered and be in repository. Field qualifiedName always
+        // must be compact string because only such strings are allowed in repository
+        this.qualifiedName = QualifiedNameCache.getManager().getString(qualName);
         // can't register here, because descendant class' constructor hasn't yet finished!
         // so registering is a descendant class' responsibility
     }
@@ -309,8 +313,8 @@ public abstract class ClassEnumBase<T> extends OffsetableDeclarationBase<T> impl
     private synchronized void onDispose() {
         if (this.scopeRef == null) {
             // restore container from it's UID if not directly initialized
-            this.scopeRef = this.scopeRef != null ? this.scopeRef : UIDCsmConverter.UIDtoScope(this.scopeUID);
-            
+            this.scopeRef = UIDCsmConverter.UIDtoScope(this.scopeUID);
+
             // there could be a situation when scope is already disposed
             // i.e. like in  #191610 -  unresolved reference to class declared with outer scope
 //            assert (this.scopeRef != null || this.scopeUID == null) : "empty scope for UID " + this.scopeUID + " when dispose " + this;
