@@ -61,10 +61,8 @@ import org.netbeans.modules.cnd.api.model.CsmObject;
 import org.netbeans.modules.cnd.api.model.CsmOffsetableDeclaration;
 import org.netbeans.modules.cnd.api.model.CsmScope;
 import org.netbeans.modules.cnd.api.model.CsmScopeElement;
-import org.netbeans.modules.cnd.api.model.CsmType;
 import org.netbeans.modules.cnd.api.model.CsmUID;
 import org.netbeans.modules.cnd.api.model.deep.CsmCompoundStatement;
-import org.netbeans.modules.cnd.api.model.services.CsmClassifierResolver;
 import org.netbeans.modules.cnd.api.model.services.CsmSelect;
 import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
 import org.netbeans.modules.cnd.api.model.util.CsmKindUtilities;
@@ -192,8 +190,11 @@ public class FunctionDefinitionImpl<T> extends FunctionImplEx<T> implements CsmF
     }
 
     private void _setDeclaration(CsmFunction decl) {
-        this.declarationUID = UIDCsmConverter.declarationToUID(decl);
-        assert this.declarationUID != null || decl == null;
+        CsmUID<CsmFunction> uid = UIDCsmConverter.declarationToUID(decl);
+        this.declarationUID = uid;
+        // check local variable in assert
+        // field can be already cleared by another _setDeclaration(null)
+        assert uid != null || decl == null : "unexpected " + uid + " for " + decl;
     }
 
     // method try to find declaration in case class have exactly one cast operator with desired name
