@@ -97,7 +97,7 @@ import org.netbeans.modules.cnd.modelimpl.csm.core.RawNamable;
 import org.netbeans.modules.cnd.modelimpl.csm.core.Utils;
 import org.netbeans.modules.cnd.modelimpl.impl.services.InstantiationProviderImpl;
 import org.netbeans.modules.cnd.modelimpl.parser.generated.CPPTokenTypes;
-import static org.netbeans.modules.cnd.modelimpl.repository.KeyUtilities.UID_SIGNATURE_PREFIX;
+import static org.netbeans.modules.cnd.modelimpl.repository.KeyUtilities.UID_INTERNAL_DATA_PREFIX;
 import org.netbeans.modules.cnd.modelimpl.repository.PersistentUtils;
 import org.netbeans.modules.cnd.modelimpl.textcache.NameCache;
 import org.netbeans.modules.cnd.modelimpl.textcache.QualifiedNameCache;
@@ -124,7 +124,7 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
     private CsmType returnType;
     private FunctionParameterListImpl parameterList;
     private CharSequence signature;
-    private CharSequence macroSignature;
+    private CharSequence uidExtraSuffix;
 
     // only one of scopeRef/scopeAccessor must be used
     private /*final*/ CsmScope scopeRef;// can be set in onDispose or contstructor only
@@ -136,13 +136,13 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
 
     protected CharSequence classTemplateSuffix;
 
-    private static final byte FLAGS_VOID_PARMLIST = 1 << 0;
-    private static final byte FLAGS_STATIC = 1 << 1;
-    private static final byte FLAGS_CONST = 1 << 2;
-    private static final byte FLAGS_OPERATOR = 1 << 3;
-    private static final byte FLAGS_INVALID = 1 << 4;
+    private static final short FLAGS_VOID_PARMLIST = 1 << 0;
+    private static final short FLAGS_STATIC = 1 << 1;
+    private static final short FLAGS_CONST = 1 << 2;
+    private static final short FLAGS_OPERATOR = 1 << 3;
+    private static final short FLAGS_INVALID = 1 << 4;
     protected static final int LAST_USED_FLAG_INDEX = 4;
-    private byte flags;
+    private short flags;
     
     protected FunctionImpl(CharSequence name, CharSequence rawName, CsmScope scope, boolean _static, boolean _const, CsmFile file, int startOffset, int endOffset, boolean global) {
         super(file, startOffset, endOffset);
@@ -194,20 +194,20 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
     }
     
     /**
-     * Method is used to get temporary signature for UID
+     * Method is used to get extra suffix for UID (like signature, scope, etc)
      * @return signature field
      */
-    public CharSequence getSignatureForUID() {
-        return macroSignature;
-    }    
+    public final CharSequence getUIDExtraSuffix() {
+        return uidExtraSuffix;
+    }
     
-    protected static CharSequence createSignatureForUID(AST ast) {
+    protected CharSequence createUIDExtraSuffix(AST ast) {
         // Do it only if needed
         if (AstUtil.hasExpandedTokens(ast)) {
             AST params = AstUtil.findChildOfType(ast, CPPTokenTypes.CSM_PARMLIST);
             if (params != null) {
                 boolean first = true;
-                StringBuilder sb = new StringBuilder(UID_SIGNATURE_PREFIX); 
+                StringBuilder sb = new StringBuilder(UID_INTERNAL_DATA_PREFIX); 
                 sb.append("("); // NOI18N
                 AST param = AstUtil.findChildOfType(params, CPPTokenTypes.CSM_PARAMETER_DECLARATION);
                 do {
@@ -224,14 +224,19 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
                     first = false;
                 } while ((param = AstUtil.findSiblingOfType(param.getNextSibling(), CPPTokenTypes.CSM_PARAMETER_DECLARATION)) != null);
                 sb.append(")"); // NOI18N
-                return QualifiedNameCache.getManager().getString(sb.toString());
+                return sb.toString();
             }
         }
         return null;
     }
     
     protected static<T> void temporaryRepositoryRegistration(AST ast, boolean global, FunctionImpl<T> fun) {
-        fun.macroSignature = createSignatureForUID(ast);
+        CharSequence uidExtraSuffix = fun.createUIDExtraSuffix(ast);
+        if (uidExtraSuffix != null) {
+            fun.uidExtraSuffix = QualifiedNameCache.getManager().getString(uidExtraSuffix);
+        } else {
+            fun.uidExtraSuffix = null;
+        }
         temporaryRepositoryRegistration(global, fun);
     }
 
@@ -281,11 +286,11 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
                 getKind() == CsmDeclaration.Kind.FUNCTION_FRIEND_DEFINITION;
     }
 
-    protected boolean hasFlags(byte mask) {
+    protected boolean hasFlags(short mask) {
         return (flags & mask) == mask;
     }
 
-    protected final void setFlags(byte mask, boolean value) {
+    protected final void setFlags(short mask, boolean value) {
         if (value) {
             flags |= mask;
         } else {
@@ -670,19 +675,21 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
             Collection<CsmOffsetableDeclaration> decls = ((ProjectBase)prj).findDeclarationsByPrefix(from);
             CsmFunctionDefinition candidate = null;
             for(CsmOffsetableDeclaration decl : decls){
-                CsmFunctionDefinition def = (CsmFunctionDefinition) decl;
-                int candidateParamSize = def.getParameters().size();
-                if (!isVoid && parmSize == 0) {
-                    if (!Utils.isCppFile(decl.getContainingFile())){
-                        return def;
+                if (CsmKindUtilities.isFunctionDefinition(decl)) {
+                    CsmFunctionDefinition def = (CsmFunctionDefinition) decl;
+                    int candidateParamSize = def.getParameters().size();
+                    if (!isVoid && parmSize == 0) {
+                        if (!Utils.isCppFile(decl.getContainingFile())){
+                            return def;
+                        }
                     }
-                }
-                if (parmSize == candidateParamSize) {
-                    // TODO check overloads
-                    if (candidate == null) {
-                        candidate = def;
-                    } else {
-//                        return null;
+                    if (parmSize == candidateParamSize) {
+                        // TODO check overloads
+                        if (candidate == null) {
+                            candidate = def;
+                        } else {
+//                          return null;
+                        }
                     }
                 }
             }
@@ -760,7 +767,7 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
         if( signature == null ) {
             signature = QualifiedNameCache.getManager().getString(createSignature(getName(), getParameters(), getOwnTemplateParameters(), isConst()));
         }
-        assert !signature.toString().startsWith(UID_SIGNATURE_PREFIX) : "Signature requested when object is not fully constructed!"; // NOI18N
+        assert !signature.toString().startsWith(UID_INTERNAL_DATA_PREFIX) : "Signature requested when object is not fully constructed!"; // NOI18N
         return signature;
     }   
 
@@ -1025,14 +1032,14 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
         super.write(output);
         assert this.name != null;
         PersistentUtils.writeUTF(name, output);
-        PersistentUtils.writeUTF(macroSignature, output);
+        PersistentUtils.writeUTF(uidExtraSuffix, output);
         PersistentUtils.writeType(this.returnType, output);
         UIDObjectFactory factory = UIDObjectFactory.getDefaultFactory();
         PersistentUtils.writeParameterList(this.parameterList, output);
         PersistentUtils.writeUTF(this.rawName, output);
         factory.writeUID(this.scopeUID, output);
         PersistentUtils.writeUTF(this.signature, output);
-        output.writeByte(flags);
+        output.writeShort(flags);
         PersistentUtils.writeUTF(getScopeSuffix(), output);
         PersistentUtils.writeTemplateDescriptor(templateDescriptor, output);
     }
@@ -1041,7 +1048,7 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
         super(input);
         this.name = PersistentUtils.readUTF(input, QualifiedNameCache.getManager());
         assert this.name != null;
-        this.macroSignature = PersistentUtils.readUTF(input, QualifiedNameCache.getManager());
+        this.uidExtraSuffix = PersistentUtils.readUTF(input, QualifiedNameCache.getManager());
         this.returnType = PersistentUtils.readType(input);
         UIDObjectFactory factory = UIDObjectFactory.getDefaultFactory();
         this.parameterList = (FunctionParameterListImpl) PersistentUtils.readParameterList(input, this);
@@ -1049,7 +1056,7 @@ public class FunctionImpl<T> extends OffsetableDeclarationBase<T>
         this.scopeUID = factory.readUID(input);
         this.scopeRef = null;
         this.signature = PersistentUtils.readUTF(input, QualifiedNameCache.getManager());
-        this.flags = input.readByte();
+        this.flags = input.readShort();
         this.classTemplateSuffix = PersistentUtils.readUTF(input, NameCache.getManager());
         this.templateDescriptor = PersistentUtils.readTemplateDescriptor(input);
     }
