@@ -52,7 +52,6 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
-import java.util.Stack;
 import org.netbeans.modules.cnd.antlr.collections.AST;
 import org.netbeans.modules.cnd.api.model.CsmClassifier;
 import org.netbeans.modules.cnd.api.model.CsmFile;
@@ -66,10 +65,8 @@ import org.netbeans.modules.cnd.api.model.CsmTemplateParameterType;
 import org.netbeans.modules.cnd.api.model.CsmType;
 import org.netbeans.modules.cnd.api.model.CsmTypedef;
 import org.netbeans.modules.cnd.api.model.CsmUID;
-import org.netbeans.modules.cnd.api.model.services.CsmCacheManager;
 import org.netbeans.modules.cnd.api.model.services.CsmIncludeResolver;
 import org.netbeans.modules.cnd.api.model.services.CsmInstantiationProvider;
-import org.netbeans.modules.cnd.api.model.services.CsmResolveContext;
 import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
 import org.netbeans.modules.cnd.api.model.util.CsmKindUtilities;
 import org.netbeans.modules.cnd.api.model.xref.CsmReference;
@@ -80,7 +77,6 @@ import org.netbeans.modules.cnd.modelimpl.csm.core.AstUtil.ASTTokenVisitor.Actio
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.OffsetableBase;
 import org.netbeans.modules.cnd.modelimpl.csm.core.ProjectBase;
-import org.netbeans.modules.cnd.modelimpl.csm.core.Utils;
 import org.netbeans.modules.cnd.modelimpl.csm.deep.ExpressionStatementImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.resolver.Resolver;
 import org.netbeans.modules.cnd.modelimpl.csm.resolver.Resolver.SafeTemplateBasedProvider;
@@ -110,6 +106,7 @@ import org.openide.util.CharSequences;
  */
 public class TypeImpl extends OffsetableBase implements CsmType, SafeTemplateBasedProvider {
     private static final CharSequence NON_INITIALIZED_CLASSIFIER_TEXT = CharSequences.empty();
+    private static final int MAX_CLASSIFIER_TEXT_LENGTH = 512;
     
     private static final byte FLAGS_TYPE_OF_TYPEDEF = 1;
     private static final byte FLAGS_REFERENCE = 1 << 1;
@@ -335,7 +332,11 @@ public class TypeImpl extends OffsetableBase implements CsmType, SafeTemplateBas
 
     private static AST getLastNode(AST first, boolean greedy) {
         AST last = first;
-        if(last != null) {            
+        int parensDepth = 0;
+        int squareBracketsDepth = 0;
+        int angleBracketsDepth = 0;
+        if(last != null) {   
+            outer:
             for( AST token = last.getNextSibling(); token != null; token = token.getNextSibling() ) {
                 switch( token.getType() ) {                    
                     case CPPTokenTypes.CSM_VARIABLE_DECLARATION:
@@ -349,9 +350,48 @@ public class TypeImpl extends OffsetableBase implements CsmType, SafeTemplateBas
                         return AstUtil.getLastChildRecursively(last);
                         
                     case CPPTokenTypes.LPAREN: 
-                        // lparen cannot be last - entity's end should be on the left side of lparen
+                        ++parensDepth;
+                        // LPAREN cannot be last - entity's end should be on the left side of LPAREN
                         // if there are no type modificators after lparen (*, &, ...)
                         break;
+                        
+                    case CPPTokenTypes.RPAREN:
+                        if (--parensDepth < 0 && !(angleBracketsDepth > 0 || squareBracketsDepth > 0)) {
+                            break outer;
+                        }
+                        last = token;
+                        break;
+                        
+                    case CPPTokenTypes.LESSTHAN:
+                        ++angleBracketsDepth;
+                        // LESSTHAN cannot be last - entity's end should be on the left side of LESSTHAN
+                        break;
+                        
+                    case CPPTokenTypes.GREATERTHAN:
+                        if (--angleBracketsDepth < 0 && !(parensDepth > 0 || squareBracketsDepth > 0)) {
+                            break outer;
+                        }
+                        last = token;
+                        break;
+                        
+                    case CPPTokenTypes.LSQUARE:
+                        ++squareBracketsDepth;
+                        // LSQUARE cannot be last - entity's end should be on the left side of LSQUARE
+                        break;
+                        
+                    case CPPTokenTypes.RSQUARE:
+                        if (--squareBracketsDepth < 0 && !(parensDepth > 0 || angleBracketsDepth > 0)) {
+                            break outer;
+                        }
+                        last = token;
+                        break;      
+                        
+                    case CPPTokenTypes.COMMA:
+                        if (!(squareBracketsDepth > 0 || parensDepth > 0 || angleBracketsDepth > 0)) {
+                            break outer;
+                        }
+                        last = token;
+                        break;                              
                                             
                     default:
                         last = token;
@@ -673,25 +713,33 @@ public class TypeImpl extends OffsetableBase implements CsmType, SafeTemplateBas
     /*
      * Add text without instantiation params
      */
-    private static void addText(StringBuilder sb, AST ast) {
+    private static boolean addText(StringBuilder sb, AST ast) {
         if( ! (ast instanceof FakeAST) ) {
             if( sb.length() > 0 ) {
                 sb.append(' ');
             }
             sb.append(AstUtil.getText(ast));
         }
-        int curDepth = 0;
-        for( AST token = ast.getFirstChild(); token != null; token = token.getNextSibling() ) {
-            if (token.getType() == CPPTokenTypes.LESSTHAN) {
-                curDepth++;
-                continue;
-            } else if (token.getType() == CPPTokenTypes.GREATERTHAN) {
-                curDepth--;
-                continue;
-            }
-            if (curDepth == 0) {
-                addText(sb,  token);
+        if (sb.length() < MAX_CLASSIFIER_TEXT_LENGTH) {
+            int curDepth = 0;
+            for( AST token = ast.getFirstChild(); token != null; token = token.getNextSibling() ) {
+                if (token.getType() == CPPTokenTypes.LESSTHAN) {
+                    curDepth++;
+                    continue;
+                } else if (token.getType() == CPPTokenTypes.GREATERTHAN) {
+                    curDepth--;
+                    continue;
+                }
+                if (curDepth == 0) {
+                    if (!addText(sb,  token)) {
+                        return false;
+                    }
+                }
             }
+            return true;
+        } else {
+            sb.append("..."); // NOI18N
+            return false;
         }
     }
 
