@@ -49,7 +49,6 @@ import org.netbeans.modules.cnd.antlr.ASTVisitor;
 import org.netbeans.modules.cnd.antlr.Token;
 import org.netbeans.modules.cnd.antlr.collections.AST;
 import org.netbeans.modules.cnd.apt.utils.APTUtils;
-import org.netbeans.modules.cnd.modelimpl.csm.deep.DeepUtil;
 import org.netbeans.modules.cnd.modelimpl.parser.CsmAST;
 import org.netbeans.modules.cnd.modelimpl.parser.FakeAST;
 import org.netbeans.modules.cnd.modelimpl.parser.OffsetableAST;
@@ -328,6 +327,14 @@ public class AstUtil {
         }
         return result;
     }
+    
+    public static AST skipTokens(AST ast, int...tokens) {
+        AST next = ast;
+        while (next != null && arrayContains(next.getType(), tokens)) {
+            next = next.getNextSibling();
+        }
+        return next;
+    }
 
     public static AST getLastChild(AST token) {
         if( token == null ) {
@@ -636,7 +643,16 @@ public class AstUtil {
         public int getNumberOfStringizedTokens() {
             return numStringizedTokens;
         }     
-    }        
+    }
+    
+    private static boolean arrayContains(int value, int...array) {
+        for (int elem : array) {
+            if (value == elem) {
+                return true;
+            }
+        }
+        return false;
+    }
 }
 
  
\ No newline at end of file
