@@ -41,7 +41,6 @@
  */
 package org.netbeans.modules.cnd.modelimpl.csm.core;
 
-import java.io.File;
 import java.io.PrintWriter;
 import java.nio.BufferUnderflowException;
 import java.util.ArrayList;
@@ -51,6 +50,8 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
 import org.netbeans.modules.cnd.api.model.CsmChangeEvent;
 import org.netbeans.modules.cnd.api.model.CsmFile;
 import org.netbeans.modules.cnd.api.model.CsmListeners;
@@ -72,18 +73,28 @@ import org.netbeans.modules.cnd.api.project.NativeProjectRegistry;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
 import org.netbeans.modules.cnd.modelimpl.trace.NativeProjectProvider;
 import org.netbeans.modules.cnd.modelutil.CsmUtilities;
+import org.netbeans.modules.cnd.utils.CndLanguageStandards;
+import org.netbeans.modules.cnd.utils.CndLanguageStandards.CndLanguageStandard;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.CndUtils;
 import org.netbeans.modules.cnd.utils.FSPath;
+import org.netbeans.modules.cnd.utils.MIMEExtensions;
+import org.netbeans.modules.cnd.utils.MIMENames;
 import org.netbeans.modules.cnd.utils.NamedRunnable;
 import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
+import org.openide.filesystems.FileAttributeEvent;
+import org.openide.filesystems.FileChangeListener;
+import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileRenameEvent;
 import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
+import org.openide.filesystems.FileUtil;
 import org.openide.loaders.DataObject;
 import org.openide.loaders.DataObjectNotFoundException;
 import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
+import org.openide.util.Pair;
 
 /**
  *
@@ -96,6 +107,8 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
     private static final class Lock{}
     private static final Lock lock = new Lock();
     private static final Set<String> toBeRmoved = new HashSet<>();
+    // equals to CompileExecSupport.PROP_LANG_STANDARD
+    private static final String PROP_LANG_STANDARD = "standard"; // NOI18N
 
     private final CsmModelListener listener = new CsmModelListener() {
 
@@ -313,10 +326,10 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
 
     private static void trace(String pattern, Object... args) {
         assert TRACE : "Should not be called if TRACE is off!"; //NOI18N
-        System.err.printf("### Standalone provider:  %s\n", String.format(pattern, args)); //NOI18N
+        System.err.printf("### Standalone provider:  %s%n", String.format(pattern, args)); //NOI18N
     }
 
-    /*package*/ static final class NativeProjectImpl implements NativeProject {
+    /*package*/ static final class NativeProjectImpl implements NativeProject, ChangeListener, FileChangeListener {
 
         private final List<FSPath> sysIncludes;
         private final List<FSPath> usrIncludes;
@@ -360,28 +373,15 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             List<String> usrMacros = new ArrayList<>();
             List<String> undefinedMacros = new ArrayList<>();
             NativeFileItem.Language lang;
-            LanguageFlavor flavor;
+            Pair<LanguageFlavor,MIMEExtensions> flavorExt;
             if (itemPrototype != null) {
                 lang = itemPrototype.getLanguage();
-                flavor = itemPrototype.getLanguageFlavor();
+                flavorExt = Pair.of(itemPrototype.getLanguageFlavor(), null);
             } else {
                 lang = NativeProjectProvider.getLanguage(file, dao);
-                flavor = LanguageFlavor.UNKNOWN;
-                String key = "cnd.standalone.default.flavor." + lang.name(); //NOI18N
-                String defFlavorTxt = System.getProperty(key);
-                if (defFlavorTxt != null) {
-                    try {
-                        flavor = LanguageFlavor.valueOf(defFlavorTxt);
-                    } catch (IllegalArgumentException e) {
-                        StringBuilder all = new StringBuilder();
-                        for (LanguageFlavor lf : LanguageFlavor.values()) {
-                            all.append(all.length() > 0 ? ',' : ' ').append(lf.name());
-                        }
-                        System.err.printf("Wrong parameter -J-D%s=%s. Should be one of %s\n", key, defFlavorTxt, all);
-                    }
-                }
+                flavorExt = getDefaultStandard(lang);
             }
-            NativeProject prototype = null;            
+            NativeProject prototype = null;
             for (CsmProject csmProject : model.projects()) {
                 Object p = csmProject.getPlatformProject();
                 if (p instanceof NativeProject) {
@@ -404,7 +404,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             if (prototype != null && ModelImpl.instance().isProjectDisabled(prototype)){
                 return null;
             }
-                    
+
             FileSystem fs;
             try {
                 fs = file.getFileSystem();
@@ -430,11 +430,87 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
                 sysMacros.addAll(DefaultSystemSettings.getDefault().getSystemMacros(lang, impl));
             }
             impl.checkPaths();
-            impl.addFile(file, lang, flavor);
+            LanguageFlavor resultingFlavor = flavorExt.first();
+            CndLanguageStandard standard = impl.getStandard(file);
+            if (standard != null) {
+                LanguageFlavor standardToFlavor = standardToFlavor(standard);
+                if (standardToFlavor != LanguageFlavor.UNKNOWN) {
+                    resultingFlavor = standardToFlavor;
+                }
+            }
+            impl.addFile(file, lang, resultingFlavor);
             set.add(impl.findFileItem(file));
+            MIMEExtensions me = flavorExt.second();
+            if (me != null) {
+                me.addChangeListener(impl);
+            }
+            file.addFileChangeListener(impl);
             return impl;
         }
 
+        private static Pair<LanguageFlavor,MIMEExtensions> getDefaultStandard(NativeFileItem.Language lang) {
+            LanguageFlavor flavor = LanguageFlavor.UNKNOWN;
+            MIMEExtensions me = null;
+            switch(lang) {
+                case C:
+                    me = MIMEExtensions.get(MIMENames.C_MIME_TYPE);
+                    break;
+                case CPP:
+                    me = MIMEExtensions.get(MIMENames.CPLUSPLUS_MIME_TYPE);
+                    break;
+                case C_HEADER:
+                    me = MIMEExtensions.get(MIMENames.HEADER_MIME_TYPE);
+                    break;
+            }
+            if (me != null) {
+                CndLanguageStandard defaultStandard = me.getDefaultStandard();
+                if (defaultStandard != null) {
+                    flavor = standardToFlavor(defaultStandard);
+                }
+            }
+            if (LanguageFlavor.UNKNOWN.equals(flavor)) {
+                String key = "cnd.standalone.default.flavor." + lang.name(); //NOI18N
+                String defFlavorTxt = System.getProperty(key);
+                if (defFlavorTxt != null) {
+                    try {
+                        flavor = LanguageFlavor.valueOf(defFlavorTxt);
+                    } catch (IllegalArgumentException e) {
+                        StringBuilder all = new StringBuilder();
+                        for (LanguageFlavor lf : LanguageFlavor.values()) {
+                            all.append(all.length() > 0 ? ',' : ' ').append(lf.name());
+                        }
+                        System.err.printf("Wrong parameter -J-D%s=%s. Should be one of %s%n", key, defFlavorTxt, all);
+                    }
+                }
+            }
+            return Pair.of(flavor, me);
+        }
+
+        private static LanguageFlavor standardToFlavor(CndLanguageStandard defaultStandard) {
+            LanguageFlavor flavor = LanguageFlavor.UNKNOWN;
+            switch (defaultStandard) {
+                case C89:
+                    flavor =LanguageFlavor.C89;
+                    break;
+                case C99:
+                    flavor =LanguageFlavor.C99;
+                    break;
+                case C11:
+                    flavor =LanguageFlavor.C11;
+                    break;
+                case CPP98:
+                    flavor =LanguageFlavor.CPP;
+                    break;
+                case CPP11:
+                    flavor =LanguageFlavor.CPP11;
+                    break;
+                case CPP14:
+                    flavor =LanguageFlavor.CPP14;
+                    break;
+            }
+            return flavor;
+        }
+
         private NativeProjectImpl(FileObject projectRoot,
                 List<FSPath> sysIncludes, List<FSPath> usrIncludes, List<String> usrFiles,
                 List<String> sysMacros, List<String> usrMacros, List<String> undefinedMacros) {
@@ -447,7 +523,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             this.sysMacros = sysMacros;
             this.usrMacros = usrMacros;
         }
-        
+
         private static FileSystem getFileSystem(FileObject fo) {
             try {
                 return fo.getFileSystem();
@@ -461,7 +537,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             check(sysIncludes);
             check(usrIncludes);
         }
-        
+
         private void check(List<FSPath> list) {
             for(Iterator<FSPath> it = list.iterator(); it.hasNext();){
                 FSPath path = it.next();
@@ -471,7 +547,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
                 }
             }
         }
-        
+
         private void addFile(FileObject file, NativeFileItem.Language lang, LanguageFlavor flavor) {
             NativeFileItemImpl item = new NativeFileItemImpl(file, this, lang, flavor);
             //TODO: put item in loockup of DataObject
@@ -502,7 +578,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
                 Exceptions.printStackTrace(ex);
                 return CndFileUtils.getLocalFileSystem();
             }
-        }        
+        }
 
         @Override
         public String getProjectDisplayName() {
@@ -528,6 +604,36 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             }
         }
 
+        @Override
+        public void stateChanged(ChangeEvent e) {
+            Object source = e.getSource();
+            if (source instanceof MIMEExtensions) {
+                if (files.size()>0) {
+                    FileObject fo = files.get(0).getFileObject();
+                    Object attribute = fo.getAttribute(PROP_LANG_STANDARD);
+                    if (attribute instanceof String) {
+                        return;
+                    }
+                }
+                ArrayList<NativeProjectItemsListener> list = new ArrayList<>();
+                synchronized (listenersLock) {
+                    list.addAll(listeners);
+                }
+                MIMEExtensions me = (MIMEExtensions) source;
+                CndLanguageStandard defaultStandard = me.getDefaultStandard();
+                for(NativeFileItemImpl nfi : files) {
+                    NativeFileItem.LanguageFlavor flavor = standardToFlavor(defaultStandard);
+                    if (flavor != LanguageFlavor.UNKNOWN) {
+                        nfi.setLanguageFlavor(flavor);
+                    }
+                }
+                for(NativeProjectItemsListener listener : list) {
+                    listener.filesPropertiesChanged();
+                }
+            }
+        }
+
+
         @Override
         public NativeFileItemImpl findFileItem(FileObject fileObject) {
             for (NativeFileItemImpl item : files) {
@@ -552,7 +658,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         public List<String> getIncludeFiles() {
             return this.usrFiles;
         }
-        
+
         @Override
         public List<String> getSystemMacroDefinitions() {
             return this.sysMacros;
@@ -572,11 +678,81 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         public void runOnProjectReadiness(NamedRunnable task) {
             task.run();
         }
-        
+
         @Override
         public void fireFilesPropertiesChanged() {
         }
 
+        @Override
+        public void fileFolderCreated(FileEvent fe) {
+        }
+
+        @Override
+        public void fileDataCreated(FileEvent fe) {
+        }
+
+        @Override
+        public void fileChanged(FileEvent fe) {
+        }
+
+        @Override
+        public void fileDeleted(FileEvent fe) {
+        }
+
+        @Override
+        public void fileRenamed(FileRenameEvent fe) {
+        }
+
+        private CndLanguageStandard getStandard(FileObject fo) {
+            if (fo == null) {
+                return null;
+            }
+            String mimeType = FileUtil.getMIMEType(fo);
+            if (mimeType == null) {
+                return null;
+            }
+            return CndLanguageStandards.StringToLanguageStandard((String) fo.getAttribute(PROP_LANG_STANDARD));
+        }
+
+        @Override
+        public void fileAttributeChanged(FileAttributeEvent fe) {
+            String name = fe.getName();
+            if (!PROP_LANG_STANDARD.equals(name)) {
+                return;
+            }
+            FileObject fo = fe.getFile();
+            if (fo == null) {
+                return;
+            }
+            CndLanguageStandard standard = getStandard(fo);
+            if (standard == null) {
+                String mimeType = FileUtil.getMIMEType(fo);
+                if (mimeType == null) {
+                    return;
+                }
+                MIMEExtensions me = MIMEExtensions.get(mimeType);
+                if (me == null) {
+                    return;
+                }
+                // use standatd from me
+                stateChanged(new ChangeEvent(me));
+                return;
+            }
+            for(NativeFileItemImpl nfi : files) {
+                NativeFileItem.LanguageFlavor flavor = standardToFlavor(standard);
+                if (flavor != LanguageFlavor.UNKNOWN) {
+                    nfi.setLanguageFlavor(flavor);
+                }
+            }
+            ArrayList<NativeProjectItemsListener> list = new ArrayList<>();
+            synchronized (listenersLock) {
+                list.addAll(listeners);
+            }
+            for(NativeProjectItemsListener listener : list) {
+                listener.filesPropertiesChanged();
+            }
+        }
+
         @Override
         public final String toString() {
             return "SA " + projectRoot + ' ' + getClass().getName() + " @" + hashCode() + ":" + System.identityHashCode(this); // NOI18N
@@ -588,10 +764,9 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         private final FileObject fileObject;
         private final NativeProjectImpl project;
         private final NativeFileItem.Language lang;
-        private final NativeFileItem.LanguageFlavor flavor;
+        private NativeFileItem.LanguageFlavor flavor;
 
         public NativeFileItemImpl(FileObject file, NativeProjectImpl project, NativeFileItem.Language language, NativeFileItem.LanguageFlavor flavor) {
-
             this.project = project;
             this.fileObject = file;
             this.lang = language;
@@ -607,7 +782,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         public FileObject getFileObject() {
             return fileObject;
         }
-        
+
         @Override
         public String getAbsolutePath() {
             return CndFileUtils.normalizePath(fileObject);
@@ -616,7 +791,7 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         @Override
         public String getName() {
             return fileObject.getNameExt();
-        }       
+        }
 
         @Override
         public List<FSPath> getSystemIncludePaths() {
@@ -638,7 +813,6 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
         }
 
         private void checkAbsolute(List<FSPath> orig) {
-            List<FSPath> result = new ArrayList<>(orig.size());
             for (FSPath path : orig) {
                 CndUtils.assertAbsolutePathInConsole(path.getPath());
             }
@@ -664,6 +838,10 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             return flavor;
         }
 
+        public void setLanguageFlavor(NativeFileItem.LanguageFlavor flavor) {
+            this.flavor = flavor;
+        }
+
         @Override
         public boolean isExcluded() {
             return false;
@@ -674,13 +852,13 @@ public class CsmStandaloneFileProviderImpl extends CsmStandaloneFileProvider {
             return "SA " + fileObject + " " + System.identityHashCode(this) + " " + lang + " from project:" + project; // NOI18N
         }
     }
-    
+
     public void dumpInfo(PrintWriter printOut) {
-        printOut.printf("SAProvider %s has toBeRemoved=%d entries\n", this.getClass().getSimpleName(), toBeRmoved.size());// NOI18N 
+        printOut.printf("SAProvider %s has toBeRemoved=%d entries%n", this.getClass().getSimpleName(), toBeRmoved.size());// NOI18N
         int ind = 1;
         for (String str : toBeRmoved) {
-            printOut.printf("[%d] %s\n", ind++, str);// NOI18N
+            printOut.printf("[%d] %s%n", ind++, str);// NOI18N
         }
     }
-    
+
 }
