@@ -61,7 +61,6 @@ import org.netbeans.modules.cnd.api.model.CsmModelAccessor;
 import org.netbeans.modules.cnd.api.model.CsmProject;
 import org.netbeans.modules.cnd.api.model.CsmUID;
 import org.netbeans.modules.cnd.apt.support.ResolvedPath;
-import org.netbeans.modules.cnd.apt.utils.APTSerializeUtils;
 import org.netbeans.modules.cnd.modelimpl.debug.TraceFlags;
 import org.netbeans.modules.cnd.modelimpl.repository.PersistentUtils;
 import org.netbeans.modules.cnd.modelimpl.uid.UIDCsmConverter;
@@ -73,6 +72,7 @@ import org.netbeans.modules.cnd.utils.CndUtils;
 import org.netbeans.modules.cnd.utils.cache.CharSequenceUtils;
 import org.openide.filesystems.FileSystem;
 import org.openide.util.CharSequences;
+import org.openide.util.Parameters;
 
 /**
  * Artificial libraries manager.
@@ -84,9 +84,9 @@ import org.openide.util.CharSequences;
 public final class LibraryManager {
 
     private static final Map<Integer, LibraryManager> instances = new HashMap<>();
-    
+
     private final int repositoryId;
-    
+
     public  static LibraryManager getInstance(int sourceUnitId) {
         int repositoryId = Repository.getLayeringSupport(sourceUnitId).getStorageID();
         return getInstanceByRepositoryId(repositoryId);
@@ -106,9 +106,9 @@ public final class LibraryManager {
     private LibraryManager(int repositoryId) {
         this.repositoryId = repositoryId;
     }
-    
+
     private final ConcurrentHashMap<LibraryKey, LibraryEntry> librariesEntries = new ConcurrentHashMap<>();
-    
+
     private static final class Lock {}
     private final Object lock = new Lock();
 
@@ -125,7 +125,7 @@ public final class LibraryManager {
     private void shutdownImpl(){
         librariesEntries.clear();
     }
-    
+
     /**
      * Returns collection of artificial libraries used in project
      */
@@ -134,7 +134,7 @@ public final class LibraryManager {
         CsmUID<CsmProject> projectUid = project.getUID();
         for (LibraryEntry entry : librariesEntries.values()) {
             if (entry.containsProject(projectUid)) {
-                CsmUID<CsmProject> library = entry.getLibrary(project.getUnitId());
+                CsmUID<CsmProject> library = entry.getLibrary();
                 CsmProject lib = library.getObject();
                 if (lib instanceof LibProjectImpl) {
                     res.add((LibProjectImpl)lib);
@@ -155,22 +155,22 @@ public final class LibraryManager {
             List<ProjectBase> projects = new ArrayList<>(uids.size());
             for (CsmUID<CsmProject> uid : uids) {
                 ProjectBase project = (ProjectBase) uid.getObject();
-                if (project != null && ! project.isDisposing() && project.isValid()) {                    
+                if (project != null && ! project.isDisposing() && project.isValid()) {
                     projects.add(project);
                 }
-            }            
+            }
             return projects;
         }
     }
-    
+
     /**
      * Returns collection uids of artificial libraries used in project
      */
-    public Collection<CsmUID<CsmProject>> getLirariesKeys(CsmUID<CsmProject> projectUid, int unitId) {
+    public Collection<CsmUID<CsmProject>> getLirariesKeys(CsmUID<CsmProject> projectUid) {
         List<CsmUID<CsmProject>> res = new ArrayList<>();
         for (LibraryEntry entry : librariesEntries.values()) {
             if (entry.containsProject(projectUid)) {
-                res.add(entry.getLibrary(unitId));
+                res.add(entry.getLibrary());
             }
         }
         return res;
@@ -191,7 +191,7 @@ public final class LibraryManager {
      * Find project for resolved file.
      * Search for project in project, dependencies, artificial libraries.
      * If search is false then method creates artificial library or returns base project.
-     * 
+     *
      * Can return NULL !
      */
     public ProjectBase resolveFileProjectOnInclude(ProjectBase baseProject, FileImpl curFile, ResolvedPath resolvedPath) {
@@ -214,8 +214,8 @@ public final class LibraryManager {
                 trace("Projects roots", curFile, resolvedPath, res, baseProject);//NOI18N
             }
             return res;
-        }   
-        List<CsmProject> libraries = baseProject.getLibraries();        
+        }
+        List<CsmProject> libraries = baseProject.getLibraries();
         res = searchInProjectFilesArtificial(libraries, resolvedPath, antiLoop);
         if (res != null) {
             baseProject.prepareIncludeStorage(res);
@@ -230,13 +230,20 @@ public final class LibraryManager {
             if (res == null) {
                 if (resolvedPath.isDefaultSearchPath()) {
                     res = curFile.getProjectImpl(true);
-                    if (TraceFlags.TRACE_RESOLVED_LIBRARY) {
-                        trace("Base Project as Default Search Path", curFile, resolvedPath, res, baseProject);//NOI18N
+                    if (res != null) {
+                        if (resolvedPath.getFileSystem() == res.getFileSystem()) {
+                            if (TraceFlags.TRACE_RESOLVED_LIBRARY) {
+                                trace("Base Project as Default Search Path", curFile, resolvedPath, res, baseProject);//NOI18N
+                            }
+                        } else {
+                            CndUtils.assertTrue(false, "Wrong FS for " + resolvedPath + ": " + res.getFileSystem() + " vs " + resolvedPath.getFileSystem()); // NOI18N
+                            res = null;
+                        }
                     }
                     // if (res != null && res.isArtificial()) { // TODO: update lib source roots here }
                 } else if (!baseProject.isArtificial()) {
                     res = getLibrary((ProjectImpl) baseProject, resolvedPath.getFileSystem(), folder);
-                    if (res == null && CndUtils.isDebugMode()) {
+                    if (res == null && CndUtils.isDebugMode() && baseProject.isValid() ) {
                         CndUtils.assertTrue(false, "Can not create library; folder=" + folder + " curFile=" + //NOI18N
                                 curFile + " path=" + resolvedPath + " baseProject=" + baseProject); //NOI18N
                     }
@@ -244,10 +251,10 @@ public final class LibraryManager {
                         trace("Library for folder " + folder, curFile, resolvedPath, res, baseProject); //NOI18N
                     }
                 } else {
-                    if (CndUtils.isDebugMode()) {
+                    if (CndUtils.isDebugMode() && baseProject.isValid()) {
                         CndUtils.assertTrue(false, "Can not get library for artificial project; folder=" + folder + " curFile=" + //NOI18N
                                 curFile + " path=" + resolvedPath + " baseProject=" + baseProject); //NOI18N
-                    }                    
+                    }
                     if (TraceFlags.TRACE_RESOLVED_LIBRARY) {
                         trace("Base Project", curFile, resolvedPath, res, baseProject);//NOI18N
                     }
@@ -305,7 +312,7 @@ public final class LibraryManager {
         }
         return path;
     }
-    
+
     private static ProjectBase searchInProjectFiles(ProjectBase baseProject, ResolvedPath searchFor, Set<ProjectBase> set) {
         if (set.contains(baseProject)) {
             return null;
@@ -396,17 +403,20 @@ public final class LibraryManager {
         LibraryKey libraryKey = new LibraryKey(fs, folder);
         LibraryEntry entry = librariesEntries.get(libraryKey);
         if (entry == null) {
-            entry = getOrCreateLibrary(libraryKey, project.getUnitId());
+            if (!project.isValid()) {
+                return null;
+            }
+            entry = getOrCreateLibrary(libraryKey);
         }
         if (!entry.containsProject(projectUid)) {
             entry.addProject(projectUid);
             Notificator.instance().registerChangedLibraryDependency(project);
-            Notificator.instance().flush(); // should we rely on subsequent flush instead? 
+            Notificator.instance().flush(); // should we rely on subsequent flush instead?
         }
-        return (LibProjectImpl) entry.getLibrary(project.getUnitId()).getObject();
+        return (LibProjectImpl) entry.getLibrary().getObject();
     }
 
-    private LibraryEntry getOrCreateLibrary(LibraryKey libraryKey, final int sourceUnitId) {
+    private LibraryEntry getOrCreateLibrary(LibraryKey libraryKey) {
         LibraryEntry entry = librariesEntries.get(libraryKey);
         if (entry == null) {
             boolean needFire = false;
@@ -423,7 +433,7 @@ public final class LibraryManager {
 
                     @Override
                     public void run() {
-                        ListenersImpl.getImpl().fireProjectOpened((ProjectBase) passEntry.getLibrary(sourceUnitId).getObject());
+                        ListenersImpl.getImpl().fireProjectOpened((ProjectBase) passEntry.getLibrary().getObject());
                     }
                 }, "postponed library opened " + libraryKey.folder); // NOI18N
             }
@@ -444,14 +454,14 @@ public final class LibraryManager {
         }
         if (notify) {
             Notificator.instance().registerChangedLibraryDependency(project);
-            Notificator.instance().flush(); // should we rely on subsequent flush instead? 
+            Notificator.instance().flush(); // should we rely on subsequent flush instead?
         }
     }
 
     /**
      * Close unused artificial libraries.
      */
-    public void onProjectClose(CsmUID<CsmProject> project, int unitId) {
+    public void onProjectClose(CsmUID<CsmProject> project) {
         List<LibraryEntry> toClose = new ArrayList<>();
         for (LibraryEntry entry : librariesEntries.values()) {
             entry.removeProject(project);
@@ -464,7 +474,7 @@ public final class LibraryManager {
                 librariesEntries.remove(entry.getKey());
             }
         }
-        closeLibraries(toClose, unitId);
+        closeLibraries(toClose);
     }
 
     /*package*/
@@ -484,7 +494,7 @@ public final class LibraryManager {
             getInstanceByRepositoryId(entry.getKey()).cleanLibrariesDataImpl(entry.getValue());
         }
     }
-    
+
     private void cleanLibrariesDataImpl(Collection<LibProjectImpl> libs) {
         for (LibProjectImpl entry : libs) {
             librariesEntries.remove(new LibraryKey(entry.getFileSystem(), entry.getPath()));
@@ -492,10 +502,10 @@ public final class LibraryManager {
         }
     }
 
-    private void closeLibraries(Collection<LibraryEntry> entries, int sourceUnitId) {
+    private void closeLibraries(Collection<LibraryEntry> entries) {
         ModelImpl model = (ModelImpl) CsmModelAccessor.getModel();
         for (LibraryEntry entry : entries) {
-            CsmUID<CsmProject> uid = entry.getLibrary(sourceUnitId);
+            CsmUID<CsmProject> uid = entry.getLibrary();
             ProjectBase lib = (ProjectBase) uid.getObject();
             assert lib != null : "Null project for UID " + uid;
             model.disposeProject(lib);
@@ -505,30 +515,30 @@ public final class LibraryManager {
     /**
      * Write artificial libraries for project
      */
-    /*package-local*/ void writeProjectLibraries(CsmUID<CsmProject> project, RepositoryDataOutput aStream, int unutId) throws IOException {
+    /*package-local*/ void writeProjectLibraries(CsmUID<CsmProject> project, RepositoryDataOutput aStream) throws IOException {
         assert aStream != null;
         Set<LibraryKey> keys = new HashSet<>();
         for (Map.Entry<LibraryKey, LibraryEntry> entry : librariesEntries.entrySet()) {
             if (entry.getValue().containsProject(project)) {
                 keys.add(entry.getKey());
             }
-        }        
+        }
         aStream.writeInt(keys.size());
         for (LibraryKey libraryKey : keys) {
-            libraryKey.write(aStream, unutId);
+            libraryKey.write(aStream);
         }
     }
 
     /**
      * Read artificial libraries for project
      */
-    /*package-local*/ void readProjectLibraries(CsmUID<CsmProject> project, RepositoryDataInput input, int unitId) throws IOException {
+    /*package-local*/ void readProjectLibraries(CsmUID<CsmProject> project, RepositoryDataInput input) throws IOException {
         assert input != null;
         int len = input.readInt();
         if (len != AbstractObjectFactory.NULL_POINTER) {
             for (int i = 0; i < len; i++) {
-                LibraryKey key =  new LibraryKey(input, unitId);
-                LibraryEntry entry =  getOrCreateLibrary(key, unitId);
+                LibraryKey key =  new LibraryKey(input);
+                LibraryEntry entry =  getOrCreateLibrary(key);
                 entry.addProject(project); // no need to notiy here, we are called from project constructor here
             }
         }
@@ -540,23 +550,20 @@ public final class LibraryManager {
         private final CharSequence folder;
 
         public LibraryKey(FileSystem fileSystem, CharSequence folder) {
+            Parameters.notNull("fileSystem", fileSystem);
             this.fileSystem = fileSystem;
             this.folder = folder;
         }
 
-        private LibraryKey(RepositoryDataInput input, int contextProjectID) throws IOException {
+        private LibraryKey(RepositoryDataInput input) throws IOException {
             this.fileSystem = PersistentUtils.readFileSystem(input);
-            int storedContextProjectID = input.readUnitId();
-            assert contextProjectID == storedContextProjectID;
-            int fileIndex = input.readInt();
-            this.folder = APTSerializeUtils.getFileNameById(contextProjectID, fileIndex);
+            assert fileSystem != null;
+            this.folder = input.readFilePathForFileSystem(fileSystem);
         }
-        
-        private void write(RepositoryDataOutput out, int contextProjectID) throws IOException {            
+
+        private void write(RepositoryDataOutput out) throws IOException {
             PersistentUtils.writeFileSystem(fileSystem, out);
-            out.writeUnitId(contextProjectID);
-            int fileIndex = APTSerializeUtils.getFileIdByName(contextProjectID, folder);
-            out.writeInt(fileIndex);
+            out.writeFilePathForFileSystem(fileSystem, folder);
         }
 
         @Override
@@ -584,7 +591,7 @@ public final class LibraryManager {
             }
             return true;
         }
-        
+
     }
 
     private final class LibraryEntry {
@@ -609,20 +616,19 @@ public final class LibraryManager {
         public LibraryKey getKey() {
             return key;
         }
-        
-        private CsmUID<CsmProject> getLibrary(int sourceUnitId) {
+
+        private CsmUID<CsmProject> getLibrary() {
             if (libraryUID == null) {
-                createUID(sourceUnitId);
+                createUID();
             }
             assert libraryUID != null : "libraryUID is null for folder " + getFolder();
-            return libraryUID;            
+            return libraryUID;
         }
 
-        private synchronized void createUID(int sourceUnitId) {
-            assert Repository.getLayeringSupport(sourceUnitId).getStorageID() == repositoryId;
+        private synchronized void createUID() {
             if (libraryUID == null) {
                 ModelImpl model = (ModelImpl) CsmModelAccessor.getModel();
-                LibProjectImpl library = LibProjectImpl.createInstance(model, getFileSystem(), getFolder(), sourceUnitId);
+                LibProjectImpl library = LibProjectImpl.createInstance(model, getFileSystem(), getFolder(), repositoryId);
                 libraryUID = library.getUID();
             }
         }
@@ -634,7 +640,7 @@ public final class LibraryManager {
         private boolean containsProject(CsmUID<CsmProject> project) {
             return dependentProjects.containsKey(project);
         }
-        
+
         private Collection<CsmUID<CsmProject>> getDependentProjects() {
             return dependentProjects.keySet();
         }
@@ -646,7 +652,7 @@ public final class LibraryManager {
         private Boolean removeProject(CsmUID<CsmProject> project) {
             return dependentProjects.remove(project);
         }
-        
+
         @Override
         public String toString() {
             StringBuilder sb = new StringBuilder();
@@ -661,9 +667,9 @@ public final class LibraryManager {
             }
             return sb.toString();
         }
-        
+
     }
-    
+
     public static void dumpInfo(PrintWriter printOut, boolean withContainers) {
         Collection<LibraryManager> list;
         synchronized (instances) {
@@ -673,21 +679,21 @@ public final class LibraryManager {
             manager.dumpInfoImpl(printOut, withContainers);
         }
     }
-    
+
     private void dumpInfoImpl(PrintWriter printOut, boolean withContainers) {
-        printOut.printf("LibraryManager [%d]: libs=%d\n", repositoryId, librariesEntries.size());// NOI18N
+        printOut.printf("LibraryManager [%d]: libs=%d%n", repositoryId, librariesEntries.size());// NOI18N
         int ind = 1;
         for (Map.Entry<LibraryKey, LibraryEntry> entry : librariesEntries.entrySet()) {
-            printOut.printf("Lib[%d] %s with LibEntry %s\n", ind++, entry.getKey(), entry.getValue());// NOI18N
+            printOut.printf("Lib[%d] %s with LibEntry %s%n", ind++, entry.getKey(), entry.getValue());// NOI18N
             if (withContainers) {
                 CsmProject library = UIDCsmConverter.UIDtoProject(entry.getValue().libraryUID);
                 if (library == null) {
-                    printOut.printf("Library was NOT restored from repository\n");// NOI18N
+                    printOut.printf("Library was NOT restored from repository%n");// NOI18N
                 } else if (library instanceof ProjectBase) {
-                    printOut.printf("[%d] disposing=%s\n", ind, ((ProjectBase)library).isDisposing());// NOI18N
+                    printOut.printf("[%d] disposing=%s%n", ind, ((ProjectBase)library).isDisposing());// NOI18N
                     ProjectBase.dumpFileContainer(library, printOut);
                 } else {
-                    printOut.printf("Library's project has unexpected class type %s\n", library.getClass().getName());// NOI18N
+                    printOut.printf("Library's project has unexpected class type %s%n", library.getClass().getName());// NOI18N
                 }
             }
         }
