@@ -57,6 +57,7 @@ import org.netbeans.modules.cnd.api.project.NativeProjectSettings;
 import org.netbeans.modules.cnd.apt.support.APTDriver;
 import org.netbeans.modules.cnd.apt.support.APTFileCacheManager;
 import org.netbeans.modules.cnd.apt.support.APTSystemStorage;
+import org.netbeans.modules.cnd.apt.support.ClankDriver;
 import org.netbeans.modules.cnd.modelimpl.accessors.CsmCorePackageAccessor;
 import org.netbeans.modules.cnd.modelimpl.content.file.ReferencesIndex;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
@@ -94,7 +95,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
     static {
         CsmCorePackageAccessor.register(new AccessorImpl());
     }
-    
+
     public ModelImpl() {
         startup();
     }
@@ -175,7 +176,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
             synchronized (lock) {
                 prj = obj2Project(id);
                 if (prj == null && id instanceof Project) {
-                    // for compatibility 
+                    // for compatibility
                     if (TraceFlags.DEBUG) {
                         System.err.println("getProject called with Project... expected NativeProject");
                         new Throwable().printStackTrace(System.err);
@@ -198,7 +199,9 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
                     try {
                         projectsBeingCreated.add(nativeProject);
                         prj = ProjectImpl.createInstance(this, nativeProject, name);
-                        putProject2Map(id, prj);
+                        if (prj != null) {
+                            putProject2Map(id, prj);
+                        }
                     } finally {
                         projectsBeingCreated.remove(nativeProject);
                     }
@@ -222,11 +225,13 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
                 }
                 prj = obj2Project(id);
                 if (prj == null) {
-                    try {                        
+                    try {
                         projectsBeingCreated.add(id);
                         prj = ProjectImpl.createInstance(this, id, name);
-                        putProject2Map(id, prj);
-                        fireOpened = true;
+                        if (prj != null) {
+                            putProject2Map(id, prj);
+                            fireOpened = true;
+                        }
                     } finally {
                         projectsBeingCreated.remove(id);
                     }
@@ -335,7 +340,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         if (prj != null) {
             disposeProject(prj, cleanRepository);
             if (!prj.isArtificial()) {
-                LibraryManager.getInstance(prj.getUnitId()).onProjectClose(prj.getUID(), prj.getUnitId());
+                LibraryManager.getInstance(prj.getUnitId()).onProjectClose(prj.getUID());
             }
         }
 
@@ -385,7 +390,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
 
     @Override
     public Cancellable enqueue(Runnable task, CharSequence name) {
-        return enqueueOrCreate(true, userTasksProcessor, task, clientTaskPrefix + " :" + name); // NOI18N
+        return enqueueOrCreate(userTasksProcessor, task, clientTaskPrefix + " :" + name, false); // NOI18N
     }
 
     public static ModelImpl instance() {
@@ -393,27 +398,36 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
     }
 
     public RequestProcessor.Task enqueueModelTask(Runnable task, String name) {
-        return enqueueOrCreate(true, modelProcessor, task, modelTaskPrefix + ": " + name); // NOI18N
+        return enqueueOrCreate(modelProcessor, task, modelTaskPrefix + ": " + name, false); // NOI18N
     }
 
     public RequestProcessor.Task createModelTask(Runnable task, String name) {
-        return enqueueOrCreate(true, modelProcessor, task, modelTaskPrefix + ": " + name); // NOI18N
+        return enqueueOrCreate(modelProcessor, task, modelTaskPrefix + ": " + name, false); // NOI18N
     }
 
     public static boolean isModelRequestProcessorThread() {
         return ModelImpl.instance().modelProcessor.isRequestProcessorThread();
     }
-    
+
     public void waitModelTasks() {
-        RequestProcessor.Task task = enqueueModelTask(new Runnable() {
+        RequestProcessor.Task task = enqueueOrCreate(modelProcessor, new Runnable() {
             @Override
             public void run() {
             }
-        }, "wait finished other tasks"); //NOI18N
+        }, "wait finished other tasks", true); //NOI18N
         task.waitFinished();
     }
-    
-    private RequestProcessor.Task enqueueOrCreate(boolean post, RequestProcessor processor, final Runnable task, final String taskName) {
+
+    private RequestProcessor.Task enqueueOrCreate(RequestProcessor processor, final Runnable task, final String taskName, boolean force) {
+        if (!force) {
+            if (!CsmModelAccessor.isModelAlive()) {
+                if (TraceFlags.TRACE_MODEL_STATE) {
+                    System.err.println("Reject task ["+taskName+"] on model closing"); // NOI18N
+                }
+                return null;
+            }
+        }
+
         if (TraceFlags.TRACE_182342_BUG) {
             new Exception(taskName).printStackTrace(System.err);
         }
@@ -431,7 +445,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
                 }
             }
         };
-        return post ? processor.post(r) : processor.create(r);
+        return  processor.post(r);
     }
 
     @Override
@@ -468,7 +482,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         }
         return ret.toArray(new CsmFile[ret.size()]);
     }
-    
+
     @Override
     public CsmFile findFile(FSPath absPath, boolean createIfPossible, boolean snapShot) {
         CndUtils.assertAbsolutePathInConsole(absPath.getPath());
@@ -541,22 +555,17 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         if (TraceFlags.TRACE_MODEL_STATE) {
             System.err.println("ModelImpl.closing");
         }
-        waitModelTasks();
-        setState(CsmModelState.CLOSING);        
+        setState(CsmModelState.CLOSING);
+        ParserThreadManager.instance().shutdown();
     }
-    
-    public void shutdown() {
 
+    public void shutdown() {
         if (TraceFlags.TRACE_MODEL_STATE) {
             System.err.println("ModelImpl.shutdown");
         }
-        waitModelTasks();
         setState(CsmModelState.CLOSING);
-
-        // it's now done in ProjectBase.setDisposed()
-        // unregisterProjectListeners();
-
         ParserThreadManager.instance().shutdown();
+        waitModelTasks();
 
         if (TraceFlags.CHECK_MEMORY) {
             LowMemoryNotifier.instance().removeListener(this);
@@ -588,7 +597,6 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         RepositoryUtils.shutdown();
 
         ModelSupport.instance().setModel(null);
-        waitModelTasks();
     }
 
     @Override
@@ -599,7 +607,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         final boolean warning = percentage >= warningThreshold && projects().size() > 0;
 
 //	final boolean fatal = percentage >= fatalThreshold && projects().size() > 0;
-//	
+//
 //	if( fatal ) {
 //	    LowMemoryNotifier.instance().removeListener(this);
 //	}
@@ -767,7 +775,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         boolean actionPerformed = false;
         if (project != null) {
             NativeProjectSettings settings = project.getLookup().lookup(NativeProjectSettings.class);
-            if (settings != null) {                
+            if (settings != null) {
                 settings.setCodeAssistanceEnabled(enable);
                 actionPerformed = true;
             }
@@ -781,7 +789,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
 //            CndUtils.assertTrueInConsole(false, msg, project);
 //        }
     }
-    
+
     public static Lookup.Provider findProjectByNativeProject(NativeProject nativeProjectToSearch) {
         for(NativeProject nativeProject : NativeProjectRegistry.getDefault().getOpenProjects()) {
             if (nativeProject == nativeProjectToSearch) {
@@ -792,12 +800,13 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
     }
 
     /**
-     * @return 
+     * @return
      * Boolean.TRUE if the project is enabled
      * Boolean.FALSE if the project is disabled
      * null if the project is being created
      */
     @Override
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP")
     public Boolean isProjectEnabled(Object nativeProject) {
         assert nativeProject instanceof NativeProject : "unexpected class " + nativeProject;
         if (projectsBeingCreated.contains((NativeProject)nativeProject)) {
@@ -821,6 +830,7 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
         FileNameCache.getManager().dispose();
         ProjectNameCache.getManager().dispose();
         APTDriver.close();
+        ClankDriver.close();
         APTFileCacheManager.close();
         UIDManager.instance().dispose();
         KeyManager.instance().dispose();
@@ -830,65 +840,73 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
     }
 
     @Override
-    public void scheduleReparse(Collection<CsmProject> projects) {
-        CndFileUtils.clearFileExistenceCache();
-        ParserQueue.instance().clearParseWatch();
-        APTFileCacheManager.invalidateAll();
-        Collection<LibProjectImpl> libs = new HashSet<>();
-        Collection<ProjectBase> toReparse = new HashSet<>();
-        for (CsmProject csmProject : projects) {
-            if (csmProject instanceof ProjectBase) {
-                ProjectBase project = (ProjectBase) csmProject;
-                toReparse.add(project);
-                for (CsmProject csmLib : project.getLibraries()) {
-                    if (csmLib instanceof LibProjectImpl) {
-                        LibProjectImpl lib = (LibProjectImpl) csmLib;
-                        if (!libs.contains(lib)) {
-                            libs.add(lib);
+    public void scheduleReparse(final Collection<CsmProject> projects) {
+        enqueueModelTask(
+        new Runnable() {
+            @Override
+            public void run() {
+                CndFileUtils.clearFileExistenceCache();
+                ParserQueue.instance().clearParseWatch();
+                ClankDriver.invalidateAll();
+                APTFileCacheManager.invalidateAll();
+                APTSystemStorage.dispose();
+                Collection<LibProjectImpl> libs = new HashSet<>();
+                Collection<ProjectBase> toReparse = new HashSet<>();
+                for (CsmProject csmProject : projects) {
+                    if (csmProject instanceof ProjectBase) {
+                        ProjectBase project = (ProjectBase) csmProject;
+                        toReparse.add(project);
+                        for (CsmProject csmLib : project.getLibraries()) {
+                            if (csmLib instanceof LibProjectImpl) {
+                                LibProjectImpl lib = (LibProjectImpl) csmLib;
+                                if (!libs.contains(lib)) {
+                                    libs.add(lib);
+                                }
+                            }
                         }
                     }
                 }
-            }
-        }
-        for(CsmProject csmProject : projects()) {
-            if (!projects.contains(csmProject)) {
-                if (csmProject instanceof ProjectBase) {
-                    ProjectBase project = (ProjectBase) csmProject;
-                    for (CsmProject csmLib : project.getLibraries()) {
-                        if (csmLib instanceof LibProjectImpl) {
-                            libs.remove((LibProjectImpl)csmLib);
+                for(CsmProject csmProject : projects()) {
+                    if (!projects.contains(csmProject)) {
+                        if (csmProject instanceof ProjectBase) {
+                            ProjectBase project = (ProjectBase) csmProject;
+                            for (CsmProject csmLib : project.getLibraries()) {
+                                if (csmLib instanceof LibProjectImpl) {
+                                    libs.remove((LibProjectImpl)csmLib);
+                                }
+                            }
                         }
                     }
                 }
+                for (LibProjectImpl lib : libs) {
+                    lib.initFields();
+                }
+                Collection<Object> platformProjects = new ArrayList<>();
+                for (ProjectBase projectBase : toReparse) {
+                    final Object platformProject = projectBase.getPlatformProject();
+                    if (platformProject != null) {
+                        platformProjects.add(platformProject);
+                        closeProject(platformProject, true);
+                    }
+                }
+                for (LibProjectImpl lib : libs) {
+                    Object platformProject = lib.getPlatformProject();
+                    CndUtils.assertTrue(platformProject != null || lib.isDisposing(), "No Platform project for ", lib);
+                    // lib can be already closed when last project was closed in the loop above
+                    if (platformProject != null) {
+                        closeProject(platformProject, true);
+                    }
+                }
+                LibraryManager.cleanLibrariesData(libs);
+                for (Object platformProject : platformProjects) {
+                    ProjectBase newPrj = (ProjectBase) _getProject(platformProject);
+                    if (newPrj != null) { // VK: at least once I've got NPE here: might be already closed?
+                        newPrj.scheduleReparse();
+                        ListenersImpl.getImpl().fireProjectOpened(newPrj);
+                    }
+                }
             }
-        }
-        for (LibProjectImpl lib : libs) {
-            lib.initFields();
-        }
-        Collection<Object> platformProjects = new ArrayList<>();
-        for (ProjectBase projectBase : toReparse) {
-            final Object platformProject = projectBase.getPlatformProject();
-            if (platformProject != null) {
-                platformProjects.add(platformProject);
-                closeProject(platformProject, true);
-            }
-        }
-        for (LibProjectImpl lib : libs) {
-            Object platformProject = lib.getPlatformProject();
-            CndUtils.assertTrue(platformProject != null || lib.isDisposing(), "No Platform project for ", lib);
-            // lib can be already closed when last project was closed in the loop above
-            if (platformProject != null) {
-                closeProject(platformProject, true);
-            }
-        }
-        LibraryManager.cleanLibrariesData(libs);
-        for (Object platformProject : platformProjects) {
-            ProjectBase newPrj = (ProjectBase) _getProject(platformProject);
-            if (newPrj != null) { // VK: at least once I've got NPE here: might be already closed? 
-                newPrj.scheduleReparse();
-                ListenersImpl.getImpl().fireProjectOpened(newPrj);
-            }
-        }
+        }, "Reparse projects"); // NOI18N
     }
 
     private static final class Lock {}
@@ -904,45 +922,45 @@ public class ModelImpl implements CsmModel, LowMemoryListener {
     private final Set<Runnable> modelProcessorTasks = new HashSet<>();
     private final RequestProcessor userTasksProcessor = new RequestProcessor("User model tasks processor", 4); // NOI18N
     private final Set<Runnable> userProcessorTasks = new HashSet<>();
-        
-    /////////// 
+
+    ///////////
     // tracing
     public void dumpInfo(PrintWriter printOut, boolean withContainers) {
-        printOut.printf("ModelImpl: disabled=%d, projects=%d\n", disabledProjects.size(), platf2csm.size());// NOI18N
+        printOut.printf("ModelImpl: disabled=%d, projects=%d%n", disabledProjects.size(), platf2csm.size());// NOI18N
         int ind = 1;
         for (Object prj : disabledProjects) {
-            printOut.printf("D[%d] %s\n", ind++, prj);// NOI18N
+            printOut.printf("D[%d] %s%n", ind++, prj);// NOI18N
         }
         ind=1;
         for (Map.Entry<Object, CsmUID<CsmProject>> entry : platf2csm.entrySet()) {
             final Object key = entry.getKey();
             CsmUID<CsmProject> value = entry.getValue();
-            printOut.printf("[%d] key=[%s] %s\n\tprj=(%d)%s\n", ind, key.getClass().getSimpleName(), key, System.identityHashCode(value), value);// NOI18N
+            printOut.printf("[%d] key=[%s] %s%n\tprj=(%d)%s%n", ind, key.getClass().getSimpleName(), key, System.identityHashCode(value), value);// NOI18N
             CsmProject prj = UIDCsmConverter.UIDtoProject(value);
             if (prj == null) {
-                printOut.printf("Project was NOT restored from repository\n");// NOI18N
+                printOut.printf("Project was NOT restored from repository%n");// NOI18N
             } else if (prj instanceof ProjectBase) {
-                printOut.printf("[%d] disposing?=%s\n", ind, ((ProjectBase)prj).isDisposing());// NOI18N
+                printOut.printf("[%d] disposing?=%s%n", ind, ((ProjectBase)prj).isDisposing());// NOI18N
                 Collection<CsmProject> libraries = prj.getLibraries();
                 int libInd = 0;
                 for (CsmProject lib : libraries) {
-                    printOut.printf("\tlib[%d]=%s\n", ++libInd, lib);// NOI18N
+                    printOut.printf("\tlib[%d]=%s%n", ++libInd, lib);// NOI18N
                 }
                 Object platformProject = prj.getPlatformProject();
-                printOut.printf("platformProjec=%s\n", platformProject);// NOI18N
+                printOut.printf("platformProjec=%s%n", platformProject);// NOI18N
                 if (platformProject instanceof NativeProject) {
                     NativeProject np = (NativeProject) platformProject;
                     List<NativeProject> dependences = np.getDependences();
                     libInd = 0;
                     for (NativeProject nativeLib : dependences) {
-                        printOut.printf("\tnativeLib[%d]=%s\n", ++libInd, nativeLib);// NOI18N
+                        printOut.printf("\tnativeLib[%d]=%s%n", ++libInd, nativeLib);// NOI18N
                     }
                 }
                 if (withContainers) {
                     ProjectBase.dumpFileContainer(prj, printOut);
                 }
             } else {
-                printOut.printf("Project has unexpected class type %s\n", prj.getClass().getName());// NOI18N
+                printOut.printf("Project has unexpected class type %s%n", prj.getClass().getName());// NOI18N
             }
             ind++;
         }
