@@ -52,18 +52,26 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.logging.Level;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import org.netbeans.modules.cnd.api.model.CsmFile;
+import org.netbeans.modules.cnd.api.model.CsmModelAccessor;
+import org.netbeans.modules.cnd.api.model.CsmProject;
 import org.netbeans.modules.cnd.api.model.CsmUID;
 import org.netbeans.modules.cnd.api.project.NativeFileItem;
 import org.netbeans.modules.cnd.api.project.NativeProject;
 import org.netbeans.modules.cnd.apt.support.APTDriver;
 import org.netbeans.modules.cnd.apt.support.APTFileCacheManager;
+import org.netbeans.modules.cnd.apt.support.ClankDriver;
 import org.netbeans.modules.cnd.modelimpl.debug.Diagnostic;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
 import org.netbeans.modules.cnd.modelimpl.debug.TraceFlags;
 import org.netbeans.modules.cnd.modelimpl.platform.FileBufferSnapshot2;
+import org.netbeans.modules.cnd.modelimpl.repository.KeyUtilities;
+import org.netbeans.modules.cnd.modelimpl.repository.RepositoryUtils;
+import org.netbeans.modules.cnd.repository.spi.Key;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataInput;
 import org.netbeans.modules.cnd.repository.spi.RepositoryDataOutput;
 import org.netbeans.modules.cnd.support.Interrupter;
@@ -77,8 +85,21 @@ import org.openide.util.RequestProcessor.Task;
  */
 public final class ProjectImpl extends ProjectBase {
 
+    private static void cleanProjectRepository(NativeProject platformProject) {
+        Key key = createProjectKey(platformProject);
+        RepositoryUtils.closeUnit(key, null, true);
+    }
+
+    private static Key createProjectKey(NativeProject platfProj) {
+         return KeyUtilities.createProjectKey(platfProj);
+    }
+
+    private static ProjectBase readProjectInstance(ModelImpl model, NativeProject platformProject, String name) {
+        return readInstance(model, createProjectKey(platformProject), platformProject, name);
+    }
+
     private ProjectImpl(ModelImpl model, NativeProject platformProject, CharSequence name) {
-        super(model, platformProject, name);
+        super(model, platformProject.getFileSystem(), (Object) platformProject, name, createProjectKey(platformProject));
     // RepositoryUtils.put(this);
     }
 
@@ -86,33 +107,55 @@ public final class ProjectImpl extends ProjectBase {
         ProjectBase instance = null;
         if (TraceFlags.PERSISTENT_REPOSITORY) {
             try {
-                instance = readInstance(model, platformProject, name);
+                instance = readProjectInstance(model, platformProject, name);
             } catch (Exception e) {
                 // just report to console;
                 // the code below will create project "from scratch"
-                cleanRepository(platformProject, false);
                 DiagnosticExceptoins.register(e);
+                cleanProjectRepository(platformProject);
             }
         }
         if (instance != null && !(instance instanceof ProjectImpl)) {
             DiagnosticExceptoins.register(new IllegalStateException(
                     "Expected " + ProjectImpl.class.getName() + //NOI18N
                     " but restored from repository " + instance.getClass().getName())); //NOI18N
-            cleanRepository(platformProject, false);
+            cleanProjectRepository(platformProject);
             instance = null;
         }
         if (instance == null) {
-            instance = new ProjectImpl(model, platformProject, name);
+            if (CsmModelAccessor.isModelAlive()) {
+                instance = new ProjectImpl(model, platformProject, name);
+            }
         }
         return (ProjectImpl) instance;
     }
 
+    @Override
+    protected Collection<Key> getLibrariesKeys() {
+        List<Key> res = new ArrayList<>();
+        assert (getPlatformProject() instanceof NativeProject) : "Expected NativeProject, got " + getPlatformProject();
+        for (NativeProject nativeLib : ((NativeProject) getPlatformProject()).getDependences()) {
+            final Key key = createProjectKey(nativeLib);
+            res.add(key);
+        }
+        // Last dependent project is common library.
+        //final Key lib = KeyUtilities.createProjectKey("/usr/include"); // NOI18N
+        //if (lib != null) {
+        //    res.add(lib);
+        //}
+        for (CsmUID<CsmProject> library : getLibraryManager().getLirariesKeys(getUID())) {
+            res.add(RepositoryUtils.UIDtoKey(library));
+        }
+        return res;
+    }
+
+
     @Override
     protected final ParserQueue.Position getIncludedFileParserQueuePosition() {
         return ParserQueue.Position.HEAD;
     }
 
-    public 
+    public
     @Override
     void onFileEditStart(final FileBuffer buf, NativeFileItem nativeFile) {
         if (TraceFlags.DEBUG) {
@@ -121,6 +164,7 @@ public final class ProjectImpl extends ProjectBase {
         final FileImpl impl = getFile(buf.getAbsolutePath(), false);
         if (impl != null) {
             APTDriver.invalidateAPT(buf);
+            ClankDriver.invalidate(buf);
             APTFileCacheManager.getInstance(buf.getFileSystem()).invalidate(buf.getAbsolutePath());
             // listener will be triggered immediately, because editor based buffer
             // will be notifies about editing event exactly after onFileEditStart
@@ -148,7 +192,7 @@ public final class ProjectImpl extends ProjectBase {
         }
     }
 
-    public 
+    public
     @Override
     void onFileEditEnd(FileBuffer buf, NativeFileItem nativeFile, boolean undo) {
         if (TraceFlags.DEBUG) {
@@ -182,6 +226,18 @@ public final class ProjectImpl extends ProjectBase {
         }
     }
 
+    @Override
+    protected void addModifiedFile(FileImpl file) {
+        if (!isDisposing()) {
+            modifiedFiles.put(file, Boolean.TRUE);
+        }
+    }
+
+    @Override
+    protected void removeModifiedFile(FileImpl file) {
+        modifiedFiles.remove(file);
+    }
+
     @Override
     public void onFileImplRemoved(Collection<FileImpl> physicallyRemoved, Collection<FileImpl> excluded) {
         try {
@@ -204,7 +260,7 @@ public final class ProjectImpl extends ProjectBase {
 
     @Override
     protected void ensureChangedFilesEnqueued() {
-        List<FileImpl> addToParse = new ArrayList<>();
+        Set<FileImpl> addToParse = new HashSet<>();
         synchronized (editedFiles) {
             super.ensureChangedFilesEnqueued();
             for (Iterator<CsmFile> iter = editedFiles.keySet().iterator(); iter.hasNext();) {
@@ -213,6 +269,15 @@ public final class ProjectImpl extends ProjectBase {
                     addToParse.add(file);
                 }
             }
+            for (Iterator<CsmFile> iter = modifiedFiles.keySet().iterator(); iter.hasNext();) {
+                FileImpl file = (FileImpl) iter.next();
+                if (!file.isParsingOrParsed()) {
+                    if (WAIT_PARSE_LOGGER.isLoggable(Level.FINE)) {
+                        WAIT_PARSE_LOGGER.fine("### Added modified file " + file);
+                    }
+                    addToParse.add(file);
+                }
+            }
         }
         for (FileImpl file : addToParse) {
             ParserQueue.instance().add(file, getPreprocHandlersForParse(file, Interrupter.DUMMY), ParserQueue.Position.TAIL);
@@ -220,7 +285,7 @@ public final class ProjectImpl extends ProjectBase {
     //N.B. don't clear list of editedFiles here.
     }
 
-    protected 
+    protected
     @Override
     boolean hasChangedFiles(CsmFile skipFile) {
         if (skipFile == null) {
@@ -266,15 +331,15 @@ public final class ProjectImpl extends ProjectBase {
                 return false;
             }
             if (TraceFlags.TRACE_182342_BUG || TraceFlags.TRACE_191307_BUG) {
-                System.err.printf("EditingTask.updateLastModified: set lastModified from %d to %d\n", this.lastModified, lm);// NOI18N
+                System.err.printf("EditingTask.updateLastModified: set lastModified from %d to %d%n", this.lastModified, lm);// NOI18N
             }
             this.lastModified = lm;
             return true;
         }
-        
+
         public void setTask(Task task) {
             if (TraceFlags.TRACE_182342_BUG || TraceFlags.TRACE_191307_BUG) {
-                System.err.printf("EditingTask.setTask: set new EditingTask %d for %s\n", task.hashCode(), buf.getUrl());
+                System.err.printf("EditingTask.setTask: set new EditingTask %d for %s%n", task.hashCode(), buf.getUrl());
             }
             this.task = task;
         }
@@ -305,8 +370,9 @@ public final class ProjectImpl extends ProjectBase {
 
     // remove as soon as TraceFlags.USE_PARSER_API becomes always true
     private final Map<CsmFile, EditingTask> editedFiles = new HashMap<>();
+    private final ConcurrentHashMap<CsmFile, Boolean> modifiedFiles = new ConcurrentHashMap<>();
 
-    public 
+    public
     @Override
     ProjectBase findFileProject(CharSequence absPath, boolean waitFilesCreated) {
         ProjectBase retValue = super.findFileProject(absPath, waitFilesCreated);
@@ -347,9 +413,10 @@ public final class ProjectImpl extends ProjectBase {
     protected void onDispose() {
         nativeFiles.clear();
         editedFiles.clear();
+        modifiedFiles.clear();
         projectRoots.clear();
     }
-    
+
     private final SourceRootContainer projectRoots = new SourceRootContainer(false);
     @Override
     protected SourceRootContainer getProjectRoots() {
@@ -358,14 +425,14 @@ public final class ProjectImpl extends ProjectBase {
 
     ////////////////////////////////////////////////////////////////////////////
     // impl of persistent
-    public 
+    public
     @Override
     void write(RepositoryDataOutput aStream) throws IOException {
         super.write(aStream);
         // we don't need this since ProjectBase persists fqn
         //UIDObjectFactory aFactory = UIDObjectFactory.getDefaultFactory();
         //aFactory.writeUID(getUID(), aStream);
-        getLibraryManager().writeProjectLibraries(getUID(), aStream, getUnitId());
+        getLibraryManager().writeProjectLibraries(getUID(), aStream);
     }
 
     public ProjectImpl(RepositoryDataInput input) throws IOException {
@@ -374,7 +441,7 @@ public final class ProjectImpl extends ProjectBase {
         //UIDObjectFactory aFactory = UIDObjectFactory.getDefaultFactory();
         //CsmUID uid = aFactory.readUID(input);
         //LibraryManager.getInsatnce().read(uid, input);
-        getLibraryManager().readProjectLibraries(getUID(), input, getUnitId());
+        getLibraryManager().readProjectLibraries(getUID(), input);
     //nativeFiles = new NativeFileContainer();
     }
 
@@ -394,7 +461,7 @@ public final class ProjectImpl extends ProjectBase {
         synchronized (editedFiles) {
             if (TraceFlags.TRACE_182342_BUG || TraceFlags.TRACE_191307_BUG) {
                 new Exception("scheduleParseOnEditing " + file).printStackTrace(System.err); // NOI18N
-            }            
+            }
             EditingTask pair = editedFiles.get(file);
             if (pair == null) {
                 // we were removed between rescheduling and finish of edit
@@ -410,11 +477,11 @@ public final class ProjectImpl extends ProjectBase {
                 }
                 return;
             }
-            
-            // markReparseNeeded have to be called synchroniously 
+
+            // markReparseNeeded have to be called synchroniously
             // otherwise it will be delayed till DeepReparsingUtils.reparseOnEditingFile is called from task
-            // but task is delayed (or even turned off), so this could never happen and client 
-            // using CsmFile.scheduleParsing(true) get file without wait for reparsing, because 
+            // but task is delayed (or even turned off), so this could never happen and client
+            // using CsmFile.scheduleParsing(true) get file without wait for reparsing, because
             // file is still in state PARSED if delayed till task starts execution
             // see #203526 - Code completion is empty if typing too fast
             file.markReparseNeeded(false);
@@ -432,7 +499,7 @@ public final class ProjectImpl extends ProjectBase {
                     public void run() {
                         try {
                             if (TraceFlags.TRACE_182342_BUG || TraceFlags.TRACE_191307_BUG) {
-                                System.err.printf("scheduleParseOnEditing: RUN scheduleParseOnEditing task for %s\n", file);
+                                System.err.printf("scheduleParseOnEditing: RUN scheduleParseOnEditing task for %s%n", file);
                             }
                             if (isDisposing()) {
                                 return;
@@ -464,7 +531,7 @@ public final class ProjectImpl extends ProjectBase {
                 delay = Integer.MAX_VALUE;
             }
         }
-        // to prevent frequent re-post 
+        // to prevent frequent re-post
         if (task.getDelay() < Math.max(100, delay - 100)) {
             task.schedule(delay);
         }
