@@ -43,7 +43,6 @@
 package org.netbeans.modules.cnd.modelimpl.csm.resolver;
 
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -314,7 +313,7 @@ public final class FileMapsCollector {
     }
 
     private static void gatherMaps(CsmFile file, int stopAtOffset, MapsCollection out) {
-        if (file == null || out.antiLoop.contains(file)) {
+        if (file == null  || !file.isValid() || out.antiLoop.contains(file)) {
             return;
         }
         out.antiLoop.add(file);
