@@ -162,9 +162,8 @@ public final class Resolver3 implements Resolver {
     
     private CsmClassifier findClassifier(CsmNamespace ns, CharSequence qualifiedNamePart, AtomicBoolean outVisibility) {
         outVisibility.set(false);
-        CsmClassifier result = null;
         CsmClassifier backupResult = null;
-        while ( ns != null  && result == null) {
+        while ( ns != null) {
             String fqn = ns.getQualifiedName() + "::" + qualifiedNamePart; // NOI18N
             CsmClassifier aCls = findClassifierUsedInFile(fqn, outVisibility);
             if (aCls != null) {
@@ -179,10 +178,7 @@ public final class Resolver3 implements Resolver {
             }
             ns = ns.getParent();
         }
-        if (result == null) {
-            result = backupResult;
-        }
-        return result;
+        return backupResult;
     }
 
     private CsmClassifier findClassifierUsedInFile(CharSequence qualifiedName, AtomicBoolean resultIsVisible) {
@@ -440,31 +436,45 @@ public final class Resolver3 implements Resolver {
     }
 
     private CsmObject resolveInInlinedNamespaces(CsmObject result, CsmNamespace namespace, CharSequence nameToken, AtomicBoolean outVisibility) {
-        return resolveInInlinedNamespacesImpl(result, new HashSet<CharSequence>(), namespace, nameToken, outVisibility);
+        return resolveInInlinedNamespaces(result, new HashSet<CharSequence>(), namespace, nameToken, outVisibility);
     }
     
-    private CsmObject resolveInInlinedNamespacesImpl(CsmObject result, Set<CharSequence> checked, CsmNamespace namespace, CharSequence nameToken, AtomicBoolean outVisibility) {
+    private CsmObject resolveInInlinedNamespaces(CsmObject result, Set<CharSequence> checked, CsmNamespace namespace, CharSequence nameToken, AtomicBoolean outVisibility) {
         if (result == null || !outVisibility.get()) {
             for (CsmNamespace ns : namespace.getInlinedNamespaces()) {
-                final CharSequence name = ns.getQualifiedName();
-                if (checked.add(name)) {
-                    String fqn = name + "::" + nameToken; // NOI18N
-                    if (fqn.startsWith("::")) { // NOI18N
-                        fqn = fqn.substring(2);
+                result = resolveInInlinedNamespace(ns, checked, nameToken, outVisibility);
+                if (result != null && outVisibility.get()) {
+                    return result;
+                }
+            }
+            for (CsmProject library : project.getLibraries()) {
+                CsmNamespace libNs = library.findNamespace(namespace.getQualifiedName());
+                if (libNs != null) {
+                    for (CsmNamespace ns : libNs.getInlinedNamespaces()) {
+                        result = resolveInInlinedNamespace(ns, checked, nameToken, outVisibility);
+                        if (result != null && outVisibility.get()) {
+                            return result;
+                        }
                     }
-                    
-                    result = findClassifierUsedInFile(fqn, outVisibility);
-                    
-                    result = resolveInInlinedNamespacesImpl(result, checked, ns, nameToken, outVisibility);
-
-                    if (result != null && outVisibility.get()) {
-                        break;
-                    }                            
                 }
             }
         }
         return result;
-    }    
+    }   
+    
+    private CsmObject resolveInInlinedNamespace(CsmNamespace ns, Set<CharSequence> checked, CharSequence nameToken, AtomicBoolean outVisibility) {
+        CsmObject result = null;
+        final CharSequence name = ns.getQualifiedName();
+        if (checked.add(name)) {
+            String fqn = name + "::" + nameToken; // NOI18N
+            if (fqn.startsWith("::")) { // NOI18N
+                fqn = fqn.substring(2);
+            }
+            result = findClassifierUsedInFile(fqn, outVisibility);
+            result = resolveInInlinedNamespaces(result, checked, ns, nameToken, outVisibility);
+        }
+        return result;
+    }
 
     void traceRecursion(){
         System.out.println("Detected recursion in resolver:"); // NOI18N
@@ -928,7 +938,7 @@ public final class Resolver3 implements Resolver {
             }
         }
         if (result == null) {
-            if (TemplateUtils.isTemplateQualifiedName(fullName.toString())) {
+            if (TemplateUtils.isTemplateQualifiedName(fullName)) {
                 StringBuilder sb2 = new StringBuilder(TemplateUtils.getTemplateQualifiedNameWithoutSiffix(nameTokens[0].toString()));
                 for (int i = 1; i < nameTokens.length; i++) {
                     sb2.append("::"); // NOI18N
