@@ -30,18 +30,13 @@
  */
 package org.netbeans.modules.cnd.modelimpl.impl.services;
 
-import org.netbeans.modules.cnd.antlr.Token;
-import org.netbeans.modules.cnd.antlr.TokenStream;
-import org.netbeans.modules.cnd.antlr.TokenStreamException;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
-import java.util.TreeSet;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
@@ -55,34 +50,33 @@ import org.netbeans.modules.cnd.api.model.services.CsmFileInfoQuery;
 import org.netbeans.modules.cnd.api.model.xref.CsmReference;
 import org.netbeans.modules.cnd.api.project.NativeFileItem;
 import org.netbeans.modules.cnd.api.project.NativeProject;
-import org.netbeans.modules.cnd.apt.structure.APTFile;
-import org.netbeans.modules.cnd.apt.support.APTDriver;
-import org.netbeans.modules.cnd.apt.support.APTFileCacheEntry;
+import org.netbeans.modules.cnd.apt.debug.APTTraceFlags;
 import org.netbeans.modules.cnd.apt.support.APTHandlersSupport;
 import org.netbeans.modules.cnd.apt.support.APTIncludeHandler;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler.State;
-import org.netbeans.modules.cnd.apt.support.APTToken;
-import org.netbeans.modules.cnd.apt.support.StartEntry;
-import org.netbeans.modules.cnd.apt.utils.APTUtils;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler.State;
+import org.netbeans.modules.cnd.apt.support.api.StartEntry;
+import org.netbeans.modules.cnd.apt.support.lang.APTLanguageSupport;
 import org.netbeans.modules.cnd.modelimpl.content.project.FileContainer;
+import org.netbeans.modules.cnd.modelimpl.csm.IncludeImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.ErrorDirectiveImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileBuffer;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FilePreprocessorConditionState;
-import org.netbeans.modules.cnd.modelimpl.csm.core.Offsetable;
 import org.netbeans.modules.cnd.modelimpl.csm.core.PreprocessorStatePair;
 import org.netbeans.modules.cnd.modelimpl.csm.core.ProjectBase;
 import org.netbeans.modules.cnd.modelimpl.csm.core.Utils;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
-import org.netbeans.modules.cnd.modelimpl.parser.apt.APTFindMacrosWalker;
-import org.netbeans.modules.cnd.modelimpl.parser.apt.GuardBlockWalker;
+import org.netbeans.modules.cnd.modelimpl.parser.apt.APTFileInfoQuerySupport;
+import org.netbeans.modules.cnd.modelimpl.parser.clank.ClankFileInfoQuerySupport;
 import org.netbeans.modules.cnd.modelimpl.platform.CndParserResult;
 import org.netbeans.modules.cnd.modelimpl.uid.UIDUtilities;
 import org.netbeans.modules.cnd.support.Interrupter;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.cnd.utils.CndUtils;
+import org.netbeans.modules.cnd.utils.cache.CharSequenceUtils;
 import org.netbeans.modules.parsing.spi.Parser;
+import org.openide.util.Pair;
 
 /**
  * CsmFileInfoQuery implementation
@@ -90,6 +84,46 @@ import org.netbeans.modules.parsing.spi.Parser;
  */
 @org.openide.util.lookup.ServiceProvider(service=org.netbeans.modules.cnd.api.model.services.CsmFileInfoQuery.class)
 public final class FileInfoQueryImpl extends CsmFileInfoQuery {
+    
+    @Override
+    public boolean isCpp98OrLater(CsmFile csmFile) {
+        if (csmFile != null) {
+            Pair<NativeFileItem.Language, NativeFileItem.LanguageFlavor> languageFlavor = getFileLanguageFlavor(csmFile);
+            if (NativeFileItem.Language.CPP == languageFlavor.first()) {
+                return true;
+            }
+        }
+        return false;
+    }
+    
+    @Override
+    public boolean isCpp11OrLater(CsmFile csmFile) {
+        if (csmFile != null) {
+            Pair<NativeFileItem.Language, NativeFileItem.LanguageFlavor> languageFlavor = getFileLanguageFlavor(csmFile);
+            if (NativeFileItem.Language.CPP == languageFlavor.first()) {
+                switch (languageFlavor.second()) {
+                    case CPP11:
+                    case CPP14:
+                        return true;
+                }
+            }
+        }
+        return false;
+    }
+    
+    @Override
+    public boolean isCpp14OrLater(CsmFile csmFile) {
+        if (csmFile != null) {
+            Pair<NativeFileItem.Language, NativeFileItem.LanguageFlavor> languageFlavor = getFileLanguageFlavor(csmFile);
+            if (NativeFileItem.Language.CPP == languageFlavor.first()) {
+                switch (languageFlavor.second()) {
+                    case CPP14:
+                        return true;
+                }
+            }
+        }
+        return false;
+    }
 
     @Override
     public List<FSPath> getSystemIncludePaths(CsmFile file) {
@@ -241,6 +275,13 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
         return null;
     }
 
+    public static int getIncludeDirectiveIndex(CsmInclude inc) {
+        if (inc instanceof IncludeImpl) {
+            return ((IncludeImpl) inc).getIncludeDirectiveIndex();
+        }
+        return -1;
+    }
+
     private static final class NamedLock {
         private final CharSequence name;
 
@@ -293,47 +334,16 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
                     }
                     try {
                         long lastParsedTime = fileImpl.getLastParsedTime();
-                        APTFile apt = APTDriver.findAPT(fileImpl.getBuffer(), fileImpl.getFileLanguage(), fileImpl.getFileLanguageFlavor());
-                        if (apt != null) {
-                            Collection<APTPreprocHandler> handlers = fileImpl.getPreprocHandlersForParse(interrupter);
-                            if (interrupter.cancelled()) {
-                                return out;
-                            }
-                            if (handlers.isEmpty()) {
-                                DiagnosticExceptoins.register(new IllegalStateException("Empty preprocessor handlers for " + file.getAbsolutePath())); //NOI18N
-                                return Collections.<CsmReference>emptyList();
-                            } else if (handlers.size() == 1) {
-                                APTPreprocHandler handler = handlers.iterator().next();
-                                State state = handler.getState();
-                                // ask for concurrent entry if absent
-                                APTFileCacheEntry cacheEntry = fileImpl.getAPTCacheEntry(state, Boolean.FALSE);
-                                APTFindMacrosWalker walker = new APTFindMacrosWalker(apt, fileImpl, handler, cacheEntry) {
-
-                                    @Override
-                                    protected boolean isStopped() {
-                                        return super.isStopped() || interrupter.cancelled();
-                                    }
-                                };
-                                out = walker.collectMacros();
-                                // remember walk info
-                                fileImpl.setAPTCacheEntry(state, cacheEntry, false);
-                            } else {
-                                Comparator<CsmReference> comparator = new OffsetableComparator<>();
-                                TreeSet<CsmReference> result = new TreeSet<>(comparator);
-                                for (APTPreprocHandler handler : handlers) {
-                                    // ask for concurrent entry if absent
-                                    State state = handler.getState();
-                                    APTFileCacheEntry cacheEntry = fileImpl.getAPTCacheEntry(state, Boolean.FALSE);
-                                    APTFindMacrosWalker walker = new APTFindMacrosWalker(apt, fileImpl, handler, cacheEntry);
-                                    result.addAll(walker.collectMacros());
-                                    // remember walk info
-                                    fileImpl.setAPTCacheEntry(state, cacheEntry, false);
-                                }
-                                out = new ArrayList<>(result);
-                            }
+                        if (APTTraceFlags.USE_CLANK) {
+                          out = ClankFileInfoQuerySupport.getMacroUsages(fileImpl, interrupter);
+                        } else {
+                          out = APTFileInfoQuerySupport.getMacroUsages(fileImpl, interrupter);
                         }
                         if (lastParsedTime == fileImpl.getLastParsedTime()) {
-                            fileImpl.setLastMacroUsages(out);
+                            // cache only if calc wasn't interrupted
+                            if (!interrupter.cancelled()) {
+                                fileImpl.setLastMacroUsages(out);
+                            }
                         }
                     } catch (FileNotFoundException ex) {
                         // file could be removed
@@ -353,39 +363,27 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
     public CsmOffsetable getGuardOffset(CsmFile file) {
         if (file instanceof FileImpl) {
             FileImpl fileImpl = (FileImpl) file;
-            try {
-                APTFile apt = APTDriver.findAPT(fileImpl.getBuffer(), fileImpl.getFileLanguage(), fileImpl.getFileLanguageFlavor());
-
-                GuardBlockWalker guardWalker = new GuardBlockWalker(apt);
-                TokenStream ts = guardWalker.getTokenStream();
-                try {
-                    Token token = ts.nextToken();
-                    while (!APTUtils.isEOF(token)) {
-                        if (!APTUtils.isCommentToken(token)) {
-                            guardWalker.clearGuard();
-                            break;
-                        }
-                        token = ts.nextToken();
-                    }
-                } catch (TokenStreamException ex) {
-                    guardWalker.clearGuard();
-                }
-
-                Token guard = guardWalker.getGuard();
-                if (guard != null) {
-                    if (guard instanceof APTToken) {
-                        APTToken aptGuard = ((APTToken) guard);
-                        return new Offsetable(file, aptGuard.getOffset(), aptGuard.getEndOffset());
-                    }
-                }
-            } catch (FileNotFoundException ex) {
-                // file could be removed
-            } catch (IOException ex) {
-                System.err.println("IOExeption in getGuardOffset:" + ex.getMessage()); //NOI18N
+            if (APTTraceFlags.USE_CLANK) {
+              return ClankFileInfoQuerySupport.getGuardOffset(fileImpl);
+            } else {
+              return APTFileInfoQuerySupport.getGuardOffset(fileImpl);
             }
         }
         return null;
     }
+    
+    @Override
+    public boolean hasGuardBlock(CsmFile file) {
+        if (file instanceof FileImpl) {
+            FileImpl fileImpl = (FileImpl) file;
+            if (APTTraceFlags.USE_CLANK) {
+              return ClankFileInfoQuerySupport.hasGuardBlock(fileImpl);
+            } else {
+              return APTFileInfoQuerySupport.hasGuardBlock(fileImpl);
+            }            
+        }
+        return false;
+    }
 
     @Override
     public NativeFileItem getNativeFileItem(CsmFile file) {
@@ -395,6 +393,124 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
         return null;
     }
 
+    @Override
+    public Pair<NativeFileItem.Language, NativeFileItem.LanguageFlavor> getFileLanguageFlavor(CsmFile csmFile) {
+        if (csmFile != null) {
+            Collection<CsmCompilationUnit> compilationUnits = getCompilationUnits(csmFile, 0);
+            if (!compilationUnits.isEmpty()) {
+                NativeFileItem.Language bestLanguage = null;
+                NativeFileItem.LanguageFlavor bestFlavor = null;
+                for (CsmCompilationUnit cu : compilationUnits) {
+                    NativeFileItem startItem = getNativeFileItem(cu.getStartFile());
+                    if (startItem != null) {
+                        if (getLangPriority(bestLanguage) < getLangPriority(startItem.getLanguage())) {
+                            bestLanguage = startItem.getLanguage();
+                        }
+                        if (getFlavorPriority(bestFlavor) < getFlavorPriority(startItem.getLanguageFlavor())) {
+                            bestFlavor = startItem.getLanguageFlavor();
+                        }
+                    }
+                }
+                if (bestLanguage != null && bestFlavor != null) {
+                    return Pair.of(bestLanguage, bestFlavor);
+                }
+            }
+            if (csmFile.isHeaderFile()) {
+                return Pair.of(NativeFileItem.Language.C_HEADER, NativeFileItem.LanguageFlavor.UNKNOWN);
+            } else if (csmFile.isSourceFile()) {
+                return Pair.of(NativeFileItem.Language.CPP, NativeFileItem.LanguageFlavor.UNKNOWN);
+            } 
+        }
+        return Pair.of(NativeFileItem.Language.OTHER, NativeFileItem.LanguageFlavor.UNKNOWN);
+    }
+    
+    private int getLangPriority(NativeFileItem.Language lang) {
+        if (lang == null) {
+            return -1;
+        }
+        switch (lang) {
+            case OTHER:
+                return 0;
+            case C_HEADER:
+                return 1;
+            case C:
+                return 2;
+            case CPP:
+                return 3;
+        }
+        return 0;
+    }
+    
+    private int getFlavorPriority(NativeFileItem.LanguageFlavor flavor) {
+        if (flavor == null) {
+            return -1;
+        }
+        switch (flavor) {
+            case DEFAULT:
+            case UNKNOWN:
+                return 0;
+            case C:
+                return 1;
+            case C89:
+                return 2;
+            case C99:
+                return 3;
+            case C11:
+                return 4;
+            case CPP:
+                return 5;
+            case CPP11:
+                return 6;
+            case CPP14:
+                return 7;
+        }
+        return 0;
+    }
+
+    @Override
+    public Pair<String, String> getAPTLanguageFlavor(Pair<NativeFileItem.Language, NativeFileItem.LanguageFlavor> langFlavor) {
+        String aptLang = APTLanguageSupport.UNKNOWN;
+        switch (langFlavor.first()) {
+            case C:
+                aptLang = APTLanguageSupport.GNU_C;
+                break;
+                
+            case CPP:
+                aptLang = APTLanguageSupport.GNU_CPP;
+                break;
+                
+            case C_HEADER:
+                aptLang = APTLanguageSupport.GNU_CPP;
+                break;
+                
+            case FORTRAN:
+                aptLang = APTLanguageSupport.FORTRAN;
+                break;
+        }
+        String aptFlavor = APTLanguageSupport.FLAVOR_UNKNOWN;
+        switch (langFlavor.second()) {
+            case C:
+            case C89:
+            case C99:
+            case C11:
+                aptFlavor = APTLanguageSupport.FLAVOR_UNKNOWN;
+                break;
+                
+            case CPP:
+            case CPP11:
+            case CPP14:
+                aptFlavor = APTLanguageSupport.FLAVOR_CPP11;
+                break;
+                
+            case F77:
+            case F90:
+            case F95:
+                aptFlavor = APTLanguageSupport.FLAVOR_FORTRAN_FREE;
+                break;
+        }
+        return Pair.of(aptLang, aptFlavor);
+    }
+
     @Override
     public Collection<CsmCompilationUnit> getCompilationUnits(CsmFile file, int contextOffset) {
         Collection<CsmCompilationUnit> out = new ArrayList<>(1);
@@ -432,7 +548,7 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
 
     @Override
     public List<CsmInclude> getIncludeStack(CsmErrorDirective err) {
-        APTPreprocHandler.State state = null;
+        PreprocHandler.State state = null;
         if (err instanceof ErrorDirectiveImpl) {
             state = ((ErrorDirectiveImpl)err).getState();
         }
@@ -446,7 +562,7 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
     
     @Override
     public List<CsmInclude> getIncludeStack(CsmFile file) {
-        APTPreprocHandler.State state = null;
+        PreprocHandler.State state = null;
         if (file instanceof FileImpl) {
             FileImpl impl = (FileImpl) file;
             // use stack from one of states (i.e. first)
@@ -456,37 +572,52 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
         return getIncludeStackImpl(state);
     }
     
-    private List<CsmInclude> getIncludeStackImpl(APTPreprocHandler.State state) {
+    private List<CsmInclude> getIncludeStackImpl(PreprocHandler.State state) {
         if (state == null) {
             return Collections.<CsmInclude>emptyList();
         }
         CndUtils.assertNotNull(state, "state must not be null in non empty collection");// NOI18N
-        List<APTIncludeHandler.IncludeInfo> reverseInclStack = APTHandlersSupport.extractIncludeStack(state);
+        List<APTIncludeHandler.IncludeInfo> includeChain = APTHandlersSupport.extractIncludeStack(state);
         StartEntry startEntry = APTHandlersSupport.extractStartEntry(state);
         ProjectBase startProject = Utils.getStartProject(startEntry);
         if (startProject != null) {
-            CsmFile startFile = startProject.getFile(startEntry.getStartFile(), false);
-            if (startFile != null) {
+            CsmFile includeOwner = startProject.getFile(startEntry.getStartFile(), false);
+            if (includeOwner != null) {
                 List<CsmInclude> res = new ArrayList<>();
-                Iterator<APTIncludeHandler.IncludeInfo> it = reverseInclStack.iterator();
+                Iterator<APTIncludeHandler.IncludeInfo> it = includeChain.iterator();
                 while(it.hasNext()){
                     APTIncludeHandler.IncludeInfo info = it.next();
-                    int offset = info.getIncludeDirectiveOffset();
-                    CsmInclude find = null;
-                    for(CsmInclude inc : startFile.getIncludes()){
-                        if (offset == inc.getStartOffset()){
-                            find = inc;
-                            break;
+                    int includeDirectiveIndex = info.getIncludeDirectiveIndex();
+                    CharSequence includedPath = info.getIncludedPath();
+                    CsmInclude foundDirective = null;
+                    CsmFile    foundIncludedFile = null;
+                    for(CsmInclude inc : includeOwner.getIncludes()) {
+                        int currentIncludeIndex = getIncludeDirectiveIndex(inc);
+                        // fast check by index
+                        if (includeDirectiveIndex == currentIncludeIndex) {
+                            // but several CsmInclude directives
+                            // in one header can have same index in different include states
+                            CsmFile includedFile = inc.getIncludeFile();
+                            // so check by expected name
+                            if (includedFile != null && CharSequenceUtils.contentEquals(includedPath, includedFile.getAbsolutePath())) {
+                                foundDirective = inc;
+                                foundIncludedFile = includedFile;
+                                if (inc.getStartOffset() == info.getIncludeDirectiveOffset()) {
+                                    // full match
+                                    break;
+                                } else {
+                                    // keep it as the best candidate
+                                }
+                            }
                         }
                     }
-                    if (find != null) {
-                        res.add(find);
-                        startFile = find.getIncludeFile();
-                        if (startFile == null) {
-                            break;
-                        }
+                    if (foundDirective == null) {
+                        // break broken include chain
+                        return Collections.<CsmInclude>emptyList();
                     } else {
-                        break;
+                        assert foundIncludedFile != null : "must be initialized with " + foundDirective;
+                        includeOwner = foundIncludedFile;
+                        res.add(foundDirective);
                     }
                 }
                 return res;
@@ -513,18 +644,6 @@ public final class FileInfoQueryImpl extends CsmFileInfoQuery {
         return Collections.<CsmInclude>emptyList();
     }
 
-    private static class OffsetableComparator<T extends CsmOffsetable> implements Comparator<T> {
-        @Override
-        public int compare(CsmOffsetable o1, CsmOffsetable o2) {
-            int diff = o1.getStartOffset() - o2.getStartOffset();
-            if (diff == 0) {
-                return o1.getEndOffset() - o2.getEndOffset();
-            } else {
-                return diff;
-            }
-        }
-    }
-
     @Override
     public long getFileVersion(CsmFile file) {
         if (file instanceof FileImpl) {
