@@ -54,7 +54,6 @@
  */
 package org.netbeans.modules.cnd.modelimpl.impl.services;
 
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -79,20 +78,15 @@ import org.netbeans.modules.cnd.api.model.CsmInclude;
 import org.netbeans.modules.cnd.api.model.CsmProject;
 import org.netbeans.modules.cnd.api.model.services.CsmFileInfoQuery;
 import org.netbeans.modules.cnd.api.model.services.CsmMacroExpansion;
-import org.netbeans.modules.cnd.apt.structure.APT;
-import org.netbeans.modules.cnd.apt.structure.APTFile;
-import org.netbeans.modules.cnd.apt.support.APTDriver;
-import org.netbeans.modules.cnd.apt.support.APTFileCacheEntry;
-import org.netbeans.modules.cnd.apt.support.APTMacroExpandedStream;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.debug.APTTraceFlags;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.apt.support.APTToken;
-import org.netbeans.modules.cnd.apt.support.APTTokenStreamBuilder;
 import org.netbeans.modules.cnd.apt.support.APTTokenTypes;
-import org.netbeans.modules.cnd.apt.utils.APTCommentsFilter;
 import org.netbeans.modules.cnd.apt.utils.APTUtils;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileImpl;
 import org.netbeans.modules.cnd.modelimpl.csm.core.ProjectBase;
-import org.netbeans.modules.cnd.modelimpl.parser.apt.APTParseFileWalker;
+import org.netbeans.modules.cnd.modelimpl.parser.apt.APTFileInfoQuerySupport;
+import org.netbeans.modules.cnd.modelimpl.parser.clank.ClankFileInfoQuerySupport;
 import org.netbeans.modules.cnd.modelutil.CsmUtilities;
 import org.netbeans.modules.cnd.spi.model.services.CsmMacroExpansionDocProvider;
 import org.openide.text.NbDocument;
@@ -430,6 +424,7 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
         return null;
     }
 
+    /** returns expanded code or NULL on error */
     @Override
     public String expand(Document doc, int offset, String code) {
         if (doc == null) {
@@ -440,51 +435,20 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
             return code;
         }
         FileImpl fileImpl = (FileImpl) file;
-        APTPreprocHandler handler = ((FileImpl) file).getPreprocHandler(offset);
+        PreprocHandler handler = ((FileImpl) file).getPreprocHandler(offset);
         if (handler == null) {
             return code;
         }
-        APTFile aptLight = null;
-        try {
-            aptLight = APTDriver.findAPTLight(fileImpl.getBuffer());
-        } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
-        }
-        if (aptLight == null) {
-            return code;
-        }
         CsmProject project = file.getProject();
         if(!(project instanceof ProjectBase)) {
             return code;
         }
         ProjectBase base = (ProjectBase) project;
-
-        // create concurrent entry if absent
-        APTFileCacheEntry cacheEntry = fileImpl.getAPTCacheEntry(handler.getState(), Boolean.FALSE);
-        StopOnOffsetParseFileWalker walker = new StopOnOffsetParseFileWalker(base, aptLight, fileImpl, offset, handler,cacheEntry);
-        walker.visit();
-        // we do not remember cache entry because it is stopped before end of file
-        // fileImpl.setAPTCacheEntry(handler, cacheEntry, false);
-        TokenStream ts = APTTokenStreamBuilder.buildTokenStream(code, fileImpl.getFileLanguage());
-        if (ts != null) {
-            ts = new APTMacroExpandedStream(ts, handler.getMacroMap(), true);
-            
-            // skip comments, see IZ 207378
-            ts = new APTCommentsFilter(ts);
-            
-            StringBuilder sb = new StringBuilder(""); // NOI18N
-            try {
-                APTToken t = (APTToken) ts.nextToken();
-                while (t != null && !APTUtils.isEOF(t)) {
-                    sb.append(t.getTextID());
-                    t = (APTToken) ts.nextToken();
-                }
-            } catch (TokenStreamException ex) {
-                Exceptions.printStackTrace(ex);
-            }
-            return sb.toString();
+        if (APTTraceFlags.USE_CLANK) {
+          return ClankFileInfoQuerySupport.expand(fileImpl, code, handler, base, offset);
+        } else {
+          return APTFileInfoQuerySupport.expand(fileImpl, code, handler, base, offset);
         }
-        return code;
     }
 
     private String expandInterval(Document doc, TransformationTable tt, int startOffset, int endOffset) {
@@ -652,8 +616,7 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
                 skipIndent = false;
             }
             APTToken prevFileToken = fileToken;
-            fileTS.moveNext();
-            fileToken = fileTS.token();
+            fileToken = skipMetaTokens(fileTS, prevFileToken);
             while (fileToken != null && !APTUtils.isEOF(fileToken) && fileToken.getOffset() < docTokenEndOffset) {
                 if (formatter != null) {
                     format = formatter.process(fileToken, fileTS);
@@ -731,6 +694,26 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
         return expandedToken;
     }
 
+    private APTToken skipMetaTokens(MyTokenSequence fileTS, APTToken prevFileToken) {
+        if (APTUtils.isMacroExpandedToken(prevFileToken) && APTUtils.isCommentToken(prevFileToken)) {
+            // Conversion from Clank tokens to APT tokens requires to add fake annotation tokens
+            // to capture additional info about macro expansion. If there is a macro call with nested
+            // macro calls, skip all meta tokens after the first one.
+            APTToken fileToken;
+            do {
+                fileTS.moveNext();
+                fileToken = fileTS.token();
+            } while (APTUtils.isMacroExpandedToken(fileToken)
+                && APTUtils.isCommentToken(fileToken)
+                && prevFileToken.getOffset() < fileToken.getOffset()
+                && prevFileToken.getEndOffset() > fileToken.getEndOffset());
+            return fileToken;
+        } else {
+            fileTS.moveNext();
+            return fileTS.token();
+        }
+    }
+
     private void expandMacroToken(TokenSequence docTS, MyTokenSequence fileTS, TransformationTable tt, StringBuilder expandedData, Formatter formatter) {
         expandMacroToken(docTS.token(), docTS.offset(), fileTS, tt, expandedData, formatter);
     }
@@ -1394,7 +1377,7 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
                                 int shift = inOffset - i.getStart();
                                 List<Interval> params = lastMacro.getParamIntervals(k);
                                 Interval j = params.get(0);
-                                if (shift >= j.length() || shift >= j.length()) {
+                                if (shift >= j.length()) {
                                     return j.getEnd();
                                 } else {
                                     return j.getStart() + shift;
@@ -1560,24 +1543,6 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
         }
         return tt;
     }
-
-    private static class StopOnOffsetParseFileWalker extends APTParseFileWalker {
-
-        private final int stopOffset;
-        public StopOnOffsetParseFileWalker(ProjectBase base, APTFile apt, FileImpl file, int offset, APTPreprocHandler preprocHandler, APTFileCacheEntry cacheEntry) {
-            super(base, apt, file, preprocHandler, false, null, cacheEntry);
-            stopOffset = offset;
-        }
-
-        @Override
-        protected boolean onAPT(APT node, boolean wasInBranch) {
-            if(node.getEndOffset() >= stopOffset) {
-                stop();
-                return false;
-            }
-            return super.onAPT(node, wasInBranch);
-        }
-    }
     
     private static final class UndoIndent implements CharSequence {
         private final int length;
@@ -1621,7 +1586,7 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
         }
 
         private void init(APTToken fileToken) {
-            shift = fileToken.getColumn();
+            shift = 0;
             indent = 0;
         }
 
@@ -1644,7 +1609,6 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
                     column = APTUtils.getExpandedToken(fileToken).getColumn();
                 }
                 StringBuilder prefix = null;
-                StringBuilder suffix = null;
                 if (aLine > 0) {
                     if (line > 0 && aLine != line) {
                         prefix = new StringBuilder();
@@ -1657,16 +1621,25 @@ public class MacroExpansionDocProviderImpl implements CsmMacroExpansionDocProvid
                     }
                     line = aLine;
                 }
-                if (prefix == null && suffix == null) {
+                if (prefix == null) {
                     return null;
                 }
-                return Pair.of(prefix, suffix);
+                return Pair.of(prefix, null);
             }
         }
 
         private final class TokenBasedFormatter implements Engine {
             public Pair<? extends CharSequence, ? extends CharSequence> process(APTToken fileToken, MyTokenSequence fileTS) {
                 // Do simplified reformatting
+                boolean isMacroExpansionView = false;
+                final String macroViewClass = "org.netbeans.modules.cnd.navigation.macroview.impl.services.MacroExpansionViewProviderImpl"; // NOI18N
+                for (StackTraceElement stackElement : Thread.currentThread().getStackTrace()) {
+                    if (stackElement.getClassName().startsWith(macroViewClass)) {
+                        isMacroExpansionView = true;
+                        break;
+                    }
+                }
+                shift = isMacroExpansionView ? fileTS.file.getLineColumn(fileToken.getOffset())[1] : 0;
                 switch (fileToken.getType()) {
                     case APTTokenTypes.LCURLY: // {
                     {
