@@ -43,11 +43,14 @@ package org.netbeans.modules.cnd.modelimpl.impl.services.evaluator;
 
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+import org.netbeans.cnd.api.lexer.CppTokenId;
+import org.netbeans.lib.editor.util.CharSequenceUtilities;
 import org.netbeans.modules.cnd.antlr.TokenStream;
 import org.netbeans.modules.cnd.antlr.collections.AST;
 import org.netbeans.modules.cnd.api.model.CsmClass;
@@ -55,7 +58,6 @@ import org.netbeans.modules.cnd.api.model.CsmClassifier;
 import org.netbeans.modules.cnd.api.model.CsmExpressionBasedSpecializationParameter;
 import org.netbeans.modules.cnd.api.model.CsmField;
 import org.netbeans.modules.cnd.api.model.CsmFile;
-import org.netbeans.modules.cnd.api.model.CsmFunctional;
 import org.netbeans.modules.cnd.api.model.CsmInstantiation;
 import org.netbeans.modules.cnd.api.model.CsmMember;
 import org.netbeans.modules.cnd.api.model.CsmObject;
@@ -71,10 +73,8 @@ import org.netbeans.modules.cnd.api.model.CsmTypeBasedSpecializationParameter;
 import org.netbeans.modules.cnd.api.model.deep.CsmExpression;
 import org.netbeans.modules.cnd.api.model.services.CsmClassifierResolver;
 import org.netbeans.modules.cnd.api.model.services.CsmExpressionResolver;
-import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
 import org.netbeans.modules.cnd.api.model.util.CsmKindUtilities;
 import org.netbeans.modules.cnd.apt.support.APTTokenStreamBuilder;
-import org.netbeans.modules.cnd.apt.support.lang.APTLanguageFilter;
 import org.netbeans.modules.cnd.apt.support.lang.APTLanguageSupport;
 import org.netbeans.modules.cnd.apt.utils.APTUtils;
 import org.netbeans.modules.cnd.modelimpl.csm.Instantiation;
@@ -90,8 +90,7 @@ import org.netbeans.modules.cnd.modelimpl.impl.services.InstantiationProviderImp
 import org.netbeans.modules.cnd.modelimpl.impl.services.MemberResolverImpl;
 import org.netbeans.modules.cnd.modelimpl.parser.CPPParserEx;
 import org.netbeans.modules.cnd.modelimpl.util.MapHierarchy;
-import org.netbeans.modules.cnd.utils.Antiloop;
-import org.netbeans.modules.cnd.utils.cache.CharSequenceUtils;
+import org.netbeans.modules.cnd.modelutil.CsmUtilities;
 
 /**
  *
@@ -109,6 +108,8 @@ public class VariableProvider {
     private int variableStartOffset;
     private int variableEndOffset;
     
+    // pattern to parse fun calls like __is_class(T)
+    private static final Pattern intrisicOneArgFunCall = Pattern.compile("([\\w_]+)\\(([\\w_]+)\\)"); // NOI18N
     
     public VariableProvider(int level, CsmScope scope) {
         this.level = level;
@@ -147,13 +148,16 @@ public class VariableProvider {
                 return 0;
             }
             if (decl != null) { // TODO: why this condition?
+                final String scopeQualifiedName = CsmKindUtilities.isQualified(scope) ? 
+                        ((CsmQualifiedNamedElement) scope).getQualifiedName().toString() : 
+                        decl.getQualifiedName().toString();
+                
+                final String fullVariableName = scopeQualifiedName + APTUtils.SCOPE + variableName;   
+                
                 for (Map.Entry<CsmTemplateParameter, CsmSpecializationParameter> entry : mapping.entries()) {
                     CsmTemplateParameter param = entry.getKey();
-                    String scopeQualifiedName = CsmKindUtilities.isQualified(scope) ? 
-                            ((CsmQualifiedNamedElement) scope).getQualifiedName().toString() : 
-                            decl.getQualifiedName().toString();
-                    if (variableName.equals(param.getQualifiedName().toString()) ||
-                            (scopeQualifiedName + APTUtils.SCOPE + variableName).equals(param.getQualifiedName().toString())) {
+                    if (variableName.equals(param.getQualifiedName().toString()) || 
+                            fullVariableName.equals(param.getQualifiedName().toString())) {
                         CsmSpecializationParameter spec = entry.getValue();
                         if (CsmKindUtilities.isExpressionBasedSpecalizationParameter(spec)) {
                             CsmExpressionBasedSpecializationParameter specParam = (CsmExpressionBasedSpecializationParameter) spec;
@@ -186,40 +190,42 @@ public class VariableProvider {
                         }
                     }
                 }
-                if(CsmKindUtilities.isClass(decl)) {
-                    String varName = variableName.replaceAll(".*::(.*)", "$1"); // NOI18N
-                    final CsmClass clazz = (CsmClass) decl;
-                    MemberResolverImpl r = new MemberResolverImpl();
-                    final CsmMember member = r.getDeclaration(clazz, varName);
-                    if (member != null) {
-                        if(member.isStatic() && CsmKindUtilities.isField(member) && member.getName().toString().equals(varName)) {
-                            CsmExpression expr = ((CsmField)member).getInitialValue();
-                            if(CsmKindUtilities.isInstantiation(member)) {
-                                Object eval = new ExpressionEvaluator(level+1).eval(
-                                        expr.getExpandedText().toString(), 
-                                        member.getContainingClass(), 
-                                        member.getScope(),
-                                        expr.getContainingFile(),
-                                        expr.getStartOffset(),
-                                        expr.getEndOffset(),
-                                        getMapping((CsmInstantiation) member)
-                                );
-                                if (eval instanceof Integer) {
-                                    return (Integer) eval;
+                if (CsmKindUtilities.isClass(decl)) {
+                    if (CharSequenceUtilities.equals(scopeQualifiedName, decl.getQualifiedName())) {
+                        String varName = variableName.replaceAll(".*::(.*)", "$1"); // NOI18N
+                        final CsmClass clazz = (CsmClass) decl;
+                        MemberResolverImpl r = new MemberResolverImpl();
+                        final CsmMember member = r.getDeclaration(clazz, varName);
+                        if (member != null) {
+                            if(member.isStatic() && CsmKindUtilities.isField(member) && member.getName().toString().equals(varName)) {
+                                CsmExpression expr = ((CsmField)member).getInitialValue();
+                                if(CsmKindUtilities.isInstantiation(member)) {
+                                    Object eval = new ExpressionEvaluator(level+1).eval(
+                                            expr.getExpandedText().toString(), 
+                                            member.getContainingClass(), 
+                                            member.getScope(),
+                                            expr.getContainingFile(),
+                                            expr.getStartOffset(),
+                                            expr.getEndOffset(),
+                                            getMapping((CsmInstantiation) member)
+                                    );
+                                    if (eval instanceof Integer) {
+                                        return (Integer) eval;
+                                    }
+                                } else if (expr != null) {
+                                    Object eval = new ExpressionEvaluator(level+1).eval(
+                                            expr.getExpandedText().toString(), 
+                                            member.getContainingClass(), 
+                                            member.getScope(),
+                                            expr.getContainingFile(),
+                                            expr.getStartOffset(),
+                                            expr.getEndOffset(),
+                                            Collections.<CsmTemplateParameter, CsmSpecializationParameter>emptyMap()
+                                    );
+                                    if (eval instanceof Integer) {
+                                        return (Integer) eval;
+                                    }                            
                                 }
-                            } else if (expr != null) {
-                                Object eval = new ExpressionEvaluator(level+1).eval(
-                                        expr.getExpandedText().toString(), 
-                                        member.getContainingClass(), 
-                                        member.getScope(),
-                                        expr.getContainingFile(),
-                                        expr.getStartOffset(),
-                                        expr.getEndOffset(),
-                                        Collections.<CsmTemplateParameter, CsmSpecializationParameter>emptyMap()
-                                );
-                                if (eval instanceof Integer) {
-                                    return (Integer) eval;
-                                }                            
                             }
                         }
                     }
@@ -281,18 +287,7 @@ public class VariableProvider {
                                 }
 
                                 if (CsmKindUtilities.isTemplateParameterType(type)) {
-                                    CsmSpecializationParameter instantiatedType = mapping.get(((CsmTemplateParameterType) type).getParameter());
-                                    int iteration = 15;
-                                    while (CsmKindUtilities.isTypeBasedSpecalizationParameter(instantiatedType) &&
-                                            CsmKindUtilities.isTemplateParameterType(((CsmTypeBasedSpecializationParameter) instantiatedType).getType()) && iteration != 0) {
-                                        CsmSpecializationParameter nextInstantiatedType = mapping.get(((CsmTemplateParameterType) ((CsmTypeBasedSpecializationParameter) instantiatedType).getType()).getParameter());
-                                        if (nextInstantiatedType != null) {
-                                            instantiatedType = nextInstantiatedType;
-                                        } else {
-                                            break;
-                                        }
-                                        iteration--;
-                                    } 
+                                    CsmSpecializationParameter instantiatedType = resolveTemplateParameter(((CsmTemplateParameterType) type).getParameter());
                                     if (CsmKindUtilities.isTypeBasedSpecalizationParameter(instantiatedType)) {
                                         type = ((CsmTypeBasedSpecializationParameter) instantiatedType).getType();
                                     }
@@ -360,11 +355,23 @@ public class VariableProvider {
     }
     
     public int getFunCallValue(String funCall) {
+        if (funCall != null) {
+            if (funCall.startsWith(CppTokenId.__IS_CLASS.fixedText())) {
+                CsmType type = resolveIntrisicTypeTraceFunParam(CppTokenId.__IS_CLASS.fixedText(), funCall);
+                return (type != null && CsmKindUtilities.isClass(type.getClassifier())) ? 1 : 0;
+            } else if (funCall.startsWith(CppTokenId.__IS_ENUM.fixedText())) {
+                CsmType type = resolveIntrisicTypeTraceFunParam(CppTokenId.__IS_ENUM.fixedText(), funCall);
+                return (type != null && CsmKindUtilities.isEnum(type.getClassifier())) ? 1 : 0;                
+            } else if (funCall.startsWith(CppTokenId.__IS_UNION.fixedText())) {
+                CsmType type = resolveIntrisicTypeTraceFunParam(CppTokenId.__IS_UNION.fixedText(), funCall);
+                return (type != null && CsmKindUtilities.isUnion(type.getClassifier())) ? 1 : 0;                
+            }
+        }
         return Integer.MAX_VALUE; // Not supported yet
     }
     
     public int getSizeOfValue(String obj) {
-        if (true) {
+        if (false) {
             return Integer.MAX_VALUE; // Not supported yet
         }
         
@@ -394,26 +401,73 @@ public class VariableProvider {
             }
         }
         
-        CsmScope objScope = CsmKindUtilities.isScope(decl) ? (CsmScope) decl : null;
+        CsmScope objScope = scope;
+        if (objScope == null && CsmKindUtilities.isScope(decl)) {
+            objScope = (CsmScope) decl;
+        }
         
         CsmType objType = CsmExpressionResolver.resolveType(obj, variableFile, variableEndOffset, objScope, instantiations);
         
         // This is necessary to resolve classifiers defined in macroses
-        int counter = Antiloop.MAGIC_PLAIN_TYPE_RESOLVING_CONST;
-        while (objType != null && !CsmBaseUtilities.isValid(objType.getClassifier()) && !CharSequenceUtils.isNullOrEmpty(objType.getClassifierText()) && counter > 0) {
-            objType = CsmExpressionResolver.resolveType(
-                objType.getClassifierText(), 
-                variableFile, 
-                variableEndOffset, 
-                objScope, 
-                instantiations
-            );
-            counter--;
-        }
+        objType = CsmExpressionResolver.resolveMacroType(objType, objScope, instantiations, null);
         
         return Utils.getSizeOfType(objType, variableFile);
     }
     
+    private CsmType resolveIntrisicTypeTraceFunParam(String suggestedFunName, String funCall) {
+        Matcher matcher =  intrisicOneArgFunCall.matcher(funCall);
+        if (matcher.matches() && matcher.groupCount() >= 2 && suggestedFunName.equals(matcher.group(1))) {
+            String paramName = matcher.group(2);
+            CsmSpecializationParameter resolvedParam = resolveTemplateParameter(paramName);
+            if (CsmKindUtilities.isTypeBasedSpecalizationParameter(resolvedParam)) {
+                CsmType type = ((CsmTypeBasedSpecializationParameter) resolvedParam).getType();
+                return CsmUtilities.iterateTypeChain(type, new CsmUtilities.ConstantPredicate<CsmType>(false));
+            }
+        }
+        return null;
+    }
+    
+    private CsmSpecializationParameter resolveTemplateParameter(String variableName) {
+        if (decl != null) { // TODO: why this condition?
+            final String scopeQualifiedName = CsmKindUtilities.isQualified(scope) ? 
+                ((CsmQualifiedNamedElement) scope).getQualifiedName().toString() : 
+                decl.getQualifiedName().toString();
+            
+            final String fullVariableName = scopeQualifiedName + APTUtils.SCOPE + variableName;
+        
+            for (Map.Entry<CsmTemplateParameter, CsmSpecializationParameter> entry : mapping.entries()) {
+                CsmTemplateParameter param = entry.getKey();
+                if (variableName.equals(param.getQualifiedName().toString()) || 
+                        fullVariableName.equals(param.getQualifiedName().toString())) {        
+                    if (CsmKindUtilities.isTypeBasedSpecalizationParameter(entry.getValue())) {
+                        final CsmType paramType = ((CsmTypeBasedSpecializationParameter) entry.getValue()).getType();
+                        if (CsmKindUtilities.isTemplateParameterType(paramType)) {
+                            return resolveTemplateParameter(((CsmTemplateParameterType) paramType).getParameter());
+                        }
+                    }
+                    return entry.getValue();
+                }
+            }
+        }
+        return null;
+    }
+    
+    private CsmSpecializationParameter resolveTemplateParameter(CsmTemplateParameter param) {
+        CsmSpecializationParameter instParam = mapping.get(param);
+        int iteration = 15;
+        while (CsmKindUtilities.isTypeBasedSpecalizationParameter(instParam) &&
+                CsmKindUtilities.isTemplateParameterType(((CsmTypeBasedSpecializationParameter) instParam).getType()) && iteration != 0) {
+            CsmSpecializationParameter nextInstParam = mapping.get(((CsmTemplateParameterType) ((CsmTypeBasedSpecializationParameter) instParam).getType()).getParameter());
+            if (nextInstParam != null) {
+                instParam = nextInstParam;
+            } else {
+                break;
+            }
+            iteration--;
+        } 
+        return instParam;
+    }
+    
     private CsmType instantiateType(CsmType type, CsmInstantiation inst) {
         if (CsmKindUtilities.isInstantiation(inst.getTemplateDeclaration())) {
             type = instantiateType(type, (CsmInstantiation) inst.getTemplateDeclaration());
