@@ -61,11 +61,12 @@ import org.netbeans.modules.cnd.apt.structure.APTInclude;
 import org.netbeans.modules.cnd.apt.structure.APTPragma;
 import org.netbeans.modules.cnd.apt.support.APTFileCacheEntry;
 import org.netbeans.modules.cnd.apt.support.APTHandlersSupport;
-import org.netbeans.modules.cnd.apt.support.APTIncludeHandler.IncludeState;
+import org.netbeans.modules.cnd.apt.support.api.PPIncludeHandler.IncludeState;
 import org.netbeans.modules.cnd.apt.support.lang.APTLanguageFilter;
 import org.netbeans.modules.cnd.apt.support.APTMacroExpandedStream;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.apt.support.APTToken;
+import org.netbeans.modules.cnd.apt.support.APTTokenAbstact;
 import org.netbeans.modules.cnd.apt.support.APTTokenTypes;
 import org.netbeans.modules.cnd.apt.support.PostIncludeData;
 import org.netbeans.modules.cnd.apt.support.ResolvedPath;
@@ -93,7 +94,7 @@ import org.netbeans.modules.cnd.modelimpl.textcache.NameCache;
  */
 public class APTParseFileWalker extends APTProjectFileBasedWalker {
 
-    /** 
+    /**
      * A callback that should be invoked
      * when each conditional is evaluated
      */
@@ -102,7 +103,7 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         void onEval(APT apt, boolean result);
 
         void onErrorDirective(APT apt);
-        
+
         void onPragmaOnceDirective(APT apt);
     }
     private FileContent fileContent;
@@ -118,12 +119,12 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
     private final CsmCorePackageAccessor csmCorePackageAccessor;
 
 
-    public APTParseFileWalker(ProjectBase base, APTFile apt, FileImpl file, APTPreprocHandler preprocHandler, boolean triggerParsingActivity, EvalCallback evalCallback, APTFileCacheEntry cacheEntry) {
+    public APTParseFileWalker(ProjectBase base, APTFile apt, FileImpl file, PreprocHandler preprocHandler, boolean triggerParsingActivity, EvalCallback evalCallback, APTFileCacheEntry cacheEntry) {
         super(base, apt, file, preprocHandler, cacheEntry);
         this.evalCallback = evalCallback != null ? evalCallback : EMPTY_EVAL_CALLBACK;
         this.triggerParsingActivity = triggerParsingActivity;
         csmCorePackageAccessor = CsmCorePackageAccessor.get();
-        
+
     }
 
     public void setFileContent(FileContent content) {
@@ -158,13 +159,13 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         return getTokenStream(true);
     }
 
-    public TokenStream getTokenStream(boolean filtered) {
+    public TokenStream getTokenStream(boolean filterOutComments) {
         setMode(ProjectBase.GATHERING_TOKENS);
         // get original
         TokenStream ts = super.getTokenStream();
         // expand macros
-        ts = new APTMacroExpandedStream(ts, getMacroMap(), !filtered);
-        if (filtered) {
+        ts = new APTMacroExpandedStream(ts, getMacroMap(), !filterOutComments);
+        if (filterOutComments) {
             // remove comments
             ts = new APTCommentsFilter(ts);
         }
@@ -175,10 +176,8 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
     protected void onDefine(APT apt) {
         super.onDefine(apt);
         if (needMacroAndIncludes()) {
-            MacroImpl macro = createMacro((APTDefine) apt);
-            if (macro != null) {
-                this.fileContent.addMacro(macro);
-            }
+            CsmMacro macro = createMacro((APTDefine) apt);
+            this.fileContent.addMacro(macro);
         }
     }
 
@@ -206,7 +205,7 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
                 } else if (ENABLE_LDSCOPE.contentEquals(textID)) {
                     ldScopeEnabled = true;
                 }
-            }            
+            }
         }
     }
 
@@ -215,7 +214,8 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
     @Override
     protected void postInclude(APTInclude apt, FileImpl included, IncludeState pushIncludeState) {
         if (needMacroAndIncludes()) {
-            this.fileContent.addInclude(createInclude(apt, included, pushIncludeState == IncludeState.Recursive), pushIncludeState != IncludeState.Success);
+            int includeDirectiveIndex = super.getCurIncludeDirectiveFileIndex();
+            this.fileContent.addInclude(createInclude(apt, included, pushIncludeState == IncludeState.Recursive, includeDirectiveIndex), pushIncludeState != IncludeState.Success);
         }
     }
 
@@ -227,13 +227,13 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
     @Override
     protected FileImpl includeAction(ProjectBase inclFileOwner, CharSequence inclPath, int mode, APTInclude apt, PostIncludeData postIncludeState) throws IOException {
         try {
-            APTPreprocHandler preprocHandler = getPreprocHandler();
+            PreprocHandler preprocHandler = getPreprocHandler();
             FileImpl includedFile = inclFileOwner.prepareIncludedFile(inclFileOwner, inclPath, preprocHandler);
             if (includedFile != null) {
                 ProjectBase startProject = getStartProject();
                 if (inclFileOwner.isDisposing() || startProject.isDisposing()) {
                     if (TraceFlags.TRACE_VALIDATION || TraceFlags.TRACE_MODEL_STATE) {
-                        System.err.printf("onFileIncluded: %s file [%s] is interrupted on disposing project\n", inclPath, inclFileOwner.getName());
+                        System.err.printf("onFileIncluded: %s file [%s] is interrupted on disposing project%n", inclPath, inclFileOwner.getName());
                     }
                 } else {
                     FileIncludeInParams params = new FileIncludeInParams(inclFileOwner, startProject, includedFile, inclPath, preprocHandler, postIncludeState, mode, isTriggerParsingActivity());
@@ -271,20 +271,45 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         }
     }
     
+    /*package*/ static int[] getDefineOffsets(APTDefine define, APTToken lastParam) {
+        int startOffset = define.getToken().getOffset();
+        List<APTToken> bodyTokens = define.getBody();
+        APTToken last;
+        if (bodyTokens.isEmpty()) {
+            if (false && lastParam != null && !APTUtils.isEOF(lastParam) && lastParam.getEndOffset() > 0) {
+                // To make APT and Clank more similar for 
+                // #define FUN_LIKE(param)
+                // for closing ) use last param + 1
+                final int lParentOffset = lastParam.getEndOffset()+1;
+                last = new APTTokenAbstact() { 
+                    public int getEndOffset() {
+                        return lParentOffset;
+                    }
+                };
+            } else {
+                last = define.getName() ;
+            }
+        } else {
+            last = bodyTokens.get(bodyTokens.size() - 1);
+        }
+        int endOffset = (last != null && !APTUtils.isEOF(last) && last.getEndOffset() > 0) ? last.getEndOffset() : startOffset;
+        return new int[]{startOffset, endOffset};
+    }
+
     ////////////////////////////////////////////////////////////////////////////
     // implementation details
-    
+
     private static final class FileIncludeInParams {
         private final ProjectBase inclFileOwner;
         private final ProjectBase startProject;
         private final FileImpl includedFile;
         private final CharSequence includedPath;
-        private final APTPreprocHandler preprocHandler;
+        private final PreprocHandler preprocHandler;
         private final PostIncludeData postIncludeState;
         private final int mode;
         private final boolean triggerParsingActivity;
 
-        public FileIncludeInParams(ProjectBase inclFileOwner, ProjectBase startProject, FileImpl includedFile, CharSequence includedFileName, APTPreprocHandler preprocHandler, PostIncludeData postIncludeState, int mode, boolean triggerParsingActivity) {
+        public FileIncludeInParams(ProjectBase inclFileOwner, ProjectBase startProject, FileImpl includedFile, CharSequence includedFileName, PreprocHandler preprocHandler, PostIncludeData postIncludeState, int mode, boolean triggerParsingActivity) {
             this.inclFileOwner = inclFileOwner;
             this.startProject = startProject;
             this.includedFile = includedFile;
@@ -295,32 +320,32 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
             this.triggerParsingActivity = triggerParsingActivity;
         }
     }
-    
+
     private static final class FileIncludeOutParams {
         private final FileIncludeInParams inParams;
-        private final APTPreprocHandler.State ppState;
+        private final PreprocHandler.State ppState;
         private final FilePreprocessorConditionState pcState;
-        private final FilePreprocessorConditionState.Builder pcBuilder;
+        private final APTBasedPCStateBuilder pcBuilder;
         private final APTFileCacheEntry aptCacheEntry;        
 
-        public FileIncludeOutParams(FileIncludeInParams inParams, APTPreprocHandler.State ppState, FilePreprocessorConditionState pcState, APTFileCacheEntry aptCacheEntry) {
+        public FileIncludeOutParams(FileIncludeInParams inParams, PreprocHandler.State ppState, FilePreprocessorConditionState pcState, APTFileCacheEntry aptCacheEntry) {
             this(inParams, ppState, pcState, null, aptCacheEntry);
             assert pcState != null;
         }
 
-        public FileIncludeOutParams(FileIncludeInParams inParams, APTPreprocHandler.State ppState, FilePreprocessorConditionState.Builder pcBuilder, APTFileCacheEntry aptCacheEntry) {
+        public FileIncludeOutParams(FileIncludeInParams inParams, PreprocHandler.State ppState, APTBasedPCStateBuilder pcBuilder, APTFileCacheEntry aptCacheEntry) {
             this(inParams, ppState, null, pcBuilder, aptCacheEntry);
             assert pcBuilder != null;
-        }        
+        }
 
-        private FileIncludeOutParams(FileIncludeInParams inParams, APTPreprocHandler.State ppState, FilePreprocessorConditionState pcState, FilePreprocessorConditionState.Builder pcBuilder, APTFileCacheEntry aptCacheEntry) {
+        private FileIncludeOutParams(FileIncludeInParams inParams, PreprocHandler.State ppState, FilePreprocessorConditionState pcState, APTBasedPCStateBuilder pcBuilder, APTFileCacheEntry aptCacheEntry) {
             this.inParams = inParams;
             this.ppState = ppState;
             this.pcState = pcState;
             this.pcBuilder = pcBuilder;
             this.aptCacheEntry = aptCacheEntry;
         }
-        
+
         private PreprocessorStatePair getStatePair() {
             if (pcState != null) {
                 return new PreprocessorStatePair(ppState, pcState);
@@ -330,15 +355,15 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
             }
         }
     }
-    
+
     private FileIncludeOutParams includeFileWithTokens(FileIncludeInParams params) throws IOException {
-        APTFile aptFile = getCsmCorePackageAccessor().getFileAPT(params.includedFile, true);
+        APTFile aptFile = APTTokenStreamProducer.getFileAPT(params.includedFile, true);
         if (aptFile != null) {
-            APTPreprocHandler.State ppIncludeState = params.preprocHandler.getState();
+            PreprocHandler.State ppIncludeState = params.preprocHandler.getState();
             // ask for exclusive entry if absent
-            APTFileCacheEntry aptCacheEntry = params.includedFile.getAPTCacheEntry(ppIncludeState, Boolean.TRUE);   
+            APTFileCacheEntry aptCacheEntry = params.includedFile.getAPTCacheEntry(ppIncludeState, Boolean.TRUE);
             // gather macro map from all includes and fill preprocessor conditions state
-            FilePreprocessorConditionState.Builder pcBuilder = new FilePreprocessorConditionState.Builder(params.includedFile.getAbsolutePath());
+            APTBasedPCStateBuilder pcBuilder = new APTBasedPCStateBuilder(params.includedFile.getAbsolutePath());
             APTParseFileWalker walker = new APTParseFileWalker(params.startProject, aptFile, params.includedFile, params.preprocHandler, params.triggerParsingActivity, pcBuilder, aptCacheEntry);
             FileContent inclFileContent = params.includedFile.prepareIncludedFileParsingContent();
             walker.setFileContent(inclFileContent);
@@ -368,22 +393,23 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         assert params.preprocHandler != null : "null preprocHandler for " + params.includedPath;
         assert params.includedFile != null : "null FileImpl for " + params.includedPath;
 
-        APTPreprocHandler.State newState = params.preprocHandler.getState();
+        PreprocHandler.State newState = params.preprocHandler.getState();
         PreprocessorStatePair cachedOut = null;
         APTFileCacheEntry aptCacheEntry = null;
         FilePreprocessorConditionState pcState = null;
         boolean foundInCache = false;
-        // check post include cache
-        if (params.postIncludeState != null && params.postIncludeState.hasDeadBlocks()) {
-            assert params.postIncludeState.hasPostIncludeMacroState() : "how could it be? " + params.includedPath;
-            pcState = getCsmCorePackageAccessor().createPCState(params.includedPath, params.postIncludeState.getDeadBlocks());
+        // check cache if it has complete post include state
+        if (params.postIncludeState != null
+                && params.postIncludeState.hasPostIncludeMacroState()
+                && params.postIncludeState.hasDeadBlocks()) {
+            pcState = FilePreprocessorConditionState.build(params.includedPath, params.postIncludeState.getDeadBlocks());
             params.preprocHandler.getMacroMap().setState(params.postIncludeState.getPostIncludeMacroState());
             foundInCache = true;
         }
         // check visited file cache
         boolean isFileCacheApplicable = (params.mode == ProjectBase.GATHERING_TOKENS) && (APTHandlersSupport.getIncludeStackDepth(newState) == 1);
         if (!foundInCache && isFileCacheApplicable) {
-            
+
             cachedOut = getCsmCorePackageAccessor().getCachedVisitedState(params.includedFile, newState);
             if (cachedOut != null) {
                 params.preprocHandler.getMacroMap().setState(APTHandlersSupport.extractMacroMapState(cachedOut.state));
@@ -393,7 +419,7 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         }
         // if not found in caches => visit include file
         if (!foundInCache) {
-            APTFile aptLight = getCsmCorePackageAccessor().getFileAPT(params.includedFile, false);
+            APTFile aptLight = APTTokenStreamProducer.getFileAPT(params.includedFile, false);
             if (aptLight == null) {
                 // in the case file was just removed
                 Utils.LOG.log(Level.INFO, "Can not find or build APT for file {0}", params.includedPath); //NOI18N
@@ -401,7 +427,7 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
             }
 
             // gather macro map from all includes and fill preprocessor conditions state
-            FilePreprocessorConditionState.Builder pcBuilder = new FilePreprocessorConditionState.Builder(params.includedFile.getAbsolutePath());
+            APTBasedPCStateBuilder pcBuilder = new APTBasedPCStateBuilder(params.includedFile.getAbsolutePath());
             // ask for exclusive entry if absent
             aptCacheEntry = params.includedFile.getAPTCacheEntry(newState, Boolean.TRUE);
             APTParseFileWalker walker = new APTParseFileWalker(params.startProject, aptLight, params.includedFile, params.preprocHandler, params.triggerParsingActivity, pcBuilder, aptCacheEntry);
@@ -416,7 +442,7 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
             params.postIncludeState.setDeadBlocks(deadBlocks);
         }
         // updated visited file cache
-        if (cachedOut == null && isFileCacheApplicable) {            
+        if (cachedOut == null && isFileCacheApplicable) {
             getCsmCorePackageAccessor().cacheVisitedState(params.includedFile, newState, params.preprocHandler, pcState);
         }
         return new FileIncludeOutParams(params, newState, pcState, aptCacheEntry);
@@ -429,50 +455,47 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
         return ErrorDirectiveImpl.create(this.getFile(), token.getTextID(), pos, getPreprocHandler().getState());
     }
 
-    private MacroImpl createMacro(APTDefine define) {
+    private CsmMacro createMacro(APTDefine define) {
         // create even for invalid macro (to have possibility of showing error HL)
         List<CharSequence> params = null;
         Collection<APTToken> paramTokens = define.getParams();
+        APTToken lastParam = null;
         if (paramTokens != null) {
             params = new ArrayList<>(paramTokens.size());
             for (APTToken elem : paramTokens) {
                 if (APTUtils.isID(elem)) {
                     params.add(NameCache.getManager().getString(elem.getTextID()));
                 }
+                if (!APTUtils.isVaArgsToken(elem)) {
+                    // in APT VaArgs is shared token without real offsets 
+                    lastParam = elem;
+                }
             }
             if (params.isEmpty()) {
                 params = Collections.<CharSequence>emptyList();
             }
         }
+        
+        int offsets[] = getDefineOffsets(define, lastParam);
 
-        int startOffset = define.getToken().getOffset();
-        List<APTToken> bodyTokens = define.getBody();
-        APTToken last;
-        String body = "";
-        if (bodyTokens.isEmpty()) {
-            last = define.getName();
-        } else {
-            last = bodyTokens.get(bodyTokens.size() - 1);
-            //APTToken start = (APTToken) bodyTokens.get(0);
-            // FIXUP (performance/memory). For now:
-            // 1) nobody uses macros.getText
-            // 2) its realization is ineffective
-            // so we temporarily switch this off
-            body = ""; //file.getText( start.getOffset(), last.getEndOffset());
-        }
-        int endOffset = (last != null && !APTUtils.isEOF(last) && last.getEndOffset() > 0) ? last.getEndOffset() : startOffset;       
+        // FIXUP (performance/memory). For now:
+        // 1) nobody uses macros.getText
+        // 2) its realization is ineffective
+        // so we temporarily switch this off
+        String body = ""; //file.getText( start.getOffset(), last.getEndOffset());
+        
         CsmMacro.Kind kind = define.isValid() ? CsmMacro.Kind.DEFINED : CsmMacro.Kind.INVALID;
-        return MacroImpl.create(define.getName().getTextID(), params, body/*sb.toString()*/, getFile(), startOffset, endOffset, kind);
+        return MacroImpl.create(define.getName().getTextID(), params, body/*sb.toString()*/, getFile(), offsets[0], offsets[1], kind);
     }
 
-    private IncludeImpl createInclude(final APTInclude apt, final FileImpl included, boolean recursive) {
+    private IncludeImpl createInclude(final APTInclude apt, final FileImpl included, boolean recursive, int includedDirectiveIndex) {
         int startOffset = apt.getToken().getOffset();
         APTToken lastToken = getLastToken(apt.getInclude());
         if(lastToken == null || APTUtils.isEOF(lastToken)) {
             lastToken = apt.getToken();
         }
         int endOffset = (lastToken != null && !APTUtils.isEOF(lastToken)) ? lastToken.getEndOffset() : startOffset;
-        IncludeImpl incImpl = IncludeImpl.create(apt.getFileName(getMacroMap()), apt.isSystem(getMacroMap()), recursive, included, getFile(), startOffset, endOffset);
+        IncludeImpl incImpl = IncludeImpl.create(apt.getFileName(getMacroMap()), apt.isSystem(getMacroMap()), recursive, included, getFile(), startOffset, endOffset, includedDirectiveIndex);
         return incImpl;
     }
 
@@ -506,12 +529,12 @@ public class APTParseFileWalker extends APTProjectFileBasedWalker {
     protected void onEval(APT apt, boolean result) {
         evalCallback.onEval(apt, result);
     }
-    
+
     // #pragme disable_ldscope
     // force the __global keyword to be just an identifier
     private static final String DISABLE_LDSCOPE = "disable_ldscope"; // NOI18N
     private static final String ENABLE_LDSCOPE = "enable_ldscope"; // NOI18N
-    private boolean ldScopeEnabled = true;    
+    private boolean ldScopeEnabled = true;
     private final class LdScopeFilter implements TokenStream {
 
         private final TokenStream orig;
