@@ -49,7 +49,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Set;
-import org.netbeans.modules.cnd.api.model.CsmFunction;
 import org.netbeans.modules.cnd.api.model.CsmParameter;
 import org.netbeans.modules.cnd.api.model.CsmParameterList;
 import org.netbeans.modules.cnd.api.model.CsmScope;
@@ -59,7 +58,7 @@ import org.netbeans.modules.cnd.api.model.CsmVisibility;
 import org.netbeans.modules.cnd.api.model.deep.CsmCompoundStatement;
 import org.netbeans.modules.cnd.api.model.deep.CsmExpression;
 import org.netbeans.modules.cnd.apt.support.APTHandlersSupport;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.utils.cache.APTStringManager;
 import org.netbeans.modules.cnd.modelimpl.csm.NoType;
 import org.netbeans.modules.cnd.modelimpl.csm.TypeFunPtrImpl;
@@ -104,6 +103,7 @@ public class PersistentUtils {
 
     public static FileSystem readFileSystem(RepositoryDataInput input) throws IOException {
         FileSystem fs = input.readFileSystem();
+        assert fs != null;
 //        CharSequence rootUrl = PersistentUtils.readUTF(input, FilePathCache.getManager());
 //        FileSystem fs = CndFileUtils.urlToFileSystem(rootUrl);
         //assert (fs != null) : "Restored null file system for URL " + rootUrl;
@@ -116,19 +116,19 @@ public class PersistentUtils {
         //PersistentUtils.writeUTF(rootUrl, output);        
     }
 
-    public static void readErrorDirectives(Set<ErrorDirectiveImpl> errors, FileSystem fs, RepositoryDataInput input, int unitIndex) throws IOException {
+    public static void readErrorDirectives(Set<ErrorDirectiveImpl> errors, RepositoryDataInput input) throws IOException {
         int size = input.readInt();
         for (int i = 0; i < size; i++) {
-            ErrorDirectiveImpl offs = new ErrorDirectiveImpl(fs, input, unitIndex);
+            ErrorDirectiveImpl offs = new ErrorDirectiveImpl(input);
             errors.add(offs);
         }
     }
 
-    public static void writeErrorDirectives(Set<ErrorDirectiveImpl> errors, RepositoryDataOutput output, int unitIndex) throws IOException {
+    public static void writeErrorDirectives(Set<ErrorDirectiveImpl> errors, RepositoryDataOutput output) throws IOException {
         int size = errors.size();
         output.writeInt(size);
         for (ErrorDirectiveImpl error : errors) {
-            error.write(output, unitIndex);
+            error.write(output);
         }
     }
 
@@ -245,22 +245,22 @@ public class PersistentUtils {
     
     ////////////////////////////////////////////////////////////////////////////
     // support file buffers
-    public static void writeBuffer(FileBuffer buffer, RepositoryDataOutput output, int unitId) throws IOException {
+    public static void writeBuffer(FileBuffer buffer, RepositoryDataOutput output) throws IOException {
         assert buffer != null;
         if (buffer instanceof AbstractFileBuffer) {
             // always write as file buffer file
             output.writeByte(FILE_BUFFER_FILE);
-            ((AbstractFileBuffer) buffer).write(output, unitId);
+            ((AbstractFileBuffer) buffer).write(output);
         } else {
             throw new IllegalArgumentException("instance of unknown FileBuffer " + buffer);  //NOI18N
         }
     }
 
-    public static FileBuffer readBuffer(RepositoryDataInput input, int unitId) throws IOException {
+    public static FileBuffer readBuffer(RepositoryDataInput input) throws IOException {
         FileBuffer buffer;
         int handler = input.readByte();
         assert handler == FILE_BUFFER_FILE;
-        buffer = new FileBufferFile(input, unitId);
+        buffer = new FileBufferFile(input);
         return buffer;
     }
 
@@ -318,19 +318,6 @@ public class PersistentUtils {
 
     private static final String NULL_STRING = new String(new char[]{0});
 
-    public static void writeFileNameIndex(CharSequence st, RepositoryDataOutput aStream, int unitId) throws IOException {
-        int id = KeyUtilities.getFileIdByName(unitId, st);
-        aStream.writeInt(id);
-    }
-
-    public static CharSequence readFileNameIndex(RepositoryDataInput aStream, APTStringManager manager, int unitId) throws IOException {
-        int id = aStream.readInt();
-        CharSequence path = KeyUtilities.getFileNameById(unitId, id);
-        CharSequence res = manager.getString(path);
-        assert CharSequences.isCompact(res);
-        return res;
-    }
-
     public static void writeUTF(CharSequence st, RepositoryDataOutput aStream) throws IOException {
         if (st == null) {
             aStream.writeUTF(NULL_STRING);
@@ -743,41 +730,42 @@ public class PersistentUtils {
     ////////////////////////////////////////////////////////////////////////////
     // support preprocessor states
 // Unused for the time being
-//    public static void writeStringToStateMap(Map<String, APTPreprocHandler.State> filesHandlers, DataOutput output) throws IOException {
+//    public static void writeStringToStateMap(Map<String, PreprocHandler.State> filesHandlers, DataOutput output) throws IOException {
 //        assert filesHandlers != null;
 //        int collSize = filesHandlers.size();
 //        output.writeInt(collSize);
 //
-//        for (Entry<String, APTPreprocHandler.State> entry: filesHandlers.entrySet()) {
+//        for (Entry<String, PreprocHandler.State> entry: filesHandlers.entrySet()) {
 //            assert entry != null;
 //            String key = entry.getKey();
 //            output.writeUTF(key);
 //            assert key != null;
-//            APTPreprocHandler.State state = entry.getValue();
+//            PreprocHandler.State state = entry.getValue();
 //            writePreprocState(state, output);
 //        }
 //    }
 
 // Unused for the time being
-//    public static void readStringToStateMap(Map<CharSequence, APTPreprocHandler.State> filesHandlers, DataInput input) throws IOException {
+//    public static void readStringToStateMap(Map<CharSequence, PreprocHandler.State> filesHandlers, DataInput input) throws IOException {
 //        assert filesHandlers != null;
 //        int collSize = input.readInt();
 //
 //        for (int i = 0; i < collSize; i++) {
 //            CharSequence key = FilePathCache.getString(input.readUTF());
 //            assert key != null;
-//            APTPreprocHandler.State state = readPreprocState(input);
+//            PreprocHandler.State state = readPreprocState(input);
 //            assert state != null;
 //            filesHandlers.put(key, state);
 //        }
 //    }
-    public static void writePreprocState(APTPreprocHandler.State state, RepositoryDataOutput output, int unitIndex) throws IOException {
-        APTPreprocHandler.State cleanedState = APTHandlersSupport.createCleanPreprocState(state);
-        APTSerializeUtils.writePreprocState(cleanedState, output, unitIndex);
+    public static void writePreprocState(PreprocHandler.State state, RepositoryDataOutput output) throws IOException {
+        PreprocHandler.State cleanedState = APTHandlersSupport.createCleanPreprocState(state);
+        assert cleanedState.isCleaned();
+        APTSerializeUtils.writePreprocState(cleanedState, output);
     }
 
-    public static APTPreprocHandler.State readPreprocState(FileSystem fs, RepositoryDataInput input, int unitIndex) throws IOException {
-        APTPreprocHandler.State state = APTSerializeUtils.readPreprocState(fs, input, unitIndex);
+    public static PreprocHandler.State readPreprocState(RepositoryDataInput input) throws IOException {
+        PreprocHandler.State state = APTSerializeUtils.readPreprocState(input);
         assert state.isCleaned();
         return state;
     }
