@@ -44,7 +44,7 @@
 package org.netbeans.modules.cnd.modelimpl.trace;
 
 import java.text.NumberFormat;
-import org.netbeans.modules.cnd.apt.support.StartEntry;
+import org.netbeans.modules.cnd.apt.support.api.StartEntry;
 import org.netbeans.modules.cnd.modelimpl.debug.Diagnostic;
 import org.netbeans.modules.cnd.modelimpl.debug.TraceFlags;
 import org.netbeans.modules.cnd.modelimpl.parser.CPPParserEx;
@@ -73,14 +73,16 @@ import org.netbeans.modules.cnd.apt.support.APTMacroExpandedStream;
 import org.netbeans.modules.cnd.apt.structure.APT;
 import org.netbeans.modules.cnd.apt.structure.APTFile;
 import org.netbeans.modules.cnd.apt.support.APTFileCacheManager;
-import org.netbeans.modules.cnd.apt.support.APTIncludeHandler;
+import org.netbeans.modules.cnd.apt.support.api.PPIncludeHandler;
 import org.netbeans.modules.cnd.apt.support.lang.APTLanguageSupport;
-import org.netbeans.modules.cnd.apt.support.APTMacroMap;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.support.api.PPMacroMap;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.apt.support.APTHandlersSupport;
 import org.netbeans.modules.cnd.apt.support.APTIncludePathStorage;
+import org.netbeans.modules.cnd.apt.support.APTMacroCallback;
 import org.netbeans.modules.cnd.apt.support.APTToken;
 import org.netbeans.modules.cnd.apt.support.APTTokenTypes;
+import org.netbeans.modules.cnd.apt.support.ClankDriver;
 import org.netbeans.modules.cnd.apt.support.IncludeDirEntry;
 import org.netbeans.modules.cnd.apt.support.ResolvedPath;
 import org.netbeans.modules.cnd.apt.utils.APTUtils;
@@ -88,7 +90,6 @@ import org.netbeans.modules.cnd.modelimpl.accessors.CsmCorePackageAccessor;
 import org.netbeans.modules.cnd.modelimpl.debug.DiagnosticExceptoins;
 import org.netbeans.modules.cnd.modelimpl.parser.CsmAST;
 import org.netbeans.modules.cnd.modelimpl.platform.ModelSupport;
-import org.netbeans.modules.cnd.modelimpl.repository.RepositoryUtils;
 import org.netbeans.modules.cnd.repository.support.RepositoryTestUtils;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.cnd.utils.CndPathUtilities;
@@ -103,20 +104,20 @@ import org.openide.util.CharSequences;
  */
 public class TraceModel extends TraceModelBase {
 
-    private static final class TestResult {
+    public static final class TestResult {
 
         private long time;
         private long lineCount;
 
-        public TestResult() {
+        private TestResult() {
             this(0);
         }
 
-        public TestResult(long time) {
+        private TestResult(long time) {
             this.setTime(time);
         }
 
-        public TestResult(long time, long lineCount) {
+        private TestResult(long time, long lineCount) {
             this.setTime(time);
             this.setLineCount(lineCount);
         }
@@ -133,7 +134,7 @@ public class TraceModel extends TraceModelBase {
             return time;
         }
 
-        public void setTime(long time) {
+        private void setTime(long time) {
             this.time = time;
         }
 
@@ -145,11 +146,11 @@ public class TraceModel extends TraceModelBase {
             return lineCount >= 0;
         }
 
-        public void setLineCount(long lineCount) {
+        private void setLineCount(long lineCount) {
             this.lineCount = lineCount;
         }
 
-        public void accumulate(TestResult toAdd) {
+        private void accumulate(TestResult toAdd) {
             time += toAdd.time;
             if (isLineCountValid()) {
                 if (toAdd.isLineCountValid()) {
@@ -160,11 +161,21 @@ public class TraceModel extends TraceModelBase {
             }
         }
     }
+
+    public interface ParsingTimeResultListener {
+        void notifyParsingTime(TestResult parsingTime);
+    }
+
+    void addParsingTimeResultListener(ParsingTimeResultListener listener) {
+        parsingTimeResultListener = listener;
+    }
+
     private static final int APT_REPEAT_TEST = Integer.getInteger("apt.repeat.test", 3).intValue(); // NOI18N
 
     public static void main(String[] args) {
         new TraceModel(true).test(args);
         APTDriver.close();
+        ClankDriver.close();
         APTFileCacheManager.close();
     //System.out.println("" + org.netbeans.modules.cnd.apt.utils.APTIncludeUtils.getHitRate());
     }
@@ -209,9 +220,18 @@ public class TraceModel extends TraceModelBase {
         this.dumpModel = dumpModel;
     }
 
+    /**
+     * Note that if you switch dumping ON - this must be done BEFORE parsing starts
+     * since this flag now affects gathering handlers as well.
+     */
     public void setDumpPPState(boolean dumpPPState) {
         this.dumpPPState = dumpPPState;
     }
+
+    public boolean isDumpingPPState() {
+        return this.dumpPPState;
+    }
+    
     private boolean listFilesAtEnd = false;
     private boolean testRawPerformance = false;
     private boolean printUserFileList = false;
@@ -221,26 +241,46 @@ public class TraceModel extends TraceModelBase {
 //    private boolean testFolding = false;
     private Map<String, Long> cacheTimes = new HashMap<>();
     private int lap = 0;
-    private final Map<CsmFile, APTPreprocHandler> states = new ConcurrentHashMap<>();
+    private final Map<CsmFile, PreprocHandler> states = new ConcurrentHashMap<>();
     public interface TestHook {
 
-        void parsingFinished(CsmFile file, APTPreprocHandler preprocHandler);
+        void parsingFinished(CsmFile file, PreprocHandler preprocHandler);
     }
-    
+
     TestHook hook = new TestHook() {
 
         @Override
-        public void parsingFinished(CsmFile file, APTPreprocHandler preprocHandler) {
-            states.put(file, preprocHandler);
+        public void parsingFinished(CsmFile file, PreprocHandler preprocHandler) {
+            if (dumpPPState) {
+                states.put(file, preprocHandler);
+            }
         }
     };
-    
+    private ParsingTimeResultListener parsingTimeResultListener;
+
+    private void notifyPrseTime(TestResult total) {
+        if (parsingTimeResultListener != null) {
+            parsingTimeResultListener.notifyParsingTime(total);
+        }
+    }
+
+    @Override
+    protected void shutdown(boolean clearCache) {
+        super.shutdown(clearCache); 
+        states.clear();
+    }
+
     public interface ErrorListener {
         void error(String text, int line, int column);
     }
 
+
     public TraceModel(boolean cleanCache) {
-        super(cleanCache);
+        this(cleanCache, null);
+    }
+
+    public TraceModel(boolean cleanCache, TraceModelFileFilter filter) {
+        super(cleanCache, filter);
         CsmCorePackageAccessor.get().setFileImplTestHook(hook);
     }
 
@@ -261,7 +301,7 @@ public class TraceModel extends TraceModelBase {
                 testAPTWalkerGetFilteredStream = true;
                 printTokens = true;
                 testAPT = true;
-                breakAfterAPT = true;                
+                breakAfterAPT = true;
                 break;
             case 'e':
                 System.setErr(System.out);
@@ -441,7 +481,7 @@ public class TraceModel extends TraceModelBase {
             processArguments(args);
             doTest();
         } catch (Error thr) {
-            System.err.printf("\n");
+            System.err.printf("%n");
             DiagnosticExceptoins.register(thr);
             return;
         } finally {
@@ -507,6 +547,7 @@ public class TraceModel extends TraceModelBase {
         long t = System.currentTimeMillis();
         TestResult total = test();
         total.time = System.currentTimeMillis() - t;
+        notifyPrseTime(total);
 
         if (testRawPerformance) {
             print("Take one finished."); // NOI18N
@@ -776,7 +817,7 @@ public class TraceModel extends TraceModelBase {
     private final APTSystemStorage sysAPTData = APTSystemStorage.getInstance();
     private final APTIncludePathStorage userPathStorage = new APTIncludePathStorage();
     
-    private APTIncludeHandler getIncludeHandler(FileObject fo) {
+    private PPIncludeHandler getIncludeHandler(FileObject fo) {
         FileSystem localFS = CndFileUtils.getLocalFileSystem();
         List<FSPath> systemIncludes = CndFileUtils.toFSPathList(localFS, getSystemIncludes());
         List<IncludeDirEntry> sysIncludes = sysAPTData.getIncludes(systemIncludes.toString(), systemIncludes); // NOI18N
@@ -794,7 +835,7 @@ public class TraceModel extends TraceModelBase {
                         path = pathFile.getPath();
                         qInc.add(path);
                     }
-                }                
+                }
             }
         }
         StartEntry startEntry = new StartEntry(localFS, fo.getPath(), getProject().getUIDKey());
@@ -802,23 +843,23 @@ public class TraceModel extends TraceModelBase {
         return APTHandlersSupport.createIncludeHandler(startEntry, sysIncludes, userIncludes, Collections.<String>emptyList(), null);
     }
 
-    private APTMacroMap getMacroMap(FileObject fo) {
+    private PPMacroMap getMacroMap(FileObject fo) {
         //print("SystemIncludePaths: " + systemIncludePaths.toString() + "\n");
         //print("QuoteIncludePaths: " + quoteIncludePaths.toString() + "\n");
-        APTMacroMap map = APTHandlersSupport.createMacroMap(getSysMap(fo), getMacros());
+        PPMacroMap map = APTHandlersSupport.createMacroMap(getSysMap(fo), getMacros());
         return map;
     }
 
-//    private APTPreprocHandler getPreprocHandler(File file) {
-//	APTPreprocHandler preprocHandler = APTHandlersSupport.createPreprocHandler(getMacroMap(file), getIncludeHandler(file), !file.getPath().endsWith(".h")); // NOI18N
+//    private PreprocHandler getPreprocHandler(File file) {
+//	PreprocHandler preprocHandler = APTHandlersSupport.createPreprocHandler(getMacroMap(file), getIncludeHandler(file), !file.getPath().endsWith(".h")); // NOI18N
 //	return preprocHandler;
 //    }
-    private APTMacroMap getSysMap(FileObject fo) {
-        APTMacroMap map = sysAPTData.getMacroMap("TraceModelSysMacros", getSysMacros()); // NOI18N
+    private PPMacroMap getSysMap(FileObject fo) {
+        PPMacroMap map = sysAPTData.getMacroMap("TraceModelSysMacros", getSysMacros()); // NOI18N
         return map;
     }
 
-//    
+//
 //    @Override
 //    protected List<String> getSystemIncludes() {
 //	List<String> result = super.getSystemIncludes();
@@ -876,7 +917,7 @@ public class TraceModel extends TraceModelBase {
             time = System.currentTimeMillis();
             apt = APTDriver.findAPTLight(buffer);
         }
-        APTPreprocHandler ppHandler = APTHandlersSupport.createPreprocHandler(getMacroMap(fo), getIncludeHandler(fo), true, CharSequences.empty(), CharSequences.empty());
+        PreprocHandler ppHandler = APTHandlersSupport.createPreprocHandler(getMacroMap(fo), getIncludeHandler(fo), true, CharSequences.empty(), CharSequences.empty());
         APTWalkerTest walker = new APTWalkerTest(apt, ppHandler);
         walker.visit();
         time = System.currentTimeMillis() - time;
@@ -911,12 +952,12 @@ public class TraceModel extends TraceModelBase {
             time = System.currentTimeMillis();
             apt = APTDriver.findAPT(buffer, getFileLanguage(fo), APTLanguageSupport.FLAVOR_UNKNOWN);
         }
-        APTMacroMap macroMap = getMacroMap(fo);
-        APTPreprocHandler ppHandler = APTHandlersSupport.createPreprocHandler(macroMap, getIncludeHandler(fo), true, CharSequences.empty(), CharSequences.empty());
+        PPMacroMap macroMap = getMacroMap(fo);
+        PreprocHandler ppHandler = APTHandlersSupport.createPreprocHandler(macroMap, getIncludeHandler(fo), true, CharSequences.empty(), CharSequences.empty());
         APTWalkerTest walker = new APTWalkerTest(apt, ppHandler);
         TokenStream ts = walker.getTokenStream();
         if (expand) {
-            ts = new APTMacroExpandedStream(ts, macroMap, false);
+            ts = new APTMacroExpandedStream(ts, (APTMacroCallback)macroMap, false);
         }
         if (filter) {
             ts = APTLanguageSupport.getInstance().getFilter(APTLanguageSupport.GNU_CPP).getFilteredStream(new APTCommentsFilter(ts));
@@ -941,7 +982,7 @@ public class TraceModel extends TraceModelBase {
                     newLine = true;
                     forceNewLine = true;
                 }
-                print(text, newLine); 
+                print(text, newLine);
             }
             lastLine = t.getLine();
         }
@@ -960,7 +1001,7 @@ public class TraceModel extends TraceModelBase {
     private static boolean isIncludeToken(int kind) {
         return kind == APTTokenTypes.INCLUDE || kind == APTTokenTypes.INCLUDE_NEXT;
     }
-    
+
     private long testAPTParser(NativeFileItem item, boolean cleanAPT) throws IOException, RecognitionException, TokenStreamException {
         FileBuffer buffer = ModelSupport.createFileBuffer(item.getFileObject());
         print("Testing APT Parser"); // NOI18N
@@ -969,8 +1010,7 @@ public class TraceModel extends TraceModelBase {
             invalidateAPT(buffer);
             time = System.currentTimeMillis();
         }
-        FileImpl fileImpl = null;
-        fileImpl = (FileImpl) getProject().testAPTParseFile(item);
+        FileImpl fileImpl = (FileImpl) getProject().testAPTParseFile(item);
         getProject().waitParse();
         time = System.currentTimeMillis() - time;
 
@@ -1101,10 +1141,12 @@ public class TraceModel extends TraceModelBase {
         if (firstFile == null || firstFile.equalsIgnoreCase(absPath)) {
             firstFile = absPath;
             APTDriver.invalidateAll();
+            ClankDriver.invalidateAll();
             APTFileCacheManager.invalidateAll();
             getProject().debugInvalidateFiles();
         } else {
             APTDriver.invalidateAPT(buffer);
+            ClankDriver.invalidate(buffer);
             APTFileCacheManager.getInstance(buffer.getFileSystem()).invalidate(buffer.getAbsolutePath());
         }
     }
@@ -1197,7 +1239,7 @@ public class TraceModel extends TraceModelBase {
             while (antiLoop++ < 100 && !states.containsKey(fileImpl)) {
                 sleep(100); // so that we don't run ahead of fileParsingFinished event
             }
-            APTPreprocHandler preprocHandler = states.get(fileImpl);
+            PreprocHandler preprocHandler = states.get(fileImpl);
             assert preprocHandler != null : "no handler was kept for " + fileImpl;
             dumpMacroMap(preprocHandler.getMacroMap());
         }
@@ -1253,7 +1295,7 @@ public class TraceModel extends TraceModelBase {
                     }
                 } finally {
                     CsmCacheManager.leave();
-                }                
+                }
             } else {
                 print("FileImpl is null - not possible to dump File Model"); // NOI18N
             }
@@ -1313,7 +1355,7 @@ public class TraceModel extends TraceModelBase {
     public static void getFileErrors(CsmFile file, ErrorListener errorListener) {
         CsmCorePackageAccessor.get().testFileImplErrors((FileImpl)file, errorListener);
     }
-    
+
 //    private boolean isDummyUnresolved(CsmDeclaration decl) {
 //	return decl == null || decl instanceof Unresolved.UnresolvedClass;
 //    }
@@ -1336,7 +1378,7 @@ public class TraceModel extends TraceModelBase {
         visitor.visit(ast);
     }
 
-    private void dumpMacroMap(APTMacroMap macroMap) {
+    private void dumpMacroMap(PPMacroMap macroMap) {
         tracer.print("State of macro map:"); // NOI18N
         tracer.print(macroMap == null ? "empty macro map" : macroMap.toString()); // NOI18N
     }
@@ -1467,23 +1509,22 @@ public class TraceModel extends TraceModelBase {
         Object platformProject = getProject().getPlatformProject();
         if (platformProject instanceof NativeProject) {
             NativeProject nativeProject = (NativeProject) platformProject;
-            if (nativeProject != null) {
-                result.addAll(nativeProject.getAllFiles());
+            result.addAll(nativeProject.getAllFiles());
 // these are all files specified in command line; it does not make sense to filter them
-//                for(NativeFileItem item : nativeProject.getAllFiles()){
-//                    if (!item.isExcluded()) {
-//                        switch(item.getLanguage()){
-//                            case C:
-//                            case CPP:
-//                            case C_HEADER:
-//                                result.add(item);
-//                                break;
-//                            default:
-//                                break;
-//                        }
+//            for(NativeFileItem item : nativeProject.getAllFiles()){
+//                if (!item.isExcluded()) {
+//                    switch(item.getLanguage()){
+//                        case C:
+//                        case CPP:
+//                        case C_HEADER:
+//                            result.add(item);
+//                            break;
+//                        default:
+//                            break;
 //                    }
 //                }
-            }
+//            }
+
         }
         return result;
     }
