@@ -62,9 +62,14 @@ public class TraceModelBase {
     // if true, then relative include paths oin -I option are considered
     // to be based on the file that we currently compile rather then current dir
     private boolean pathsRelCurFile = false;
+    private final TraceModelFileFilter filter;
+
+    public TraceModelBase(boolean clearCache) {
+        this(clearCache, null);
+    }
 
     @org.netbeans.api.annotations.common.SuppressWarnings("LG")
-    public TraceModelBase(boolean clearCache) {
+    public TraceModelBase(boolean clearCache, TraceModelFileFilter filter) {
         Logger openideLogger = Logger.getLogger("org.openide.loaders"); // NOI18N
         // reduce log level to prevent unnecessary messages in tests
         openideLogger.setLevel(Level.SEVERE);
@@ -75,6 +80,17 @@ public class TraceModelBase {
             RepositoryTestUtils.deleteDefaultCacheLocation();
         }
         currentIncludePaths = quoteIncludePaths;
+        if (filter == null) {
+            this.filter = new TraceModelFileFilter() {
+
+                @Override
+                public boolean isProjectFile(String filename) {
+                    return true;
+                }
+            };
+        } else {
+            this.filter = filter;
+        }
     }
 
     private static ModelImpl createModel() {
@@ -92,7 +108,7 @@ public class TraceModelBase {
         this.libProjectsPaths = libProjectsPaths;
     }
 
-    protected final void shutdown(boolean clearCache) {
+    protected void shutdown(boolean clearCache) {
         model.shutdown();
         if (clearCache){
             RepositoryTestUtils.deleteDefaultCacheLocation();
@@ -159,7 +175,7 @@ public class TraceModelBase {
         return result;
     }
 
-    /** 
+    /**
      * Processes a string flag
      * @return true if the flag has been recognised and processed,
      * otherwise false
@@ -176,8 +192,12 @@ public class TraceModelBase {
     private void addFile(List<File> files, File file) {
         if (file.isDirectory()) {
             String[] list = file.list();
-            for (int i = 0; i < list.length; i++) {
-                addFile(files, new File(file, list[i]));
+            if (list != null) {
+                for (int i = 0; i < list.length; i++) {
+                    if (filter.isProjectFile(list[i])) {
+                        addFile(files, new File(file, list[i]));
+                    }
+                }
             }
         } else {
             files.add(file);
@@ -206,7 +226,7 @@ public class TraceModelBase {
     public static void enableProjectListeners(CsmProject p, boolean enable) {
         ((ProjectBase) p).enableProjectListeners(enable);
     }
-    
+
     public static void shutdownModel(CsmModel model) {
         if (model instanceof ModelImpl) {
             ((ModelImpl)model).shutdown();
@@ -214,7 +234,7 @@ public class TraceModelBase {
             CndUtils.assertTrueInConsole(false, "unexpected model instance ", model);
         }
     }
-    
+
     public static CsmProject addNativeProject(NativeProject np) {
         CsmModel model = CsmModelAccessor.getModel();
         CsmProject csmProject = null;
@@ -225,7 +245,7 @@ public class TraceModelBase {
         }
         return csmProject;
     }
-    
+
     public static void closeNativeProject(NativeProject np) {
         CsmModel model = CsmModelAccessor.getModel();
         if (model instanceof ModelImpl) {
@@ -234,7 +254,7 @@ public class TraceModelBase {
             CndUtils.assertTrueInConsole(false, "unexpected model instance ", model);
         }
     }
-    
+
     public static void closeProject(CsmProject project) {
         closeProject(project, false);
     }
