@@ -45,7 +45,9 @@ package org.netbeans.modules.cnd.modelimpl.trace;
 import java.io.File;
 import java.io.FileWriter;
 import java.util.Collection;
-import org.netbeans.modules.cnd.apt.support.APTPreprocHandler;
+import org.netbeans.modules.cnd.apt.debug.APTTraceFlags;
+import org.netbeans.modules.cnd.apt.support.APTMacroCallback;
+import org.netbeans.modules.cnd.apt.support.api.PreprocHandler;
 import org.netbeans.modules.cnd.modelimpl.csm.core.FileImpl;
 
 /**
@@ -64,6 +66,8 @@ public class FileModel2Test extends TraceModelTestBase {
         System.setProperty("cnd.modelimpl.tracemodel.project.name", "DummyProject"); // NOI18N
         System.setProperty("parser.report.errors", "true");
         System.setProperty("antlr.exceptions.hideExpectedTokens", "true");
+//        System.setProperty("apt.use.clank", "true");
+//        System.setProperty("cnd.modelimpl.parser.threads", "1");
         super.setUp();
     }
 
@@ -130,6 +134,16 @@ public class FileModel2Test extends TraceModelTestBase {
         performTest("iz197997.cc");
     }
     
+    protected TraceModelFileFilter getProjectFileFilter() {
+        if (true) return super.getProjectFileFilter();
+        return new TraceModelFileFilter() {
+            @Override
+            public boolean isProjectFile(String filename) {
+                return filename.endsWith("iz191446.cc");
+            }
+        };
+    }
+    
     public void test191446() throws Exception {
         // #191446 - no code assistance for elementes #include'ed in namespace body
         performTest("iz191446.cc");
@@ -261,15 +275,19 @@ public class FileModel2Test extends TraceModelTestBase {
     }
 
     public void testIZ147284isDefined() throws Exception {
+        if (APTTraceFlags.USE_CLANK) {
+          // this is the test for non-clank mode only
+          return;
+        }
         // IZ#147284 APTMacroCallback.isDefined(CharSequence) ignores #undef
         String base = "iz147284_is_defined";
         performTest(base + ".cc");
         FileImpl fileImpl = findFile(base + ".h");
         assertNotNull(fileImpl);
-        Collection<APTPreprocHandler> handlers = fileImpl.getFileContainerOwnPreprocHandlersToDump();
+        Collection<PreprocHandler> handlers = fileImpl.getFileContainerOwnPreprocHandlersToDump();
         assertEquals(handlers.size(), 1);
         String macro = "MAC";
-        assertFalse(macro + " should be undefined!", handlers.iterator().next().getMacroMap().isDefined(macro));
+        assertFalse(macro + " should be undefined!", ((APTMacroCallback)handlers.iterator().next().getMacroMap()).isDefined(macro));
     }
 
     public void testIZ147574() throws Exception {
@@ -522,4 +540,9 @@ public class FileModel2Test extends TraceModelTestBase {
         // Bug 245802 - inaccuracy tests(regression): operator< breaks parser
         performTest("bug245802.cpp");
     }
+    
+    public void testBug254698() throws Exception {
+        // Bug 254698 - java.io.UTFDataFormatException: encoded string too long: 169505 bytes
+        performTest("bug254698.cpp");
+    }
 }
