@@ -53,6 +53,7 @@ import org.netbeans.modules.cnd.api.model.CsmTypedef;
 import org.netbeans.modules.cnd.api.model.services.CsmCacheManager;
 import org.netbeans.modules.cnd.api.model.util.CsmBaseUtilities;
 import org.netbeans.modules.cnd.api.model.util.CsmKindUtilities;
+import org.netbeans.modules.cnd.apt.debug.APTTraceFlags;
 
 /**
  * pre-integration tests for parser
@@ -69,6 +70,8 @@ public class FileModelTest extends TraceModelTestBase {
         System.setProperty("cnd.modelimpl.tracemodel.project.name", "DummyProject"); // NOI18N
         System.setProperty("parser.report.errors", "true");
         System.setProperty("antlr.exceptions.hideExpectedTokens", "true");
+//        System.setProperty("apt.use.clank", "true");
+//        System.setProperty("cnd.modelimpl.parser.threads", "1");
         super.setUp();
     }
 
@@ -122,12 +125,34 @@ public class FileModelTest extends TraceModelTestBase {
     }
     
     public void testIncompleteString() throws Exception {
+        // Clank: to fix this case in Clank mode I had to modify:
+        // Lexer.LexCharConstant
+        // Lexer.LexStringLiteral
+        // and return token with real Kind even for incomplete tokens
+        // instead of tok.TokenKind.unknown
         performTest("incomplete_string.cc");        
     }
     
     public void testPreProcDefinedKeyword() throws Exception {
         performTest("preproc_defined_keyword.cc");        
     }
+
+    public void testPreProcTrueKeywordID_Studio() throws Exception {
+        // "true" in preprocessor for C++ mode was fixed in OSS (21194403)
+        // hack was removed as rev http://hg.netbeans.org/cnd-main/rev/9c543f5a42d3
+        if (false) {
+            // clank doesn't have this specific of Studio compiler
+            performTest("check.true.studio.cc");
+        }
+    }
+    
+    public void testPreProcTrueKeywordIDCPP() throws Exception {
+        performTest("check.true.cc");        
+    }
+    
+    public void testPreProcTrueKeywordIDC() throws Exception {
+        performTest("check.true.c");        
+    }
     
     public void testFriendsDeclaration() throws Exception {
         performTest("friend.cc"); // NOI18N
@@ -402,6 +427,10 @@ public class FileModelTest extends TraceModelTestBase {
     }
 
     public void testStringizeMacro() throws Exception {
+        if (APTTraceFlags.USE_CLANK) {
+          // this is the test for non-clank mode only
+          return;
+        }
         // IZ 137465 : wrong macro expansion for #x
         performPreprocessorTest("stringize_macro.cc"); // NOI18N
     }
