@@ -56,8 +56,6 @@ import java.awt.Insets;
 import java.awt.LayoutManager;
 import java.awt.font.TextAttribute;
 import java.text.AttributedString;
-import java.util.HashMap;
-import java.util.Map;
 import java.util.ArrayList;
 import java.util.List;
 import javax.swing.BorderFactory;
@@ -72,58 +70,56 @@ import org.netbeans.swing.plaf.LFCustoms;
  */
 
 public abstract class CsmPaintComponent extends JPanel {
-            
+
     DrawState drawState = new DrawState();
-    
+
     protected Font drawFont;
-           
+
     private static final int ICON_WIDTH = 16;
     private static final int ICON_TEXT_GAP = 5;
-            
+
     private int fontHeight;
-    
+
     private int ascent;
-    
-    private Map widths;
-    
+
     private FontMetrics fontMetrics;
-    
+
     protected boolean isSelected;
-    
+
    // private String text;
-    
+
     private ArrayList<PostfixString> postfixes;
-    
+
     private static final String THROWS = " throws "; // NOI18N
-    
-    
+
+
     private static final String[] frequentWords = new String[] {
         "", " ", "[]", "(", ")", ", ", "String", THROWS // NOI18N
     };
-    
+
     private final static Color KEYWORD_COLOR = Color.gray;
     private final static Color POSTFIX_COLOR = Color.lightGray;
-    
+
     private Icon icon;
-    
+
     protected int modifiers = 0;
-    
+
     private static Border BORDER = BorderFactory.createEmptyBorder(0, 3, 0, 3);
     private static LayoutManager layout = new FlowLayout();
     public CsmPaintComponent(){
-        super(layout, true);        
+        super(layout, true);
         setBorder(BORDER);
-        postfixes = new ArrayList<PostfixString>();        
+        postfixes = new ArrayList<PostfixString>();
     }
-    
+
     public void setSelected(boolean isSelected){
         this.isSelected = isSelected;
     }
-    
+
     protected boolean isSelected(){
         return isSelected;
     }
-    
+
     @Override
     public void paintComponent(Graphics g) {
         // clear background
@@ -132,53 +128,53 @@ public abstract class CsmPaintComponent extends JPanel {
         java.awt.Rectangle r = g.getClipBounds();
         g.fillRect(r.x, r.y, r.width, r.height);
         draw(g);
-        
+
         if(!postfixes.isEmpty()) {
             drawString(g, " (", postfixColor); // NOI18N
-            Iterator iter = postfixes.iterator();
+            Iterator<PostfixString> iter = postfixes.iterator();
             while(iter.hasNext()) {
-                ((PostfixString) iter.next()).Draw(g);
+                iter.next().Draw(g);
                 if(iter.hasNext()) {
                     drawString(g, ",  ", postfixColor); // NOI18N
                 }
-            } 
+            }
             drawString(g, ")", postfixColor); // NOI18N
-        }        
+        }
     }
-    
+
     public void appendPostfix(String text, Color c, int font) {
         postfixes.add(new PostfixString(text, c, font));
     }
-    
+
     public void removePostfixes() {
         postfixes.clear();
     }
-    
+
     public boolean hasPostfixes() {
         return !postfixes.isEmpty();
     }
-    
+
     /** IMPORTANT:
      * when implemented => have to update toString!
      */
     abstract protected void draw(Graphics g);
-    
+
     /**
      * returns string representation of paint item
      * IMPORTANT: have to be in sync with draw() method
-     */   
+     */
     @Override
     abstract public String toString();
-    
+
     protected void setIcon(Icon icon){
         this.icon = icon;
     }
-    
+
     protected Icon getIcon(){
         return icon;
     }
-    
-    
+
+
     /** Draw the icon if it is valid for the given type.
      * Here the initial drawing assignments are also done.
      */
@@ -191,7 +187,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawState.drawX = 0;
             drawState.drawY = 0;
         }
-        
+
         if (icon != null) {
             if (g != null) {
                 icon.paintIcon(this, g, drawState.drawX, drawState.drawY);
@@ -207,11 +203,11 @@ public abstract class CsmPaintComponent extends JPanel {
         drawState.drawHeight += drawState.drawY;
         drawState.drawY += ascent;
     }
-    
+
     protected void drawString(Graphics g, CharSequence s){
         drawString(g, s, false);
     }
-    
+
     /** Draw string using the foreground color */
     protected void drawString(Graphics g, CharSequence s, boolean strike) {
         if (g != null) {
@@ -219,8 +215,8 @@ public abstract class CsmPaintComponent extends JPanel {
         }
         drawStringToGraphics(g, s, null, strike);
     }
-    
-    
+
+
     /** Draw string with given color which is first possibly modified
      * by calling getColor() method to care about selection etc.
      */
@@ -230,7 +226,7 @@ public abstract class CsmPaintComponent extends JPanel {
         }
         drawStringToGraphics(g, s);
     }
-    
+
     protected void drawString(Graphics g, CharSequence s, Color c, Font font, boolean strike) {
         if (g != null) {
             g.setColor(getColor(s, c));
@@ -240,9 +236,9 @@ public abstract class CsmPaintComponent extends JPanel {
         if (g != null) {
             g.setFont(drawFont);
         }
-        
+
     }
-    
+
     protected void drawTypeName(Graphics g, String s, Color c) {
         if (g == null) {
             drawString(g, "   "); // NOI18N
@@ -261,11 +257,11 @@ public abstract class CsmPaintComponent extends JPanel {
             drawString(g, s, c);
         }
     }
-    
+
     protected void drawStringToGraphics(Graphics g, CharSequence s) {
         drawStringToGraphics(g, s, null, false);
     }
-    
+
     protected void drawStringToGraphics(Graphics g, CharSequence s, Font font, boolean strike) {
         String str = s != null ? s.toString() : "";
         if (g != null) {
@@ -281,54 +277,44 @@ public abstract class CsmPaintComponent extends JPanel {
         }
         drawState.drawX += getWidth(str, font);
     }
-    
+
     protected int getWidth(String s) {
-        Integer i = (Integer)widths.get(s);
-        if (i != null) {
-            return i.intValue();
-        } else {
-            return fontMetrics.stringWidth(s);
-        }
+        return fontMetrics.stringWidth(s);
     }
-    
+
     protected int getWidth(String s, Font font) {
         if (font == null) {
             return getWidth(s);
         }
         return getFontMetrics(font).stringWidth(s);
     }
-    
+
     protected Color getColor(CharSequence s, Color defaultColor) {
         return isSelected ? getForeground()
         : defaultColor;
     }
-    
+
     private void storeWidth(String s) {
         fontMetrics.stringWidth(s);
     }
-    
+
     @Override
     public void setFont(Font font) {
         super.setFont(font);
-        
+
         fontMetrics = this.getFontMetrics(font);
         fontHeight = fontMetrics.getHeight();
         ascent = fontMetrics.getAscent();
-        if (widths != null) {
-            widths.clear();
-        } else {
-            widths = new HashMap();
-        }
         for (int i = 0; i < frequentWords.length; i++) {
             storeWidth(frequentWords[i]);
         }
         drawFont = font;
     }
-    
+
     protected Font getDrawFont(){
         return drawFont;
     }
-    
+
     @Override
     public Dimension getPreferredSize() {
         draw(null);
@@ -341,7 +327,7 @@ public abstract class CsmPaintComponent extends JPanel {
         }
         return new Dimension(drawState.drawX, drawState.drawHeight);
     }
-    
+
     public void setModifiers(int modifiers){
         this.modifiers = modifiers;
     }
@@ -349,68 +335,68 @@ public abstract class CsmPaintComponent extends JPanel {
     public int getModifiers(){
         return modifiers;
     }
-      
+
     DrawState getDrawState() {
         return drawState;
     }
-    
+
     void setDrawState(DrawState drawState) {
         this.drawState = drawState;
     }
-    
+
     //.................. INNER CLASSES .......................
-    
+
     private class PostfixString {
         private String text;
         private Color c;
         private int fontStyle;
-        
+
         public PostfixString(String text, Color c, int fontStyle) {
             this.text = text;
             this.c = c;
             this.fontStyle = fontStyle;
         }
-        
+
         public PostfixString(String text, int fontStyle) {
             this(text, LFCustoms.shiftColor(CsmPaintComponent.POSTFIX_COLOR), fontStyle);
         }
-        
-        void Draw(Graphics g) {            
-            CsmPaintComponent.this.drawString(g, text, c, new Font(getDrawFont().getName(), 
-                                                                   getDrawFont().getStyle() | fontStyle, 
+
+        void Draw(Graphics g) {
+            CsmPaintComponent.this.drawString(g, text, c, new Font(getDrawFont().getName(),
+                                                                   getDrawFont().getStyle() | fontStyle,
                                                                    getDrawFont().getSize()),
                                                false);
-                                        
-        }        
+
+        }
     }
-    
+
     private static class DrawState {
         int drawX, drawY;
-        int drawHeight;    
-               
+        int drawHeight;
+
         public DrawState() {
             drawX = drawY = drawHeight = 0;
-        }        
+        }
     }
-    
+
     public static class NamespacePaintComponent extends CsmPaintComponent{
 
         private String pkgName;
         private boolean displayFullNamespacePath;
         private Color NAMESPACE_COLOR = LFCustoms.shiftColor(new Color(64,255,64));
-        
+
         public NamespacePaintComponent(){
             super();
         }
-        
+
         public void setNamespaceName(String pkgName){
             this.pkgName = pkgName;
         }
-        
+
         public void setDisplayFullNamespacePath(boolean displayFullNamespacePath){
             this.displayFullNamespacePath = displayFullNamespacePath;
         }
-        
+
         @Override
         protected void draw(Graphics g) {
             // IMPORTANT:
@@ -422,7 +408,7 @@ public abstract class CsmPaintComponent extends JPanel {
             }
             drawString(g, name,	    NAMESPACE_COLOR);
         }
-        
+
         /**
          * returns string representation of paint item
          * IMPORTANT: have to be in sync with draw() method
@@ -432,20 +418,20 @@ public abstract class CsmPaintComponent extends JPanel {
             return pkgName;
         }
     }
-    
+
     public static class NamespaceAliasPaintComponent extends CsmPaintComponent{
 
         private String aliasName;
         private Color NAMESPACE_COLOR = LFCustoms.shiftColor(new Color(64,255,64));
-        
+
         public NamespaceAliasPaintComponent(){
             super();
         }
-        
+
         public void setAliasName(String aliasName){
             this.aliasName = aliasName;
         }
-        
+
         @Override
         protected void draw(Graphics g) {
             // IMPORTANT:
@@ -453,7 +439,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawIcon(g, getIcon());
             drawString(g, aliasName,	    NAMESPACE_COLOR);
         }
-        
+
         /**
          * returns string representation of paint item
          * IMPORTANT: have to be in sync with draw() method
@@ -465,19 +451,19 @@ public abstract class CsmPaintComponent extends JPanel {
     }
 
     public static class EnumPaintComponent extends CsmPaintComponent {
-        
+
         String formatEnumName;
         private Color ENUM_COLOR = LFCustoms.shiftColor(new Color(255,64,64));
         private boolean displayFQN;
-        
+
         public void EnumPaintComponent(String formatEnumName){
             this.formatEnumName = formatEnumName;
         }
-        
+
         protected Color getColor(){
             return ENUM_COLOR;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -486,7 +472,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawIcon(g, getIcon());
             drawString(g, formatEnumName, getColor(), null, strike);
         }
-        
+
         public void setFormatEnumName(String formatEnumName){
             this.formatEnumName = formatEnumName;
         }
@@ -500,21 +486,21 @@ public abstract class CsmPaintComponent extends JPanel {
             return formatEnumName;
         }
     }
-    
+
     public static class EnumeratorPaintComponent extends CsmPaintComponent {
-        
+
         String formatEnumeratorName;
         private Color ENUMERATOR_COLOR = LFCustoms.shiftColor(new Color(64,64,255));
         private boolean displayFQN;
-        
+
         public void EnumeratorPaintComponent(String formatEnumeratorName){
             this.formatEnumeratorName = formatEnumeratorName;
         }
-        
+
         protected Color getColor(){
             return ENUMERATOR_COLOR;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -523,7 +509,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawIcon(g, getIcon());
             drawString(g, formatEnumeratorName, getColor(), null, strike);
         }
-        
+
         public void setFormatEnumeratorName(String formatEnumeratorName){
             assert(formatEnumeratorName != null);
             this.formatEnumeratorName = formatEnumeratorName;
@@ -538,21 +524,21 @@ public abstract class CsmPaintComponent extends JPanel {
             return formatEnumeratorName;
         }
     }
-    
+
     public static class ClassPaintComponent extends CsmPaintComponent{
-        
+
         String formatClassName;
         private Color CLASS_COLOR = LFCustoms.shiftColor(new Color(255,64,64));
         private boolean displayFQN;
-        
+
         public void setFormatClassName(String formatClassName){
             this.formatClassName = formatClassName;
         }
-        
+
         protected Color getColor(){
             return CLASS_COLOR;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -561,7 +547,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawIcon(g, getIcon());
             drawString(g, formatClassName, getColor(), null, strike);
         }
-      
+
         /**
          * returns string representation of paint item
          * IMPORTANT: have to be in sync with draw() method
@@ -569,25 +555,25 @@ public abstract class CsmPaintComponent extends JPanel {
         @Override
         public String toString() {
             return formatClassName;
-        }        
+        }
     }
 
-    
+
     public static class TypedefPaintComponent extends CsmPaintComponent{
-        
+
         String formatTypedefName;
         private final Color TYPEDEF_COLOR = CsmFontColorManager.instance().getColor(FontColorProvider.Entity.TYPEDEF); //new Color(64,64,255).darker().darker().darker();
         //private boolean displayFQN;
-        
+
         public void setFormatTypedefName(String formatTypedefName){
             this.formatTypedefName = formatTypedefName;
-            
+
         }
-        
+
         protected Color getColor(){
             return TYPEDEF_COLOR;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -596,7 +582,7 @@ public abstract class CsmPaintComponent extends JPanel {
             drawIcon(g, getIcon());
             drawString(g, formatTypedefName, getColor(), null, strike);
         }
-      
+
         /**
          * returns string representation of paint item
          * IMPORTANT: have to be in sync with draw() method
@@ -604,78 +590,78 @@ public abstract class CsmPaintComponent extends JPanel {
         @Override
         public String toString() {
             return formatTypedefName;
-        }        
+        }
     }
 
     public static class StructPaintComponent extends ClassPaintComponent{
-        
+
         private Color STRUCT_COLOR = LFCustoms.shiftColor(new Color(255,64,64));
-        
+
         @Override
         protected Color getColor(){
             return STRUCT_COLOR;
         }
-        
+
         public StructPaintComponent(){
             super();
         }
     }
-    
+
     public static class UnionPaintComponent extends ClassPaintComponent{
-        
+
         private Color UNION_COLOR = LFCustoms.shiftColor(new Color(255,64,64));
-        
+
         @Override
         protected Color getColor(){
             return UNION_COLOR;
         }
-        
+
         public UnionPaintComponent(){
             super();
         }
     }
-    
+
     public static class FieldPaintComponent extends CsmPaintComponent{
         private Color FIELD_COLOR = CsmFontColorManager.instance().getColor(FontColorProvider.Entity.CLASS_FIELD);//new Color(64,64,255).darker();
         protected String typeName;
         protected Color typeColor;
         protected String fldName;
-        
+
         private boolean drawTypeAsPrefix = false;
-        
+
         public FieldPaintComponent() {
             super();
         }
-        
+
         public Color getNameColor() {
             return FIELD_COLOR;
         }
-        
+
         @Override
         public void setName(String fldName){
             this.fldName= fldName;
         }
-        
+
         public void setTypeColor(Color typeColor){
             this.typeColor = typeColor;
         }
-        
+
         public void setTypeName(String typeName){
             this.typeName = typeName;
         }
-        
+
         public Color getTypeColor(){
             return this.typeColor;
         }
-        
+
         public String getTypeName(){
             return this.typeName;
         }
-        
+
         public void setDrawTypeAsPrefix(boolean asPrefix) {
             this.drawTypeAsPrefix = asPrefix;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -683,10 +669,10 @@ public abstract class CsmPaintComponent extends JPanel {
             boolean strike = false;
             //int level = CsmUtilities.getLevel(modifiers);
             drawIcon(g, getIcon());
-            
+
             if (drawTypeAsPrefix) {
                 drawString(g, getTypeName(), getTypeColor(), null, strike);
-                drawString(g, " ", strike); // NOI18N                   
+                drawString(g, " ", strike); // NOI18N
             }
             if ((modifiers & CsmUtilities.LOCAL_MEMBER_BIT) != 0){
                 // it is local field, draw as bold
@@ -716,17 +702,17 @@ public abstract class CsmPaintComponent extends JPanel {
                 buf.append(typeName);
             }
             return buf.toString();
-        }        
+        }
     }
-    
+
     public static class LocalVariablePaintComponent extends FieldPaintComponent {
         private Color VARIABLE_COLOR = LFCustoms.shiftColor(new Color(255,64,64));
-        
+
         public LocalVariablePaintComponent(){
             super();
             this.modifiers |= CsmUtilities.LOCAL_MEMBER_BIT | this.modifiers;
         }
-        
+
         @Override
         public Color getNameColor() {
             return VARIABLE_COLOR;
@@ -737,37 +723,37 @@ public abstract class CsmPaintComponent extends JPanel {
             super.setModifiers(modifiers | CsmUtilities.LOCAL_MEMBER_BIT);
         }
     }
-    
+
     public static class FileLocalVariablePaintComponent extends FieldPaintComponent {
         private Color VARIABLE_COLOR = LFCustoms.shiftColor(new Color(64,64,255));
-        
+
         public FileLocalVariablePaintComponent(){
             super();
         }
-        
+
         @Override
         public Color getNameColor() {
             return VARIABLE_COLOR;
         }
     }
-    
+
     public static class GlobalVariablePaintComponent extends FieldPaintComponent {
         private Color VARIABLE_COLOR = LFCustoms.shiftColor(new Color(64,64,255));
-        
+
         public GlobalVariablePaintComponent(){
             super();
         }
-        
+
         @Override
         public Color getNameColor() {
             return VARIABLE_COLOR;
         }
     }
-    
+
     public static class MacroPaintComponent extends CsmPaintComponent{
         private Color MACRO_NAME_COLOR = CsmFontColorManager.instance().getColor(FontColorProvider.Entity.DEFINED_MACRO);//new Color(64,255,64).darker().darker();
         private Color MACRO_PARAMETER_NAME_COLOR = LFCustoms.shiftColor(new Color(227, 166, 74));//Color.magenta.darker();
-        private List params = null;
+        private List<CharSequence> params = null;
         private String name;
 
         public MacroPaintComponent(){
@@ -778,17 +764,17 @@ public abstract class CsmPaintComponent extends JPanel {
         public String getName(){
             return name;
         }
-        
+
         @Override
         public void setName(String name){
             this.name = name;
         }
-        
-        public void setParams(List params){
+
+        public void setParams(List<CharSequence> params){
             this.params = params;
         }
-        
-        protected List getParamList(){
+
+        protected List<CharSequence> getParamList(){
             return params;
         }
 
@@ -802,13 +788,13 @@ public abstract class CsmPaintComponent extends JPanel {
             drawParameterList(g, getParamList(), strike);
         }
 
-        protected void drawParameterList(Graphics g, List prmList, boolean strike) {
+        protected void drawParameterList(Graphics g, List<CharSequence> prmList, boolean strike) {
             if (prmList == null || prmList.size()==0){
                 return;
             }
             drawString(g, "(", strike); // NOI18N
-            for (Iterator it = prmList.iterator(); it.hasNext();) {
-                drawString(g, (CharSequence)it.next(), MACRO_PARAMETER_NAME_COLOR, null, strike);
+            for (Iterator<CharSequence> it = prmList.iterator(); it.hasNext();) {
+                drawString(g, it.next(), MACRO_PARAMETER_NAME_COLOR, null, strike);
                 if (it.hasNext()) {
                     drawString(g, ", ", strike); // NOI18N
                 }
@@ -816,13 +802,13 @@ public abstract class CsmPaintComponent extends JPanel {
             drawString(g, ")", strike); // NOI18N
         }
 
-        protected String toStringParameterList(List prmList) {
+        protected String toStringParameterList(List<CharSequence> prmList) {
             if (prmList == null || prmList.size()==0){
                 return "";
             }
             StringBuilder buf = new StringBuilder();
             buf.append('('); // NOI18N
-            for (Iterator it = prmList.iterator(); it.hasNext();) {
+            for (Iterator<CharSequence> it = prmList.iterator(); it.hasNext();) {
                 buf.append(it.next());
                 if (it.hasNext()) {
                     buf.append(", "); // NOI18N
@@ -844,12 +830,12 @@ public abstract class CsmPaintComponent extends JPanel {
             //macro params
             buf.append(toStringParameterList(getParamList()));
             return buf.toString();
-        }    
+        }
     }
-    
+
     public static class TemplateParameterPaintComponent extends CsmPaintComponent{
         private Color PARAMETER_NAME_COLOR = LFCustoms.getTextFgColor();
-        private List params = null;
+        private List<CharSequence> params = null;
         private String name;
 
         public TemplateParameterPaintComponent(){
@@ -860,17 +846,17 @@ public abstract class CsmPaintComponent extends JPanel {
         public String getName(){
             return name;
         }
-        
+
         @Override
         public void setName(String name){
             this.name = name;
         }
-        
-        public void setParams(List params){
+
+        public void setParams(List<CharSequence> params){
             this.params = params;
         }
-        
-        protected List getParamList(){
+
+        protected List<CharSequence> getParamList(){
             return params;
         }
 
@@ -893,12 +879,12 @@ public abstract class CsmPaintComponent extends JPanel {
             //macro name
             buf.append(getName());
             return buf.toString();
-        }    
+        }
     }
 
     public static class LabelPaintComponent extends  CsmPaintComponent {
         private Color LABEL_NAME_COLOR = LFCustoms.getTextFgColor();
-        private List params = null;
+        private List<CharSequence> params = null;
         private String name;
 
         public LabelPaintComponent(){
@@ -909,17 +895,17 @@ public abstract class CsmPaintComponent extends JPanel {
         public String getName(){
             return name;
         }
-        
+
         @Override
         public void setName(String name){
             this.name = name;
         }
-        
-        public void setParams(List params){
+
+        public void setParams(List<CharSequence> params){
             this.params = params;
         }
-        
-        protected List getParamList(){
+
+        protected List<CharSequence> getParamList(){
             return params;
         }
 
@@ -942,55 +928,55 @@ public abstract class CsmPaintComponent extends JPanel {
             //macro name
             buf.append(getName());
             return buf.toString();
-        }    
+        }
     }
-    
+
     public static class ConstructorPaintComponent extends CsmPaintComponent{
-        
+
         private Color CONSTRUCTOR_COLOR = LFCustoms.shiftColor(Color.orange);
         private Color PARAMETER_NAME_COLOR = LFCustoms.shiftColor(new Color(227, 166, 74));//Color.magenta.darker();
-        private List params = new ArrayList();
-        private List excs = new ArrayList();
+        private List<ParamStr> params = new ArrayList<>();
+        private List<ExceptionStr> excs = new ArrayList<>();
         private String name;
-        
+
         public ConstructorPaintComponent(){
             super();
         }
-        
+
         public int getMethodModifiers(){
             return modifiers;
         }
-        
+
         @Override
         public String getName(){
             return name;
         }
-        
+
         @Override
         public void setName(String name){
             this.name = name;
         }
-        
-        public void setParams(List params){
+
+        public void setParams(List<ParamStr> params){
             this.params = params;
         }
-        
-        public void setExceptions(List excs){
+
+        public void setExceptions(List<ExceptionStr> excs){
             this.excs = excs;
         }
-        
-        protected List getParamList(){
+
+        protected List<ParamStr> getParamList(){
             return params;
         }
-        
-        protected List getExceptionList(){
+
+        protected List<ExceptionStr> getExceptionList(){
             return excs;
         }
-        
+
         protected void drawParameter(Graphics g, ParamStr prm) {
             drawParameter(g, prm, false);
         }
-        
+
         protected void drawParameter(Graphics g, ParamStr prm, boolean strike) {
             String parmName = prm.getName();
             String simpleTypeName = prm.getSimpleTypeName();
@@ -1010,36 +996,36 @@ public abstract class CsmPaintComponent extends JPanel {
                 drawString(g, simpleTypeName.substring(indexOfSqr), prm.getTypeColor(), null, strike);
             }
         }
-        
-        protected void drawParameterList(Graphics g, List prmList) {
+
+        protected void drawParameterList(Graphics g, List<ParamStr> prmList) {
             drawParameterList(g, prmList, false);
         }
-        
-        protected void drawParameterList(Graphics g, List prmList, boolean strike) {
+
+        protected void drawParameterList(Graphics g, List<ParamStr> prmList, boolean strike) {
             drawString(g, "(", strike); // NOI18N
-            for (Iterator it = prmList.iterator(); it.hasNext();) {
-                drawParameter(g, (ParamStr)it.next(), strike);
+            for (Iterator<ParamStr> it = prmList.iterator(); it.hasNext();) {
+                drawParameter(g, it.next(), strike);
                 if (it.hasNext()) {
                     drawString(g, ", ", strike); // NOI18N
                 }
             }
             drawString(g, ")", strike); // NOI18N
         }
-        
-        protected void drawExceptions(Graphics g, List exc, boolean strike) {
+
+        protected void drawExceptions(Graphics g, List<ExceptionStr> exc, boolean strike) {
             if (exc.size() > 0) {
                 drawString(g, THROWS, LFCustoms.shiftColor(KEYWORD_COLOR), null, strike);
-                for (Iterator it = exc.iterator(); it.hasNext();) {
-                    ExceptionStr ex = (ExceptionStr) it.next();
+                for (Iterator<ExceptionStr> it = exc.iterator(); it.hasNext();) {
+                    ExceptionStr ex = it.next();
                     drawString(g, ex.getName(), ex.getTypeColor(), null, strike);
                     if (it.hasNext()) {
                         drawString(g, ", ", strike); // NOI18N
                     }
-                    
+
                 }
             }
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -1067,7 +1053,7 @@ public abstract class CsmPaintComponent extends JPanel {
             buf.append(toStringExceptions(getExceptionList()));
             return buf.toString();
         }
-        
+
         protected String toStringParameter(ParamStr prm) {
             StringBuilder builder = new StringBuilder();
             String parmName = prm.getName();
@@ -1087,12 +1073,12 @@ public abstract class CsmPaintComponent extends JPanel {
             }
             return builder.toString();
         }
-        
-        protected String toStringParameterList(List prmList) {
+
+        protected String toStringParameterList(List<ParamStr> prmList) {
             StringBuilder buf = new StringBuilder();
             buf.append('('); // NOI18N
-            for (Iterator it = prmList.iterator(); it.hasNext();) {
-                buf.append(toStringParameter((ParamStr)it.next()));
+            for (Iterator<ParamStr> it = prmList.iterator(); it.hasNext();) {
+                buf.append(toStringParameter(it.next()));
                 if (it.hasNext()) {
                     buf.append(", "); // NOI18N
                 }
@@ -1100,60 +1086,60 @@ public abstract class CsmPaintComponent extends JPanel {
             buf.append(')'); // NOI18N
             return buf.toString();
         }
-        
-        protected String toStringExceptions(List exc) {
+
+        protected String toStringExceptions(List<ExceptionStr> exc) {
             StringBuilder buf = new StringBuilder();
             if (exc.size() > 0) {
                 buf.append(THROWS);
-                for (Iterator it = exc.iterator(); it.hasNext();) {
-                    ExceptionStr ex = (ExceptionStr) it.next();
+                for (Iterator<ExceptionStr> it = exc.iterator(); it.hasNext();) {
+                    ExceptionStr ex = it.next();
                     buf.append(ex.getName());
                     if (it.hasNext()) {
                         buf.append(", "); // NOI18N
                     }
-                    
+
                 }
             }
             return buf.toString();
         }
     }
-    
+
     public static class MethodPaintComponent extends ConstructorPaintComponent {
-        
+
         //private Color PARAMETER_NAME_COLOR = Color.magenta.darker();
         private Color METHOD_COLOR = LFCustoms.getTextFgColor();
         private String typeName;
         private Color typeColor;
         private boolean drawTypeAsPrefix = false;
-        
+
         public MethodPaintComponent(){
             super();
         }
-        
+
         public Color getNameColor() {
             return METHOD_COLOR;
         }
-        
+
         public String getTypeName(){
             return typeName;
         }
-        
+
         public Color getTypeColor(){
             return typeColor;
         }
-        
+
         public void setTypeName(String typeName){
             this.typeName = typeName;
         }
-        
+
         public void setTypeColor(Color typeColor){
             this.typeColor = typeColor;
         }
-        
+
         public void setDrawTypeAsPrefix(boolean asPrefix) {
             this.drawTypeAsPrefix = asPrefix;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             // IMPORTANT:
@@ -1161,11 +1147,11 @@ public abstract class CsmPaintComponent extends JPanel {
             boolean strike = false;
             //int level = CsmUtilities.getLevel(getModifiers());
             drawIcon(g, getIcon());
-            
+
             if (drawTypeAsPrefix) {
                 drawString(g, getTypeName(), getTypeColor(), null, strike);
-                drawString(g, " ", strike); // NOI18N                
-            }            
+                drawString(g, " ", strike); // NOI18N
+            }
             if ((getModifiers() & CsmUtilities.LOCAL_MEMBER_BIT) != 0){
                 drawString(g, getName(), getNameColor() , new Font(getDrawFont().getName(), getDrawFont().getStyle() | Font.BOLD, getDrawFont().getSize()), strike);
             }else{
@@ -1187,7 +1173,7 @@ public abstract class CsmPaintComponent extends JPanel {
             StringBuilder buf = new StringBuilder();
             if (drawTypeAsPrefix) {
                 //return type
-                buf.append(getTypeName());                
+                buf.append(getTypeName());
                 buf.append(' '); // NOI18N
             }
             //method name
@@ -1199,47 +1185,47 @@ public abstract class CsmPaintComponent extends JPanel {
             if (!drawTypeAsPrefix) {
                 //return type
                 buf.append(' '); // NOI18N
-                buf.append(getTypeName());                
+                buf.append(getTypeName());
             }
-            return buf.toString();            
-        }        
+            return buf.toString();
+        }
     }
 
     public static class FileLocalFunctionPaintComponent extends MethodPaintComponent {
         private Color FUN_COLOR = LFCustoms.getTextFgColor();
-        
+
         public FileLocalFunctionPaintComponent(){
             super();
         }
-        
+
         @Override
         public Color getNameColor() {
             return FUN_COLOR;
         }
     }
-    
+
     public static class GlobalFunctionPaintComponent extends MethodPaintComponent {
         private Color FUN_COLOR = LFCustoms.getTextFgColor();
-        
+
         public GlobalFunctionPaintComponent(){
             super();
         }
-        
+
         @Override
         public Color getNameColor() {
             return FUN_COLOR;
         }
     }
-    
-    public static class CsmPaintComponentWrapper extends CsmPaintComponent {    
+
+    public static class CsmPaintComponentWrapper extends CsmPaintComponent {
         private CsmPaintComponent comp;
         private boolean drawTypeAsPrefix = true;
-        
+
         public CsmPaintComponentWrapper() {
-            super();        
+            super();
         }
-        
-        public void setCsmComponent(CsmPaintComponent comp) {           
+
+        public void setCsmComponent(CsmPaintComponent comp) {
             this.comp = comp;
         }
 
@@ -1251,20 +1237,20 @@ public abstract class CsmPaintComponent extends JPanel {
                         ((CsmPaintComponent.FieldPaintComponent)comp).setDrawTypeAsPrefix(true);
                     } else if (comp instanceof CsmPaintComponent.MethodPaintComponent) {
                         ((CsmPaintComponent.MethodPaintComponent)comp).setDrawTypeAsPrefix(true);
-                    }                
+                    }
                 }
-                comp.draw(g);          
+                comp.draw(g);
                 if (drawTypeAsPrefix) {
                     if (comp instanceof CsmPaintComponent.FieldPaintComponent) {
                         ((CsmPaintComponent.FieldPaintComponent)comp).setDrawTypeAsPrefix(false);
                     } else if (comp instanceof CsmPaintComponent.MethodPaintComponent) {
                         ((CsmPaintComponent.MethodPaintComponent)comp).setDrawTypeAsPrefix(false);
-                    }                
+                    }
                 }
                 setDrawState(comp.getDrawState());
             }
         }
-        
+
         @Override
         public void setFont(Font font) {
             super.setFont(font);
@@ -1272,24 +1258,24 @@ public abstract class CsmPaintComponent extends JPanel {
                 comp.setFont(font);
             }
         }
-        
+
         @Override
         public String toString() {
             if (comp != null) {
                 return comp.toString();
             }
             return "";
-        }    
-    } 
-    
+        }
+    }
+
     public static class StringPaintComponent extends CsmPaintComponent {
 
         private String str;
 
         public void setString(String str){
-            this.str = str;            
+            this.str = str;
         }
-        
+
         @Override
         protected void draw(Graphics g){
             drawIcon(g, null);
@@ -1300,5 +1286,5 @@ public abstract class CsmPaintComponent extends JPanel {
         public String toString() {
             return str;
         }
-    }    
+    }
 }
