@@ -57,12 +57,7 @@ import javax.swing.JRadioButtonMenuItem;
 import javax.swing.text.JTextComponent;
 import org.netbeans.api.editor.EditorRegistry;
 import org.netbeans.modules.cnd.api.model.CsmFile;
-import org.netbeans.modules.cnd.api.model.CsmModel;
-import org.netbeans.modules.cnd.api.model.CsmModelAccessor;
 import org.netbeans.modules.cnd.api.model.services.CsmCacheManager;
-import org.netbeans.modules.cnd.api.project.NativeFileItem;
-import org.netbeans.modules.cnd.api.project.NativeFileItemSet;
-import org.netbeans.modules.cnd.api.project.NativeProject;
 import org.netbeans.modules.cnd.modelutil.CsmImageLoader;
 import org.netbeans.modules.cnd.modelutil.CsmUtilities;
 import org.netbeans.modules.cnd.qnavigator.navigator.CsmFileFilter.SortMode;
@@ -585,54 +580,6 @@ public class NavigatorModel {
         }
     }
     
-    private class NoCodeModelNode extends AbstractNode {
-        private final NativeProject project;
-        
-        public NoCodeModelNode(DataObject dobj) {
-            super(Children.LEAF);
-            
-            boolean loading = false;
-            NativeProject owner = null;
-            boolean excluded = true;
-            CsmModel model = CsmModelAccessor.getModel();
-            
-            if (dobj != null && dobj.isValid()) {
-                NativeFileItemSet set = dobj.getLookup().lookup(NativeFileItemSet.class);
-                if (set != null && !set.isEmpty()) {
-                    for (NativeFileItem item : set.getItems()) {
-                        owner = item.getNativeProject();
-                        if (!item.isExcluded()) {
-                            excluded = false;
-                        }
-                        if (model.isProjectEnabled(owner) == null) {
-                            loading = true;
-                            break;
-                        }
-                    }
-                }
-            }
-            
-            if (loading) {
-                setName(NbBundle.getMessage(NavigatorModel.class, "Initializing"));
-                owner = null;
-            } else if (owner == null) {
-                setName(NbBundle.getMessage(NavigatorModel.class, "OrphanFile"));
-            } else if (excluded) {
-                setName(NbBundle.getMessage(NavigatorModel.class, "FileExcludedFromCodeAssistance"));
-            } else {
-                setName(NbBundle.getMessage(NavigatorModel.class, "ModelDisabled", owner.getProjectDisplayName()));
-            }
-            
-            this.project = owner;
-            setIconBaseWithExtension("org/netbeans/modules/cnd/qnavigator/resources/exclamation.gif");
-        }
-
-        @Override
-        public Action getPreferredAction() {
-            return new EnableCodeAssistanceAction(project);
-        }
-    }
-
     @Override
     public String toString() {
         return "" + cdo;
