@@ -86,7 +86,7 @@ import org.netbeans.modules.cnd.refactoring.support.GeneratorUtils;
 import org.netbeans.modules.cnd.refactoring.support.GeneratorUtils.InsertInfo;
 import org.netbeans.modules.cnd.refactoring.support.ModificationResult;
 import org.netbeans.modules.cnd.refactoring.support.ModificationResult.Difference;
-import org.netbeans.modules.cnd.refactoring.ui.EncapsulateFieldPanel.InsertPoint;
+import org.netbeans.modules.cnd.refactoring.ui.InsertPoint;
 import org.netbeans.modules.cnd.support.Interrupter;
 import org.netbeans.modules.refactoring.api.AbstractRefactoring;
 import org.netbeans.modules.refactoring.api.Problem;
@@ -138,7 +138,9 @@ public final class EncapsulateFieldRefactoringPlugin extends CsmModificationRefa
     
     @Override
     public Problem preCheck() {
-        fireProgressListenerStart(AbstractRefactoring.PRE_CHECK, 2);
+        fireProgressListenerStart(AbstractRefactoring.PRE_CHECK, 3);
+        CsmRefactoringUtils.waitParsedAllProjects();
+        fireProgressListenerStep();
         try {
             CsmField field = refactoring.getSourceField();
             Problem result = checkIfModificationPossible(null, field);
@@ -272,7 +274,7 @@ public final class EncapsulateFieldRefactoringPlugin extends CsmModificationRefa
         private int startOffset = -1;
         private int endOffset = -1;
         private CharSequence origParamsText = "";
-        private List<CharSequence> paramText = new ArrayList<CharSequence>();
+        private List<CharSequence> paramText = new ArrayList<>();
 
         public CharSequence getOriginalParamsText() {
             return origParamsText;
@@ -662,7 +664,7 @@ public final class EncapsulateFieldRefactoringPlugin extends CsmModificationRefa
             // do not interrupt refactoring
             Collection<CsmReference> refs = CsmReferenceRepository.getDefault().getReferences(field, csmFile, CsmReferenceKind.ALL, Interrupter.DUMMY);
             if (refs.size() > 0) {
-                List<CsmReference> sortedRefs = new ArrayList<CsmReference>(refs);
+                List<CsmReference> sortedRefs = new ArrayList<>(refs);
                 Collections.sort(sortedRefs, new Comparator<CsmReference>() {
 
                     @Override
