@@ -52,7 +52,6 @@ import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.text.BadLocationException;
@@ -82,8 +81,9 @@ import org.netbeans.modules.cnd.api.model.xref.CsmIncludeHierarchyResolver;
 import org.netbeans.modules.cnd.editor.api.CodeStyle;
 import org.netbeans.modules.cnd.modelutil.CsmUtilities;
 import org.netbeans.modules.cnd.refactoring.api.EncapsulateFieldsRefactoring;
+import org.netbeans.modules.cnd.refactoring.codegen.ConstructorGenerator.Inited;
 import org.netbeans.modules.cnd.refactoring.hints.infrastructure.Utilities;
-import org.netbeans.modules.cnd.refactoring.ui.EncapsulateFieldPanel.InsertPoint;
+import org.netbeans.modules.cnd.refactoring.ui.InsertPoint;
 import org.openide.util.CharSequences;
 import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.editor.indent.api.Reformat;
@@ -95,6 +95,7 @@ import org.openide.text.CloneableEditorSupport;
 import org.openide.text.PositionRef;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
+import org.openide.util.Pair;
 
 /**
  *
@@ -132,7 +133,7 @@ public class GeneratorUtils {
     public static Collection<CsmFunction> getAllOutOfClassMethodDefinitions(CsmClass clazz) {
         // get all method declarations
         Iterator<CsmMember> methods = CsmSelect.getClassMembers(clazz, CsmSelect.FUNCTION_KIND_FILTER);
-        List<CsmFunction> result = new ArrayList<CsmFunction>();
+        List<CsmFunction> result = new ArrayList<>();
         // find definitions of that declarations
         while (methods.hasNext()) {
             CsmMethod method = (CsmMethod) methods.next();
@@ -220,8 +221,7 @@ public class GeneratorUtils {
 //        return result;
 //    }
 //
-    public static void scanForFieldsAndConstructors(final CsmClass clsPath, final Set<CsmField> shouldBeInitializedFields, final Set<CsmField> mayBeIninitializedFields,
-            final Set<CsmField> cannotBeInitializedFields, final List<CsmConstructor> constructors) {
+    public static void scanForFieldsAndConstructors(final CsmClass clsPath, List<Pair<CsmField, Inited>> fields, final List<CsmConstructor> constructors) {
         for (CsmMember member : clsPath.getMembers()) {
             if (CsmKindUtilities.isField(member)) {
                 CsmField field = (CsmField) member;
@@ -230,14 +230,14 @@ public class GeneratorUtils {
                 }
                 CsmType type = field.getType();
                 if (type.getArrayDepth() > 0) {
-                    cannotBeInitializedFields.add(field);
+                    fields.add(Pair.of(field, Inited.cannot));
                     continue;
                 }
                 if (type.isConst() || type.isReference()) {
-                    shouldBeInitializedFields.add(field);
+                    fields.add(Pair.of(field, Inited.must));
                     continue;
                 }
-                mayBeIninitializedFields.add(field);
+                fields.add(Pair.of(field, Inited.may));
             } else if (CsmKindUtilities.isConstructor(member)) {
                 constructors.add((CsmConstructor)member);
             }
@@ -791,7 +791,7 @@ public class GeneratorUtils {
             RefactoringSession session = RefactoringSession.create(getGetterSetterDisplayName(type));
             EncapsulateFieldsRefactoring refactoring = new EncapsulateFieldsRefactoring(null, path);
 
-            Collection<EncapsulateFieldsRefactoring.EncapsulateFieldInfo> refFields = new ArrayList<EncapsulateFieldsRefactoring.EncapsulateFieldInfo>();
+            Collection<EncapsulateFieldsRefactoring.EncapsulateFieldInfo> refFields = new ArrayList<>();
             for (CsmField field : fields) {
                 String gName = (type != Kind.SETTERS_ONLY) ? computeGetterName(field, isUpperCase) : null;
                 String sName = (type != Kind.GETTERS_ONLY) ? computeSetterName(field, isUpperCase) : null;
