@@ -45,7 +45,6 @@ package org.netbeans.modules.cnd.remote.projectui.wizard.cnd;
 
 import java.awt.Component;
 import java.io.IOException;
-import java.net.URL;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -60,7 +59,6 @@ import javax.swing.JComponent;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.progress.ProgressHandle;
-import org.netbeans.api.project.Project;
 import org.netbeans.modules.cnd.api.remote.RemoteFileUtil;
 import org.netbeans.modules.cnd.api.remote.SelectHostWizardProvider;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
@@ -71,19 +69,20 @@ import org.netbeans.modules.cnd.makeproject.api.configurations.CompilerSet2Confi
 import org.netbeans.modules.cnd.makeproject.api.configurations.DevelopmentHostConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.MakeConfiguration;
 import org.netbeans.modules.cnd.makeproject.api.configurations.QmakeConfiguration;
-import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension.ProjectKind;
+import org.netbeans.modules.cnd.makeproject.api.wizards.IteratorExtension;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels;
 import org.netbeans.modules.cnd.makeproject.api.wizards.ProjectWizardPanels.NamedPanel;
 import org.netbeans.modules.cnd.makeproject.api.wizards.WizardConstants;
 import org.netbeans.modules.cnd.makeproject.spi.DatabaseProjectProvider;
+import org.netbeans.modules.cnd.utils.CndLanguageStandards;
 import org.netbeans.modules.cnd.utils.FSPath;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.openide.WizardDescriptor;
 import org.openide.filesystems.FileObject;
-import org.openide.filesystems.URLMapper;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.Pair;
 
 /**
  * Wizard to create a new Make project.
@@ -241,18 +240,6 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
         }
     }
 
-    private SelectHostWizardProvider getSelectHostWizardProvider() {
-        if (selectHostWizardProvider == null) {
-            selectHostWizardProvider = SelectHostWizardProvider.createInstance(false, false, new ChangeListener() {
-                @Override
-                public void stateChanged(ChangeEvent e) {
-                    fireStateChanged();
-                }
-            });
-        }
-        return selectHostWizardProvider;
-    }
-
     private void setupPanelsAndStepsIfNeed() {        
         if (wizardtype == TYPE_APPLICATION || wizardtype == TYPE_DYNAMIC_LIB || wizardtype == TYPE_STATIC_LIB || wizardtype == TYPE_QT_APPLICATION || wizardtype == TYPE_QT_DYNAMIC_LIB || wizardtype == TYPE_QT_STATIC_LIB) {
             if (panels == null) {
@@ -261,7 +248,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
                 String[] steps = createSteps(panels);
             }
         } else if (wizardtype == TYPE_MAKEFILE) {
-            String hostUID = (wiz == null) ? null : (String) wiz.getProperty(WizardConstants.PROPERTY_HOST_UID);
+            String hostUID = (wiz == null) ? null : WizardConstants.PROPERTY_HOST_UID.get(wiz);
             Boolean setupHost = null;
 
             if (panels != null) {
@@ -367,46 +354,59 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     @Override
     public Set<FileObject> instantiate() throws IOException {
         Set<FileObject> resultSet = new HashSet<FileObject>();
-        FSPath dirF = (FSPath) wiz.getProperty(WizardConstants.PROPERTY_PROJECT_FOLDER);
+        FSPath dirF = WizardConstants.PROPERTY_PROJECT_FOLDER.get(wiz);
         //do not see any reasons why to use local env here
-        final ExecutionEnvironment env = (ExecutionEnvironment) wiz.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV);
+        final ExecutionEnvironment env = WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wiz);
         String hostUID = ExecutionEnvironmentFactory.toUniqueID(env);
-        CompilerSet toolchain = (CompilerSet) wiz.getProperty(WizardConstants.PROPERTY_TOOLCHAIN);
-        boolean defaultToolchain = Boolean.TRUE.equals(wiz.getProperty(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT));
+        CompilerSet toolchain = WizardConstants.PROPERTY_TOOLCHAIN.get(wiz);
+        boolean defaultToolchain = Boolean.TRUE.equals(WizardConstants.PROPERTY_TOOLCHAIN_DEFAULT.get(wiz));
         if (dirF != null) {
-            dirF = new FSPath(dirF.getFileSystem(), RemoteFileUtil.normalizeAbsolutePath(dirF.getPath(), (ExecutionEnvironment) wiz.getProperty(WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV)));
+            dirF = new FSPath(dirF.getFileSystem(), RemoteFileUtil.normalizeAbsolutePath(dirF.getPath(), WizardConstants.PROPERTY_REMOTE_FILE_SYSTEM_ENV.get(wiz)));
         }
-        String projectName = (String) wiz.getProperty(WizardConstants.PROPERTY_NAME);
-        String makefileName = (String) wiz.getProperty(WizardConstants.PROPERTY_GENERATED_MAKEFILE_NAME);
+        String projectName = WizardConstants.PROPERTY_NAME.get(wiz);
+        String makefileName = WizardConstants.PROPERTY_GENERATED_MAKEFILE_NAME.get(wiz);
         if (isSimple()) {
-            ImportRemoteProject importRemoteProject = new ImportRemoteProject(getSelectModePanel().getWizardStorage().getAdapter());
-            resultSet.addAll(importRemoteProject.create());
+            IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
+            if (extension != null) {
+                resultSet.addAll(extension.createProject(wiz));
+            }
         } else if (wizardtype == TYPE_MAKEFILE) { // thp
-            ImportRemoteProject importRemoteProject = new ImportRemoteProject(wiz);
-            resultSet.addAll(importRemoteProject.create());
+            IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
+            if (extension != null) {
+                resultSet.addAll(extension.createProject(wiz));
+            }
         } else if (wizardtype == TYPE_BINARY) {
-            String binary = (String) wiz.getProperty(WizardConstants.PROPERTY_BUILD_RESULT);
-            boolean trueSourceRoot = (Boolean)wiz.getProperty(WizardConstants.PROPERTY_TRUE_SOURCE_ROOT);
-            List<String> dlls = (List<String>) wiz.getProperty(WizardConstants.PROPERTY_DEPENDENCIES);
-            String libraries = null;
-            if (dlls != null && !dlls.isEmpty()) {
-                StringBuilder buf = new StringBuilder();
-                for(String s : dlls) {
-                    if (!s.isEmpty()) {
-                        if (buf.length()>0) {
-                            buf.append(':');
-                        }
-                        buf.append(s);
-                    }
+            IteratorExtension extension = Lookup.getDefault().lookup(IteratorExtension.class);
+            if (extension != null) {
+                IteratorExtension.ProjectKind kind = WizardConstants.PROPERTY_DEPENDENCY_KIND.get(wiz);
+                if (kind == null) {
+                    kind = IteratorExtension.ProjectKind.IncludeDependencies;
                 }
-                libraries = buf.toString();
-            }
-
-            CreateProjectFromBinary creator = new CreateProjectFromBinary(dirF.getFileSystem(), dirF.getPath(), binary, !trueSourceRoot, libraries, ProjectKind.IncludeDependencies);
-            Project createRemoteProject = creator.createRemoteProject();
-            if (createRemoteProject != null) {
-                //resultSet.add(createRemoteProject);
+                extension.discoverProject(wiz.getProperties(), null, kind);
+                //resultSet.addAll(extension.createProject(wiz));
             }
+//            String binary = WizardConstants.PROPERTY_BUILD_RESULT.get(wiz);
+//            boolean trueSourceRoot = WizardConstants.PROPERTY_TRUE_SOURCE_ROOT.get(wiz);
+//            List<String> dlls = WizardConstants.PROPERTY_DEPENDENCIES.get(wiz);
+//            String libraries = null;
+//            if (dlls != null && !dlls.isEmpty()) {
+//                StringBuilder buf = new StringBuilder();
+//                for(String s : dlls) {
+//                    if (!s.isEmpty()) {
+//                        if (buf.length()>0) {
+//                            buf.append(':');
+//                        }
+//                        buf.append(s);
+//                    }
+//                }
+//                libraries = buf.toString();
+//            }
+//
+//            CreateProjectFromBinary creator = new CreateProjectFromBinary(dirF.getFileSystem(), dirF.getPath(), binary, !trueSourceRoot, libraries, ProjectKind.IncludeDependencies);
+//            Project createRemoteProject = creator.createRemoteProject();
+//            if (createRemoteProject != null) {
+//                //resultSet.add(createRemoteProject);
+//            }
         } else if (wizardtype == TYPE_APPLICATION || wizardtype == TYPE_DYNAMIC_LIB || wizardtype == TYPE_STATIC_LIB || wizardtype == TYPE_QT_APPLICATION || wizardtype == TYPE_QT_DYNAMIC_LIB || wizardtype == TYPE_QT_STATIC_LIB || wizardtype == TYPE_DB_APPLICATION) {
             int conftype = -1;
             String customizerId = null;
@@ -426,17 +426,21 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
                 conftype = MakeConfiguration.TYPE_DB_APPLICATION;
             }
             String mainFile = null;
-            if (((Boolean) wiz.getProperty("createMainFile")).booleanValue()) { // NOI18N
-                String fname = (String) wiz.getProperty("mainFileName"); // NOI18N
-                String template = (String) wiz.getProperty("mainFileTemplate"); // NOI18N
+            if (WizardConstants.PROPERTY_CREATE_MAIN_FILE.get(wiz)) { // NOI18N
+                WizardConstants.PROPERTY_MAIN_FILE_NAME.get(wiz);
+                String fname = WizardConstants.PROPERTY_MAIN_FILE_NAME.get(wiz);
+                String template = WizardConstants.PROPERTY_MAIN_TEMPLATE_NAME.get(wiz);
                 mainFile = fname + "|" + template; // NOI18N
             }
+            String langStandard = WizardConstants.PROPERTY_LANGUAGE_STANDARD.get(wiz);
+
             MakeConfiguration debug = MakeConfiguration.createConfiguration(dirF, "Debug", conftype, customizerId,  hostUID, toolchain, defaultToolchain); // NOI18N
             debug.getCCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getCCCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getFortranCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getAssemblerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_DEBUG);
             debug.getQmakeConfiguration().getBuildMode().setValue(QmakeConfiguration.DEBUG_MODE);
+            setupLanguageStandard(debug, langStandard);
             //debug.setRemoteMode(Mode.REMOTE_SOURCES);
 
             int platform = CompilerSetManager.get((env)).getPlatform();
@@ -462,6 +466,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
             release.getFortranCompilerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_RELEASE);
             release.getAssemblerConfiguration().getDevelopmentMode().setValue(BasicCompilerConfiguration.DEVELOPMENT_MODE_RELEASE);
             release.getQmakeConfiguration().getBuildMode().setValue(QmakeConfiguration.RELEASE_MODE);
+            setupLanguageStandard(release, langStandard);
             //release.setRemoteMode(Mode.REMOTE_SOURCES);
             release.getDevelopmentHost().setBuildPlatform(platform);
             release.setCompilerSet(compilerSet2Configuration);
@@ -495,11 +500,65 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     private transient int index;
     private transient List<WizardDescriptor.Panel<WizardDescriptor>> panels;
     private transient WizardDescriptor wiz;
-
+    
+//<editor-fold defaultstate="collapsed" desc="Copy from PanelProjectLocationVisual">
+    private static final String[] CPP = new String[]{"C++", // NOI18N
+        CndLanguageStandards.CndLanguageStandard.CPP98.toString(),
+        CndLanguageStandards.CndLanguageStandard.CPP11.toString(),
+        CndLanguageStandards.CndLanguageStandard.CPP14.toString()
+    };
+    private static final String[] C = new String[]{"C", // NOI18N
+        CndLanguageStandards.CndLanguageStandard.C89.toString(),
+        CndLanguageStandards.CndLanguageStandard.C99.toString(),
+        CndLanguageStandards.CndLanguageStandard.C11.toString()
+    };
+    private static final String[] FORTRAN = new String[]{"Fortran90 Fixed", // NOI18N
+        "Fortran90 Free", // NOI18N
+        "Fortran95", // NOI18N
+        "Fortran2003", // NOI18N
+        "Fortran2008" // NOI18N
+    };
+    
+    private static Pair<String,Integer> getLanguageStandard(String value) {
+        if (value == null) {
+            return null;
+        }
+        for(int i = 0; i < C.length; i++) {
+            if (value.equals(C[i])) {
+                return Pair.of(C[0], i);
+            }
+        }
+        for(int i = 0; i < CPP.length; i++) {
+            if (value.equals(CPP[i])) {
+                return Pair.of(CPP[0], i);
+            }
+        }
+        for(int i = 0; i < FORTRAN.length; i++) {
+            if (value.equals(FORTRAN[i])) {
+                return Pair.of(FORTRAN[0], i);
+            }
+        }
+        return null;
+    }
+    
+    private void setupLanguageStandard(MakeConfiguration conf, String langStandard) {
+        Pair<String, Integer> languageStandard = getLanguageStandard(langStandard);
+        if (languageStandard != null) {
+            if (C[0].equals(languageStandard.first())) {
+                conf.getCCompilerConfiguration().getCStandard().setValue(languageStandard.second());
+            } else if (CPP[0].equals(languageStandard.first())) {
+                conf.getCCCompilerConfiguration().getCppStandard().setValue(languageStandard.second());
+            } else if (FORTRAN[0].equals(languageStandard.first())) {
+                //conf.getFortranCompilerConfiguration().getFortranStandard().setValue(languageStandard.second());
+            }
+        }
+    }
+//</editor-fold>
+    
     @Override
     public void initialize(WizardDescriptor wiz) {
         this.wiz = wiz;
-        wiz.putProperty(WizardConstants.PROPERTY_SOURCE_HOST_ENV, getDefaultSourceEnvironment());
+        WizardConstants.PROPERTY_SOURCE_HOST_ENV.put(wiz, getDefaultSourceEnvironment());
         index = 0;
         setupPanelsAndStepsIfNeed();
     }
@@ -517,14 +576,16 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
 
     @Override
     public void uninitialize(WizardDescriptor wiz) {
-        this.wiz.putProperty(WizardConstants.PROPERTY_PROJECT_FOLDER, null);
-        this.wiz.putProperty(WizardConstants.PROPERTY_NAME, null);
-        this.wiz.putProperty(WizardConstants.MAIN_CLASS, null); // NOI18N
-        if (wizardtype == TYPE_MAKEFILE) {
-            this.wiz.putProperty("sourceRoot", null); // NOI18N
+        if (wiz != null) {
+            WizardConstants.PROPERTY_PROJECT_FOLDER.put(wiz, null);
+            WizardConstants.PROPERTY_NAME.put(wiz, null);
+            WizardConstants.MAIN_CLASS.put(wiz, null); // NOI18N
+            if (wizardtype == TYPE_MAKEFILE) {
+                wiz.putProperty("sourceRoot", null); // NOI18N
+            }
+            this.wiz = null;
+            panels = null;
         }
-        this.wiz = null;
-        panels = null;
     }
 
     @Override
@@ -533,7 +594,7 @@ public class NewMakeProjectWizardIterator implements WizardDescriptor.ProgressIn
     }
 
     private boolean isSimple() {
-        return wizardtype == TYPE_MAKEFILE && wiz != null && Boolean.TRUE.equals(wiz.getProperty(WizardConstants.PROPERTY_SIMPLE_MODE));
+        return wizardtype == TYPE_MAKEFILE && wiz != null && Boolean.TRUE.equals(WizardConstants.PROPERTY_SIMPLE_MODE.get(wiz));
     }
 
     @Override
