@@ -44,6 +44,7 @@ package org.netbeans.modules.cnd.remote.fs;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -177,6 +178,7 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
     }
 
     @Override
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // three state
     protected Boolean canReadImpl(CharSequence path) {
         FileSystemAndString p = getFileSystemAndRemotePath(path);
         if (p != null) {
@@ -189,6 +191,7 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
     }
 
     @Override
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // three state
     protected Boolean existsImpl(CharSequence path) {
         FileSystemAndString p = getFileSystemAndRemotePath(path);
         if (p != null) {
@@ -223,8 +226,8 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
         FileSystemProvider.removeFileChangeListener(listener);
         return true;
     }
-    
-    
+
+
 
     private FileSystemAndString getFileSystemAndRemotePath(CharSequence path) {
         String prefix = getPrefix();
@@ -290,19 +293,53 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
         }
         return result;
     }
-    
-    private final List<ProblemListenerAdapter> adapters = new ArrayList<ProblemListenerAdapter>();
+
+    private final List<ProblemListenerAdapter> adapters = new ArrayList<>();
+
+    private void cleanDeadListeners() {
+        assert Thread.holdsLock(adapters);
+        for (Iterator<ProblemListenerAdapter> it = adapters.iterator(); it.hasNext();) {
+            ProblemListenerAdapter adapter = it.next();
+            if (adapter.listenerRef.get() == null) {
+                it.remove();
+            }
+        }
+    }
     
     @Override
-    protected void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener, FileSystem fileSystem) {
-        ProblemListenerAdapter newAdapter = new ProblemListenerAdapter(listener);
+    protected void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener) {
+        ProblemListenerAdapter newAdapter = new ProblemListenerAdapter(listener, null);
         synchronized (adapters) {
-            for (Iterator<ProblemListenerAdapter> it = adapters.iterator(); it.hasNext(); ) {
-                ProblemListenerAdapter adapter = it.next();
-                if (adapter.listenerRef.get() == null) {
-                    it.remove();
+            cleanDeadListeners();
+            adapters.add(newAdapter);
+        }
+        FileSystemProvider.addFileSystemProblemListener(newAdapter);
+    }
+
+    @Override
+    protected void fireFileSystemProblemOccurredImpl(FSPath fsPath) {
+        List<CndFileSystemProblemListener> listeners = new ArrayList<>();
+        synchronized (adapters) {
+            for (ProblemListenerAdapter adapter : adapters) {
+                CndFileSystemProblemListener l = adapter.listenerRef.get();
+                if (l != null) {                    
+                    FileSystem listenerFS = (adapter.fileSystemRef == null) ? null : adapter.fileSystemRef.get();
+                    if (listenerFS == null || listenerFS.equals(fsPath.getFileSystem())) {
+                        listeners.add(l);
+                    }
                 }
             }
+        }
+        for (CndFileSystemProblemListener l : listeners) {
+            l.problemOccurred(fsPath);
+        }
+    }
+
+    @Override
+    protected void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener, FileSystem fileSystem) {
+        ProblemListenerAdapter newAdapter = new ProblemListenerAdapter(listener, fileSystem);
+        synchronized (adapters) {
+            cleanDeadListeners();
             adapters.add(newAdapter);
         }
         FileSystemProvider.addFileSystemProblemListener(newAdapter, fileSystem);
@@ -324,11 +361,11 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
                 } else if (l == listener) {
                     FileSystemProvider.removeFileSystemProblemListener(adapter, fileSystem);
                     it.remove();
-                }                
+                }
             }
         }
     }
-    
+
     private static HostInfo getHostInfoIfAvailable(ExecutionEnvironment env) {
         if (HostInfoUtils.isHostInfoAvailable(env)) {
             try {
@@ -370,16 +407,35 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
        }
     }
 
-    private static class ProblemListenerAdapter implements FileSystemProblemListener {
-        
-        private final WeakReference<CndFileSystemProblemListener> listenerRef;
+    @Override
+    protected boolean isRemoteImpl(FileSystem fs) {
+        return FileSystemProvider.getExecutionEnvironment(fs).isRemote();
+    }
 
-        public ProblemListenerAdapter(CndFileSystemProblemListener listener) {
-            listenerRef = new WeakReference<CndFileSystemProblemListener>(listener);
+    @Override
+    protected CndStatInfo getStatInfoImpl(FileObject fo) {
+       FileSystemProvider.Stat stat = FileSystemProvider.getStat(fo);
+       return stat.isValid() ? CndStatInfo.create(stat.device, stat.inode) : CndStatInfo.createInvalid();
+    }
+
+    @Override
+    protected InputStream getInputStreamImpl(FileObject fo, int maxSize) throws IOException {
+        return FileSystemProvider.getInputStream(fo, maxSize);
+    }
+
+    private static class ProblemListenerAdapter implements FileSystemProblemListener {
+
+        private final WeakReference<CndFileSystemProblemListener> listenerRef;
+        private final WeakReference<FileSystem> fileSystemRef;
+
+        public ProblemListenerAdapter(CndFileSystemProblemListener listener, FileSystem fileSystem) {
+            listenerRef = new WeakReference<>(listener);
+            fileSystemRef = (fileSystem == null) ? null : new WeakReference<>(fileSystem);
         }
 
         @Override
         public void problemOccurred(FileSystem fileSystem, String path) {
+            checkFileSystem(fileSystem);
             CndFileSystemProblemListener listener = listenerRef.get();
             if (listener != null) {
                 listener.problemOccurred(new FSPath(fileSystem, path));
@@ -388,11 +444,21 @@ public class CndFileSystemProviderImpl extends CndFileSystemProvider {
 
         @Override
         public void recovered(FileSystem fileSystem) {
+            checkFileSystem(fileSystem);
             CndFileSystemProblemListener listener = listenerRef.get();
             if (listener != null) {
                 listener.recovered(fileSystem);
             }
-        }        
+        }
+        
+        private void checkFileSystem(FileSystem fileSystem) {
+            if (fileSystemRef != null && CndUtils.isDebugMode()) {
+                FileSystem fs = fileSystemRef.get();
+                if (fs != null) {
+                    CndUtils.assertTrue(fs.equals(fileSystem), "Unexpected file system: " + fileSystem + " , expected " + fs); //NOI18N
+                }
+            }
+        }
     }
 
     private static class FileSystemAndString {
