@@ -23,7 +23,7 @@
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
  * "Portions Copyrighted [year] [name of copyright owner]"
- * 
+ *
  * If you wish your version of this file to be governed by only the CDDL
  * or only the GPL Version 2, indicate your decision by adding
  * "[Contributor] elects to include this software in this distribution
@@ -34,9 +34,9 @@
  * However, if you add GPL Version 2 code and therefore, elected the GPL
  * Version 2 license, then the option applies only if the new code is
  * made subject to such option by the copyright holder.
- * 
+ *
  * Contributor(s):
- * 
+ *
  * Portions Copyrighted 2008 Sun Microsystems, Inc.
  */
 package org.netbeans.modules.cnd.remote.mapper;
@@ -46,15 +46,18 @@ import java.awt.event.ActionListener;
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.File;
-import java.io.FileReader;
-import java.io.FileWriter;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.InputStreamReader;
+import java.io.OutputStreamWriter;
 import java.net.ConnectException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicReference;
 import javax.swing.Timer;
@@ -62,7 +65,6 @@ import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.cnd.api.remote.PathMap;
 import org.netbeans.modules.cnd.api.remote.ServerList;
 import org.netbeans.modules.cnd.api.utils.PlatformInfo;
-import org.netbeans.modules.cnd.remote.support.RemoteCommandSupport;
 import org.netbeans.modules.cnd.remote.ui.EditPathMapDialog;
 import org.netbeans.modules.cnd.spi.remote.setup.MirrorPathProvider;
 import org.netbeans.modules.cnd.utils.CndUtils;
@@ -70,6 +72,7 @@ import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager.CancellationException;
+import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
 import org.netbeans.modules.nativeexecution.api.util.WindowsSupport;
 import org.openide.util.Lookup;
 import org.openide.util.NbPreferences;
@@ -77,16 +80,16 @@ import org.openide.util.Utilities;
 
 /**
  * An implementation of PathMap which returns remote path information.
- * 
+ *
  * @author gordonp
  */
 public abstract class RemotePathMap extends PathMap {
 
     private final static Map<ExecutionEnvironment, Map<String, RemotePathMap>> fixedPathMaps =
-            new HashMap<ExecutionEnvironment, Map<String, RemotePathMap>>();
+            new HashMap<>();
 
     private final static Map<ExecutionEnvironment, Map<String, RemotePathMap>> customPathMaps =
-            new HashMap<ExecutionEnvironment, Map<String, RemotePathMap>>();
+            new HashMap<>();
 
 
     public static RemotePathMap getPathMap(ExecutionEnvironment env) {
@@ -103,14 +106,14 @@ public abstract class RemotePathMap extends PathMap {
         RemotePathMap pathmap = null;
         if (pathmaps == null) {
             synchronized (pmtable) {
-                pathmaps = new HashMap<String, RemotePathMap>();
+                pathmaps = new HashMap<>();
                 pmtable.put(env, pathmaps);
             }
         }
         pathmap = pathmaps.get(syncID);
-        if (pathmap == null) {            
+        if (pathmap == null) {
             synchronized (pmtable) {
-                pathmap = customizable ? new CustomizableRemotePathMap(env) : new FixedRemotePathMap(env);                
+                pathmap = customizable ? new CustomizableRemotePathMap(env) : new FixedRemotePathMap(env);
                 pathmaps.put(syncID, pathmap);
             }
         }
@@ -118,7 +121,7 @@ public abstract class RemotePathMap extends PathMap {
         return pathmap;
     }
 
-    protected final HashMap<String, String> map = new HashMap<String, String>();
+    protected final HashMap<String, String> map = new HashMap<>();
     protected final ExecutionEnvironment execEnv;
     protected volatile String localBase;
 
@@ -139,7 +142,7 @@ public abstract class RemotePathMap extends PathMap {
 
                     if (file.exists() && file.canRead()) {
                         try {
-                            BufferedReader in = new BufferedReader(new FileReader(file));
+                            BufferedReader in = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8")); // NOI18N
                             try {
                                 while ((line = in.readLine()) != null) {
                                     int pos = line.indexOf(' ');
@@ -170,17 +173,17 @@ public abstract class RemotePathMap extends PathMap {
             return true;
         }
     }
-    /** 
+    /**
      *
      * Initialization the path map here:
      */
     public abstract void initIfNeeded();
-    
+
     // PathMap
     @Override
     public String getRemotePath(String lpath, boolean useDefault) {
-        CndUtils.assertNotNull(lpath, "local path should not be null"); // nOI18N
         if (lpath == null) {
+            CndUtils.assertUnconditional("local path should not be null"); // nOI18N
             return null;
         }
         String ulpath = unifySeparators(lpath); // NB: adds a trailing slash
@@ -210,8 +213,8 @@ public abstract class RemotePathMap extends PathMap {
 
     @Override
     public String getLocalPath(String rpath, boolean useDefault) {
-        CndUtils.assertNotNull(rpath, "remote path should not be null"); // nOI18N
         if (rpath == null) {
+            CndUtils.assertUnconditional("remote path should not be null"); // nOI18N
             return null;
         }
         String urpath = unifySeparators(rpath); // NB: adds a trailing slash
@@ -225,7 +228,7 @@ public abstract class RemotePathMap extends PathMap {
                 }
                 return mpoint + rest;
             }
-        }        
+        }
         if (useDefault) {
             initLocalBase();
             return localBase  + '/' + rpath;
@@ -235,12 +238,12 @@ public abstract class RemotePathMap extends PathMap {
 
     @Override
     public String getTrueLocalPath(String rpath) {
-        return getLocalPath(rpath, false); 
+        return getLocalPath(rpath, false);
     }
 
     @Override
     public boolean checkRemotePaths(File[] localFiles, boolean fixMissingPaths) {
-        List<String> localPaths = new ArrayList<String>();
+        List<String> localPaths = new ArrayList<>();
         for (File file : localFiles) {
             if (file.isDirectory()) {
                 localPaths.add(file.getAbsolutePath());
@@ -253,7 +256,7 @@ public abstract class RemotePathMap extends PathMap {
         }
         // sort local paths so that if there are parent paths, they go first
         Collections.sort(localPaths);
-        List<String> invalidLocalPaths = new ArrayList<String>();
+        List<String> invalidLocalPaths = new ArrayList<>();
         for (String lPath : localPaths) {
             if (!checkRemotePath(lPath)) {
                 invalidLocalPaths.add(lPath);
@@ -283,8 +286,8 @@ public abstract class RemotePathMap extends PathMap {
 
 
     private boolean checkRemotePath(String lpath) {
-        CndUtils.assertNotNull(lpath, "local path should not be null"); // nOI18N
         if (lpath == null) {
+            CndUtils.assertUnconditional("local path should not be null"); // nOI18N
             return false;
         }
         String ulpath = unifySeparators(lpath);
@@ -326,7 +329,7 @@ public abstract class RemotePathMap extends PathMap {
             return;
         }
         synchronized( map ) {
-            Map<String, String> clone = new LinkedHashMap<String, String>(map);
+            Map<String, String> clone = new LinkedHashMap<>(map);
             clone.put(localParent,remoteParent);
             updatePathMapImpl(clone);
         }
@@ -368,12 +371,12 @@ public abstract class RemotePathMap extends PathMap {
             return path;
         }
     }
-    // inside path mapper we use only / and lowercase 
+    // inside path mapper we use only / and lowercase
     // TODO: lowercase should be only windows issue -- possible flaw
     private static String unifySeparators(String path) {
         String result = path.replace('\\', '/');
         if (!CndFileUtils.isSystemCaseSensitive()) {
-            result = result.toLowerCase();
+            result = result.toLowerCase(Locale.getDefault());
         }
         if (!result.endsWith("/")) { //NOI18N
             result = result + "/"; //NOI18N
@@ -414,7 +417,7 @@ public abstract class RemotePathMap extends PathMap {
         }
         return false;
     }
-    
+
     /**
      * Determines whether local and remote directories coincide,
      * i.e. map to the same physical directory
@@ -428,24 +431,26 @@ public abstract class RemotePathMap extends PathMap {
     public static boolean isTheSame(ExecutionEnvironment execEnv, String rpath, File path) throws InterruptedException {
         if (path.exists() && path.isDirectory()) {
             File validationFile = null;
+            BufferedWriter out = null;
             try {
                 // create file
                 validationFile = File.createTempFile("cnd", "tmp", path); // NOI18N
                 if (validationFile.exists()) {
-                    BufferedWriter out = new BufferedWriter(new FileWriter(validationFile));
+                    out = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(validationFile), "UTF-8")); // NOI18N
                     String validationLine = Double.toString(Math.random());
                     out.write(validationLine);
                     out.close();
+                    out = null;
 
-                    RemoteCommandSupport rcs = new RemoteCommandSupport(
-                            execEnv, "grep", null, // NOI18N
+                    ProcessUtils.ExitStatus rcs = ProcessUtils.execute(
+                            execEnv, "grep", // NOI18N
                             validationLine,
                             rpath + "/" + validationFile.getName()); // NOI18N
 
-                    if (rcs.run() == 0) {
+                    if (rcs.isOK()) {
                         return true;
                     }
-                    if (rcs.isCancelled() || rcs.isInterrupted()) {
+                    if (rcs.exitCode== -100) { // there is no official way to check for cancelled
                         throw new InterruptedException();
                     }
                 }
@@ -455,6 +460,12 @@ public abstract class RemotePathMap extends PathMap {
                 if (validationFile != null && validationFile.exists()) {
                     validationFile.delete(); // it isn\t worth removing RV FindBugs violation here
                 }
+                if (out != null) {
+                    try {
+                        out.close();
+                    } catch (IOException ex) {
+                    }
+                }
             }
         }
         return false;
@@ -494,7 +505,7 @@ public abstract class RemotePathMap extends PathMap {
                     if (!ConnectionManager.getInstance().isConnectedTo(execEnv)) {
                         return;
                     }
-                    final AtomicReference<Boolean> cancelled = new AtomicReference<Boolean>(Boolean.FALSE);
+                    final AtomicReference<Boolean> cancelled = new AtomicReference<>(Boolean.FALSE);
                     // 2. Automated mappings gathering entry point
                     final HostMappingsAnalyzer ham = new HostMappingsAnalyzer(execEnv);
                     Timer timer = new Timer(TIMEOUT, new ActionListener() {
@@ -517,12 +528,12 @@ public abstract class RemotePathMap extends PathMap {
             }
         }
     }
-        
+
     private static final String NO_MAPPING_PREFIX = "///"; // NOI18N
     private final static class FixedRemotePathMap extends RemotePathMap {
 
         private volatile String remoteBase;
-        
+
         private FixedRemotePathMap(ExecutionEnvironment exc) {
             super(exc);
             initRemoteBase(false);
@@ -532,7 +543,7 @@ public abstract class RemotePathMap extends PathMap {
         public void initIfNeeded() {
             // Fix for noIZ: IDE fails to build if -J-Dcnd.remote.sync.root is specified
             // Loading from prefs leads to incompatibility with MirrorPathProvider.getRemoteMirror,
-            // which is widely used 
+            // which is widely used
             //if (!loadFromPrefs()) {
                 if (remoteBase != null) {
                     super.addMappingImpl("/", remoteBase); // NOI18N
@@ -542,8 +553,8 @@ public abstract class RemotePathMap extends PathMap {
 
         @Override
         public String getRemotePath(String lpath, boolean useDefault) {
-            CndUtils.assertNotNull(lpath, "local path should not be null"); // nOI18N
             if (lpath == null) {
+                CndUtils.assertUnconditional("local path should not be null"); // nOI18N
                 return null;
             }
             initRemoteBase(true);
