@@ -23,7 +23,7 @@
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
  * "Portions Copyrighted [year] [name of copyright owner]"
- * 
+ *
  * If you wish your version of this file to be governed by only the CDDL
  * or only the GPL Version 2, indicate your decision by adding
  * "[Contributor] elects to include this software in this distribution
@@ -34,9 +34,9 @@
  * However, if you add GPL Version 2 code and therefore, elected the GPL
  * Version 2 license, then the option applies only if the new code is
  * made subject to such option by the copyright holder.
- * 
+ *
  * Contributor(s):
- * 
+ *
  * Portions Copyrighted 2008 Sun Microsystems, Inc.
  */
 package org.netbeans.modules.cnd.remote.server;
@@ -79,20 +79,23 @@ import org.openide.util.WeakListeners;
 
 /**
  * The cnd.remote implementation of ServerList.
- * 
+ *
  * @author gordonp
  */
 @org.openide.util.lookup.ServiceProvider(service = ServerListImplementation.class)
 public class RemoteServerList implements ServerListImplementation, ConnectionListener {
 
+    public static final boolean TRACE_SETUP = Boolean.getBoolean("cnd.remote.trace.setup"); //NOI18N
+    public static final String TRACE_SETUP_PREFIX = "#HostSetup"; //NOI18N
+
     private static final String CND_REMOTE = "cnd.remote"; // NOI18N
     private static final String REMOTE_SERVERS = CND_REMOTE + ".servers"; // NOI18N
     private static final String DEFAULT_RECORD = CND_REMOTE + ".defaultEnv"; // NOI18N
     private volatile RemoteServerRecord defaultRecord;
     private final PropertyChangeSupport pcs;
     private final ChangeSupport cs;
-    private final CopyOnWriteArrayList<RemoteServerRecord> unlisted = new CopyOnWriteArrayList<RemoteServerRecord>();
-    private final CopyOnWriteArrayList<RemoteServerRecord> items = new CopyOnWriteArrayList<RemoteServerRecord>();
+    private final CopyOnWriteArrayList<RemoteServerRecord> unlisted = new CopyOnWriteArrayList<>();
+    private final CopyOnWriteArrayList<RemoteServerRecord> items = new CopyOnWriteArrayList<>();
     private final Object lock = new Object();
     private static final RequestProcessor RP = new RequestProcessor("Remote setup", 1); // NOI18N
 
@@ -124,7 +127,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             defaultIndex = Math.min(defaultIndex, items.size() - 1);
             if (defaultIndex >= 0) {
                 defaultRecord = items.get(defaultIndex);
-            }            
+            }
         } else {
             ExecutionEnvironment defEnv = ExecutionEnvironmentFactory.fromUniqueID(defaultEnvId);
             for (RemoteServerRecord r : items) {
@@ -146,30 +149,34 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             public void run() {
                 checkSetup(env);
             }
-        });  
+        });
     }
 
     private void checkSetup(ExecutionEnvironment env) {
-        Collection<RemoteServerRecord> recordsToNotify = new ArrayList<RemoteServerRecord>();
+        Collection<RemoteServerRecord> recordsToNotify = new ArrayList<>();
         for (RemoteServerRecord rec : items) {
             if (rec.getExecutionEnvironment().equals(env)) {
-                recordsToNotify.add(rec);
+                if (rec.needsValidationOnConnect()) {
+                    recordsToNotify.add(rec);
+                }
             }
         }
         // previously, it was done by RemoteFileSupport, but it is moved to dlight.remote
         if (recordsToNotify.isEmpty()) {
             // inlined RemoteServerListUI.revalidate
-            ServerRecord record = get(env);
-            if (record.isDeleted()) {
-                addServer(record.getExecutionEnvironment(), record.getDisplayName(), record.getSyncFactory(), false, true);
-            } else if (!record.isOnline()) {
-                record.validate(true);
-            }            
+            RemoteServerRecord record = get(env);
+            if (record.needsValidationOnConnect()) {
+                if (record.isDeleted()) {
+                    addServer(record.getExecutionEnvironment(), record.getDisplayName(), record.getSyncFactory(), false, true);
+                } else if (!record.isOnline()) {
+                    record.validate(true);
+                }
+            }
         } else {
             for (RemoteServerRecord rec : recordsToNotify) {
                 rec.checkHostInfo();
             }
-        }        
+        }
     }
 
     @Override
@@ -178,12 +185,12 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
 
     /**
      * Get a ServerRecord pertaining to env. If needed, create the record.
-     * 
+     *
      * @param env specifies the host
      * @return A RemoteServerRecord for env
      */
     @Override
-    public ServerRecord get(ExecutionEnvironment env) {
+    public RemoteServerRecord get(ExecutionEnvironment env) {
         return get(env, true);
     }
 
@@ -200,7 +207,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             if (env.equals(record.getExecutionEnvironment())) {
                 return record;
             }
-        }        
+        }
         if (create) {
             CndUtils.assertNonUiThread();
             synchronized (lock) {
@@ -261,7 +268,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
 
     @Override
     public List<ExecutionEnvironment> getEnvironments() {
-        List<ExecutionEnvironment> result = new ArrayList<ExecutionEnvironment>(items.size());
+        List<ExecutionEnvironment> result = new ArrayList<>(items.size());
         for (RemoteServerRecord item : items) {
             result.add(item.getExecutionEnvironment());
         }
@@ -310,7 +317,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
                 record.setSyncFactory(syncFactory);
                 unlisted.remove(record);
             }
-            ArrayList<RemoteServerRecord> oldItems = new ArrayList<RemoteServerRecord>(items);
+            ArrayList<RemoteServerRecord> oldItems = new ArrayList<>(items);
             insert(items, record, RECORDS_COMPARATOR);
             if (asDefault) {
                 defaultRecord = record;
@@ -319,7 +326,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
                 refresh();
                 storePreferences();
                 getPreferences().put(DEFAULT_RECORD, ExecutionEnvironmentFactory.toUniqueID(defaultRecord.getExecutionEnvironment()));
-                firePropertyChange(ServerList.PROP_RECORD_LIST, oldItems, new ArrayList<RemoteServerRecord>(items));
+                firePropertyChange(ServerList.PROP_RECORD_LIST, oldItems, new ArrayList<>(items));
             }
             return record;
         }
@@ -371,7 +378,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             RemoteUtil.LOGGER.warning("Can not find RemoteServerList instance");
             return;
         }
-        List<RemoteServerRecord> records = new ArrayList<RemoteServerRecord>();
+        List<RemoteServerRecord> records = new ArrayList<>();
         for (RemoteServerRecord record : instance.items) {
             if (record.isRemote()) {
                 records.add(record);
@@ -384,10 +391,10 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
     public void set(List<ServerRecord> records, ServerRecord defaultRecord) {
         CndUtils.assertNonUiThread();
         synchronized (lock) {
-            ArrayList<RemoteServerRecord> oldItems = new ArrayList<RemoteServerRecord>(items);
+            ArrayList<RemoteServerRecord> oldItems = new ArrayList<>(items);
             RemoteUtil.LOGGER.log(Level.FINEST, "ServerList: set {0}", records);
             Collection<ExecutionEnvironment> removed = clear();
-            List<ExecutionEnvironment> allEnv = new ArrayList<ExecutionEnvironment>();
+            List<ExecutionEnvironment> allEnv = new ArrayList<>();
             for (ServerRecord rec : records) {
                 addServerImpl(rec.getExecutionEnvironment(), rec.getDisplayName(), rec.getSyncFactory(), false, false, false);
                 removed.remove(rec.getExecutionEnvironment());
@@ -397,7 +404,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             refresh();
             storePreferences();
             PasswordManager.getInstance().setServerList(allEnv);
-            firePropertyChange(ServerList.PROP_RECORD_LIST, oldItems, new ArrayList<RemoteServerRecord>(items));
+            firePropertyChange(ServerList.PROP_RECORD_LIST, oldItems, new ArrayList<>(items));
         }
     }
 
@@ -407,7 +414,7 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
     }
 
     private Collection<ExecutionEnvironment> clear() {
-        Collection<ExecutionEnvironment> removed = new ArrayList<ExecutionEnvironment>();
+        Collection<ExecutionEnvironment> removed = new ArrayList<>();
         CndUtils.assertNonUiThread();
         synchronized (lock) {
             for (RemoteServerRecord record : items) {
@@ -438,10 +445,10 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
         }
         if (SwingUtilities.isEventDispatchThread()) {
             RemoteUtil.LOGGER.warning("RemoteServerList.isValidExecutable from EDT"); // NOI18N
-        }        
+        }
         if (!CndPathUtilities.isPathAbsolute(path)) {
-            if (RemoteUtil.isWindows(env) ? 
-                    (path.contains("\\") | path.contains("/")) : //NOI18N
+            if (RemoteUtil.isWindows(env) ?
+                    (path.contains("\\") || path.contains("/")) : //NOI18N
                     path.contains("/")) { //NOI18N
                 // path contains slashes - don't call 'which'
                 return false;
@@ -451,10 +458,10 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
                 path = res.output;
             } else {
                 return false;
-            }            
+            }
         }
         try {
-            FileInfoProvider.StatInfo info = FileInfoProvider.stat(env, path, new PrintWriter(System.err)).get();
+            FileInfoProvider.StatInfo info = FileInfoProvider.stat(env, path).get();
             return info.canExecute(env);
         } catch (InterruptedException ex) {
             return false;
@@ -463,10 +470,10 @@ public class RemoteServerList implements ServerListImplementation, ConnectionLis
             return false;
         }
     }
-    
+
     @Override
     public Collection<? extends ServerRecord> getRecords() {
-        return new ArrayList<RemoteServerRecord>(items);
+        return new ArrayList<>(items);
     }
 
     // TODO: Are these still needed?
