@@ -81,7 +81,6 @@ import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
 import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
 import org.netbeans.modules.nativeexecution.api.util.ShellScriptRunner;
-import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.Utilities;
@@ -108,14 +107,14 @@ import org.openide.util.Utilities;
      * Maps remote canonical remote path remote controller operates with
      * to the absolute remote path local controller uses
      */
-    private final Map<String, String> canonicalToAbsolute = new HashMap<String, String>();
-    private final List<FileCollectorInfo> filesToFeed = new ArrayList<FileCollectorInfo>(512);
+    private final Map<String, String> canonicalToAbsolute = new HashMap<>();
+    private final List<FileCollectorInfo> filesToFeed = new ArrayList<>(512);
     private String timeStampFile;
 
-    private static final RequestProcessor RP = new RequestProcessor("RfsLocalController", 1); // NOI18N
+    private static final RequestProcessor RP = new RequestProcessor("FileCollector", 1); // NOI18N
 
     public FileCollector(File[] files, List<File> buildResults, RemoteUtil.PrefixedLogger logger, RemotePathMap mapper, SharabilityFilter filter,
-            FileData fileData, ExecutionEnvironment execEnv, PrintWriter err) {        
+            FileData fileData, ExecutionEnvironment execEnv, PrintWriter err) {
         this.files = new ArrayList<>(files.length);
         this.files.addAll(Arrays.asList(files));
         this.buildResults = new ArrayList<>(buildResults);
@@ -145,11 +144,11 @@ import org.openide.util.Utilities;
     }
 
     public void gatherFiles() {
-        long time = System.currentTimeMillis();        
+        long time = System.currentTimeMillis();
 
         // the set of top-level dirs
-        Set<File> topDirs = new HashSet<File>();
-        DupsPreventer<File> dupsPreventer = new DupsPreventer<File>();
+        Set<File> topDirs = new HashSet<>();
+        DupsPreventer<File> dupsPreventer = new DupsPreventer<>();
 
         for (File file : files) {
             file = CndFileUtils.normalizeFile(file);
@@ -234,7 +233,7 @@ import org.openide.util.Utilities;
 
 
     private Collection<File> gatherParents(Collection<File> files) {
-        Set<File> parents = new HashSet<File>();
+        Set<File> parents = new HashSet<>();
         for (File file : files) {
             gatherParents(file, parents);
         }
@@ -258,7 +257,7 @@ import org.openide.util.Utilities;
         // the real cycling check is inside checkLinks(List,List) logic
         int cnt = 0;
         final int max = 16;
-        Collection<FileCollectorInfo> filesToCheck = new ArrayList<FileCollectorInfo>(filesToFeed);
+        Collection<FileCollectorInfo> filesToCheck = new ArrayList<>(filesToFeed);
         do {
             filesToCheck = checkLinks(filesToCheck, filesToFeed);
         } while (!filesToCheck.isEmpty() && cnt++ < max);
@@ -269,7 +268,7 @@ import org.openide.util.Utilities;
     }
 
     private Collection<FileCollectorInfo> checkLinks(final Collection<FileCollectorInfo> filesToCheck, final List<FileCollectorInfo> filesToAdd) {
-        Set<FileCollectorInfo> addedInfos = new HashSet<FileCollectorInfo>();
+        Set<FileCollectorInfo> addedInfos = new HashSet<>();
         NativeProcessBuilder pb = NativeProcessBuilder.newLocalProcessBuilder();
         pb.setExecutable("sh"); //NOI18N
         pb.setArguments("-c", "xargs ls -ld | grep '^l'"); //NOI18N
@@ -284,8 +283,9 @@ import org.openide.util.Utilities;
         RP.post(new Runnable() {
             @Override
             public void run() {
-                BufferedWriter requestWriter = new BufferedWriter(new OutputStreamWriter(process.getOutputStream()));
+                BufferedWriter requestWriter = null;
                 try {
+                    requestWriter = new BufferedWriter(new OutputStreamWriter(process.getOutputStream(), "UTF-8")); //NOI18N
                     for (FileCollectorInfo info : filesToCheck) {
                         String path = "\"" + info.file.getAbsolutePath() + "\""; // NOI18N
                         requestWriter.append(path);
@@ -294,42 +294,48 @@ import org.openide.util.Utilities;
                 } catch (IOException ex) {
                     ex.printStackTrace(System.err);
                 } finally {
-                    try {
-                        requestWriter.close();
-                    } catch (IOException ex) {
-                        ex.printStackTrace(System.err);
+                    if (requestWriter != null) {
+                        try {
+                            requestWriter.close();
+                        } catch (IOException ex) {
+                            ex.printStackTrace(System.err);
+                        }
                     }
                 }
             }
         });
 
         RP.post(new Runnable() {
-            private final BufferedReader errorReader = new BufferedReader(new InputStreamReader(process.getErrorStream()));
             @Override
             public void run() {
+                BufferedReader errorReader = null;
                 try {
+                    errorReader = new BufferedReader(new InputStreamReader(process.getErrorStream(), "UTF-8")); //NOI18N
                     for (String errLine = errorReader.readLine(); errLine != null; errLine = errorReader.readLine()) {
                         logger.log(Level.INFO, errLine);
                     }
                 } catch (IOException ex) {
                     ex.printStackTrace(System.err);
                 } finally {
-                    try {
-                        errorReader.close();
-                    } catch (IOException ex) {
-                        ex.printStackTrace(System.err);
+                    if (errorReader != null) {
+                        try {
+                            errorReader.close();
+                        } catch (IOException ex) {
+                            ex.printStackTrace(System.err);
+                        }
                     }
                 }
             }
         });
 
-        Map<String, FileCollectorInfo> map = new HashMap<String, FileCollectorInfo>(filesToCheck.size());
+        Map<String, FileCollectorInfo> map = new HashMap<>(filesToCheck.size());
         for (FileCollectorInfo info : filesToCheck) {
             map.put(info.file.getAbsolutePath(), info);
         }
 
-        BufferedReader outputReader = new BufferedReader(new InputStreamReader(process.getInputStream()));
+        BufferedReader outputReader = null;
         try {
+            outputReader = new BufferedReader(new InputStreamReader(process.getInputStream(), "UTF-8")); //NOI18N
             boolean errorReported = false;
             for (String line = outputReader.readLine(); line != null; line = outputReader.readLine()) {
                 // line format is:
@@ -382,9 +388,16 @@ import org.openide.util.Utilities;
         } catch (InterruptedException ex) {
             // don't report InterruptedException
         }
+        if (outputReader != null) {
+            try {
+                outputReader.close();
+            } catch (IOException ex) {
+                ex.printStackTrace(System.err);
+            }
+        }
         return addedInfos;
     }
-    
+
     private boolean isBsdBased() {
         HostInfo.OSFamily os;
         try {
@@ -424,7 +437,7 @@ import org.openide.util.Utilities;
             String errMsg = NbBundle.getMessage(getClass(), "MSG_Error_Running_Command", "mktemp -p " + remoteSyncRoot, execEnv, res.error, res.exitCode);
             logger.log(Level.INFO, errMsg);
             if (err != null) {
-                err.printf("%s\n", errMsg); // NOI18N
+                err.printf("%s%n", errMsg); // NOI18N
             }
             return false;
         }
@@ -442,7 +455,7 @@ import org.openide.util.Utilities;
         remoteUpdates.add(localFile);
     }
 
-    public void shutDownNewFilesDiscovery() {        
+    public void shutDownNewFilesDiscovery() {
         try {
             if (!remoteUpdates.isEmpty()) {
                 HostUpdates.register(remoteUpdates, execEnv, fileData.getDataFile().getParent());
@@ -471,11 +484,11 @@ import org.openide.util.Utilities;
         int oldSize = remoteUpdates.size();
 
         StringBuilder remoteDirs = new StringBuilder();
-        
+
         List<File> filesAndBuildResults = new ArrayList<>(files.size()+ buildResults.size());
         filesAndBuildResults.addAll(files);
         filesAndBuildResults.addAll(buildResults);
-        
+
         for (File file : filesAndBuildResults) {
             if (file.isDirectory() || buildResults.contains(file)) {
                 String rPath = mapper.getRemotePath(file.getAbsolutePath(), false);
@@ -494,7 +507,7 @@ import org.openide.util.Utilities;
 
         StringBuilder extOptions = new StringBuilder();
         if (srcOnly) {
-            Collection<Collection<String>> values = new ArrayList<Collection<String>>();
+            Collection<Collection<String>> values = new ArrayList<>();
             values.add(MIMEExtensions.get(MIMENames.C_MIME_TYPE).getValues());
             values.add(MIMEExtensions.get(MIMENames.CPLUSPLUS_MIME_TYPE).getValues());
             values.add(MIMEExtensions.get(MIMENames.HEADER_MIME_TYPE).getValues());
