@@ -54,7 +54,6 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
-import org.netbeans.modules.cnd.api.remote.PathMap;
 import org.netbeans.modules.cnd.api.remote.RemoteSyncWorker;
 import org.netbeans.modules.cnd.api.remote.ServerList;
 import org.netbeans.modules.cnd.remote.mapper.RemotePathMap;
@@ -74,7 +73,6 @@ import org.netbeans.modules.nativeexecution.api.NativeProcessBuilder;
 import org.netbeans.modules.nativeexecution.api.util.CommonTasksSupport;
 import org.netbeans.modules.nativeexecution.api.util.CommonTasksSupport.UploadStatus;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
-import org.netbeans.modules.nativeexecution.api.util.MacroMap;
 import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
 import org.openide.filesystems.FileObject;
 import org.openide.util.Cancellable;
@@ -102,8 +100,8 @@ import org.openide.util.RequestProcessor;
     private final RequestProcessor RP = new RequestProcessor("FtpSyncWorker", 3); // NOI18N
 
     private static final boolean HARD_CODED_FILTER = Boolean.valueOf(System.getProperty("cnd.remote.hardcoded.filter", "true")); //NOI18N
-    
-    public FtpSyncWorker(ExecutionEnvironment executionEnvironment, PrintWriter out, PrintWriter err, 
+
+    public FtpSyncWorker(ExecutionEnvironment executionEnvironment, PrintWriter out, PrintWriter err,
             FileObject privProjectStorageDir, List<FSPath> paths, List<FSPath> buildResults) {
         super(executionEnvironment, out, err, privProjectStorageDir, paths, buildResults);
         this.mapper = RemotePathMap.getPathMap(executionEnvironment);
@@ -123,11 +121,8 @@ import org.openide.util.RequestProcessor;
         return sb;
     }
 
-    private boolean needsCopying(FileCollector.FileCollectorInfo collectorInfo) {
+    private boolean isIgnored(FileCollector.FileCollectorInfo collectorInfo) {
         final File file = collectorInfo.file;
-        if (!file.exists()) {
-            return false;
-        }
         if (HARD_CODED_FILTER) {
             // Filter out configurations.xml, timestamps, etc
             // Auto-copy would never request these; but FTP will copy, unless filtered out
@@ -136,19 +131,29 @@ import org.openide.util.RequestProcessor;
                 if (parent.getName().equals("nbproject")) { // NOI18N
                     // we never need configuratins.xml for build purposes; however it might be quite large
                     if (file.getName().equals("configurations.xml")) { // NOI18N
-                        return false;
+                        return true;
                     }
                 } else if (parent.getName().equals("private")) { // NOI18N
                     File granpa = parent.getParentFile();
                     if (granpa.getName().equals("nbproject")) { // NOI18N
                         if (!file.getName().endsWith(".mk") && !file.getName().endsWith(".sh") && !file.getName().endsWith(".bash")) { // NOI18N
-                            return false;
+                            return true;
                         }
                     }
                 }
             }
         }
+        return false;
+    }
 
+    private boolean needsCopying(FileCollector.FileCollectorInfo collectorInfo) {
+        final File file = collectorInfo.file;
+        if (!file.exists()) {
+            return false;
+        }
+        if (isIgnored(collectorInfo)) {
+            return false;
+        }
         FileData.FileStateInfo stateInfo = fileData.getFileInfo(file);
         FileState state = (stateInfo == null) ? FileState.INITIAL : stateInfo.state;
         switch (state) {
@@ -156,6 +161,7 @@ import org.openide.util.RequestProcessor;
             case TOUCHED:       return true;
             case COPIED:        return stateInfo.timestamp != file.lastModified();
             case ERROR:         return true;
+            case INEXISTENT:    return false;
             case UNCONTROLLED:  return false;
             default:
                 CndUtils.assertTrue(false, "Unexpected state: " + state); //NOI18N
@@ -171,7 +177,7 @@ import org.openide.util.RequestProcessor;
 
         uploadCount = 0;
         uploadSize = 0;
-        
+
         RemoteLogger.fine("Uploading {0} to {1} ...\n", getLocalFilesString(), executionEnvironment); // NOI18N
         long time = System.currentTimeMillis();
 
@@ -218,7 +224,7 @@ import org.openide.util.RequestProcessor;
             throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_NewFilesDiscovery"));
         }
         time2 = System.currentTimeMillis();
-        
+
         if (CndUtils.getBoolean("cnd.remote.zip", true)) {
             try {
                 uploadPlainFilesInZip(remoteRoot);
@@ -244,7 +250,7 @@ import org.openide.util.RequestProcessor;
 
         out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_Done"));
         out.println();
-        
+
         if (RemoteLogger.getInstance().isLoggable(Level.FINE)) {
             time = System.currentTimeMillis() - time;
             long bps = uploadSize * 1000L / time;
@@ -265,9 +271,7 @@ import org.openide.util.RequestProcessor;
         void processLine(String line);
     }
 
-    private void launchAndFeed(final Feeder feeder, 
-            final LineProcessor outProcessor, final LineProcessor errProcessor,
-            String command, String... args) throws IOException {
+    private void launchAndFeed(final Feeder feeder, final LineProcessor outProcessor, final LineProcessor errProcessor, boolean throwUponFailure, String command, String... args) throws IOException {
 
         if (cancelled) {
             return;
@@ -277,32 +281,36 @@ import org.openide.util.RequestProcessor;
         pb.setArguments(args);
         final NativeProcess process;
         process = pb.call();
- 
+
         final AtomicReference<IOException> problem = new AtomicReference<>();
 
         RP.post(new Runnable() {
             @Override
             public void run() {
-                BufferedWriter requestWriter = new BufferedWriter(new OutputStreamWriter(process.getOutputStream()));
+                BufferedWriter requestWriter = null;
                 try {
+                    requestWriter = new BufferedWriter(new OutputStreamWriter(process.getOutputStream(), "UTF-8")); //NOI18N
                     feeder.feed(requestWriter);
                 } catch (IOException ex) {
                     problem.set(ex);
                 } finally {
-                    try {
-                        requestWriter.close();
-                    } catch (IOException ex) {
-                        problem.set(ex);
+                    if (requestWriter != null) {
+                        try {
+                            requestWriter.close();
+                        } catch (IOException ex) {
+                            problem.set(ex);
+                        }
                     }
                 }
             }
         });
 
         RP.post(new Runnable() {
-            private final BufferedReader errorReader = new BufferedReader(new InputStreamReader(process.getErrorStream()));
             @Override
             public void run() {
+                BufferedReader errorReader = null;
                 try {
+                    errorReader = new BufferedReader(new InputStreamReader(process.getErrorStream(), "UTF-8")); //NOI18N
                     for (String errLine = errorReader.readLine(); errLine != null; errLine = errorReader.readLine()) {
                         if (errProcessor != null) {
                             errProcessor.processLine(errLine);
@@ -313,20 +321,23 @@ import org.openide.util.RequestProcessor;
                 } catch (IOException ex) {
                     problem.set(ex);
                 } finally {
-                    try {
-                        errorReader.close();
-                    } catch (IOException ex) {
-                        problem.set(ex);
+                    if (errorReader != null) {
+                        try {
+                            errorReader.close();
+                        } catch (IOException ex) {
+                            problem.set(ex);
+                        }
                     }
                 }
             }
         });
 
         RP.post(new Runnable() {
-            private final BufferedReader outputReader = new BufferedReader(new InputStreamReader(process.getInputStream()));
             @Override
             public void run() {
+                BufferedReader outputReader = null;
                 try {
+                    outputReader = new BufferedReader(new InputStreamReader(process.getInputStream(), "UTF-8")); //NOI18N
                     for (String errLine = outputReader.readLine(); errLine != null; errLine = outputReader.readLine()) {
                         if (outProcessor != null) {
                             outProcessor.processLine(errLine);
@@ -337,10 +348,12 @@ import org.openide.util.RequestProcessor;
                 } catch (IOException ex) {
                     problem.set(ex);
                 } finally {
-                    try {
-                        outputReader.close();
-                    } catch (IOException ex) {
-                        problem.set(ex);
+                    if (outputReader != null) {
+                        try {
+                            outputReader.close();
+                        } catch (IOException ex) {
+                            problem.set(ex);
+                        }
                     }
                 }
             }
@@ -351,14 +364,14 @@ import org.openide.util.RequestProcessor;
         }
         try {
             int rc = process.waitFor();
-            if (rc != 0) {
+            if (rc != 0 && throwUponFailure) {
                 throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_NonzeroRC", command, rc));
             }
         } catch (InterruptedException ex) {
             throw new InterruptedIOException();
         }
     }
-    
+
     private void createDirs() throws IOException {
         final List<String> dirsToCreate = new LinkedList<>();
         for (FileCollector.FileCollectorInfo fileInfo : fileCollector.getFiles()) {
@@ -381,12 +394,12 @@ import org.openide.util.RequestProcessor;
                         if (cancelled) {
                             throw new InterruptedIOException();
                         }
-                        requestWriter.append(dir).append(' ');
+                        requestWriter.append('"').append(dir).append('"').append(' '); // NOI18N
                     }
                 }
             };
             try {
-                launchAndFeed(feeder, null, null, "xargs", "mkdir", "-p"); // NOI18N
+                launchAndFeed(feeder, null, null, true, "xargs", "mkdir", "-p"); // NOI18N
             } catch (InterruptedIOException ex) {
                 throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_Canceled"));
             } catch (IOException ex) {
@@ -401,7 +414,7 @@ import org.openide.util.RequestProcessor;
     private void addExecPermissions() throws IOException {
         final List<String> filesToAdd = new LinkedList<>();
         for (FileCollector.FileCollectorInfo fileInfo : fileCollector.getFiles()) {
-            if (!fileInfo.file.isDirectory() && fileInfo.file.canExecute()) {
+            if (!fileInfo.file.isDirectory() && fileInfo.file.canExecute() && !isIgnored(fileInfo)) {
                 String remotePath = mapper.getRemotePath(fileInfo.file.getAbsolutePath(), true);
                 CndUtils.assertNotNull(remotePath, "null remote file for " + fileInfo.file.getAbsolutePath()); //NOI18N
                 if (remotePath != null) {
@@ -420,12 +433,13 @@ import org.openide.util.RequestProcessor;
                         if (cancelled) {
                             throw new InterruptedIOException();
                         }
-                        requestWriter.append(dir).append(' ');
+                        requestWriter.append('"').append(dir).append('"').append(' '); // NOI18N
                     }
                 }
             };
             try {
-                launchAndFeed(feeder, null, null, "xargs", "chmod", "+x"); // NOI18N
+                // chomod +x could fail in some situations, which does not necessarily mean that we can't build
+                launchAndFeed(feeder, null, null, false, "xargs", "chmod", "+x"); // NOI18N
             } catch (InterruptedIOException ex) {
                 throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_Canceled"));
             } catch (IOException ex) {
@@ -474,7 +488,7 @@ import org.openide.util.RequestProcessor;
                                 } else { // this never happens since mapper is fixed, but however:
                                     if (!mapErrorReported && CndUtils.isDebugMode()) {
                                         mapErrorReported = true;
-                                        CndUtils.assertNotNull(remotePath, "null remote file for " + collectorInfo.file.getAbsolutePath()); //NOI18N
+                                        CndUtils.assertUnconditional("null remote file for " + collectorInfo.file.getAbsolutePath()); //NOI18N
                                     }
                                 }
                             }
@@ -494,7 +508,7 @@ import org.openide.util.RequestProcessor;
                 } else {
                     if (!mapErrorReported && CndUtils.isDebugMode()) { // should never be the case
                         mapErrorReported = true;
-                        CndUtils.assertNotNull(localPath, "null local file for " + line); //NOI18N
+                        CndUtils.assertUnconditional("null local file for " + line); //NOI18N
                     }
                 }
                 //fileData.setState(new File, ERROR);
@@ -502,7 +516,7 @@ import org.openide.util.RequestProcessor;
         };
 
         try {
-            launchAndFeed(feeder, outProcessor, null, "sh", "-s"); // NOI18N
+            launchAndFeed(feeder, outProcessor, null, true, "sh", "-s"); // NOI18N
         } catch (InterruptedIOException ex) {
             throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_Canceled"));
         } catch (IOException ex) {
@@ -540,7 +554,7 @@ import org.openide.util.RequestProcessor;
             }
         };
         try {
-            launchAndFeed(feeder, null, null, "sh", "-s"); // NOI18N
+            launchAndFeed(feeder, null, null, true, "sh", "-s"); // NOI18N
         } catch (InterruptedIOException ex) {
             throw new IOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_Canceled"));
         } catch (IOException ex) {
@@ -574,7 +588,7 @@ import org.openide.util.RequestProcessor;
             if (cancelled) {
                 return;
             }
-            if (!fileInfo.isLink() && !fileInfo.file.isDirectory()) {                
+            if (!fileInfo.isLink() && !fileInfo.file.isDirectory()) {
                 if (needsCopying(fileInfo)) {
                     File srcFile = fileInfo.file;
                     progressHandle.progress(srcFile.getAbsolutePath());
@@ -590,8 +604,8 @@ import org.openide.util.RequestProcessor;
                             err.println(uploadStatus.getError());
                         }
                         throw new IOException(
-                                NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_UploadFile", 
-                                        srcFile, executionEnvironment, remotePath, 
+                                NbBundle.getMessage(FtpSyncWorker.class, "FTP_Msg_Err_UploadFile",
+                                        srcFile, executionEnvironment, remotePath,
                                         uploadStatus.getExitCode()));
                     }
                 }
@@ -607,11 +621,11 @@ import org.openide.util.RequestProcessor;
     }
 
     private void uploadPlainFilesInZip(String remoteRoot) throws InterruptedException, ExecutionException, IOException {
-    
+
         out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_UploadFilesInZip"));
-        
+
         List<FileCollector.FileCollectorInfo> toCopy = new ArrayList<>();
-        
+
         for (FileCollector.FileCollectorInfo fileInfo : fileCollector.getFiles()) {
             if (cancelled) {
                 throw new InterruptedException();
@@ -622,19 +636,19 @@ import org.openide.util.RequestProcessor;
                 }
             }
         }
-        
+
         if (toCopy.isEmpty()) {
             return;
         }
-        
-        out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_Zipping", toCopy.size()));  
-        progressHandle.progress(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Progress_Zipping"));            
+
+        out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_Zipping", toCopy.size()));
+        progressHandle.progress(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Progress_Zipping"));
         File zipFile = null;
         String remoteFile = null;
         try  {
             String localFileName = files[0].getName();
             if (localFileName.length() < 3) {
-                localFileName = localFileName + ((localFileName.length() == 1) ? "_" : "__"); //NOI18N
+                localFileName = localFileName + ((localFileName.length() == 1) ? "__" : "_"); //NOI18N
             }
             zipFile = File.createTempFile(localFileName, ".zip", getTemp()); // NOI18N
             Zipper zipper = new Zipper(zipFile);
@@ -671,7 +685,7 @@ import org.openide.util.RequestProcessor;
             if (cancelled) {
                 throw new InterruptedException();
             }
- 
+
             out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_UploadingZip", executionEnvironment));
             progressHandle.progress(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Progress_UploadingZip"));
             remoteFile = remoteRoot + '/' + zipFile.getName(); //NOI18N
@@ -680,18 +694,18 @@ import org.openide.util.RequestProcessor;
                 Future<UploadStatus> upload = CommonTasksSupport.uploadFile(zipFile.getAbsolutePath(), executionEnvironment, remoteFile, 0600);
                 UploadStatus uploadStatus = upload.get();
                 RemoteLogger.fine("SFTP/ZIP:  uploading {0}to {1}:{2} finished in {3} ms with rc={4}", //NOI18N
-                        zipFile, executionEnvironment, remoteFile, 
+                        zipFile, executionEnvironment, remoteFile,
                         System.currentTimeMillis()-uploadStart, uploadStatus.getExitCode());
                 if (!uploadStatus.isOK()) {
                     throw new IOException(uploadStatus.getError());
                 }
             }
-            
+
             if (cancelled) {
                 throw new InterruptedException();
             }
 
-            out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_Unzipping", executionEnvironment));  
+            out.println(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Message_Unzipping", executionEnvironment));
             progressHandle.progress(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Progress_Unzipping"),
                     (uploadCount += (toCopy.size()/3)));
             {
@@ -701,37 +715,23 @@ import org.openide.util.RequestProcessor;
                 pb.setExecutable("unzip"); // NOI18N
                 pb.setArguments("-oqq", remoteFile); // NOI18N
                 pb.setWorkingDirectory(remoteRoot);
-                Process proc = pb.call();
-                String line;
-
-                BufferedReader inReader = new BufferedReader(new InputStreamReader(proc.getInputStream()));
-                try {
-                    while ((line = inReader.readLine()) != null) {
-                        if (RemoteUtil.LOGGER.isLoggable(Level.FINEST)) {
-                            System.out.printf("\tunzip: %s\n", line); // NOI18N
-                        } //NOI18N
+                ProcessUtils.ExitStatus status = ProcessUtils.execute(pb);
+                if (RemoteUtil.LOGGER.isLoggable(Level.FINEST) && !status.output.isEmpty()) {
+                    for(String s : status.output.split("\n")) { // NOI18N
+                        System.out.printf("\tunzip: %s%n", s); // NOI18N
                     }
-                } finally {
-                    inReader.close();
                 }
-
-                BufferedReader errReader = new BufferedReader(new InputStreamReader(proc.getErrorStream()));
-                try {
-                    while ((line = errReader.readLine()) != null) {
-                        err.printf("unzip: %s\n", line); //NOI18N
+                if (!status.error.isEmpty()) {
+                    for(String s : status.error.split("\n")) { // NOI18N
+                        err.printf("unzip: %s%n", s); //NOI18N
                     }
-                } finally {
-                    errReader.close();
                 }
-
-                int rc = proc.waitFor();
-                
                 RemoteLogger.fine("SFTP/ZIP: Unzipping {0}:{1} finished in {2} ms; rc={3}", // NOI18N
-                        executionEnvironment , remoteFile, System.currentTimeMillis()-unzipTime, rc); 
-            
-                if (rc != 0) {
+                        executionEnvironment , remoteFile, System.currentTimeMillis()-unzipTime, status.exitCode);
+
+                if (status.exitCode != 0) {
                     throw new ZipIOException(NbBundle.getMessage(FtpSyncWorker.class, "FTP_Err_Unzip",
-                            remoteFile, executionEnvironment, rc)); // NOI18N
+                            remoteFile, executionEnvironment, status.exitCode)); // NOI18N
                 }
                 for (FileCollector.FileCollectorInfo fileInfo : toCopy) {
                     fileData.setState(fileInfo.file, FileState.COPIED);
@@ -749,7 +749,7 @@ import org.openide.util.RequestProcessor;
         }
         progressHandle.progress(uploadCount += (toCopy.size()/3));
     }
-    
+
     @Override
     public boolean startup(Map<String, String> env2add) {
 
@@ -762,7 +762,7 @@ import org.openide.util.RequestProcessor;
         String remoteRoot = RemotePathMap.getRemoteSyncRoot(executionEnvironment);
         if (remoteRoot == null) {
             if (err != null) {
-                err.printf("%s\n", NbBundle.getMessage(getClass(), "MSG_Cant_find_sync_root", ServerList.get(executionEnvironment).toString()));
+                err.printf("%s%n", NbBundle.getMessage(getClass(), "MSG_Cant_find_sync_root", ServerList.get(executionEnvironment).toString()));
             }
             return false; // TODO: error processing
         }
@@ -776,7 +776,7 @@ import org.openide.util.RequestProcessor;
         progressHandle.start();
         try {
             if (out != null) {
-                out.printf("%s\n", NbBundle.getMessage(getClass(), "MSG_Copying",
+                out.printf("%s%n", NbBundle.getMessage(getClass(), "MSG_Copying",
                         remoteRoot, ServerList.get(executionEnvironment).toString()));
             }
             synchronizeImpl(remoteRoot);
@@ -793,13 +793,13 @@ import org.openide.util.RequestProcessor;
         } catch (ExecutionException ex) {
             RemoteUtil.LOGGER.log(Level.FINE, null, ex);
             if (err != null) {
-                err.printf("%s\n", NbBundle.getMessage(getClass(), "MSG_Error_Copying",
+                err.printf("%s%n", NbBundle.getMessage(getClass(), "MSG_Error_Copying",
                         remoteRoot, ServerList.get(executionEnvironment).toString(), ex.getLocalizedMessage()));
             }
         } catch (IOException ex) {
             RemoteUtil.LOGGER.log(Level.FINE, null, ex);
             if (err != null) {
-                err.printf("%s\n", NbBundle.getMessage(getClass(), "MSG_Error_Copying",
+                err.printf("%s%n", NbBundle.getMessage(getClass(), "MSG_Error_Copying",
                         remoteRoot, ServerList.get(executionEnvironment).toString(), ex.getLocalizedMessage()));
             }
         } catch (ConnectionManager.CancellationException ex) {
@@ -833,10 +833,10 @@ import org.openide.util.RequestProcessor;
         }
         return true;
     }
-    
+
     private static File getTemp() {
         String tmpPath = System.getProperty("java.io.tmpdir");
         File tmpFile = CndFileUtils.createLocalFile(tmpPath);
         return tmpFile.exists() ? tmpFile : null;
-    }    
+    }
 }
