@@ -257,7 +257,7 @@ import org.openide.util.RequestProcessor;
         String versionsPattern = "VERSIONS "; // NOI18N
         if (!versionsString.startsWith(versionsPattern)) {
             if (err != null) {
-                err.printf("Protocol error, expected %s, got %s\n", versionsPattern, versionsString); //NOI18N
+                err.printf("Protocol error, expected %s, got %s%n", versionsPattern, versionsString); //NOI18N
             }
             return false;
         }
@@ -265,7 +265,7 @@ import org.openide.util.RequestProcessor;
         for (String v : versionsArray) {
             if (v.length() != 1) {
                 if (err != null) {
-                    err.printf("Protocol error: incorrect version format: %s\n", versionsString); //NOI18N
+                    err.printf("Protocol error: incorrect version format: %s%n", versionsString); //NOI18N
                 }
                 return false;
             }
@@ -283,13 +283,13 @@ import org.openide.util.RequestProcessor;
     private static class FormatException extends Exception {
         public FormatException(String message) {
             super(message);
-        }        
+        }
         public FormatException(String message, Throwable cause) {
             super(message, cause);
-        }        
+        }
     }
 
-    private long getTimeSkew() throws IOException, CancellationException, FormatException {        
+    private long getTimeSkew() throws IOException, CancellationException, FormatException {
         final int cnt = 10;
         responseStream.printf("SKEW_COUNT=%d\n", cnt); //NOI18N
         responseStream.flush();
@@ -309,17 +309,17 @@ import org.openide.util.RequestProcessor;
         }
         responseStream.printf("SKEW_END\n"); //NOI18N
         responseStream.flush();
-        
+
         long skew = 0;
         for (int i = 0; i < cnt; i++) {
             skew += deltas[i];
         }
         skew /= cnt;
-        
+
         String line = requestReader.readLine();
         if (!line.startsWith("FS_SKEW ")) { //NOI18N
             throw new FormatException("Wrong file system skew response: " + line); //NOI18N
-        }   
+        }
         try {
             long fsSkew = Long.parseLong(line.substring(8));
             fsSkew /=  1000;
@@ -337,14 +337,14 @@ import org.openide.util.RequestProcessor;
      * @return true in the case of success, otherwise false
      * NB: in the case false is returned, no shutdown will be called
      */
-    boolean init() throws IOException, CancellationException {        
+    boolean init() throws IOException, CancellationException {
         if (!checkVersion()) {
             return false;
         }
         logger.log(Level.FINE, "Initialization. Version=%c", VERSION);
         if (CHECK_ALIVE && !remoteController.isAlive()) { // fixup for remote tests unstable failure (caused by jsch issue)
             if (err != null) {
-                err.printf("Process exited unexpectedly when initializing\n"); //NOI18N
+                err.printf("Process exited unexpectedly when initializing%n"); //NOI18N
             }
             return false;
         }
@@ -356,11 +356,11 @@ import org.openide.util.RequestProcessor;
             clockSkew = getTimeSkew();
             if (logger .isLoggable(Level.FINE)) {
                 logger .log(Level.FINE, "HostInfo skew=%d calculated skew=%d", //NOI18N
-                        new Object[]{HostInfoUtils.getHostInfo(execEnv).getClockSkew(), clockSkew}); 
+                        new Object[]{HostInfoUtils.getHostInfo(execEnv).getClockSkew(), clockSkew});
             }
         } catch (FormatException ex) {
             if (err != null) {
-                err.printf("protocol error: %s\n", ex.getMessage()); // NOI18N
+                err.printf("protocol error: %s%n", ex.getMessage()); // NOI18N
             }
             return false;
         }
@@ -375,14 +375,14 @@ import org.openide.util.RequestProcessor;
                 sendFileInitRequest(info, clockSkew);
             } catch (IOException ex) {
                 if (err != null) {
-                    err.printf("Process exited unexpectedly while file info was being sent\n"); //NOI18N
+                    err.printf("Process exited unexpectedly while file info was being sent%n"); //NOI18N
                 }
                 return false;
             }
         }
         if (CHECK_ALIVE && !remoteController.isAlive()) { // fixup for remote tests unstable failure (caused by jsch issue)
             if (err != null) {
-                err.printf("Process exited unexpectedly\n"); //NOI18N
+                err.printf("Process exited unexpectedly%n"); //NOI18N
             }
             return false;
         }
@@ -396,7 +396,7 @@ import org.openide.util.RequestProcessor;
             logger.log(Level.FINE, "reading initial response took %d ms", System.currentTimeMillis() - time);
         } catch (IOException ex) {
             if (err != null) {
-                err.printf("%s\n", ex.getMessage());
+                err.printf("%s%n", ex.getMessage());
                 return false;
             }
         }
@@ -498,7 +498,7 @@ import org.openide.util.RequestProcessor;
                     newState = FileState.UNCONTROLLED;
                 } else {
                     newState = FileState.INEXISTENT;
-                }            
+                }
             }
             CndUtils.assertTrue(newState == FileState.INITIAL || newState == FileState.COPIED
                     || newState == FileState.TOUCHED || newState == FileState.UNCONTROLLED
