@@ -137,7 +137,7 @@ public class RemoteBuildTestBase extends RemoteTestBase {
         assertNotNull("FileObject for " + name + " sample not found", templateFO);
         final DataObject templateDO = DataObject.find(templateFO);
         assertNotNull("DataObject for " + name + " sample not found", templateDO);
-        final AtomicReference<IOException> exRef = new AtomicReference<IOException>();
+        final AtomicReference<IOException> exRef = new AtomicReference<>();
         SwingUtilities.invokeAndWait(new Runnable() {
             @Override
             public void run() {
@@ -145,9 +145,9 @@ public class RemoteBuildTestBase extends RemoteTestBase {
                 TemplateWizard wiz = new TemplateWizard();
                 wiz.setTemplate(templateDO);
                 projectCreator.initialize(wiz);
-                wiz.putProperty(WizardConstants.PROPERTY_NAME, destdir.getName());
+                WizardConstants.PROPERTY_NAME.put(wiz, destdir.getName());
                 ExecutionEnvironment ee = ExecutionEnvironmentFactory.getLocal();
-                wiz.putProperty(WizardConstants.PROPERTY_PROJECT_FOLDER, 
+                WizardConstants.PROPERTY_PROJECT_FOLDER.put(wiz, 
                     new FSPath(FileSystemProvider.getFileSystem(ee), RemoteFileUtil.normalizeAbsolutePath(destdir.getAbsolutePath(), ee)));
                 try {
                     projectCreator.instantiate();
@@ -164,7 +164,7 @@ public class RemoteBuildTestBase extends RemoteTestBase {
 
     @Override
     protected List<Class<?>> getServices() {
-        List<Class<?>> list = new ArrayList<Class<?>>();
+        List<Class<?>> list = new ArrayList<>();
         list.add(MakeProjectTypeImpl.class);
         list.addAll(super.getServices());
         return list;
@@ -363,9 +363,21 @@ public class RemoteBuildTestBase extends RemoteTestBase {
         buildSample(sync, toolchain, sampleName, projectDirBase, count, timeout, timeout);
     }
 
+    protected interface ProjectProcessor {
+        void processProject(MakeProject project) throws Exception;
+    }
+
     protected void buildSample(Sync sync, Toolchain toolchain, String sampleName, String projectDirBase,
             int count, int firstTimeout, int subsequentTimeout) throws Exception {
+        buildSample(sync, toolchain, sampleName, projectDirBase, count, firstTimeout, subsequentTimeout, null);
+    }
+
+    protected void buildSample(Sync sync, Toolchain toolchain, String sampleName, String projectDirBase,
+            int count, int firstTimeout, int subsequentTimeout, ProjectProcessor projectProcessor) throws Exception {
         MakeProject makeProject = prepareSampleProject(sync, toolchain, sampleName, projectDirBase);
+        if (projectProcessor != null) {
+            projectProcessor.processProject(makeProject);
+        }
         for (int i = 0; i < count; i++) {
             if (count > 0) {
                 System.err.printf("BUILDING %s, PASS %d\n", sampleName, i);
@@ -374,12 +386,17 @@ public class RemoteBuildTestBase extends RemoteTestBase {
         }
     }
 
-    protected void checkCodeModel(MakeProject makeProject) throws Exception {
+    protected CsmProject getCsmProject(MakeProject makeProject) throws Exception {
         NativeProject np = makeProject.getLookup().lookup(NativeProject.class);
         assertNotNull("Null NativeProject", np);
         CsmModel model = CsmModelAccessor.getModel();
         ((ModelImpl) model).enableProject(np);
         CsmProject csmProject = model.getProject(makeProject);
+        return csmProject;
+    }
+    
+    protected void checkCodeModel(MakeProject makeProject) throws Exception {
+        CsmProject csmProject = getCsmProject(makeProject);
         assertNotNull("Null CsmProject", csmProject);
         csmProject.waitParse();
         checkIncludes(csmProject, true);
