@@ -252,19 +252,21 @@ public class CppEditorSupport extends DataEditorSupport implements EditCookie,
         if (doc != null && !Boolean.TRUE.equals(doc.getProperty(EXTRA_DOCUMENT_PROPERTIES))) {
             // setup language flavor lexing attributes 
             Language<?> language = (Language<?>) doc.getProperty(Language.class);
-            assert language != null : "no language for " + doc;
             if (language != null) {
                 InputAttributes lexerAttrs = (InputAttributes)doc.getProperty(InputAttributes.class);
-                assert lexerAttrs != null : "no language attributes for " + doc;
                 if (lexerAttrs == null) {
+                    CndUtils.assertUnconditional("no language attributes for " + doc);
                     lexerAttrs = new InputAttributes();
                     doc.putProperty(InputAttributes.class, lexerAttrs);
                 }
                 Filter<?> filter = getDefaultFilter(language, doc);
-                assert filter != null : "no language filter for " + doc + " with language " + language;
                 if (filter != null) {
                     lexerAttrs.setValue(language, CndLexerUtilities.LEXER_FILTER, filter, true);  // NOI18N
+                } else {
+                    CndUtils.assertUnconditional("no language filter for " + doc + " with language " + language);
                 }
+            } else {
+                CndUtils.assertUnconditional("no language for " + doc);
             }
             // try to setup document's extra properties during non-EDT load if needed
             PropertiesProviders.addProperty(getDataObject(), doc);
