@@ -117,6 +117,7 @@ public final class CompilerSetImpl extends CompilerSet {
     private boolean autoGenerated;
     private boolean isDefault;
     private final String directory;
+    private  String commandDirectory;
     private final ArrayList<Tool> tools = new ArrayList<Tool>();
     private final CompilerProvider compilerProvider;
     private Map<ToolKind,String> pathSearch;
@@ -288,6 +289,22 @@ public final class CompilerSetImpl extends CompilerSet {
         return directory;
     }
 
+    @Override
+    public String getCommandFolder() {
+        synchronized(this) {
+            if (commandDirectory == null) {
+                commandDirectory = ToolUtils.getCommandFolder(this);
+                if (commandDirectory == null) {
+                    commandDirectory = "";
+                }
+            }
+        }
+        if (commandDirectory.isEmpty()) {
+            return null;
+        }
+        return commandDirectory;
+    }
+
     @Override
     public String getName() {
         return name;
@@ -430,7 +447,7 @@ public final class CompilerSetImpl extends CompilerSet {
     public void setEncoding(Charset charset) {
         this.charset = charset;
     }
-    
+
     private static class UnknownCompilerDescriptor implements CompilerDescriptor {
         private final CompilerDescriptor proxy;
         
@@ -818,11 +835,11 @@ public final class CompilerSetImpl extends CompilerSet {
         }
 
         @Override
-        public String getSubsitute() {
+        public String getSubstitute() {
             if (proxy == null) {
                 return null;
             }
-            return proxy.getSubsitute();
+            return proxy.getSubstitute();
         }
 
         @Override
