@@ -44,6 +44,7 @@
 package org.netbeans.modules.cnd.toolchain.compilerset;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.Writer;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -57,6 +58,7 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.StringTokenizer;
+import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -68,7 +70,6 @@ import org.netbeans.modules.cnd.api.remote.ServerRecord;
 import org.netbeans.modules.cnd.api.toolchain.CompilerFlavor;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSet;
 import org.netbeans.modules.cnd.api.toolchain.CompilerSetManager;
-import org.netbeans.modules.cnd.api.toolchain.CompilerSetUtils;
 import org.netbeans.modules.cnd.api.toolchain.PlatformTypes;
 import org.netbeans.modules.cnd.api.toolchain.PredefinedToolKind;
 import org.netbeans.modules.cnd.api.toolchain.Tool;
@@ -81,12 +82,17 @@ import org.netbeans.modules.cnd.spi.toolchain.CompilerSetFactory;
 import org.netbeans.modules.cnd.spi.toolchain.CompilerSetManagerEvents;
 import org.netbeans.modules.cnd.spi.toolchain.CompilerSetProvider;
 import org.netbeans.modules.cnd.spi.toolchain.ToolChainPathProvider;
+import org.netbeans.modules.cnd.utils.CndPathUtilities;
 import org.netbeans.modules.cnd.utils.CndUtils;
 import org.netbeans.modules.cnd.utils.NamedRunnable;
 import org.netbeans.modules.cnd.utils.cache.CndFileUtils;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.nativeexecution.api.HostInfo;
+import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
+import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
 import org.netbeans.modules.nativeexecution.api.util.Path;
 import org.openide.util.Cancellable;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.RequestProcessor.Task;
@@ -106,13 +112,16 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
     //private static final Object MASTER_LOCK = new Object();
 
     // CopyOnWriteArrayList because of IZ#175647
-    private List<CompilerSet> sets = new ArrayList<CompilerSet>();
+    private final CopyOnWriteArrayList<CompilerSet> sets;
 
     private final ExecutionEnvironment executionEnvironment;
     private volatile State state;
     private int platform = -1;
     private Task initializationTask;
     private CompilerSetProvider provider;
+    private boolean canceled;
+    
+    private final RequestProcessor requestProcessor;
 
     public CompilerSetManagerImpl(ExecutionEnvironment env) {
         this(env, true);
@@ -122,7 +131,9 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
         //if (log.isLoggable(Level.FINEST)) {
         //    log.log(Level.FINEST, "CompilerSetManager CTOR A @" + System.identityHashCode(this) + ' ' + env + ' ' + initialize, new Exception()); //NOI18N
         //}
+        sets = new CopyOnWriteArrayList<CompilerSet>();
         executionEnvironment = env;
+        requestProcessor = new RequestProcessor("Compiler set manager " + env, 40); //NOI18N
         if (initialize && !DISABLED) {
             state = State.STATE_PENDING;
         } else {
@@ -168,7 +179,8 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
         //    log.log(Level.FINEST, "CompilerSetManager CTOR B @" + System.identityHashCode(this) + ' '  + sets + ' ' + platform, new Exception()); //NOI18N
         //}
         this.executionEnvironment = env;
-        this.sets = sets;
+        requestProcessor = new RequestProcessor("Compiler set manager " + env, 4); //NOI18N
+        this.sets =  new CopyOnWriteArrayList<CompilerSet>(sets);
         this.platform = platform;
         completeCompilerSets();
         if (DISABLED) {
@@ -203,6 +215,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
     /** CAUTION: this is a slow method. It should NOT be called from the EDT thread */
     @Override
     public synchronized void initialize(boolean save, boolean runCompilerSetDataLoader, Writer reporter) {
+        canceled = false;
         CompilerSetReporter.setWriter(reporter);
         ProgressHandle pHandle = null;
         try {
@@ -226,11 +239,13 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
             if (pHandle != null) {
                 pHandle.finish();
             }
+            canceled = false;
         }
     }
 
     @Override
     public boolean cancel() {
+        this.canceled = true;
         CompilerSetProvider aProvider = provider;
         if (aProvider != null) {
             return aProvider.cancel();
@@ -518,6 +533,21 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
         if (arData != null) {
             for (String data : arData) {
                 if (data != null && data.length() > 0) {
+                    if (platform < 0) {
+                        HostInfo hostInfo = null;
+                        if (HostInfoUtils.isHostInfoAvailable(executionEnvironment)) {
+                            try {
+                                hostInfo = HostInfoUtils.getHostInfo(executionEnvironment);
+                            } catch (IOException ex) {
+                                Exceptions.printStackTrace(ex); // should never occur since isHostInfoAvailable is checked
+                            } catch (ConnectionManager.CancellationException ex) {
+                                Exceptions.printStackTrace(ex); // should never occur since isHostInfoAvailable is checked
+                            }
+                        }
+                        if (hostInfo != null) {
+                            platform = PlatformTypes.getPlatformFromHostInfo(hostInfo);
+                        }
+                    }
                     CompilerSetImpl cs = parseCompilerSetString(platform, data);
                     if (cs != null) {
                         cs.setAutoGenerated(false);
@@ -671,19 +701,25 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
                             if (cs != null) {
                                 CompilerSetReporter.report("CSM_Found", true, cs.getDisplayName(), cs.getDirectory()); //NOI18N
                                 addUnsafe(cs);
-                                for (Tool tool : cs.getTools()) {
-                                    if (! tool.isReady()) {
-                                        CompilerSetReporter.report("CSM_Initializing_Tool", false, tool.getDisplayName()); //NOI18N
-                                        tool.waitReady(true);
-                                        CompilerSetReporter.report("CSM_Done"); //NOI18N
+                                final List<Tool> toolsCopy = cs.getTools();
+                                requestProcessor.post(new Runnable() {
+                                    @Override
+                                    public void run() {
+                                        for (Tool tool : toolsCopy) {
+                                            if (!tool.isReady()) {
+                                                //CompilerSetReporter.report("CSM_Initializing_Tool", false, tool.getDisplayName()); //NOI18N
+                                                tool.waitReady(true);
+                                                //CompilerSetReporter.report("CSM_Done"); //NOI18N
+                                            }
+                                        }
                                     }
-                                }
+                                });
                             } else if(CompilerSetReporter.canReport()) {
                                 CompilerSetReporter.report("CSM_Err", true, data);//NOI18N
                             }
                         }
                         removeSubstitutions();
-                        completeCompilerSets();
+                        completeCompilerSets(false);
 
                         log.log(Level.FINE, "CSM.initRemoteCompilerSets: Found {0} compiler sets", sets.size()); // NOI18N
                         if (sets.isEmpty()) {
@@ -693,7 +729,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
                         }
                         // NB: function itself is synchronized!
                         state = State.STATE_COMPLETE;
-                        CompilerSetReporter.report("CSM_Conigured");//NOI18N
+                        CompilerSetReporter.report(canceled ? "CSM_Canceled" : "CSM_Conigured");//NOI18N
                         if (runCompilerSetDataLoader) {
                             finishInitialization();
                         }
@@ -715,7 +751,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
             CompilerSetReporter.report("CSM_Fail");//NOI18N
             // create empty CSM
             log.log(Level.FINE, "CSM.initRemoteCompilerSets: Adding empty CS to OFFLINE host {0}", executionEnvironment);
-            completeCompilerSets();
+            completeCompilerSets(false);
             // NB: function itself is synchronized!
             state = State.STATE_UNINITIALIZED; //STATE_ERROR;
         }
@@ -805,7 +841,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
     private void removeSubstitutions() {
         Set<CompilerSet> toRemove = new HashSet<CompilerSet>();
         for (CompilerSet cs : sets) {
-            String subsitute = cs.getCompilerFlavor().getToolchainDescriptor().getSubsitute();
+            String subsitute = cs.getCompilerFlavor().getToolchainDescriptor().getSubstitute();
             if (subsitute != null) {
                 // cs is a numbered tool collection
                 // find general tool collection that fit the numbered tool collection
@@ -857,6 +893,10 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
      * tool. If selected, this will tell the build validation things are OK.
      */
     public void completeCompilerSets() {
+        completeCompilerSets(true);
+    }
+
+    public void completeCompilerSets(boolean waitReady) {
         if (sets.isEmpty()) { // No compilers found
             addUnsafe(CompilerSetImpl.createEmptyCompilerSet(PlatformTypes.PLATFORM_NONE));
         }
@@ -865,13 +905,18 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
         }
         completeSunStudioCompilerSet(getPlatform());
         setDefaltCompilerSet();
-        Collections.<CompilerSet>sort(sets, new Comparator<CompilerSet>(){
+        ArrayList<CompilerSet> toSort = new ArrayList<CompilerSet>(sets);
+        Collections.<CompilerSet>sort(toSort, new Comparator<CompilerSet>(){
             @Override
             public int compare(CompilerSet o1, CompilerSet o2) {
                 return o1.getName().compareTo(o2.getName());
             }
         });
-        completeCompilerSetsSettings(false);
+        sets.clear();
+        sets.addAll(toSort);
+        if (waitReady) {
+            completeCompilerSetsSettings(false);
+        }
     }
 
     private void completeCompilerSetsSettings(boolean reset) {
@@ -934,7 +979,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
                                 if ("$PATH".equals(method)){ // NOI18N
                                     if (env.isLocal()) {
                                         for(String name : descriptor.getNames()){
-                                            String path = ToolUtils.findCommand(name);
+                                            String path = ToolUtils.findCommand(cs, name);
                                             if (path != null) {
                                                 if (notSkipedName(cs, descriptor, path, name)) {
                                                     return cs.addNewTool(env, ToolUtils.getBaseName(path), path, tool, null);
@@ -953,7 +998,7 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
                                 } else if ("$MSYS".equals(method)){ // NOI18N
                                     if (env.isLocal()) {
                                         for(String name : descriptor.getNames()){
-                                            String dir = CompilerSetUtils.getCommandFolder(cs.getCompilerFlavor().getToolchainDescriptor());
+                                            String dir = cs.getCommandFolder();
                                             if (dir != null) {
                                                 String path = ToolUtils.findCommand(name, dir); // NOI18N
                                                 if (path != null) {
@@ -969,6 +1014,10 @@ public final class CompilerSetManagerImpl extends CompilerSetManager {
                                 } else {
                                     if (env.isLocal()) {
                                         for(String name : descriptor.getNames()){
+                                            if (!CndPathUtilities.isAbsolute(method)) {
+                                                String directory = cs.getDirectory();
+                                                method = CndFileUtils.normalizeAbsolutePath(directory+"/"+method); // NOI18N
+                                            }
                                             String path = ToolUtils.findCommand(name, method);
                                             if (path != null) {
                                                 return cs.addNewTool(env, ToolUtils.getBaseName(path), path, tool, null);
