@@ -44,6 +44,7 @@ package org.netbeans.modules.cnd.spi.utils;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URISyntaxException;
 import java.net.URL;
@@ -72,6 +73,34 @@ public abstract class CndFileSystemProvider {
     private static final CndFileSystemProvider DEFAULT = new DefaultProvider();
     private static FileSystem rootFileSystem = null;
 
+    public static final class CndStatInfo {
+
+        public final long inode;
+        public final long device;
+
+        private CndStatInfo(long device, long inode) {
+            this.inode = inode;
+            this.device = device;
+        }
+        
+        public static CndStatInfo create(long  device, long inode) {
+            return new CndStatInfo(device, inode);
+        }
+
+        public static CndStatInfo createInvalid() {
+            return new CndStatInfo(0, 0);
+        }
+
+        public boolean isValid() {
+            return inode > 0;
+        }
+
+        @Override
+        public String toString() {
+            return "CndStatInfo(" + "dev=" + device + ",ino=" + device + ')'; //NOI18N
+        }
+    }
+
     public static class FileInfo {
         public final String absolutePath;
         public final boolean directory;
@@ -105,6 +134,16 @@ public abstract class CndFileSystemProvider {
         getDefault().removeFileSystemProblemListenerImpl(listener, fileSystem);
     }
 
+    /** restricted access - in fact to kind of friend class CndFileSystemProviderHelper) */
+    protected static void addFileSystemProblemListener(CndFileSystemProblemListener listener) {
+        getDefault().addFileSystemProblemListenerImpl(listener);
+    }
+
+    /** restricted access - in fact to kind of friend class CndFileSystemProviderHelper) */
+    protected static void fireFileSystemProblemOccurred(FSPath fSPath) {
+        getDefault().fireFileSystemProblemOccurredImpl(fSPath);
+    }
+
     public static File toFile(FileObject fileObject) {
         // TODO: do we still need this?
         File file = FileUtil.toFile(fileObject);
@@ -113,7 +152,11 @@ public abstract class CndFileSystemProvider {
         }
         return file;
     }
-    
+
+    public static InputStream getInputStream(FileObject fo, int maxSize) throws IOException {
+        return getDefault().getInputStreamImpl(fo, maxSize);
+    }
+
     /**
      * JFileChooser works in the term of files.
      * For such "perverted" files FileUtil.toFileObject won't work.
@@ -124,6 +167,17 @@ public abstract class CndFileSystemProvider {
         return getDefault().toFileObjectImpl(file);
     }    
 
+    /**
+     * Returns inode and device of the given file, if possible
+     */
+    public static CndStatInfo getStatInfo(FileObject fo) {
+        return getDefault().getStatInfoImpl(fo);
+    }
+
+    public static final boolean isRemote(FileSystem fs) {
+        return getDefault().isRemoteImpl(fs);
+    }
+
     public static Boolean exists(CharSequence path) {
         return getDefault().existsImpl(path);
     }
@@ -150,14 +204,27 @@ public abstract class CndFileSystemProvider {
         return getDefault().urlToFileSystemImpl(url);
     }
 
+    /**
+     * This method is different from fileObjectToUrl.
+     * On Windows for local file object returns true Windows path.
+     * C:\path\to\file
+     * @param fileObject
+     * @return 
+     */
     public static CharSequence toUrl(FSPath fsPath) {
         return getDefault().toUrlImpl(fsPath);
     }
-    
     public static CharSequence toUrl(FileSystem fileSystem, CharSequence absPath) {
         return getDefault().toUrlImpl(fileSystem, absPath);
     }
 
+    /**
+     * This method is different from toUrl.
+     * On Windows for local file object returns Unix-like path, but with drive letter,
+     * C:/path/to/file
+     * @param fileObject
+     * @return 
+     */
     public static CharSequence fileObjectToUrl(FileObject fileObject) {
         CharSequence result = getDefault().fileObjectToUrlImpl(fileObject);
         CndUtils.assertNotNull(result, "Null URL for file object ", fileObject); //NOI18N
@@ -184,7 +251,7 @@ public abstract class CndFileSystemProvider {
     public static boolean isAbsolute(FileSystem fs, String path) {
         return getDefault().isAbsoluteImpl(fs, path);
     }
-    
+
     public static void addFileChangeListener(FileChangeListener listener) {
         getDefault().addFileChangeListenerImpl(listener);
     }
@@ -223,6 +290,7 @@ public abstract class CndFileSystemProvider {
     protected abstract Boolean existsImpl(CharSequence path);
     protected abstract Boolean canReadImpl(CharSequence path);
     protected abstract FileInfo[] getChildInfoImpl(CharSequence path);
+    protected abstract InputStream getInputStreamImpl(FileObject fo, int maxSize) throws IOException;
 
     /** a bridge from cnd.utils to dlight.remote */
     protected abstract FileObject toFileObjectImpl(CharSequence absPath);
@@ -248,16 +316,22 @@ public abstract class CndFileSystemProvider {
 
     protected abstract void removeFileSystemProblemListenerImpl(CndFileSystemProblemListener listener, FileSystem fileSystem);
     protected abstract void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener, FileSystem fileSystem);
+    
+    protected abstract void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener);
+    protected abstract void fireFileSystemProblemOccurredImpl(FSPath fsPath);
 
     protected abstract boolean isAbsoluteImpl(FileSystem fs, String path);
 
     protected abstract boolean isMacOSImpl(FileSystem fs);
     protected abstract boolean isWindowsImpl(FileSystem fs);
-    
+
+    protected abstract boolean isRemoteImpl(FileSystem fs);
+    protected abstract CndStatInfo getStatInfoImpl(FileObject fo);
+
     private static class DefaultProvider extends CndFileSystemProvider {
         private static final String FILE_PROTOCOL_PREFIX = "file:"; // NOI18N
 
-        private CndFileSystemProvider[] cache;
+        private final CndFileSystemProvider[] cache;
 
         DefaultProvider() {
             Collection<? extends CndFileSystemProvider> instances =
@@ -555,6 +629,20 @@ public abstract class CndFileSystemProvider {
                 provider.removeFileSystemProblemListenerImpl(listener, fileSystem);
             }
         }        
+        
+        @Override
+        protected void addFileSystemProblemListenerImpl(CndFileSystemProblemListener listener) {
+            for (CndFileSystemProvider provider : cache) {
+                provider.addFileSystemProblemListenerImpl(listener);
+            }
+        }
+
+        @Override
+        protected void fireFileSystemProblemOccurredImpl(FSPath fsPath) {
+            for (CndFileSystemProvider provider : cache) {
+                provider.fireFileSystemProblemOccurredImpl(fsPath);
+            }
+        }
 
         @Override
         protected boolean isAbsoluteImpl(FileSystem fs, String path) {
@@ -578,6 +666,30 @@ public abstract class CndFileSystemProvider {
                 return provider.isWindowsImpl(fs);
             }
             return Utilities.isWindows();
-        }        
+        }
+
+        @Override
+        protected InputStream getInputStreamImpl(FileObject fo, int maxSize) throws IOException {
+            for (CndFileSystemProvider provider : cache) {
+                return provider.getInputStreamImpl(fo, maxSize);
+            }
+            return fo.getInputStream();
+        }
+
+        @Override
+        protected boolean isRemoteImpl(FileSystem fs) {
+            for (CndFileSystemProvider provider : cache) {
+                return provider.isRemoteImpl(fs);
+            }
+            return false;
+        }
+
+        @Override
+        protected CndStatInfo getStatInfoImpl(FileObject fo) {
+            for (CndFileSystemProvider provider : cache) {
+                return provider.getStatInfoImpl(fo);
+            }
+            return CndStatInfo.createInvalid();
+        }
     }
 }
