@@ -54,8 +54,6 @@ import org.netbeans.modules.dlight.libs.common.PathUtilities;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
-import org.openide.filesystems.FileUtil;
-import org.openide.util.Exceptions;
 import org.openide.util.Utilities;
 
 /**
@@ -195,7 +193,7 @@ public class CndPathUtilities {
     public static String toAbsolutePath(FileSystem fileSystem, String basePath, String path) {
         CndUtils.assertAbsolutePathInConsole(basePath);
         path = (path == null || path.length() == 0) ? "." : path; // NOI18N
-        if (!isPathAbsolute(path)) {
+        if (!CndFileSystemProvider.isAbsolute(fileSystem, path)) {
             path = basePath + '/' + path; //NOI18N
         }       
         path = CndFileUtils.normalizeAbsolutePath(fileSystem, path);
@@ -542,10 +540,22 @@ public class CndPathUtilities {
         return isPathAbsolute(path);
     }
 
+    public static boolean isPathAbsolute(FileSystem fs, String path) {
+        return CndFileSystemProvider.isAbsolute(fs, path);
+    }
+
+    public static void assertNoUrl(CharSequence path) {
+        if(CharSequenceUtils.startsWith(path, "rfs:") || CharSequenceUtils.startsWith(path, "file:")) { //NOI18N
+            CndUtils.assertTrue(false, "Path should not start with protocol: " + path); //NOI18N
+        }
+    }
+
     public static boolean isPathAbsolute(CharSequence path) {
         if (path == null || path.length() == 0) {
             return false;
-        } else if (path.charAt(0) == '/') {
+        }
+        assertNoUrl(path);
+        if (path.charAt(0) == '/') {
             return true;
         } else if (path.charAt(0) == '\\') {
             return true;
@@ -564,10 +574,14 @@ public class CndPathUtilities {
     public static boolean isIgnoredFolder(File file) {
         if (file.isDirectory()) {
             String name = file.getName();
-            return name.equals("SCCS") || name.equals("CVS") || name.equals(".hg") || name.equals("SunWS_cache") || name.equals(".svn"); // NOI18N
+            return isIgnoredFolder(name);
         }
         return false;
     }
+
+    public static boolean isIgnoredFolder(String name) {
+        return name.equals("SCCS") || name.equals("CVS") || name.equals(".hg") || name.equals("SunWS_cache") || name.equals(".svn"); // NOI18N
+    }
         
     /**
      * Same as String.equals, but allows arguments to be null
