@@ -44,6 +44,7 @@ package org.netbeans.modules.cnd.utils.cache;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
 import java.lang.ref.Reference;
 import java.lang.ref.SoftReference;
 import java.net.URI;
@@ -57,7 +58,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-import java.util.regex.Pattern;
 import org.netbeans.modules.cnd.debug.CndTraceFlags;
 import org.netbeans.modules.cnd.spi.utils.CndFileExistSensitiveCache;
 import org.netbeans.modules.cnd.spi.utils.CndFileSystemProvider;
@@ -88,6 +88,7 @@ import org.openide.util.Utilities;
 public final class CndFileUtils {
     private static final boolean TRUE_CASE_SENSITIVE_SYSTEM;
     private static final FileChangeListener FSL = new FSListener();
+    private static final FSProblemListener FSPL = new FSProblemListener();
     private static final FileSystem fileFileSystem;
     public static final int FS_TIME_OUT = 30;
     public static final String LS_FOLDER_UTILS_PERFORMANCE_EVENT = "LS_FOLDER_UTILS_PERFORMANCE_EVENT"; //NOI18N
@@ -137,7 +138,8 @@ public final class CndFileUtils {
             caseSenstive = Utilities.isUnix() && !Utilities.isMac();
         }
         TRUE_CASE_SENSITIVE_SYSTEM = caseSenstive;
-        FileUtil.addFileChangeListener(FSL);
+        CndFileSystemProvider.addFileChangeListener(FSL);
+        CndFileSystemProviderHelper.addFileSystemProblemListener(FSPL);
     }
 
     public static boolean isSystemCaseSensitive() {
@@ -163,6 +165,10 @@ public final class CndFileUtils {
         }
     }
 
+    public static InputStream getInputStream(FileObject fo, int maxSize) throws IOException {
+        return CndFileSystemProvider.getInputStream(fo, maxSize);
+    }
+
     /**
      * normalize file
      * @param file
@@ -190,13 +196,16 @@ public final class CndFileUtils {
         ConcurrentHashMap<CharSequence, FileObject> map = foCache.get(fs);
         if (map == null) {
             map = new ConcurrentHashMap<CharSequence, FileObject>();
-            foCache.putIfAbsent(fs, map);
+            ConcurrentHashMap<CharSequence, FileObject> old = foCache.putIfAbsent(fs, map);
+            if (old != null) {
+                map = old;
+            }
         }
         FileObject res = map.get(absolutePath);
         if (res == null || !res.isValid()) {
             res = toFileObjectImpl(fs, absolutePath);
-            if (res != null) {
-                map.putIfAbsent(absolutePath, res);
+            if (res != null && res.isValid()) {
+                map.put(absolutePath, res);
             }
         }
         return res;
@@ -345,6 +354,10 @@ public final class CndFileUtils {
         return getFlags(getLocalFileSystem(), file.getAbsolutePath(), true).exist;
     }
 
+    public static boolean exists(FileSystem fs, String absolutePath) {
+        return getFlags(fs, absolutePath, true).exist;
+    }
+
     public static boolean isExistingFile(String filePath) {
         return isExistingFile(getLocalFileSystem(), filePath);
     }
@@ -430,6 +443,8 @@ public final class CndFileUtils {
                         // no need to check non existing file
                         exists = Flags.NOT_FOUND;
 //                        files.put(path, exists);
+                    } else if (parentDirFlags == Flags.NOT_FOUND_CONNECTION_ISSUE) {
+                        exists = Flags.NOT_FOUND_CONNECTION_ISSUE;
                     } else if (indexParentFolder) {
                         assert (parentDirFlags == Flags.DIRECTORY) : "must be DIRECTORY but was " + parentDirFlags; // NOI18N
                         // let's index not indexed directory
@@ -454,6 +469,8 @@ public final class CndFileUtils {
                     } else if (parentDirFlags == Flags.NOT_FOUND || parentDirFlags == Flags.BROKEN_LINK) {
                         // no need to check non existing file
                         exists = Flags.NOT_FOUND;
+                    } else if (parentDirFlags == Flags.NOT_FOUND_CONNECTION_ISSUE) {
+                        exists = Flags.NOT_FOUND_CONNECTION_ISSUE;
                     } else {
                         // may be our parent was indexed in parallel thread
                         exists = files.get(absolutePath);
@@ -469,6 +486,9 @@ public final class CndFileUtils {
                 index(fs, absolutePath, files);
             }
         } else {
+            if (exists == Flags.NOT_FOUND_CONNECTION_ISSUE) {
+                CndFileSystemProviderHelper.fireFileSystemProblemOccurred(new FSPath(fs, absolutePath));
+            }
             //hits ++;
         }
         return exists;
@@ -486,7 +506,7 @@ public final class CndFileUtils {
         }
     }
 
-    private static void index(FileSystem fs, String path, ConcurrentMap<String, Flags> files) {
+    private static void index(FileSystem fs, String path, ConcurrentMap<String, Flags> files) {        
         if (isLocalFileSystem(fs)) {
             File file = new File(path);
             if (CndFileSystemProvider.canRead(path)) {
@@ -510,7 +530,14 @@ public final class CndFileUtils {
             FileObject file = fs.findResource(path);            
             if (file != null && file.isFolder() && file.canRead()) {
                 final char fileSeparatorChar = getFileSeparatorChar(fs);            
-                for (FileObject child : file.getChildren()) {
+                FileObject[] children;
+                fileSystemError.set(Boolean.FALSE);
+                children = file.getChildren();
+                if (fileSystemError.get()) {
+                    files.put(path, Flags.NOT_FOUND_CONNECTION_ISSUE);
+                    return;
+                }
+                for (FileObject child : children) {
                     //we do concat as we need to index relative path not absolute ones
                     String absPath = path + fileSeparatorChar + child.getNameExt();
                     if (child.isFolder()) {
@@ -664,6 +691,8 @@ public final class CndFileUtils {
     private static final Map<FileSystem, Reference<ConcurrentMap<String, Flags>>> maps = 
             new WeakHashMap<FileSystem, Reference<ConcurrentMap<String, Flags>>>();
 
+    private static final ThreadLocal<Boolean> fileSystemError = new ThreadLocal<>();
+    
     private final static class Flags {
 
         private final boolean exist;
@@ -676,20 +705,18 @@ public final class CndFileUtils {
         private static final Flags DIRECTORY = new Flags(true,true);
         private static final Flags INDEXED_DIRECTORY = new Flags(true,true);
         private static final Flags NOT_FOUND = new Flags(false,true);
+        private static final Flags NOT_FOUND_CONNECTION_ISSUE = new Flags(false,true);
         private static final Flags BROKEN_LINK = new Flags(false, false);
         
         private static Flags get(FileSystem fs, String absPath) {
             FileObject fo;
+            fileSystemError.set(Boolean.FALSE);
             if (isLocalFileSystem(fs)) {
                 absPath = FileUtil.normalizePath(absPath);
                 fo = CndFileSystemProvider.toFileObject(absPath);                
             } else {
                 fo = fs.findResource(absPath);
             }
-            return get(fo);
-        }
-        
-        private static Flags get(FileObject fo) {
             if (fo != null && fo.isValid()) {
                 if (fo.isFolder()) {
                     return DIRECTORY;
@@ -698,7 +725,7 @@ public final class CndFileUtils {
                     return FILE;
                 }
             } else {
-                return NOT_FOUND;
+                return fileSystemError.get() ? NOT_FOUND_CONNECTION_ISSUE : NOT_FOUND;
             }
         }
 
@@ -706,6 +733,8 @@ public final class CndFileUtils {
         public String toString() {
             if (this == NOT_FOUND) {
                 return "NOT_FOUND"; // NOI18N
+            } else if (this == NOT_FOUND_CONNECTION_ISSUE) {
+                return "NOT_FOUND_CONNECTION_ISSUE"; // NOI18N
             } else if (this == INDEXED_DIRECTORY) {
                 return "INDEXED_DIRECTORY"; // NOI18N
             } else if (this == DIRECTORY) {
@@ -720,6 +749,44 @@ public final class CndFileUtils {
         }
 
     }
+    
+    private static final class FSProblemListener implements CndFileSystemProvider.CndFileSystemProblemListener {
+
+        @Override
+        public void problemOccurred(FSPath fsPath) {
+            fileSystemError.set(Boolean.TRUE);
+        }
+
+        @Override
+        public void recovered(FileSystem fileSystem) {
+        }        
+    }
+    
+    private static class CndFileSystemProviderHelper {
+
+        private CndFileSystemProviderHelper() {
+        }
+
+        private static abstract class FakeProvider extends CndFileSystemProvider {
+
+            public static void addProblemListener(CndFileSystemProvider.CndFileSystemProblemListener listener) {
+                CndFileSystemProvider.addFileSystemProblemListener(listener);
+            }
+
+            protected static void fireProblem(FSPath fSPath) {
+                CndFileSystemProvider.fireFileSystemProblemOccurred(fSPath);
+            }
+        }
+
+        public static void addFileSystemProblemListener(CndFileSystemProvider.CndFileSystemProblemListener listener) {
+            FakeProvider.addProblemListener(listener);
+        }
+
+        public static void fireFileSystemProblemOccurred(FSPath fSPath) {
+            FakeProvider.fireProblem(fSPath);
+        }
+    }
+    
 
     private static final class FSListener implements FileChangeListener {
 
@@ -727,24 +794,24 @@ public final class CndFileUtils {
         }
 
         @Override
-        public void fileFolderCreated(FileEvent fe) {
-            File file = CndFileUtils.toFile(fe.getFile());
-            String path = file.getAbsolutePath();
-            String absPath = preparePath(path);
-            if (getFilesMap(getLocalFileSystem()).put(absPath, Flags.DIRECTORY) != null) {
+        public void fileFolderCreated(FileEvent fe) {            
+            String path = checkSeparators(fe.getFile());
+            String absPath = changeStringCaseIfNeeded(getFileSystem(fe), path);
+            FileSystem fs = getFileSystem(fe);
+            if (getFilesMap(fs).put(absPath, Flags.DIRECTORY) != null) {
                 // If there was something in the map already - invalidate it
-                invalidateFile(path, absPath);
+                invalidateFile(fs, path, absPath);
             }
         }
 
         @Override
         public void fileDataCreated(FileEvent fe) {
-            File file = CndFileUtils.toFile(fe.getFile());
-            String path = file.getAbsolutePath();
-            String absPath = preparePath(path);
-            if (getFilesMap(getLocalFileSystem()).put(absPath, Flags.FILE) != null) {
+            String path = checkSeparators(fe.getFile());
+            String absPath = changeStringCaseIfNeeded(getFileSystem(fe), path);
+            FileSystem fs = getFileSystem(fe);
+            if (getFilesMap(fs).put(absPath, Flags.FILE) != null) {
                 // If there was something in the map already - invalidate it
-                invalidateFile(path, absPath);
+                invalidateFile(fs, path, absPath);
             }
         }
 
@@ -755,12 +822,12 @@ public final class CndFileUtils {
 
         @Override
         public void fileRenamed(FileRenameEvent fe) {
-            final File parent = clearCachesAboutFile(fe);
+            final FSPath parent = clearCachesAboutFile(fe);
             // update info about old file as well
             if (parent != null) {
                 final String ext = fe.getExt();
                 final String oldName = (ext.length() == 0) ? fe.getName() : (fe.getName() + "." + ext); // NOI18N
-                clearCachesAboutFile(new File(parent, oldName), false);
+                clearCachesAboutFile(parent.getChild(oldName), false);
             }
         }
 
@@ -774,44 +841,61 @@ public final class CndFileUtils {
             // no update
         }
 
-        private File clearCachesAboutFile(FileEvent fe) {
-            return clearCachesAboutFile(CndFileUtils.toFile(fe.getFile()), false);
+        private FSPath clearCachesAboutFile(FileEvent fe) {
+            return clearCachesAboutFile(FSPath.toFSPath(fe.getFile()), false);
         }
         
-        private File clearCachesAboutFile(File f, boolean withParent) {
-            cleanCachesImpl(f.getAbsolutePath());
+        private FSPath clearCachesAboutFile(FSPath f, boolean withParent) {
+            cleanCachesImpl(f);
             if (withParent) {
-                File parent = f.getParentFile();
+                FSPath parent = f.getParent();
                 if (parent != null) {
-                    cleanCachesImpl(parent.getAbsolutePath());
+                    cleanCachesImpl(parent);
                 }
                 return parent;
             }
             return null;
         }
         
-        private String preparePath(String path) {
-            String absPath = changeStringCaseIfNeeded(getLocalFileSystem(), path);
-            if (isWindows) {
+        private String checkSeparators(FileObject fo) {
+            return checkSeparators(FSPath.toFSPath(fo));
+        }
+        
+        private String checkSeparators(FSPath path) {
+            String absPath = path.getPath();
+            if (isWindows && isLocalFileSystem(path.getFileSystem())) {
                 absPath = absPath.replace('/', '\\');
             }
             return absPath;
         }
         
-        private static void invalidateFile(String file, String absPath) {
-            for (CndFileExistSensitiveCache cache : getCaches()) {
-                cache.invalidateFile(file);
-                cache.invalidateFile(absPath);
+        private FileSystem getFileSystem(FileEvent fe) {
+            return getFileSystem(fe.getFile());
+        }
+        
+        private FileSystem getFileSystem(FileObject fo) {
+            try {
+                return fo.getFileSystem();
+            } catch (FileStateInvalidException ex) {
+                throw new IllegalStateException(ex);
             }
         }
 
-        private void cleanCachesImpl(String file) {
-            String absPath = preparePath(file);
+        private static void invalidateFile(FileSystem fileSystem, String file, String localPathOrRemoteUrl) {
+            for (CndFileExistSensitiveCache cache : getCaches()) {
+                cache.invalidateFile(fileSystem, file);
+                cache.invalidateFile(fileSystem, localPathOrRemoteUrl);
+            }
+        }
+
+        private void cleanCachesImpl(FSPath fsPath) {
+            String file = checkSeparators(fsPath);
+            String absPath = changeStringCaseIfNeeded(fsPath.getFileSystem(), file);
             Flags removed = getFilesMap(getLocalFileSystem()).remove(absPath);
             if (TRACE_EXTERNAL_CHANGES) {
                 System.err.printf("clean cache for %s->%s\n", absPath, removed);
             }
-            invalidateFile(file, absPath);
+            invalidateFile(fsPath.getFileSystem(), file, absPath);
         }
     }
     private static final boolean TRACE_EXTERNAL_CHANGES = Boolean.getBoolean("cnd.modelimpl.trace.external.changes"); // NOI18N
