@@ -69,6 +69,9 @@ import org.netbeans.modules.csl.api.DataLoadersBridge;
 import org.netbeans.modules.csl.api.Hint;
 import org.netbeans.modules.csl.api.OffsetRange;
 import org.netbeans.modules.csl.api.RuleContext;
+import org.netbeans.modules.csl.core.CancelSupportImplementation;
+import org.netbeans.modules.csl.core.SchedulerTaskCancelSupportImpl;
+import org.netbeans.modules.csl.core.SpiSupportAccessor;
 import org.netbeans.modules.csl.hints.infrastructure.GsfHintsManager;
 import org.netbeans.modules.csl.spi.ParserResult;
 import org.netbeans.modules.parsing.api.Embedding;
@@ -101,7 +104,8 @@ import org.openide.text.NbDocument;
 public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
     
     public static final Logger LOG = Logger.getLogger(GsfHintsProvider.class.getName()); // NOI18N
-    
+
+    private final CancelSupportImplementation cancel = SchedulerTaskCancelSupportImpl.create(this);
     private FileObject file;
     
     /**
@@ -133,7 +137,7 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
         }
         
         for (Error d : errors) {
-            if (isCanceled()) {
+            if (cancel.isCancelled()) {
                 return null;
             }
             
@@ -178,7 +182,7 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
             final String desc = d.getDisplayName();
             final Position[] range = getLine(d, doc, position, endPosition);
             
-            if (isCanceled()) {
+            if (cancel.isCancelled()) {
                 return null;
             }
             
@@ -189,7 +193,7 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
             descs.add(ErrorDescriptionFactory.createErrorDescription(errorKind2Severity.get(d.getSeverity()), desc, ehm, doc, range[0], range[1]));
         }
         
-        if (isCanceled()) {
+        if (cancel.isCancelled()) {
             return null;
         }
         
@@ -200,7 +204,25 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
         return DataLoadersBridge.getDefault().getDocument(file);
     }
     
-    private Position[] getLine(Error d, final Document doc, int startOffset, int endOffset) {
+    private Position[] getLine(final Error d, final Document doc, final int startOffset, final int endOffset) {
+        if (doc == null) {
+            return new Position[2];
+        }
+        final Position[][] ret = new Position[][] { new Position[2] };
+        // line nunmber conversion + getText from the line should happen
+        // under the document read-lock.
+        doc.render(new Runnable() {
+            public void run() {
+                if (cancel.isCancelled()) {
+                    return;
+                }
+                ret[0] = getLine0(d, doc, startOffset, endOffset);
+            }
+        });
+        return ret[0];
+    }
+    
+    private Position[] getLine0(Error d, final Document doc, int startOffset, int endOffset) {
         StyledDocument sdoc = (StyledDocument) doc;
         int lineNumber = NbDocument.findLineNumber(sdoc, startOffset);
         int lineOffset = NbDocument.findLineOffset(sdoc, lineNumber);
@@ -238,60 +260,39 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
         final int endOffsetFinal = endOffset;
         final Position[] result = new Position[2];
         
-        doc.render(new Runnable() {
-            public @Override void run() {
-                if (isCanceled()) {
-                    return;
-                }
-                
-                int len = doc.getLength();
-                
-                if (startOffsetFinal > len || endOffsetFinal > len) {
-                    if (!isCanceled() && LOG.isLoggable(Level.WARNING)) {
-                        LOG.log(Level.WARNING, "document changed, but not canceled?" );
-                        LOG.log(Level.WARNING, "len = " + len );
-                        LOG.log(Level.WARNING, "startOffset = " + startOffsetFinal );
-                        LOG.log(Level.WARNING, "endOffset = " + endOffsetFinal );
-                    }
-                    cancel();
-                    
-                    return;
-                }
-                
-                try {
-                    result[0] = NbDocument.createPosition(doc, startOffsetFinal, Bias.Forward);
-                    result[1] = NbDocument.createPosition(doc, endOffsetFinal, Bias.Backward);
-                } catch (BadLocationException e) {
-                    LOG.log(Level.WARNING, null, e);
-                }
+        int len = doc.getLength();
+
+        if (startOffsetFinal > len || endOffsetFinal > len) {
+            if (!cancel.isCancelled() && LOG.isLoggable(Level.WARNING)) {
+                LOG.log(Level.WARNING, "document changed, but not canceled?" );
+                LOG.log(Level.WARNING, "len = " + len );
+                LOG.log(Level.WARNING, "startOffset = " + startOffsetFinal );
+                LOG.log(Level.WARNING, "endOffset = " + endOffsetFinal );
             }
-        });
+            cancel();
+
+            return result;
+        }
+
+        try {
+            result[0] = NbDocument.createPosition(doc, startOffsetFinal, Bias.Forward);
+            result[1] = NbDocument.createPosition(doc, endOffsetFinal, Bias.Backward);
+        } catch (BadLocationException e) {
+            LOG.log(Level.WARNING, null, e);
+        }
         
         return result;
     }
-    
-    private boolean cancel;
-    
-    synchronized boolean isCanceled() {
-        return cancel;
-    }
-    
+
+
     @Override
     public void cancel() {
-        HintsProvider curProvider;
-        synchronized (this) {
-            curProvider = this.pendingProvider;
-            cancel = true;
-        }
+        final HintsProvider curProvider = this.pendingProvider;
         if (curProvider != null) {
             curProvider.cancel();
         }
     }
-    
-    synchronized void resume() {
-        cancel = false;
-    }
-    
+
     private List<Error> processProviderErrors(
             final List<ErrorDescription> descriptions, 
             Snapshot topLevelSnapshot, final ParserResult r, final Language language) throws ParseException {
@@ -314,7 +315,7 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
         try {
             synchronized (this) {
                 pendingProvider = provider;
-                if (isCanceled()) {
+                if (cancel.isCancelled()) {
                     return errors;
                 }
             }
@@ -367,7 +368,7 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
         
         for(Embedding e : resultIterator.getEmbeddings()) {
             try {
-                if (isCanceled()) {
+                if (cancel.isCancelled()) {
                     return;
                 }
             } catch (Exception ex) {
@@ -419,15 +420,12 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
     }
     
     public @Override void run(ParserResult result, SchedulerEvent event) {
-        resume();
-        
         final Document doc = getDocument();
-        
         if (doc == null) {
             LOG.log(Level.INFO, "SemanticHighlighter: Cannot get document!");
             return ;
         }
-        
+        SpiSupportAccessor.getInstance().setCancelSupport(cancel);
         try {
             ParserManager.parse(Collections.singleton(result.getSnapshot().getSource()), new UserTask() {
                 public @Override void run(ResultIterator resultIterator) throws ParseException {
@@ -437,6 +435,8 @@ public final class GsfHintsProvider extends ParserResultTask<ParserResult> {
             });
         } catch (ParseException e) {
             LOG.log(Level.WARNING, null, e);
+        } finally {
+            SpiSupportAccessor.getInstance().removeCancelSupport(cancel);
         }
     }
     
