@@ -556,18 +556,22 @@ public class DefaultCssEditorModule extends CssEditorModule {
 
             @Override
             public boolean visit(Node node) {
+                assert(node.from() != -1 && node.to() != -1);
+                if (node.from() == -1 || node.to() == -1) {
+                    return false;
+                }
                 switch (node.type()) {
                     case selectorsGroup: //rules
                         //get parent - ruleSet to obtain the { ... } range 
                         Node ruleNode = node.parent();
-                        assert ruleNode.type() == NodeType.rule;
-
-                        int so = snapshot.getOriginalOffset(ruleNode.from());
-                        int eo = snapshot.getOriginalOffset(ruleNode.to());
-                        if (eo > so) {
-                            //todo: filter out virtual selectors
-                            StructureItem item = new CssRuleStructureItem(node.image(), CssNodeElement.createElement(file, ruleNode), snapshot);
-                            addRule(item);
+                        if (ruleNode.type() == NodeType.rule) {
+                            int so = snapshot.getOriginalOffset(ruleNode.from());
+                            int eo = snapshot.getOriginalOffset(ruleNode.to());
+                            if (eo > so) {
+                                //todo: filter out virtual selectors
+                                StructureItem item = new CssRuleStructureItem(node.image(), CssNodeElement.createElement(file, ruleNode), snapshot);
+                                addRule(item);
+                            }
                         }
                         break;
                     case elementName: //element
