@@ -709,4 +709,216 @@ public class Css3ParserLessTest extends CssTestBase {
     public void testIssue240701() {
         assertParses(".linear-gradient-multi(...) {}");
     }
+    
+    public void testIssue248194() {
+        assertParses(
+        "@import (reference) \"foo.less\";\n" +
+        "@import (inline) \"not-less-compatible.css\";\n" +
+        "@import (once) \"foo.less\";\n" +
+        "@import (multiple) \"foo.less\";\n" +
+        "@import (less) \"foo.css\";\n" +
+        "@import (css) \"foo.less\";"
+        );
+    }
+    
+    public void testErrorKeywordInImport() {
+        String source = " @import(wrong) \"test\";";
+        CssParserResult result = TestUtil.parse(source);
+//        TestUtil.dumpTokens(result);
+//        TestUtil.dumpResult(result);
+
+        Node error = NodeUtil.query(result.getParseTree(),
+                TestUtil.bodysetPath
+                + "importItem/less_import_types/error");
+        assertNotNull(error);
+
+        assertEquals(9, error.from());
+        assertEquals(14, error.to());
+        assertEquals("wrong", error.image().toString());
+    }
+    
+    public void testAdditionalCommaInTheEndOfSelector() {
+        String source = ".ui-convex,\n"
+                + ".ui-convex-hover,\n"
+                + "{\n"
+                + "    width: 10em;\n"
+                + "    height: 2em;\n"
+                + "    \n"
+                + "    margin: 1em auto;\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testParentInheritingWithNumbers() {
+        String source = ".author {\n"
+                + "  &-name {  }\n"
+                + "  &-picture { }\n"
+                + "}\n"
+                + "\n"
+                + ".author {\n"
+                + "  &-1 { }\n"
+                + "  &-2 {  }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testDetachedRuleset() {
+        String source = "// declare detached ruleset\n"
+                + "@detached-ruleset: { background: red; };\n"
+                + "\n"
+                + "// use detached ruleset\n"
+                + ".top {\n"
+                + "    @detached-ruleset(); \n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testDetachedRulesetestWithMixin() {
+        String source = ".mymixin(@ruleset) {\n"
+                + "    @ruleset(); // Hint: Unexpected LPAREN found\n"
+                + "}\n"
+                + ".xx {\n"
+                + "    .mymixin({.red()}); // Hint: Unexpected IDENT found\n"
+                + "} ";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testAndWithWhen() {
+        String source = ".mixin-filled(@delta:0%) {\n"
+                + "	& when (@delta > 0%) {\n"
+                + "		background:lighten(@mixin-boxcolor, @delta);\n"
+                + "	}\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testMultipleAnds() {
+        String source = ".heading {\n"
+                + "    &&--type-small {\n"
+                + "        font-size: 15px;\n"
+                + "    }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testTwoClassesWithoutSpace() {
+        String source = "body {\n"
+                + "    .foo.bar {\n"
+                + "        // any css statement\n"
+                + "    }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testMixinCallsWithHash() {
+        String source = ".a, #b {\n"
+                + "  color: red;\n"
+                + "}\n"
+                + ".mixin-class {\n"
+                + "  .a();\n"
+                + "}\n"
+                + ".mixin-id {\n"
+                + "  #b();\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testMixinDefWithHash() {
+        String source = "#mymixin(@ruleset) { \n"
+                + "    @ruleset(); \n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testMixinCallInMedia() {
+        String source = ".desktop-and-old-ie(@rules) {\n"
+                + "  @media sceren and (min-width: 1200) { @rules(); }\n"
+                + "  html.lt-ie9 &                       { @rules(); }\n"
+                + "}";
+        assertParses(source);
+    }
+    
+    public void testExtendKeyword() {
+        
+        assertParses(".sidenav:extend(.nav, #foo, .bar) {}");
+        assertParses(".big-division,\n"
+                + ".big-bag:extend(.bag),\n"
+                + ".big-bucket:extend(.bucket) {\n"
+                + "  // body\n"
+                + "}");
+        assertParses(".b {\n"
+                + "	&:extend(.a);\n"
+                + "}");
+        assertParses(".aa{\n"
+                + "font-size: 12px;\n"
+                + "&:extend(.clearfix);\n"
+                + "}");
+        
+        String source = ".sidenav:extend(.nav) {}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testInterpolationInPseudo() {
+        assertParses(".@{var}bar{}");
+        assertParses("li:nth-child(@{somevar}+1) {}");
+        assertParses("li:nth-child(@{somevar}) {}");
+        assertParses("li:nth-child(~\"@{somevar}\") {}");
+        assertParses(".foo {\n"
+                + "\n"
+                + "	&:not(.@{var}bar):active {\n"
+                + "		color: red;\n"
+                + "	}\n"
+                + "\n"
+                + "}");
+    }
+    
+    public void testPatternMatchingInMixin() {
+        assertParses(".mixin(@s; @color) { }\n"
+                + "\n"
+                + ".class {\n"
+                + "  .mixin(@switch; #888);\n"
+                + "}");
+        assertParses(".mixin(dark; @color) {\n"
+                + "  color: darken(@color, 10%);\n"
+                + "}");
+        
+        assertParses(".mixin(@a; @b) {\n"
+                + "  color: fade(@a; @b);\n"
+                + "}");
+    }
+    
+    public void testMathExpWithUnits() {
+        assertParses("@fa-li-width: (30em / 14);");
+    }
+    
+    public void testInterpolationWithLength() {
+        assertParses(".@{fa-css-prefix}-500px:before {padding: 10;}");
+    }
+    
+    public void testIdentBeforeLessAnd() {
+        assertParses(".badge {\n"
+                + "  display: inline-block;\n"
+                + "  &:after {\n"
+                + "    display: none;\n"
+                + "  }\n"
+                + "\n"
+                + "  a& {\n"
+                + "    &:hover,\n"
+                + "    &:focus {\n"
+                + "      text-decoration: none;\n"
+                + "    }\n"
+                + "  }\n"
+                + "}\n"
+                );
+    }
 }
