@@ -874,7 +874,7 @@ public class Css3ParserScssTest extends CssTestBase {
 
         CssParserResult result = TestUtil.parse(source);
 
-//        NodeUtil.dumpTree(result.getParseTree());
+        NodeUtil.dumpTree(result.getParseTree());
         assertResultOK(result);
 
     }
@@ -1428,7 +1428,7 @@ public class Css3ParserScssTest extends CssTestBase {
     //https://netbeans.org/bugzilla/show_bug.cgi?id=227484#c19
     public void testAmpInSelector() throws ParseException, BadLocationException {
         assertParses("&.primary, input[type=\"submit\"] & { }\n");
-        assertParses("&.primary, input[type=\"submit\"]& { }\n");
+        //assertParses("&.primary, input[type=\"submit\"]& { }\n"); //this is not possible in scss
         assertParses("&.primary, & { }\n");
     }
 
@@ -1619,12 +1619,12 @@ public class Css3ParserScssTest extends CssTestBase {
                 + ".selector#{$i} { content: $i; }"
                 + "}\n");
     }
-    
+
     //can't parse an expression inside the interpolation expression
     public void _testInterpolationExpression_BUG1() {
         assertParses(".span:nth-child(#{6-$i}) { content: $i; }");
     }
-    
+
     //can't parse an interpolation expression as fn argument
     public void _testInterpolationExpression_BUG2() {
         assertParses(".span:nth-child(#{$i}) { content: $i; }");
@@ -1644,4 +1644,233 @@ public class Css3ParserScssTest extends CssTestBase {
                 + "}\n");
     }
 
+    public void testMixin() {
+        String source = "@mixin simple($selectorPrefix){}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testScssVar() {
+        String source = ".test {background-image: $var;}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testInterpolationInSelector() {
+        String source = ".#{$selectorPrefix}-odd-cols-#{$i} > .oj-row > .oj-col:nth-child(even) {}";
+
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+
+        source = ".table-odd-cols-#{$i} > .oj-row > .oj-col:nth-child(even) {}";
+        result = TestUtil.parse(source);
+        assertResultOK(result);
+
+        source = ".table-odd-cols-#{$i}-test:nth-child(even) {}";
+        result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testMapWithStrings() {
+        String source = "$map: (\n"
+                + "    '1':       'one',\n"
+                + ");";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testMapDeclarationWithDefault() {
+        String source = "$modules: () !default;";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testIfWithoutSpace() {
+        String source = "@if($allowTagSelectors)\n"
+                + "  {\n"
+                + "    #{$tagSelectors} {\n"
+                + "      color: red;\n"
+                + "    }\n"
+                + "  }";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testElseIfTogether() {
+        String source = "@mixin icon($name, $character: null, $font-family: 'Pictos') {\n"
+                + "    @if $character != null {\n"
+                + "        content: \"#{$character}\";\n"
+                + "    } @elseif $raw_character != null {\n"
+                + "        content: \"#{$raw_character}\";\n"
+                + "    }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testFunctionParametersOnNewLines() {
+        String source = "@function matte-gradient (\n"
+                + "    $bg-color: $base-color,\n"
+                + "    $direction: top,\n"
+                + "    $contrast: 1\n"
+                + ") {\n"
+                + "    @return linear-gradient(red);\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testAdditionalCommaInTheEndOfSelector() {
+        String source = ".ui-convex,\n"
+                + ".ui-convex-hover,\n"
+                + "{\n"
+                + "    width: 10em;\n"
+                + "    height: 2em;\n"
+                + "    \n"
+                + "    margin: 1em auto;\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testQuoteEscapingInString() {
+        String source = "@function icon-character-for-name($name) {\n"
+                + "    // http://pictos.cc/font/\n"
+                + "\n"
+                + "    // Row 1\n"
+                + "    @if ($name == \"anchor\") { @return \"a\"; }\n"
+                + "    @else if ($name == \"quote\") { @return \"\\\"\"; }\n"
+                + "    @else if ($name == \"volume_mute\") { @return \"<\"; }}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testEachWithMapPairs() {
+      String source = "@each $header, $size in (h1: 2em, h2: 1.5em, h3: 1.2em) {\n"
+              + "  #{$header} {\n"
+              + "    font-size: $size;\n"
+              + "  }\n"
+              + "}";
+      CssParserResult result = TestUtil.parse(source);
+      assertResultOK(result);
+    }
+    
+    public void testParenSelectorAsPropertyValue() {
+        String source = ".foo .bar, .baz { $selector: & }";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testMultiDimensionalMaps() {
+        String source = "$type-scale: (\n"
+                + "    tiny: (\n"
+                + "        font-size: 10.24px,\n"
+                + "        base-lines: 0.5\n"
+                + "    ),\n"
+                + "    small: (\n"
+                + "        font-size: 12.8px,\n"
+                + "        base-lines: 0.75\n"
+                + "    )\n"
+                + ");\n"
+                + "";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testErrorWithSemi() {
+        String source = "@mixin adjust-location($x, $y) {\n"
+                + "  @if unitless($x) {\n"
+                + "    @error \"$x may not be unitless, was #{$x}.\";\n"
+                + "  }\n"
+                + "  position: relative; left: $x; top: $y;\n"
+                + "}\n"
+                + "";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testAtRootDeclaration() {
+        String source = "@media print {\n"
+                + "  .page {\n"
+                + "    width: 8in;\n"
+                + "    @at-root (without: media) {\n"
+                + "      color: red;\n"
+                + "    }\n"
+                + "  }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testKeyframesInSass() {
+        String source = "@mixin keyframes($name)\n"
+                + "{\n"
+                + "    @-webkit-keyframes $name\n"
+                + "    {\n"
+                + "        @content;\n"
+                + "    }\n"
+                + "    @keyframes $name\n"
+                + "    {\n"
+                + "        @content;\n"
+                + "    }\n"
+                + "}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+        
+        source = "@mixin keyframes($name) {\n"
+                + "  @-webkit-keyframes #{$name} {\n"
+                + "    @content; \n"
+                + "  }}";
+        
+        result = TestUtil.parse(source);
+        assertResultOK(result);
+        
+        source = "@include keyframes(slide-down) {\n"
+                + "  0% { opacity: 1; }\n"
+                + "  90% { opacity: 0; }\n"
+                + "}";
+        
+        result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testSassNestingGreater() {
+        assertParses("div {\n"
+                + "    margin: 0;\n"
+                + "    > {\n"
+                + "        label {\n"
+                + "            float: left;\n"
+                + "        }\n"
+                + "        input {\n"
+                + "            width: 70%; \n"
+                + "        }\n"
+                + "    }\n"
+                + "}");
+    } 
+    
+    public void testPseudoClassBeforeAmpersand() {
+        assertParses("  li {\n"
+                + "        a:hover, &.selected {\n"
+                + "            display: block;\n"
+                + "        }\n"
+                + "    }");
+
+    }
+    
+    public void testDotInterpolationMinus() {
+    assertParses("$fa-css-prefix : test;\n"
+                + ".#{$fa-css-prefix}-2x { font-size: 2em; }");
+    }
+    
+    public void testAmpColonInterpolation() {
+        assertParses("a {\n"
+                + "    &:#{$state}{\n"
+                + "        color: black\n"
+                + "    }\n"
+                + "}");
+    }
+
+    public void testMathExpWithUnits() {
+        assertParses("$fa-li-width: (30em / 14) !default;");
+    }
 }
