@@ -1205,9 +1205,9 @@ public class Css3ParserTest extends CssTestBase {
     //Just a partial hotfix for nested MQ
     //complete grammar is defined in: http://www.w3.org/TR/css3-conditional/#processing
     public void testNestedMediaQuery() throws ParseException, BadLocationException {
-        String source = "@media print { // rule (1)\n"
+        String source = "@media print { \n"
                 + "  #navigation { display: none }\n"
-                + "  @media (max-width: 12cm) { // rule (2)\n"
+                + "  @media (max-width: 12cm) { \n"
                 + "    .note { float: none }\n"
                 + "  }\n"
                 + "}";
@@ -1331,7 +1331,37 @@ public class Css3ParserTest extends CssTestBase {
                 + "    padding: calc(1 * 1);\n"
                 + "}");
     }
+    
+    public void testLessScssKeywordInCss() {
+        assertParses(".and {}");
+        assertParses(".or {}");
+        assertParses(".not {}");
+        assertParses(".only {}");
+        assertParses(".when {}");
+        assertParses(".less {}");
+        assertParses(".css {}");
+        assertParses(".reference {}");
+        assertParses(".inline {}");
+        assertParses(".once {}");
+        assertParses(".multiple {}");
+    }
 
+    public void testIssue248270() {
+        assertParses("video {\n"
+                + "  display: inline-block;\n"
+                + "  *display: inline;\n"
+                + "  *zoom: 1;\n"
+                + "}\n"
+                + "\n"
+                + "select[multiple],\n"
+                + "select[size] {\n"
+                + "  height: auto;\n"
+                + "}");
+
+        assertParses(".test {\n"
+                + "  display: inline;\n"
+                + "}");
+    }
 //    public void testTemplatingMarksInBody() throws ParseException, BadLocationException {
 //        assertParses(" @@@ ");
 //        assertParses(" @@@ .clz {  } @@@ ");
@@ -1344,4 +1374,28 @@ public class Css3ParserTest extends CssTestBase {
 //                + "     margin-top: expression(0 - parseInt(this.offsetHeight / 2) + (TBWindowMargin = document.documentElement && document.documentElement.scrollTop || document.body.scrollTop) + 'px');\n"
 //                + "}");
 //    }
+
+    public void testMediaBodyMinimized() {
+        String source = "@media (min-width: 940px){.demo-appheader-appname-block{margin-top:1px}.demo-appheader-classic .demo-appheader-logo{margin-top:37px}.demo-appheader-classic .demo-appheader-toolbar{height:34px}.demo-appheader-classic .demo-appheader-nav{height:50px}html:not([dir=\"rtl\"]){}}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+
+    public void testCombinatorWithoutSpaces() {
+        String source = "a.oj>.oj {}";
+        CssParserResult result = TestUtil.parse(source);
+        assertResultOK(result);
+    }
+    
+    public void testLineCommentThrowsErrorInCSS() {
+        String source = ".div {\n"
+                + "    color: red\n"
+                + "    // hello\n"
+                + "    font-family: Ariel\n"
+                + "}";
+
+        CssParserResult result = TestUtil.parse(source);
+        assertEquals(1, result.getDiagnostics().size());
+    }
+
 }
