@@ -94,6 +94,7 @@ import org.netbeans.modules.parsing.api.Snapshot;
 import org.netbeans.modules.parsing.api.Source;
 import org.netbeans.modules.parsing.api.UserTask;
 import org.netbeans.modules.parsing.spi.ParseException;
+import org.netbeans.modules.parsing.spi.Parser;
 import org.netbeans.modules.web.common.api.DependencyType;
 import org.netbeans.modules.web.common.api.LexerUtils;
 import org.netbeans.modules.web.common.api.Lines;
@@ -233,6 +234,9 @@ public class CPCssEditorModule extends CssEditorModule {
                         proposals.addAll(getMixinsCompletionProposals(context, model));
                     }
                     break;
+                case DOT:
+                    proposals.addAll(getMixinsCompletionProposals(context, model));
+                break;
             }
                 break;
             case cp_mixin_call:
@@ -525,16 +529,19 @@ public class CPCssEditorModule extends CssEditorModule {
                                     public void run(ResultIterator resultIterator) throws Exception {
                                         ResultIterator cssRI = WebUtils.getResultIterator(resultIterator, "text/css");
                                         if (cssRI != null) {
-                                            CssParserResult result = (CssParserResult) cssRI.getParserResult();
-                                            CPModel model = CPModel.getModel(result);
-                                            for (CPElementHandle mixin : im.getMixins()) {
-                                                if (mixin.getType() == CPElementType.MIXIN_DECLARATION
-                                                        && LexerUtils.equals(searchedMixinName, mixin.getName(), false, false)) {
-                                                    CPElement element = mixin.resolve(model);
-                                                    if (element != null) {
-                                                        locations.add(Pair.of(new CPCslElementHandle(
-                                                                file, mixin.getName(), element.getRange(), mixin.getType()),
-                                                                result.getSnapshot()));
+                                            Parser.Result parserResult = cssRI.getParserResult();
+                                            if (parserResult instanceof CssParserResult) {
+                                                CssParserResult result = (CssParserResult) parserResult;
+                                                CPModel model = CPModel.getModel(result);
+                                                for (CPElementHandle mixin : im.getMixins()) {
+                                                    if (mixin.getType() == CPElementType.MIXIN_DECLARATION
+                                                            && LexerUtils.equals(searchedMixinName, mixin.getName(), false, false)) {
+                                                        CPElement element = mixin.resolve(model);
+                                                        if (element != null) {
+                                                            locations.add(Pair.of(new CPCslElementHandle(
+                                                                    file, mixin.getName(), element.getRange(), mixin.getType()),
+                                                                    result.getSnapshot()));
+                                                        }
                                                     }
                                                 }
                                             }
@@ -681,6 +688,7 @@ public class CPCssEditorModule extends CssEditorModule {
                     case sass_control_block:
                     case cp_mixin_block:
                     case sass_map:
+                    case sass_function_declaration:
                         //find the ruleSet curly brackets and create the fold between them inclusive
                         int from = node.from();
                         int to = node.to();
