@@ -48,6 +48,8 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.CopyOnWriteArrayList;
 import javax.swing.GroupLayout;
@@ -59,6 +61,7 @@ import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.JTextField;
 import javax.swing.LayoutStyle;
+import javax.swing.ListSelectionModel;
 import javax.swing.SwingConstants;
 import javax.swing.UIManager;
 import javax.swing.event.ChangeListener;
@@ -70,9 +73,15 @@ import javax.swing.event.TableModelEvent;
 import javax.swing.event.TableModelListener;
 import javax.swing.table.AbstractTableModel;
 import org.netbeans.api.options.OptionsDisplayer;
+import org.netbeans.api.project.Project;
 import org.netbeans.modules.css.prep.CssPreprocessorType;
+import org.netbeans.modules.css.prep.util.CssPreprocessorUtils;
+import org.netbeans.modules.web.common.api.CssPreprocessor;
 import org.netbeans.modules.web.common.api.CssPreprocessors;
+import org.netbeans.modules.web.common.api.ValidationResult;
 import org.openide.awt.Mnemonics;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
 import org.openide.util.ChangeSupport;
 import org.openide.util.NbBundle;
 import org.openide.util.Pair;
@@ -82,6 +91,8 @@ public class OptionsPanel extends JPanel {
     private static final long serialVersionUID = 16987546576769L;
 
     private final ChangeSupport changeSupport = new ChangeSupport(this);
+    private final CssPreprocessorType type;
+    private final Project project;
     // @GuardedBy("EDT")
     private final MappingsTableModel mappingsTableModel;
     // we must be thread safe
@@ -91,24 +102,31 @@ public class OptionsPanel extends JPanel {
     volatile boolean configured = false;
     volatile boolean enabled;
     volatile String compilerOptions;
+    // #253814
+    // @GuardedBy("EDT")
+    private boolean recompileButtonDisabled = false;
 
 
-    public OptionsPanel(CssPreprocessorType type, boolean initialEnabled, List<Pair<String, String>> initialMappings, String initialCompilerOptions) {
+    public OptionsPanel(CssPreprocessorType type, Project project, boolean initialEnabled, List<Pair<String, String>> initialMappings, String initialCompilerOptions) {
         assert EventQueue.isDispatchThread();
+        assert type != null;
+        assert project != null;
 
+        this.type = type;
+        this.project = project;
         mappingsTableModel = new MappingsTableModel(mappings);
         enabled = initialEnabled;
         compilerOptions = initialCompilerOptions;
 
         initComponents();
-        init(type, initialEnabled, initialMappings, initialCompilerOptions);
+        init(initialEnabled, initialMappings, initialCompilerOptions);
     }
 
     @NbBundle.Messages({
         "# {0} - preprocessor name",
         "OptionsPanel.compilationEnabled.label=Co&mpile {0} Files on Save",
     })
-    private void init(CssPreprocessorType type, boolean initialEnabled, List<Pair<String, String>> initialMappings, String initialCompilerOptions) {
+    private void init(boolean initialEnabled, List<Pair<String, String>> initialMappings, String initialCompilerOptions) {
         assert EventQueue.isDispatchThread();
         configureExecutablesButton.setVisible(false);
         Mnemonics.setLocalizedText(enabledCheckBox, Bundle.OptionsPanel_compilationEnabled_label(type.getDisplayName()));
@@ -120,6 +138,7 @@ public class OptionsPanel extends JPanel {
         // ui
         enablePanel(initialEnabled);
         enableRemoveButton();
+        enableMoveButtons();
         if ("Mac OS X".equals(UIManager.getLookAndFeel().getName())) { //NOI18N
             mappingsTable.setShowGrid(true);
             mappingsTable.setGridColor(Color.GRAY);
@@ -131,13 +150,13 @@ public class OptionsPanel extends JPanel {
                 enabled = e.getStateChange() == ItemEvent.SELECTED;
                 configured = true;
                 enablePanel(enabled);
-                fireChange();
+                fireChange(false);
             }
         });
         mappingsTableModel.addTableModelListener(new TableModelListener() {
             @Override
             public void tableChanged(TableModelEvent e) {
-                fireChange();
+                fireChange(true);
             }
         });
         mappingsTable.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
@@ -147,6 +166,7 @@ public class OptionsPanel extends JPanel {
                     return;
                 }
                 enableRemoveButton();
+                enableMoveButtons();
             }
         });
         compilerOptionsTextField.getDocument().addDocumentListener(new DocumentListener() {
@@ -164,7 +184,7 @@ public class OptionsPanel extends JPanel {
             }
             private void processChange() {
                 compilerOptions = compilerOptionsTextField.getText();
-                fireChange();
+                fireChange(true);
             }
         });
     }
@@ -187,7 +207,7 @@ public class OptionsPanel extends JPanel {
     }
 
     public List<Pair<String, String>> getMappings() {
-        return mappings;
+        return Collections.unmodifiableList(mappings);
     }
 
     public void setMappings(List<Pair<String, String>> mappings) {
@@ -215,11 +235,24 @@ public class OptionsPanel extends JPanel {
         changeSupport.removeChangeListener(listener);
     }
 
-    void fireChange() {
+    void fireChange(boolean disableRecompile) {
+        assert EventQueue.isDispatchThread();
         changeSupport.fireChange();
+        if (disableRecompile) {
+            boolean refresh = !recompileButtonDisabled;
+            recompileButtonDisabled = true;
+            if (refresh) {
+                enableRecompileButton();
+            }
+        }
     }
 
     void enablePanel(boolean enabled) {
+        if (enabled) {
+            enableRecompileButton();
+        } else {
+            recompileButton.setEnabled(false);
+        }
         watchLabel.setEnabled(enabled);
         mappingsTable.setEnabled(enabled);
         mappingsInfoLabel.setEnabled(enabled);
@@ -227,18 +260,64 @@ public class OptionsPanel extends JPanel {
         configureExecutablesButton.setEnabled(enabled);
         if (enabled) {
             enableRemoveButton();
+            enableMoveButtons();
         } else {
             removeButton.setEnabled(false);
+            moveDownButton.setEnabled(false);
+            moveUpButton.setEnabled(false);
         }
         compilerOptionsLabel.setEnabled(enabled);
         compilerOptionsTextField.setEnabled(enabled);
         compilerOptionsInfoLabel.setEnabled(enabled);
     }
 
+    @NbBundle.Messages({
+        "OptionsPanel.recompile.error.noWebRoot=No web root is set.",
+        "OptionsPanel.recompile.error.changeDetected=Save and reopen this dialog first.",
+    })
+    void enableRecompileButton() {
+        assert EventQueue.isDispatchThread();
+        FileObject webRoot = CssPreprocessorUtils.getWebRoot(project);
+        if (webRoot == null) {
+            recompileButton.setEnabled(false);
+            recompileButton.setToolTipText(Bundle.OptionsPanel_recompile_error_noWebRoot());
+            return;
+        }
+        if (recompileButtonDisabled) {
+            recompileButton.setEnabled(false);
+            recompileButton.setToolTipText(Bundle.OptionsPanel_recompile_error_changeDetected());
+            return;
+        }
+        ValidationResult result = type.getPreferencesValidator()
+                .validateMappings(webRoot, true, mappings)
+                .getResult();
+        recompileButton.setEnabled(result.isFaultless());
+        recompileButton.setToolTipText(null);
+    }
+
     void enableRemoveButton() {
         removeButton.setEnabled(mappingsTable.getSelectedRowCount() > 0);
     }
 
+    void enableMoveButtons() {
+        int[] selectedRows = mappingsTable.getSelectedRows();
+        if (selectedRows.length == 0) {
+            moveDownButton.setEnabled(false);
+            moveUpButton.setEnabled(false);
+            return;
+        }
+        moveDownButton.setEnabled(Arrays.binarySearch(selectedRows, mappingsTable.getRowCount() - 1) < 0);
+        moveUpButton.setEnabled(Arrays.binarySearch(selectedRows, 0) < 0);
+    }
+
+    private void selectRows(int[] selectedRows, int delta) {
+        ListSelectionModel listSelectionModel = mappingsTable.getSelectionModel();
+        listSelectionModel.clearSelection();
+        for (int selectedRow : selectedRows) {
+            listSelectionModel.addSelectionInterval(selectedRow + delta, selectedRow + delta);
+        }
+    }
+
     /**
      * This method is called from within the constructor to initialize the form. WARNING: Do NOT modify this code. The content of this method is always regenerated by the Form
      * Editor.
@@ -250,10 +329,13 @@ public class OptionsPanel extends JPanel {
         enabledCheckBox = new JCheckBox();
         configureExecutablesButton = new JButton();
         watchLabel = new JLabel();
+        recompileButton = new JButton();
         mappingsScrollPane = new JScrollPane();
         mappingsTable = new JTable();
         addButton = new JButton();
         removeButton = new JButton();
+        moveUpButton = new JButton();
+        moveDownButton = new JButton();
         mappingsInfoLabel = new JLabel();
         compilerOptionsLabel = new JLabel();
         compilerOptionsTextField = new JTextField();
@@ -271,6 +353,13 @@ public class OptionsPanel extends JPanel {
         watchLabel.setLabelFor(mappingsTable);
         Mnemonics.setLocalizedText(watchLabel, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.watchLabel.text")); // NOI18N
 
+        Mnemonics.setLocalizedText(recompileButton, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.recompileButton.text")); // NOI18N
+        recompileButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                recompileButtonActionPerformed(evt);
+            }
+        });
+
         mappingsScrollPane.setViewportView(mappingsTable);
 
         Mnemonics.setLocalizedText(addButton, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.addButton.text")); // NOI18N
@@ -287,6 +376,20 @@ public class OptionsPanel extends JPanel {
             }
         });
 
+        Mnemonics.setLocalizedText(moveUpButton, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.moveUpButton.text")); // NOI18N
+        moveUpButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                moveUpButtonActionPerformed(evt);
+            }
+        });
+
+        Mnemonics.setLocalizedText(moveDownButton, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.moveDownButton.text")); // NOI18N
+        moveDownButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                moveDownButtonActionPerformed(evt);
+            }
+        });
+
         Mnemonics.setLocalizedText(mappingsInfoLabel, NbBundle.getMessage(OptionsPanel.class, "OptionsPanel.mappingsInfoLabel.text")); // NOI18N
 
         compilerOptionsLabel.setLabelFor(compilerOptionsTextField);
@@ -298,8 +401,7 @@ public class OptionsPanel extends JPanel {
 
         GroupLayout layout = new GroupLayout(this);
         this.setLayout(layout);
-        layout.setHorizontalGroup(
-            layout.createParallelGroup(GroupLayout.Alignment.LEADING)
+        layout.setHorizontalGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
                 .addComponent(enabledCheckBox)
                 .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
@@ -309,7 +411,9 @@ public class OptionsPanel extends JPanel {
                 .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(GroupLayout.Alignment.TRAILING)
                     .addComponent(addButton)
-                    .addComponent(removeButton)))
+                    .addComponent(removeButton)
+                    .addComponent(moveDownButton, GroupLayout.Alignment.LEADING)
+                    .addComponent(moveUpButton)))
             .addGroup(layout.createSequentialGroup()
                 .addComponent(compilerOptionsLabel)
                 .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
@@ -319,29 +423,37 @@ public class OptionsPanel extends JPanel {
                         .addGap(0, 0, Short.MAX_VALUE))
                     .addComponent(compilerOptionsTextField)))
             .addGroup(layout.createSequentialGroup()
-                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
-                    .addComponent(watchLabel)
-                    .addComponent(mappingsInfoLabel))
+                .addComponent(watchLabel)
+                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                .addComponent(recompileButton))
+            .addGroup(layout.createSequentialGroup()
+                .addComponent(mappingsInfoLabel)
                 .addGap(0, 0, Short.MAX_VALUE))
         );
 
-        layout.linkSize(SwingConstants.HORIZONTAL, new Component[] {addButton, removeButton});
+        layout.linkSize(SwingConstants.HORIZONTAL, new Component[] {addButton, moveDownButton, moveUpButton, removeButton});
 
-        layout.setVerticalGroup(
-            layout.createParallelGroup(GroupLayout.Alignment.LEADING)
+        layout.setVerticalGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
                 .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
                     .addComponent(enabledCheckBox)
                     .addComponent(configureExecutablesButton))
                 .addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
-                .addComponent(watchLabel)
+                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.TRAILING)
+                    .addComponent(watchLabel)
+                    .addComponent(recompileButton))
                 .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
-                    .addComponent(mappingsScrollPane, GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE)
+                    .addComponent(mappingsScrollPane, GroupLayout.DEFAULT_SIZE, 195, Short.MAX_VALUE)
                     .addGroup(layout.createSequentialGroup()
                         .addComponent(addButton)
                         .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
-                        .addComponent(removeButton)))
+                        .addComponent(removeButton)
+                        .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(moveUpButton)
+                        .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(moveDownButton)
+                        .addGap(0, 0, Short.MAX_VALUE)))
                 .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                 .addComponent(mappingsInfoLabel)
                 .addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
@@ -373,6 +485,49 @@ public class OptionsPanel extends JPanel {
         OptionsDisplayer.getDefault().open(CssPreprocessors.OPTIONS_PATH);
     }//GEN-LAST:event_configureExecutablesButtonActionPerformed
 
+    private void recompileButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_recompileButtonActionPerformed
+        assert EventQueue.isDispatchThread();
+        CssPreprocessor cssPreprocessor = CssPreprocessors.getDefault().getCssPreprocessor(type.getIdentifier());
+        assert cssPreprocessor != null : "CSS preprocessor must be found for identifier: " + type.getIdentifier();
+        FileObject webRoot = CssPreprocessorUtils.getWebRoot(project);
+        assert webRoot != null : "No web root found for project: " + project.getProjectDirectory();
+        for (Pair<String, String> mapping : mappings) {
+            FileObject input = FileUtil.toFileObject(CssPreprocessorUtils.resolveInput(webRoot, mapping));
+            if (input == null) {
+                // non-existing file
+                continue;
+            }
+            CssPreprocessors.getDefault().process(cssPreprocessor, project, input);
+        }
+    }//GEN-LAST:event_recompileButtonActionPerformed
+
+    private void moveUpButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_moveUpButtonActionPerformed
+        assert EventQueue.isDispatchThread();
+        int[] selectedRows = mappingsTable.getSelectedRows();
+        for (int selectedRow : selectedRows) {
+            Pair<String, String> up = mappings.get(selectedRow);
+            Pair<String, String> down = mappings.get(selectedRow - 1);
+            mappings.set(selectedRow - 1, up);
+            mappings.set(selectedRow, down);
+        }
+        mappingsTableModel.fireMappingsChange();
+        selectRows(selectedRows, -1);
+    }//GEN-LAST:event_moveUpButtonActionPerformed
+
+    private void moveDownButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_moveDownButtonActionPerformed
+        assert EventQueue.isDispatchThread();
+        int[] selectedRows = mappingsTable.getSelectedRows();
+        for (int i = selectedRows.length - 1; i >= 0; --i) {
+            int selectedRow = selectedRows[i];
+            Pair<String, String> down = mappings.get(selectedRow);
+            Pair<String, String> up = mappings.get(selectedRow + 1);
+            mappings.set(selectedRow + 1, down);
+            mappings.set(selectedRow, up);
+        }
+        mappingsTableModel.fireMappingsChange();
+        selectRows(selectedRows, 1);
+    }//GEN-LAST:event_moveDownButtonActionPerformed
+
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private JButton addButton;
     private JLabel compilerOptionsInfoLabel;
@@ -383,6 +538,9 @@ public class OptionsPanel extends JPanel {
     private JLabel mappingsInfoLabel;
     private JScrollPane mappingsScrollPane;
     private JTable mappingsTable;
+    private JButton moveDownButton;
+    private JButton moveUpButton;
+    private JButton recompileButton;
     private JButton removeButton;
     private JLabel watchLabel;
     // End of variables declaration//GEN-END:variables
