@@ -221,14 +221,14 @@ public final class SQLExecuteHelper {
         private static final int STATE_MAYBE_BLOCK_COMMENT = 3;
         private static final int STATE_BLOCK_COMMENT = 4;
         private static final int STATE_MAYBE_END_BLOCK_COMMENT = 5;
-        private static final int STATE_STRING = 6;
+        private static final int STATE_QUOTED = 6;
         
-        private String sql;
-        private int sqlLength;
-        private boolean useHashComments;
+        private final String sql;
+        private final int sqlLength;
+        private final boolean useHashComments;
         
-        private StringBuffer statement = new StringBuffer();
-        private List<StatementInfo> statements = new ArrayList<StatementInfo>();
+        private final StringBuilder statement = new StringBuilder();
+        private final List<StatementInfo> statements = new ArrayList<StatementInfo>();
         
         private int pos = 0;
         private int line = -1;
@@ -263,6 +263,8 @@ public final class SQLExecuteHelper {
 
         private void parse() {
             checkDelimiterStatement();
+            int startQuote = -1;
+            int commentStart = 0;
             while (pos < sqlLength) {
                 char ch = sql.charAt(pos);
                 
@@ -294,13 +296,15 @@ public final class SQLExecuteHelper {
                             if (statement.length() == 0 || !Character.isLetterOrDigit(statement.charAt(statement.length() - 1))) {
                                 state = STATE_LINE_COMMENT;
                             }
-                        } else if (ch == '\'') {
-                            state = STATE_STRING;
+                        } else if (isStartQuote(ch)) {
+                            startQuote = ch;
+                            state = STATE_QUOTED;
                         }
                         break;
                         
                     case STATE_MAYBE_LINE_COMMENT:
                         if (ch == '-') {
+                            commentStart = pos + 1;
                             state = STATE_LINE_COMMENT;
                         } else {
                             state = STATE_MEANINGFUL_TEXT;
@@ -311,12 +315,14 @@ public final class SQLExecuteHelper {
                         
                     case STATE_LINE_COMMENT:
                         if (ch == '\n') {
+                            checkForDelimiterStmt(commentStart, pos - 1);
                             state = STATE_MEANINGFUL_TEXT;
                         } 
                         break;
                         
                     case STATE_MAYBE_BLOCK_COMMENT:
                         if (ch == '*') {
+                            commentStart = pos + 1;
                             state = STATE_BLOCK_COMMENT;
                         } else {
                             statement.append('/'); // previous char
@@ -335,6 +341,7 @@ public final class SQLExecuteHelper {
                         
                     case STATE_MAYBE_END_BLOCK_COMMENT:
                         if (ch == '/') {
+                            checkForDelimiterStmt(commentStart, pos - 2);
                             state = STATE_MEANINGFUL_TEXT;
                             // avoid writing the final / to the result
                             pos++;
@@ -344,9 +351,24 @@ public final class SQLExecuteHelper {
                         }
                         break;
                         
-                    case STATE_STRING:
-                        if (ch == '\'') {
-                            state = STATE_MEANINGFUL_TEXT;
+                    case STATE_QUOTED:
+                        int lookAhead = -1;
+                        if((pos + 1) < sqlLength) {
+                            lookAhead = sql.charAt(pos + 1);
+                        }
+                        if (isEndQuote(startQuote, ch)) {
+                            if (lookAhead >= 0 && isEndQuote(startQuote, lookAhead)) {
+                                statement.append(ch);
+                                statement.append((char) lookAhead);
+                                pos += 2;
+                                // the end offset is the character after the last non-whitespace character
+                                if (state == STATE_QUOTED || !Character.isWhitespace(ch)) {
+                                    endOffset = pos + 1;
+                                }
+                                continue;
+                            } else {
+                                state = STATE_MEANINGFUL_TEXT;
+                            }
                         }
                         break;
                         
@@ -354,7 +376,7 @@ public final class SQLExecuteHelper {
                         assert false;
                 }
                 
-                if (state == STATE_MEANINGFUL_TEXT || state == STATE_STRING) {
+                if (state == STATE_MEANINGFUL_TEXT || state == STATE_QUOTED) {
                     // don't append leading whitespace
                     if (statement.length() > 0 || !Character.isWhitespace(ch)) {
                         // remember the position of the first appended char
@@ -372,7 +394,7 @@ public final class SQLExecuteHelper {
                         }
                         statement.append(ch);
                         // the end offset is the character after the last non-whitespace character
-                        if (state == STATE_STRING || !Character.isWhitespace(ch)) {
+                        if (state == STATE_QUOTED || !Character.isWhitespace(ch)) {
                             endOffset = pos + 1;
                         }
                     }
@@ -383,6 +405,44 @@ public final class SQLExecuteHelper {
             rawEndOffset = pos;
             addStatement();
         }
+
+        // The methods to detect quoting chars are copied from SQLLexer from the 
+        // org.netbeans.modules.db.sql.editor module
+        // Copied to not introduce another dependency
+        private static boolean isStartQuote(int start) {
+            return isStartStringQuoteChar(start) || isStartIdentifierQuoteChar(start);
+        }
+        
+        private static boolean isEndQuote(int start, int end) {
+            return isEndIdentifierQuoteChar(start, end) || isEndStringQuoteChar(start, end);
+        }
+        
+        private static boolean isStartStringQuoteChar(int start) {
+            return start == '\'';  // SQL-99 string
+        }
+
+        private static boolean isStartIdentifierQuoteChar(int start) {
+            return start == '\"' || // SQL-99
+                    start == '`' || // MySQL
+                    start == '[';    // MS SQL Server
+        }
+
+        private static int getMatchingQuote(int start) {
+            switch (start) {
+                case '[':
+                    return ']';
+                default:
+                    return start;
+            }
+        }
+
+        private static boolean isEndIdentifierQuoteChar(int start, int end) {
+            return isStartIdentifierQuoteChar(start) && end == getMatchingQuote(start);
+        }
+
+        private static boolean isEndStringQuoteChar(int start, int end) {
+            return isStartStringQuoteChar(start) && end == getMatchingQuote(start);
+        }
         
         /**
          * See if the user wants to use a different delimiter for splitting
@@ -431,6 +491,47 @@ public final class SQLExecuteHelper {
             return true;
         }
         
+        /**
+         * Check for Delimiter Statement in comment.
+         * 
+         * Simulates regular behaviour found in checkDelimiterStatement
+         */
+        private void checkForDelimiterStmt(int initialOffset, int end) {
+            int start = initialOffset;
+            while(Character.isWhitespace(sql.charAt(start)) && start < end) {
+                start++;
+            }
+            if(start >= end && (end - start + 1) <= DELIMITER_TOKEN.length()) {
+                return;
+            }
+            boolean delimiterMatched = true;
+            for(int i = 0; i < DELIMITER_TOKEN.length(); i++) {
+                if(Character.toUpperCase(sql.charAt(start)) != 
+                        Character.toUpperCase(DELIMITER_TOKEN.charAt(i))) {
+                    delimiterMatched = false;
+                    break;
+                }
+                start++;
+            }
+            if(! delimiterMatched) {
+                return;
+            }
+            while (Character.isWhitespace(sql.charAt(start)) && start < end) {
+                start++;
+            }
+            StringBuilder sb = new  StringBuilder();
+            for(int i = start; i <= end; i++) {
+                if(! Character.isWhitespace(sql.charAt(i))) {
+                    sb.append(sql.charAt(i));
+                } else {
+                    break;
+                }
+            }
+            if(sb.length() > 0) {
+                delimiter = sb.toString();
+            }
+        }
+        
         private void skipWhitespace() {
             while ( pos < sqlLength && Character.isWhitespace(sql.charAt(pos)) ) {
                 nextColumn();
