@@ -43,11 +43,9 @@
  */
 package org.netbeans.modules.db.dataview.output;
 
-import java.awt.AWTEvent;
 import java.awt.Component;
 import java.awt.Container;
 import java.awt.Dimension;
-import java.awt.EventQueue;
 import java.awt.FocusTraversalPolicy;
 import java.awt.Rectangle;
 import org.netbeans.modules.db.dataview.table.JXTableRowHeader;
@@ -55,9 +53,11 @@ import java.awt.Toolkit;
 import java.awt.datatransfer.Clipboard;
 import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.StringSelection;
+import java.awt.datatransfer.UnsupportedFlavorException;
 import java.awt.event.ActionEvent;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
+import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
 import java.util.StringTokenizer;
@@ -89,7 +89,6 @@ import org.netbeans.modules.db.dataview.util.DataViewUtils;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.NbBundle;
-import org.openide.util.RequestProcessor;
 import org.openide.util.Utilities;
 import org.openide.windows.WindowManager;
 
@@ -126,22 +125,6 @@ class InsertRecordDialog extends javax.swing.JDialog {
                 if (rowIndex != -1 && columnIndex != -1 && getModel().getRowCount() > 1) {
                     removeBtn.setEnabled(true);
                 }
-                AWTEvent awtEvent = EventQueue.getCurrentEvent();
-                if (awtEvent instanceof KeyEvent) {
-                    KeyEvent keyEvt = (KeyEvent) awtEvent;
-                    if (keyEvt.getSource() != InsertRecordDialog.this) {
-                        return;
-                    }
-                    if (rowIndex == 0 && columnIndex == 0 && KeyStroke.getKeyStrokeForEvent(keyEvt).equals(KeyStroke.getKeyStroke(KeyEvent.VK_TAB, 0))) {
-                        appendEmptyRow();
-                        rowIndex = getRowCount() - 1; //Otherwise the selection switches to the first row
-                        editCellAt(rowIndex, 0);
-                    } else if (KeyStroke.getKeyStrokeForEvent(keyEvt).equals(KeyStroke.getKeyStroke(KeyEvent.VK_SHIFT + KeyEvent.VK_TAB, 0))) {
-                        editCellAt(rowIndex, columnIndex);
-                    } else {
-                        editCellAt(rowIndex, columnIndex);
-                    }
-                }
                 super.changeSelection(rowIndex, columnIndex, toggle, extend);
             }
         };
@@ -357,7 +340,7 @@ private void removeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIR
         dispose();
     }
 
-    public class TableListener implements TableModelListener {
+    private class TableListener implements TableModelListener {
 
         @Override
         public void tableChanged(TableModelEvent e) {
@@ -393,52 +376,43 @@ private void removeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIR
             return;
         }
 
-        // Get out of AWT thread because SQLExecutionHelper does calls to AWT
-        // and we need to wait here to show possible exceptions.
+        // Get out of AWT thread
         new SwingWorker<Integer, Void>() {
 
             @Override
             protected Integer doInBackground() throws Exception {
                 SQLStatementGenerator stmtBldr = dataView.getSQLStatementGenerator();
                 SQLExecutionHelper execHelper = dataView.getSQLExecutionHelper();
+                String inserts[] = new String[rows];
+
                 for (int i = 0; i < rows; i++) {
-                    boolean wasException;
-                    try {
-                        Object[] insertedRow = insertedRows[i];
-                        String insertSQL = stmtBldr.generateInsertStatement(insertTable, insertedRow);
-                        RequestProcessor.Task task = execHelper.executeInsertRow(pageContext, insertTable, insertSQL, insertedRow);
-                        task.waitFinished();
-                        wasException = dataView.hasExceptions();
-                    } catch (DBException ex) {
-                        LOG.log(Level.INFO, ex.getLocalizedMessage(), ex);
-                        DialogDisplayer.getDefault().notifyLater(new NotifyDescriptor.Message(ex.getLocalizedMessage()));
-                        wasException = true;
-                    }
-                    if (wasException) {
-                        return i;
-                    }
+                    inserts[i] = stmtBldr.generateInsertStatement(insertTable, insertedRows[i]);
                 }
-                return null;
+
+                return execHelper.executeInsertRow(pageContext, insertTable, inserts, insertedRows);
             }
 
             @Override
             protected void done() {
-                Integer brokeOn;
+                Integer doneCount;
                 try {
-                    brokeOn = get();
+                    doneCount = get();
 
-                    if (brokeOn == null) {
+                    if (doneCount == rows) {
                         dispose();
                     } else {
                         // remove i already inserted
-                        for (int j = 0; j < brokeOn; j++) {
+                        for (int j = 0; j < doneCount; j++) {
                             insertRecordTableUI.getModel().removeRow(0);
                         }
                     }
                 } catch (InterruptedException ex) {
                     throw new RuntimeException(ex);
                 } catch (ExecutionException ex) {
-                    throw new RuntimeException(ex);
+                    LOG.log(Level.INFO, ex.getCause().getLocalizedMessage(), ex);
+                    DialogDisplayer.getDefault().notifyLater(
+                            new NotifyDescriptor.Message(
+                                    ex.getCause().getLocalizedMessage()));
                 }
             }
         }.execute();
@@ -639,7 +613,7 @@ private void removeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIR
                     }
                 }
             }
-        } catch (Exception ex) {
+        } catch (UnsupportedFlavorException | IOException | RuntimeException ex) {
             LOG.log(Level.INFO, "Failed to paste the contents ", ex);
         }
     }
