@@ -50,13 +50,13 @@ import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 import java.awt.event.ItemEvent;
 import java.net.MalformedURLException;
-import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.Map.Entry;
 import java.util.Properties;
-import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import javax.swing.JComboBox;
 import javax.swing.JLabel;
 import javax.swing.JTextArea;
@@ -73,7 +73,6 @@ import org.netbeans.api.db.explorer.JDBCDriver;
 import org.netbeans.api.db.explorer.JDBCDriverManager;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
-import org.netbeans.modules.db.explorer.ConnectionList;
 import org.netbeans.modules.db.util.DatabaseExplorerInternalUIs;
 import org.netbeans.modules.db.util.JdbcUrl;
 import org.netbeans.modules.db.util.PropertyEditorPanel;
@@ -85,18 +84,18 @@ import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
 public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
-
+    private static final Logger LOGGER = Logger.getLogger(NewConnectionPanel.class.getName());
+    private static final Pattern numbers = Pattern.compile("(\\d+)");
+    private static final String USERINPUT_FIELD = "<USERNAME>";
+    
     private AddConnectionWizard wd;
-    // private Vector templates;
     private DatabaseConnection connection;
     private ProgressHandle progressHandle;
     private Window window;
     private boolean updatingUrl = false;
     private boolean updatingFields = false;
-    private final LinkedHashMap<String, UrlField> urlFields =
-            new LinkedHashMap<String, UrlField>();
-    private Set<String> knownConnectionNames = new HashSet<String>();
-    private static final Logger LOGGER = Logger.getLogger(NewConnectionPanel.class.getName());
+    private final LinkedHashMap<String, UrlField> urlFields = new LinkedHashMap<>();
+    
     private final ConnectionPanel wp;
     private Properties connectionProperties = new Properties();
 
@@ -148,11 +147,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
             }
         };
         wd.addConnectionProgressListener(progressListener);
-
-        userField.setText(connection.getUser());
-
-        passwordField.setText(connection.getPassword());
-
+        
         String driver = connection.getDriver();
         String driverName = connection.getDriverName();
         if (driver != null && driverName != null) {
@@ -171,11 +166,13 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
 
         for (Entry<String, UrlField> entry : urlFields.entrySet()) {
             new InputAdapter(entry.getValue().getField());
+            new FocusAdapter(entry.getKey(), entry.getValue().getField());
         }
 
         new InputAdapter(templateComboBox);
         new InputAdapter(userField);
         new InputAdapter(passwordField);
+        new FocusAdapter(USERINPUT_FIELD, userField);
 
         urlField.addFocusListener(new FocusListener() {
 
@@ -212,9 +209,26 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
             }
         });
 
-        urlField.setVisible(true);
-
         setUrlField();
+        
+        JdbcUrl url = getSelectedJdbcUrl();
+        
+        if(wd.getUser() != null) {
+            userField.setText(wd.getUser());
+        } else if (url.getSampleUser() != null) {
+            userField.setText(url.getSampleUser());
+        }
+        if (wd.getPassword() != null) {
+            passwordField.setText(wd.getPassword());
+        } else if (url.getSamplePassword()!= null) {
+            passwordField.setText(url.getSamplePassword());
+        }
+        if (wd.getDatabaseUrl() != null) {
+            urlField.setText(wd.getDatabaseUrl());
+        } else if (url.getSampleUrl() != null) {
+            urlField.setText(url.getSampleUrl());
+        }
+        
         updateFieldsFromUrl();
         setUpFields();
         connectionProperties = connection.getConnectionProperties();
@@ -239,10 +253,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
 
         userField.getDocument().addDocumentListener(docListener);
         passwordField.getDocument().addDocumentListener(docListener);
-
-        for (DatabaseConnection existingConnection : ConnectionList.getDefault().getConnections()) {
-            knownConnectionNames.add(existingConnection.getDisplayName());
-        }
+        
     }
 
     public void setWindow(Window window) {
@@ -451,7 +462,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
                             .addComponent(urlField, javax.swing.GroupLayout.Alignment.TRAILING)
                             .addComponent(templateComboBox, javax.swing.GroupLayout.Alignment.TRAILING, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                             .addGroup(layout.createSequentialGroup()
-                            .addComponent(passwordCheckBox, javax.swing.GroupLayout.PREFERRED_SIZE, 256, javax.swing.GroupLayout.PREFERRED_SIZE)
+                                .addComponent(passwordCheckBox, javax.swing.GroupLayout.PREFERRED_SIZE, 256, javax.swing.GroupLayout.PREFERRED_SIZE)
                                 .addGap(0, 0, Short.MAX_VALUE)))))
                 .addContainerGap())
         );
@@ -510,7 +521,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
                 .addComponent(passwordCheckBox)
                 .addGap(26, 26, 26)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
-                .addComponent(bTestConnection)
+                    .addComponent(bTestConnection)
                     .addComponent(bConnectionProperties))
                 .addGap(18, 18, 18)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
@@ -540,7 +551,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
             }
             else if (evt.getSource() == bConnectionProperties) {
                 NewConnectionPanel.this.bConnectionPropertiesActionPerformed(evt);
-        }
+            }
         }
 
         public void focusGained(java.awt.event.FocusEvent evt) {
@@ -585,7 +596,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
 
     private void templateComboBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_templateComboBoxItemStateChanged
         if (evt.getStateChange() == ItemEvent.SELECTED) {
-            Object item = templateComboBox.getSelectedItem();
+            Object item = evt.getItem();
             if (item != null && !(item instanceof JdbcUrl)) {
                 // This is an item indicating "Create a New Driver", and if
                 // we futz with the fields, then the ComboBox wants to make the
@@ -595,7 +606,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
             }
 
             JdbcUrl jdbcurl = (JdbcUrl) item;
-
+            
             // Field entry mode doesn't make sense if this URL isn't parsed.  change the mode
             // now if appropriate
             if (!jdbcurl.isParseUrl()) {
@@ -709,8 +720,6 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
                 entry.getValue().getLabel().setVisible(false);
             }
 
-            urlField.setVisible(true);
-
             checkValid();
             resize();
             return;
@@ -732,7 +741,6 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
         }
 
         if (!jdbcurl.isParseUrl()) {
-            urlField.setVisible(true);
             setUrlField();
         }
 
@@ -907,7 +915,7 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
         boolean requiredFieldMissing = false;
         if (url == null) {
             displayMessage(NbBundle.getMessage(NewConnectionPanel.class, "NewConnection.MSG_SelectADriver"), false);
-        } else if (url != null && url.isParseUrl()) {
+        } else if (url.isParseUrl()) {
             for (Entry<String, UrlField> entry : urlFields.entrySet()) {
                 if (url.requiresToken(entry.getKey()) && isEmpty(entry.getValue().getField().getText())) {
                     requiredFieldMissing = true;
@@ -1040,6 +1048,63 @@ public class NewConnectionPanel extends ConnectionDialog.FocusablePanel {
         }
     }
 
+    /**
+     * Class handles focus lost event and trims field contents and ensures port
+     * to be numeric.
+     */
+    private class FocusAdapter implements FocusListener {
+        private final String targetToken;
+
+        public FocusAdapter(String targetToken, JTextField textField) {
+            this.targetToken = targetToken;
+            textField.addFocusListener(this);
+        }
+        
+        @Override
+        public void focusGained(FocusEvent e) {}
+
+        @Override
+        public void focusLost(FocusEvent e) {
+            Object source = e.getSource();
+            if (source instanceof JTextField) {
+                JTextField textField = (JTextField) source;
+                String inputText = textField.getText();
+                switch(targetToken) {
+                    case JdbcUrl.TOKEN_HOST:
+                    case JdbcUrl.TOKEN_DB:
+                    case JdbcUrl.TOKEN_SID:
+                    case JdbcUrl.TOKEN_SERVICENAME:
+                    case JdbcUrl.TOKEN_TNSNAME:
+                    case JdbcUrl.TOKEN_DSN:
+                    case JdbcUrl.TOKEN_SERVERNAME:
+                    case JdbcUrl.TOKEN_INSTANCE:
+                    case USERINPUT_FIELD:
+                        textField.setText(inputText.trim());
+                        break;
+                    case JdbcUrl.TOKEN_PORT:
+                        Integer port = null;
+                        try {
+                            port = Integer.valueOf(inputText.trim());
+                        } catch (NumberFormatException ex) {}
+                        if(port != null) {
+                            textField.setText(Integer.toString(port));
+                        } else {
+                            Matcher numberMatcher = numbers.matcher(inputText);
+                            if(numberMatcher.find()) {
+                                textField.setText(numberMatcher.group(1));
+                            } else {
+                                textField.setText("");
+                            }
+                        }
+                        break;
+                    default:
+                        // Unhandled fields are left untouched
+                        break;
+                }
+            }
+        }
+    }
+    
     /**
      * This class is used to track user input for an associated input field.
      */
