@@ -81,7 +81,7 @@ import org.openide.util.datatransfer.ExTransferable;
  *
  * @author Rob Englander
  */
-public class ConnectionNode extends BaseNode {
+public class ConnectionNode extends BaseNode implements PropertyChangeListener {
     
     private static final String CONNECTEDICONBASE = "org/netbeans/modules/db/resources/connection.gif"; // NOI18N
     private static final String DISCONNECTEDICONBASE = "org/netbeans/modules/db/resources/connectionDisconnected.gif"; // NOI18N
@@ -110,7 +110,6 @@ public class ConnectionNode extends BaseNode {
     
     // the connection
     private final DatabaseConnection connection;
-    private PropertyChangeListener propertyChangeListener;
 
     /**
      * Constructor
@@ -126,24 +125,23 @@ public class ConnectionNode extends BaseNode {
     @Override
     protected void initialize() {
         // listen for change events
-        connection.addPropertyChangeListener(
-                new PropertyChangeListener() {
-                    private final RequestProcessor.Task UPDATE = RP.create(
-                            new Runnable() { //#203127 - asynchronous update
-                                @Override
-                                public void run() {
-                                    updateModel();
-                                }
-                            });
-
-                    @Override
-                    public void propertyChange(PropertyChangeEvent evt) {
-                        UPDATE.schedule(10);
-                    }
-                });
+        connection.addPropertyChangeListener(WeakListeners.propertyChange(this, connection));
         updateModel();
     }
 
+    private final RequestProcessor.Task UPDATE = RP.create(
+            new Runnable() { //#203127 - asynchronous update
+                @Override
+                public void run() {
+                    updateModel();
+                }
+            });
+
+    @Override
+    public void propertyChange(PropertyChangeEvent evt) {
+        UPDATE.schedule(10);
+    }
+
     @Override
     public void setPropertyValue(Property nps, Object val) {
         boolean refreshNode = true;
@@ -197,7 +195,7 @@ public class ConnectionNode extends BaseNode {
     private void updateLocalProperties() {
         try {
             clearProperties();
-            boolean connected = !connection.getConnector().isDisconnected();
+            boolean connected = connection.isConnected();
 
             addProperty(DISPLAYNAME, DISPLAYNAMEDESC, String.class, true, connection.getDisplayName());
             addProperty(DATABASEURL, DATABASEURLDESC, String.class, !connected, connection.getDatabase());
@@ -345,10 +343,10 @@ public class ConnectionNode extends BaseNode {
             new Runnable() {
                 @Override
                 public void run() {
-                    boolean connected = !connection.getConnector().isDisconnected();
+                    boolean connected = connection.isConnected();
 
                     if (connected) {
-                        MetadataModel model = MetadataModels.createModel(connection.getConnection(), connection.getSchema());
+                        MetadataModel model = MetadataModels.createModel(connection.getJDBCConnection(), connection.getSchema());
                         connection.setMetadataModel(model);
                         MetadataModelManager.update(connection.getDatabaseConnection(), model);
                         refresh();
@@ -372,7 +370,7 @@ public class ConnectionNode extends BaseNode {
         
         Connection conn = connection.getJDBCConnection();
         if (conn != null) {
-            result = ! DatabaseConnection.isVitalConnection(conn, connection);
+            result = ! connection.isVitalConnection();
         }
         
         return result;
@@ -438,7 +436,7 @@ public class ConnectionNode extends BaseNode {
 
     @Override
     public String getIconBase() {
-        boolean disconnected = ! DatabaseConnection.isVitalConnection(connection.getConnection(), null);
+        boolean disconnected = ! connection.isVitalConnection();
 
         if (disconnected) {
             return DISCONNECTEDICONBASE;
@@ -482,8 +480,7 @@ public class ConnectionNode extends BaseNode {
 
     @Override
     public Action getPreferredAction() {
-        boolean disconnected = !DatabaseConnection.isVitalConnection(
-                connection.getConnection(), null);
+        boolean disconnected = ! connection.isVitalConnection();
         if (disconnected) {
             return SystemAction.get(ConnectAction.class);
         } else {
