@@ -50,9 +50,12 @@ import com.sun.jdi.ObjectCollectedException;
 import com.sun.jdi.ReferenceType;
 import com.sun.jdi.VMDisconnectedException;
 import java.io.InvalidObjectException;
+import java.lang.ref.Reference;
+import java.lang.ref.WeakReference;
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.CopyOnWriteArrayList;
 import org.netbeans.api.debugger.jpda.CallStackFrame;
 import org.netbeans.api.debugger.jpda.Field;
 import org.netbeans.api.debugger.jpda.InvalidExpressionException;
@@ -62,6 +65,7 @@ import org.netbeans.api.debugger.jpda.LocalVariable;
 import org.netbeans.api.debugger.jpda.ObjectVariable;
 import org.netbeans.api.debugger.jpda.Variable;
 import org.netbeans.modules.debugger.jpda.js.JSUtils;
+import org.netbeans.modules.debugger.jpda.js.source.Source;
 import org.openide.util.Exceptions;
 
 /**
@@ -72,6 +76,7 @@ public final class DebuggerSupport {
     
     public  static final String DEBUGGER_SUPPORT_CLASS = "jdk.nashorn.internal.runtime.DebuggerSupport";    // NOI18N
     private static final String DEBUGGER_SUPPORT_VALUE_DESC_CLASS = "jdk.nashorn.internal.runtime.DebuggerSupport$DebuggerValueDesc"; // NOI18N
+    private static final String CONTEXT_CLASS = "jdk.nashorn.internal.runtime.Context";    // NOI18N
     
     private static final String METHOD_VALUE_INFO  = "valueInfo";       // NOI18N
     private static final String SIGNAT_VALUE_INFO  = "(Ljava/lang/String;Ljava/lang/Object;Z)Ljdk/nashorn/internal/runtime/DebuggerSupport$DebuggerValueDesc;"; // NOI18N
@@ -79,6 +84,11 @@ public final class DebuggerSupport {
     private static final String SIGNAT_VALUE_INFOS = "(Ljava/lang/Object;Z)[Ljdk/nashorn/internal/runtime/DebuggerSupport$DebuggerValueDesc;";  // NOI18N
     private static final String METHOD_EVAL        = "eval";            // NOI18N
     private static final String SIGNAT_EVAL        = "(Ljdk/nashorn/internal/runtime/ScriptObject;Ljava/lang/Object;Ljava/lang/String;Z)Ljava/lang/Object;";    // NOI18N
+    private static final String METHOD_FROM_CLASS  = "fromClass";       // NOI18N
+    private static final String SIGNAT_FROM_CLASS  = "(Ljava/lang/Class;)Ljdk/nashorn/internal/runtime/Context;";   // NOI18N
+    private static final String METHOD_CONTEXT_EVAL= "eval";            // NOI18N
+    private static final String SIGNAT_CONTEXT_EVAL= "(Ljdk/nashorn/internal/runtime/ScriptObject;Ljava/lang/String;Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;";  // NOI18N
+    private static final String SIGNAT_CONTEXT_EVAL_OLD = "(Ljdk/nashorn/internal/runtime/ScriptObject;Ljava/lang/String;Ljava/lang/Object;Ljava/lang/Object;Z)Ljava/lang/Object;";  // NOI18N
     private static final String METHOD_VALUE_AS_STRING = "valueAsString";       // NOI18N
     private static final String SIGNAT_VALUE_AS_STRING = "(Ljava/lang/Object;)Ljava/lang/String;";  // NOI18N
     private static final String METHOD_SOURCE_INFO = "getSourceInfo";   // NOI18N
@@ -93,6 +103,8 @@ public final class DebuggerSupport {
 //        this.descExpandableField    = this.DebuggerValueDescClass.fieldByName("expandable");
 //        this.descValueAsObjectField = this.DebuggerValueDescClass.fieldByName("valueAsObject");
 //        this.descValueAsStringField = this.DebuggerValueDescClass.fieldByName("valueAsString");
+    
+    private static final List<Reference<JPDADebugger>> hasOldEval = new CopyOnWriteArrayList<>();
 
     private DebuggerSupport() {}
     
@@ -156,9 +168,11 @@ public final class DebuggerSupport {
             return infosVar.getFields(0, Integer.MAX_VALUE);
         } catch (InvalidObjectException ioex) {
             return null;
-        } catch (NoSuchMethodException | InvalidExpressionException nsmex) {
+        } catch (NoSuchMethodException nsmex) {
             Exceptions.printStackTrace(nsmex);
             return null;
+        } catch (InvalidExpressionException iex) {
+            return null;
         }
     }
     
@@ -199,6 +213,24 @@ public final class DebuggerSupport {
     }
     
     public static Variable evaluate(JPDADebugger debugger, CallStackFrame frame, String expression, ObjectVariable contextVar) throws InvalidExpressionException {
+        try {
+            return doEvaluate(debugger, frame, expression, contextVar);
+        } catch (InvalidExpressionException ieex) {
+            Throwable targetException = ieex.getTargetException();
+            if (targetException == null) {
+                throw ieex;
+            }
+            String name;
+            try {
+                name = (String) targetException.getClass().getMethod("getOriginalLocalizedMessage").invoke(targetException);
+            } catch (IllegalAccessException | IllegalArgumentException | NoSuchMethodException | SecurityException | InvocationTargetException ex) {
+                name = targetException.getLocalizedMessage();
+            }
+            throw new InvalidExpressionException(name, targetException);
+        }
+    }
+    
+    private static Variable doEvaluate(JPDADebugger debugger, CallStackFrame frame, String expression, ObjectVariable contextVar) throws InvalidExpressionException {
         List<JPDAClassType> supportClasses = debugger.getClassesByName(DEBUGGER_SUPPORT_CLASS);
         if (supportClasses.isEmpty()) {
             return null;
@@ -232,6 +264,68 @@ public final class DebuggerSupport {
             // Can not evaluate
         }
         
+        // Evaluate on the current class' context:
+        Source source = Source.getSource(frame);
+        JPDAClassType sourceClassType = source.getClassType();
+        // Call Context.fromClass(clazz):
+        List<JPDAClassType> contextClassesByName = debugger.getClassesByName(CONTEXT_CLASS);
+        JPDAClassType contextClass = contextClassesByName.get(0);
+        Variable contextObj = null;
+        try {
+            contextObj = contextClass.invokeMethod(
+                    METHOD_FROM_CLASS,
+                    SIGNAT_FROM_CLASS,
+                    new Variable[] { sourceClassType.classObject() });
+        } catch (NoSuchMethodException nsmex) {
+            Exceptions.printStackTrace(nsmex);
+        }
+        if (contextObj != null) {
+            boolean oldEval = isOldEval(debugger);
+            if (!oldEval) {
+                try {
+                    Variable[] args = new Variable[4];
+                    try {
+                        args[0] = scope;
+                        args[1] = debugger.createMirrorVar(expression);
+                        args[2] = contextVar;
+                        args[3] = null; // ScriptRuntime.UNDEFINED, or null for directEval
+                    } catch (InvalidObjectException ioex) {
+                        Exceptions.printStackTrace(ioex);
+                        throw new InvalidExpressionException(ioex);
+                    }
+                    return ((ObjectVariable) contextObj).invokeMethod(
+                            METHOD_CONTEXT_EVAL,
+                            SIGNAT_CONTEXT_EVAL,
+                            args);
+                } catch (NoSuchMethodException nsmex) {
+                    oldEval = true;
+                    setOldEval(debugger);
+                }
+            }
+            if (oldEval) {
+                // older than 1.8.0_60
+                try {
+                    Variable[] args = new Variable[5];
+                    try {
+                        args[0] = scope;
+                        args[1] = debugger.createMirrorVar(expression);
+                        args[2] = contextVar;
+                        args[3] = null; // ScriptRuntime.UNDEFINED, or null for directEval
+                        args[4] = debugger.createMirrorVar(false, true);
+                    } catch (InvalidObjectException ioex) {
+                        Exceptions.printStackTrace(ioex);
+                        throw new InvalidExpressionException(ioex);
+                    }
+                    return ((ObjectVariable) contextObj).invokeMethod(
+                            METHOD_CONTEXT_EVAL,
+                            SIGNAT_CONTEXT_EVAL_OLD,
+                            args);
+                } catch (NoSuchMethodException nsmex) {
+                    Exceptions.printStackTrace(nsmex);
+                }
+            }
+        }
+        // Fallback to global evaluation...
         Variable[] args = new Variable[4];
         try {
             args[0] = scope;
@@ -248,11 +342,30 @@ public final class DebuggerSupport {
         }
     }
     
+    private static boolean isOldEval(JPDADebugger debugger) {
+        for (Reference<JPDADebugger> dbgRef : hasOldEval) {
+            JPDADebugger dbg = dbgRef.get();
+            if (dbg == null) {
+                hasOldEval.remove(dbgRef);
+            } else if (dbg == debugger) {
+                return true;
+            }
+        }
+        return false;
+    }
+    
+    private static void setOldEval(JPDADebugger debugger) {
+        hasOldEval.add(new WeakReference<>(debugger));
+    }
+    
     public static String getVarValue(JPDADebugger debugger, Variable var) {
         if (var instanceof ObjectVariable) {
             ObjectVariable ov = (ObjectVariable) var;
             List<JPDAClassType> supportClasses = debugger.getClassesByName(DEBUGGER_SUPPORT_CLASS);
-            if (supportClasses.isEmpty()) {
+            JPDAClassType ct;
+            if (supportClasses.isEmpty() ||
+                ((ct = ov.getClassType()) != null && String.class.getCanonicalName().equals(ct.getName()))) {
+
                 try {
                     return ov.getToStringValue();
                 } catch (InvalidExpressionException ex) {
@@ -300,9 +413,11 @@ public final class DebuggerSupport {
             } else {
                 return strVar;
             }
-        } catch (NoSuchMethodException | InvalidExpressionException ex) {
+        } catch (NoSuchMethodException ex) {
             Exceptions.printStackTrace(ex);
             return ov;
+        } catch (InvalidExpressionException iex) {
+            return ov;
         }
     }
     
