@@ -45,20 +45,22 @@
 package org.netbeans.modules.debugger.jpda.ui;
 
 import com.sun.jdi.AbsentInformationException;
+import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import java.lang.reflect.InvocationTargetException;
+import java.util.*;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.netbeans.api.debugger.*;
 import org.netbeans.api.debugger.DebuggerManager;
 import org.netbeans.api.debugger.Session;
 import org.netbeans.api.debugger.jpda.*;
 import org.netbeans.api.debugger.jpda.event.JPDABreakpointEvent;
 import org.netbeans.api.debugger.jpda.event.JPDABreakpointListener;
+import org.netbeans.modules.debugger.jpda.DebuggerConsoleIO;
+import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
 import org.netbeans.modules.debugger.jpda.ui.models.BreakpointsNodeModel;
 import org.netbeans.spi.debugger.ContextProvider;
-import java.beans.PropertyChangeEvent;
-import java.lang.reflect.InvocationTargetException;
-import java.util.*;
-import java.util.regex.Pattern;
-import java.util.regex.Matcher;
 import org.netbeans.spi.viewmodel.NodeModel;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
@@ -90,7 +92,6 @@ PropertyChangeListener {
         ("\\{=(.*?)\\}");
     private static final String threadStartedCondition = "{? threadStarted}";
 
-    private IOManager               ioManager;
     private JPDADebugger            debugger;
     private ContextProvider         contextProvider;
     private final Object            lock = new Object();
@@ -116,10 +117,15 @@ PropertyChangeListener {
         DebuggerManager.getDebuggerManager ().removeDebuggerListener
             (DebuggerManager.PROP_BREAKPOINTS, this);
         unhookBreakpoints ();
+        JPDADebugger dbg;
         synchronized (lock) {
-            ioManager = null;
+            dbg = debugger;
             debugger = null;
         }
+        dbg.removePropertyChangeListener (
+            JPDADebugger.PROP_STATE,
+            this
+        );
     }
 
     @Override
@@ -132,8 +138,10 @@ PropertyChangeListener {
 
     @Override
     public void breakpointReached (JPDABreakpointEvent event) {
+        JPDADebugger dbg;
         synchronized (lock) {
-            if (event.getDebugger () != debugger) {
+            dbg = debugger;
+            if (event.getDebugger () != dbg) {
                 return;
             }
         }
@@ -142,7 +150,7 @@ PropertyChangeListener {
         }
         JPDABreakpoint breakpoint = (JPDABreakpoint) event.getSource ();
         if (breakpoint.getSuspend() != JPDABreakpoint.SUSPEND_NONE) {
-            getBreakpointsNodeModel ().setCurrentBreakpoint (breakpoint);
+            getBreakpointsNodeModel ().setCurrentBreakpoint (((JPDADebuggerImpl) dbg).getSession(), breakpoint);
         }
         /*
         System.err.println("BP variable = "+event.getVariable());
@@ -158,19 +166,13 @@ PropertyChangeListener {
         if (printText == null || printText.length  () == 0) {
             return;
         }
-        synchronized (lock) {
-            if (ioManager == null) {
-                lookupIOManager ();
-                if (ioManager == null) {
-                    return;
-                }
-            }
-        }
         printText = substitute(printText, event);
+        JPDADebuggerImpl dbg;
         synchronized (lock) {
-            if (ioManager != null) {
-                ioManager.println (printText, null);
-            }
+            dbg = (JPDADebuggerImpl) debugger;
+        }
+        if (dbg != null) {
+            dbg.getConsoleIO().println(printText, null);
         }
     }
 
@@ -225,6 +227,7 @@ PropertyChangeListener {
                                  url, lineNumber);
             return ;
         }
+        JPDADebuggerImpl dbg;
         synchronized (lock) {
             if (debugger == null ||
                 !JPDADebugger.PROP_STATE.equals(evt.getPropertyName()) ||
@@ -232,65 +235,58 @@ PropertyChangeListener {
                 
                 return ;
             }
+            dbg = (JPDADebuggerImpl) debugger;
         }
-        getBreakpointsNodeModel ().setCurrentBreakpoint (null);
+        getBreakpointsNodeModel ().setCurrentBreakpoint (dbg.getSession(), null);
             
     }
     
     public void printValidityMessage(Breakpoint bp, Breakpoint.VALIDITY newValidity,
                                      String url, int lineNumber) {
+        JPDADebuggerImpl dbg;
+        synchronized (lock) {
+            dbg = (JPDADebuggerImpl) debugger;
+        }
+        if (dbg == null) {
+            return ; // Debugger has finished already.
+        }
+        DebuggerConsoleIO consoleIO = dbg.getConsoleIO();
         if (Breakpoint.VALIDITY.INVALID.equals(newValidity)) {
             String msg = bp.getValidityMessage();
-            synchronized (lock) {
-                if (ioManager == null) {
-                    lookupIOManager ();
-                    if (ioManager == null) {
-                        return;
-                    }
-                }
-                String printText = (msg != null) ?
-                                   NbBundle.getMessage(BreakpointOutput.class, "MSG_InvalidBreakpointWithReason", bp.toString(), msg) :
-                                   NbBundle.getMessage(BreakpointOutput.class, "MSG_InvalidBreakpoint", bp.toString());
-                IOManager.Line line = null;
-                if (url != null && lineNumber >= 0) {
-                    line = new IOManager.Line (
-                        url,
-                        lineNumber,
-                        debugger
-                    );
-                }
-                ioManager.println (printText, null, true);
-                if (line != null) {
-                    ioManager.println(
-                            NbBundle.getMessage(BreakpointOutput.class, "Link_InvalidBreakpoint", bp.toString()),
-                            line, true);
-                }
+            String printText = (msg != null) ?
+                               NbBundle.getMessage(BreakpointOutput.class, "MSG_InvalidBreakpointWithReason", bp.toString(), msg) :
+                               NbBundle.getMessage(BreakpointOutput.class, "MSG_InvalidBreakpoint", bp.toString());
+            DebuggerConsoleIO.Line line = null;
+            if (url != null && lineNumber >= 0) {
+                line = new DebuggerConsoleIO.Line (
+                    url,
+                    lineNumber,
+                    dbg
+                );
+            }
+            consoleIO.println (printText, null, true);
+            if (line != null) {
+                consoleIO.println (
+                        NbBundle.getMessage(BreakpointOutput.class, "Link_InvalidBreakpoint", bp.toString()),
+                        line, true);
             }
         } else if (Breakpoint.VALIDITY.VALID.equals(newValidity)) {
-            synchronized (lock) {
-                if (ioManager == null) {
-                    lookupIOManager ();
-                    if (ioManager == null) {
-                        return;
-                    }
-                }
-                String msg = bp.getValidityMessage();
-                String printText;
-                if (msg != null && msg.trim().length() > 0) {
-                    printText = NbBundle.getMessage(BreakpointOutput.class, "MSG_ValidBreakpointWithReason", bp.toString(), msg);
-                } else {
-                    printText = NbBundle.getMessage(BreakpointOutput.class, "MSG_ValidBreakpoint", bp.toString());
-                }
-                IOManager.Line line = null;
-                if (bp instanceof LineBreakpoint) {
-                    line = new IOManager.Line (
-                        ((LineBreakpoint) bp).getURL(),
-                        ((LineBreakpoint) bp).getLineNumber(),
-                        debugger
-                    );
-                }
-                ioManager.println (printText, line, false);
+            String msg = bp.getValidityMessage();
+            String printText;
+            if (msg != null && msg.trim().length() > 0) {
+                printText = NbBundle.getMessage(BreakpointOutput.class, "MSG_ValidBreakpointWithReason", bp.toString(), msg);
+            } else {
+                printText = NbBundle.getMessage(BreakpointOutput.class, "MSG_ValidBreakpoint", bp.toString());
             }
+            DebuggerConsoleIO.Line line = null;
+            if (bp instanceof LineBreakpoint) {
+                line = new DebuggerConsoleIO.Line (
+                    ((LineBreakpoint) bp).getURL(),
+                    ((LineBreakpoint) bp).getLineNumber(),
+                    dbg
+                );
+            }
+            consoleIO.println (printText, line, false);
         }
     }
 
@@ -445,13 +441,15 @@ PropertyChangeListener {
                 // expression is invalid or cannot be evaluated
                 String msg = e.getCause () != null ? 
                     e.getCause ().getMessage () : e.getMessage ();
+                JPDADebuggerImpl dbg;
                 synchronized (lock) {
-                    if (ioManager != null) {
-                        ioManager.println (
+                    dbg = (JPDADebuggerImpl) debugger;
+                }
+                if (dbg != null) {
+                    dbg.getConsoleIO().println (
                             "Cannot evaluate expression '" + expression + "' : " + msg, 
                             null
                         );
-                    }
                 }
             }
             printText = m.replaceFirst (value);
@@ -517,18 +515,6 @@ PropertyChangeListener {
         }
     }
 
-    private void lookupIOManager () {
-        List lamls = contextProvider.lookup 
-            (null, LazyActionsManagerListener.class);
-        for (Iterator i = lamls.iterator (); i.hasNext ();) {
-            Object o = i.next();
-            if (o instanceof DebuggerOutput) {
-                ioManager = ((DebuggerOutput) o).getIOManager ();
-                break;
-            }
-        }
-    }
-    
     private void hookBreakpoints () {
         Breakpoint [] bpts = DebuggerManager.getDebuggerManager ().
             getBreakpoints ();
