@@ -85,6 +85,7 @@ import org.netbeans.api.debugger.jpda.JPDAThread;
 import org.netbeans.api.debugger.jpda.MethodBreakpoint;
 import org.netbeans.api.debugger.jpda.event.JPDABreakpointEvent;
 import org.netbeans.api.debugger.jpda.event.JPDABreakpointListener;
+import org.netbeans.api.io.InputOutput;
 import org.netbeans.modules.debugger.jpda.expr.InvocationExceptionTranslated;
 import org.netbeans.modules.debugger.jpda.expr.JDIVariable;
 import org.netbeans.modules.debugger.jpda.jdi.ClassNotPreparedExceptionWrapper;
@@ -101,12 +102,12 @@ import org.netbeans.modules.debugger.jpda.jdi.VirtualMachineWrapper;
 import org.netbeans.modules.debugger.jpda.models.JPDAThreadImpl;
 import org.netbeans.modules.debugger.jpda.visual.JavaComponentInfo.Stack;
 import org.netbeans.modules.debugger.jpda.visual.breakpoints.AWTComponentBreakpointImpl;
+import org.netbeans.modules.debugger.jpda.visual.options.Options;
 import org.netbeans.modules.debugger.jpda.visual.ui.ScreenshotComponent;
 import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
-import org.openide.windows.InputOutput;
 
 /**
  *
@@ -120,23 +121,25 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
     private static final Map<JPDADebugger, Map<ObjectReference, Stack>> componentsAndStackTraces
             = new WeakHashMap<JPDADebugger, Map<ObjectReference, Stack>>();
     
-    private static final String PROPERTIES_VISUAL = "debugger.options.JPDA.visual"; // NOI18N
-    private static final String PROPERTIES_TCC = "TrackComponentChanges";  // NOI18N
-    private static final String PROPERTIES_UPLOAD_AGENT = "UploadAgent";  // NOI18N
-    
     private final Map<DebuggerEngine, Collection<Breakpoint>> helperComponentBreakpointsMap = new HashMap<DebuggerEngine, Collection<Breakpoint>>();
     private final Properties properties;
     private volatile Boolean isTrackComponentChanges = null;
     
+    private enum RemoteServiceInit {
+        SUCCESS,
+        FAIL,
+        FAIL_RETRY
+    }
+    
     public VisualDebuggerListener() {
         final RequestProcessor rp = new RequestProcessor(VisualDebuggerListener.class);
-        properties = Properties.getDefault().getProperties(PROPERTIES_VISUAL);
+        properties = Options.getProperties();
         if (RemoteAWTScreenshot.FAST_SNAPSHOT_RETRIEVAL) {
             properties.addPropertyChangeListener(new PropertyChangeListener() {
                 @Override
                 public void propertyChange(PropertyChangeEvent evt) {
                     String pName = evt.getPropertyName();
-                    if (PROPERTIES_TCC.equals(pName)) {
+                    if (Options.PROPERTY_TCC.equals(pName)) {
                         final Object newValue = evt.getNewValue();
                         if (isTrackComponentChanges != null && !isTrackComponentChanges.equals(newValue)) {
                             rp.post(new Runnable() {
@@ -162,7 +165,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
         if (debugger == null) {
             return ;
         }
-        boolean uploadAgent = properties.getBoolean(PROPERTIES_UPLOAD_AGENT, true);
+        boolean uploadAgent = Options.isUploadAgent();
         logger.log(Level.FINE, "engineAdded({0}), debugger = {1}, uploadAgent = {2}", new Object[]{engine, debugger, uploadAgent});
         Collection<Breakpoint> helperComponentBreakpoints = new ArrayList<Breakpoint>();
         if (debugger != null && uploadAgent) {
@@ -180,7 +183,14 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                         DebuggerManager.getDebuggerManager().removeBreakpoint(mb[0]);
                         DebuggerManager.getDebuggerManager().removeBreakpoint(mb[1]);
                         if (inited.compareAndSet(false, true)) {
-                            initDebuggerRemoteService(event.getThread(), RemoteServices.ServiceType.AWT);
+                            RemoteServiceInit initRet =
+                                    initDebuggerRemoteService(event.getThread(),
+                                                              RemoteServices.ServiceType.AWT);
+                            if (initRet.equals(RemoteServiceInit.FAIL_RETRY)) {
+                                DebuggerManager.getDebuggerManager().removeBreakpoint(mb[0]);
+                                DebuggerManager.getDebuggerManager().removeBreakpoint(mb[1]);
+                                inited.set(false);
+                            }
                         }
                     }
                     event.resume();
@@ -196,7 +206,14 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                         DebuggerManager.getDebuggerManager().removeBreakpoint(mb[0]);
                         DebuggerManager.getDebuggerManager().removeBreakpoint(mb[1]);
                         if (inited.compareAndSet(false, true)) {
-                            initDebuggerRemoteService(event.getThread(), RemoteServices.ServiceType.FX);
+                            RemoteServiceInit initRet =
+                                    initDebuggerRemoteService(event.getThread(),
+                                                              RemoteServices.ServiceType.FX);
+                            if (initRet.equals(RemoteServiceInit.FAIL_RETRY)) {
+                                DebuggerManager.getDebuggerManager().removeBreakpoint(mb[0]);
+                                DebuggerManager.getDebuggerManager().removeBreakpoint(mb[1]);
+                                inited.set(false);
+                            }
                         }
                     }
                     event.resume();
@@ -208,7 +225,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
             helperComponentBreakpoints.add(mb[1]);
         }
         if (debugger != null) {
-            boolean trackComponentChanges = properties.getBoolean(PROPERTIES_TCC, true);
+            boolean trackComponentChanges = Options.isTrackComponentChanges();
             isTrackComponentChanges = trackComponentChanges;
             if (trackComponentChanges) {
                 if (!RemoteAWTScreenshot.FAST_SNAPSHOT_RETRIEVAL) {
@@ -244,7 +261,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
         }
     }
 
-    private void initDebuggerRemoteService(JPDAThread thread, RemoteServices.ServiceType sType) {
+    private RemoteServiceInit initDebuggerRemoteService(JPDAThread thread, RemoteServices.ServiceType sType) {
         if (logger.isLoggable(Level.FINE)) {
             logger.log(Level.FINE, "initDebuggerRemoteService({0})", thread);
         }
@@ -262,7 +279,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
             } catch (ClassNotLoadedException ex) {
                 Exceptions.printStackTrace(ex);
             } catch (IncompatibleThreadStateException ex) {
-                Exceptions.printStackTrace(ex);
+                return RemoteServiceInit.FAIL_RETRY;
             } catch (InvocationException ex) {
                 Exceptions.printStackTrace(ex);
                 final InvocationExceptionTranslated iextr = new InvocationExceptionTranslated(ex, t.getDebugger());
@@ -275,7 +292,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                 logger.log(Level.FINE, "Uploaded class = {0}", cor);
             }
             if (cor == null) {
-                return ;
+                return RemoteServiceInit.FAIL;
             }
             ThreadReference tr = t.getThreadReference();
             
@@ -294,10 +311,10 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                     boolean success = PrimitiveValueWrapper.booleanValue((PrimitiveValue) ret);
                     RemoteServices.setAccessLoopStarted(t.getDebugger(), success);
                     if (!success) {
-                        return ;
+                        return RemoteServiceInit.FAIL;
                     }
                 }
-                boolean trackComponentChanges = properties.getBoolean(PROPERTIES_TCC, true);
+                boolean trackComponentChanges = Options.isTrackComponentChanges();
                 isTrackComponentChanges = trackComponentChanges;
                 if (trackComponentChanges && RemoteAWTScreenshot.FAST_SNAPSHOT_RETRIEVAL) {
                     Method startHierarchyListenerMethod = ClassTypeWrapper.concreteMethodByName(serviceClass, "startHierarchyListener", "()Ljava/lang/String;");
@@ -305,7 +322,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                         Value res = ClassTypeWrapper.invokeMethod(serviceClass, tr, startHierarchyListenerMethod, Collections.EMPTY_LIST, ObjectReference.INVOKE_SINGLE_THREADED);
                         if (res instanceof StringReference) {
                             String reason = ((StringReference) res).value();
-                            InputOutput io = t.getDebugger().getIO();
+                            InputOutput io = t.getDebugger().getConsoleIO().getIO();
                             io.getErr().println(NbBundle.getMessage(VisualDebuggerListener.class, "MSG_NoTrackingOfComponentChanges", reason));
                             //System.err.println("isHierarchyListenerAdded = false, reason = "+reason);
                         } else {
@@ -346,6 +363,7 @@ public class VisualDebuggerListener extends DebuggerManagerAdapter {
                 logger.log(Level.FINE, "", ex);
             }
         }
+        return RemoteServiceInit.SUCCESS;
     }
     
     private void initException(InvocationExceptionTranslated iextr, JPDAThreadImpl t) {
