@@ -181,6 +181,7 @@ public class Generate {
 
         Map<String, Set<Class>> StackFrameExceptions = new LinkedHashMap<String, Set<Class>>();
         StackFrameExceptions.put("*", Collections.singleton((Class) com.sun.jdi.InvalidStackFrameException.class));
+        StackFrameExceptions.put("setValue", Collections.singleton((Class) com.sun.jdi.ObjectCollectedException.class));
         StackFrameExceptions.put("visibleVariableByName", Collections.singleton((Class) com.sun.jdi.NativeMethodException.class));
         StackFrameExceptions.put("visibleVariables", Collections.singleton((Class) com.sun.jdi.NativeMethodException.class));
         EXCEPTIONS_BY_METHODS.put(com.sun.jdi.StackFrame.class.getName(), StackFrameExceptions);
@@ -550,6 +551,10 @@ public class Generate {
             }
         }
         w.write(" {\n");
+        String preCode = methodPreCode(className, mName);
+        if (preCode != null) {
+            w.write(preCode);
+        }
         w.write("        if (org.netbeans.modules.debugger.jpda.JDIExceptionReporter.isLoggable()) {\n");
         w.write("            org.netbeans.modules.debugger.jpda.JDIExceptionReporter.logCallStart(\n"+
                 "                    \""+className+"\",\n"+
@@ -617,6 +622,9 @@ public class Generate {
             if (com.sun.jdi.InternalException.class.equals(cex)) {
                 w.write(reportOfJDIException(className, mName, "ex"));
             }
+            if (com.sun.jdi.VMDisconnectedException.class.equals(cex)) {
+                w.write(disposeVMOnVMDisconnectedException(className, mName));
+            }
             if (defaultReturn != null && SILENT_EXCEPTIONS.contains(cex)) {
                 w.write("            return "+defaultReturn+";\n");
             } else {
@@ -1113,6 +1121,23 @@ public class Generate {
         if (index < l) return index;
         else return -1;
     }
+    
+    private static String methodPreCode(String className, String methodName) {
+        if (com.sun.jdi.ThreadReference.class.getName().equals(className)) {
+            if (methodName.equals("currentContendedMonitor")) {
+                String statusCheck        = "        int status = status0(a);\n"+
+                                            "        if (status == com.sun.jdi.ThreadReference.THREAD_STATUS_NOT_STARTED ||\n" +
+                                            "            status == com.sun.jdi.ThreadReference.THREAD_STATUS_ZOMBIE ||\n" +
+                                            "            status == com.sun.jdi.ThreadReference.THREAD_STATUS_UNKNOWN) {\n" +
+                                            "            \n" +
+                                            "            // #253058, JDWP Error: 15\n" +
+                                            "            return null;\n" +
+                                            "        }\n";
+                return statusCheck;
+            }
+        }
+        return null;
+    }
 
     // Custom code can be provided here to override the original invocation
     private static String methodImpl(String className, String methodName, String exec) {
@@ -1228,6 +1253,20 @@ public class Generate {
                 return catchJDWPException;
             }
         }
+        if (com.sun.jdi.Method.class.getName().equals(className)) {
+            if (methodName.equals("bytecodes")) {
+                String catchJDWPException = "            try {\n"+
+                                            "    "+exec+
+                                            "            } catch ("+com.sun.jdi.InternalException.class.getName()+" iex) {\n"+
+                                            "                if (iex.errorCode() == 113) { // INTERNAL, see https://netbeans.org/bugzilla/show_bug.cgi?id=255298\n"+
+                                            "                    throw new InternalExceptionWrapper(iex);\n"+
+                                            "                } else {\n"+
+                                            "                    throw iex; // re-throw the original\n"+
+                                            "                }\n"+
+                                            "            }\n";
+                return catchJDWPException;
+            }
+        }
         return exec;
     }
     
@@ -1245,6 +1284,20 @@ public class Generate {
             return JDI_EXC_REPORT1+ex+JDI_EXC_REPORT2;
         }
     }
+    
+    private static String disposeVMOnVMDisconnectedException(String className, String methodName) {
+        if (com.sun.jdi.VirtualMachine.class.getName().equals(className) &&
+            (methodName.equals("exit") || methodName.equals("dispose"))) {
+            return ""; // Ignore
+        }
+        // We should not have to do this. See #243837
+        return "            if (a instanceof com.sun.jdi.Mirror) {\n" +
+               "                com.sun.jdi.VirtualMachine vm = ((com.sun.jdi.Mirror) a).virtualMachine();\n" +
+               "                try {\n"+
+               "                    vm.dispose();\n" +
+               "                } catch (com.sun.jdi.VMDisconnectedException vmdex) {}\n"+
+               "            }\n";
+    }
 
     public static void main(String[] args) {
         /*if (args.length == 0) {
