@@ -117,6 +117,7 @@ public class ExpressionPool {
             }
             return expressions.get(exprLocation);
         } catch (InternalExceptionWrapper ex) {
+            logger.log(Level.INFO, "No expression at '"+url+"', JDI internal error", ex);
             return null;
         } catch (ObjectCollectedExceptionWrapper ex) {
             return null;
@@ -302,7 +303,7 @@ public class ExpressionPool {
                 } else if (startIndex >= 0) {
                     int ci = (int) LocationWrapper.codeIndex(l);
                     lineLocationsInExpression.add(locInExpression);
-                    if (line <= (endLine - endlocline)) {
+                    if (startLine <= line && line <= (endLine - endlocline)) {
                         indexes.add(new int[] { startIndex, ci });
                         startIndex = ci;
                         locInExpression = l;
