@@ -208,20 +208,13 @@ public class EvaluationContext {
         try {
             // Refresh the stack frame
             frame = ThreadReferenceWrapper.frame(thread.getThreadReference(), frameDepth);
-        } catch (InternalExceptionWrapper ex) {
+        } catch (InternalExceptionWrapper |
+                 ObjectCollectedExceptionWrapper |
+                 IllegalThreadStateExceptionWrapper ex) {
             InvalidExpressionException ieex = new InvalidExpressionException (ex);
-            ieex.initCause(ex);
             throw new IllegalStateException(ieex);
         } catch (VMDisconnectedExceptionWrapper ex) {
             // Ignore
-        } catch (ObjectCollectedExceptionWrapper ex) {
-            InvalidExpressionException ieex = new InvalidExpressionException (ex);
-            ieex.initCause(ex);
-            throw new IllegalStateException(ieex);
-        } catch (IllegalThreadStateExceptionWrapper ex) {
-            InvalidExpressionException ieex = new InvalidExpressionException (ex);
-            ieex.initCause(ex);
-            throw new IllegalStateException(ieex);
         }
     }
 
@@ -249,7 +242,7 @@ public class EvaluationContext {
         this.treePath = treePath;
     }
 
-    TreePath getTreePath() {
+    public TreePath getTreePath() {
         return treePath;
     }
 
@@ -406,7 +399,7 @@ public class EvaluationContext {
 
     public static abstract class VariableInfo {
 
-        public abstract void setValue(Value value);
+        public abstract void setValue(Value value) throws IllegalStateException;
 
         public abstract Type getType() throws ClassNotLoadedException;
 
