@@ -106,7 +106,7 @@ public class AbstractObjectVariable extends AbstractVariable implements ObjectVa
     
     private static final Logger logger = Logger.getLogger("org.netbeans.modules.debugger.jpda.getValue"); // NOI18N
     
-    static final int MAX_STRING_LENGTH = 100000; // Limit retrieved String length to 100K characters to limit memory consumption.
+    public static final int MAX_STRING_LENGTH = 100000; // Limit retrieved String length to 100K characters to limit memory consumption.
 
     private String          genericType;
     private Field[]         fields;
@@ -640,7 +640,11 @@ public class AbstractObjectVariable extends AbstractVariable implements ObjectVa
             Value[] vs = new Value [arguments.length];
             int i, k = arguments.length;
             for (i = 0; i < k; i++) {
-                vs [i] = ((AbstractVariable) arguments [i]).getInnerValue ();
+                if (arguments [i] == null) {
+                    vs [i] = null;
+                } else {
+                    vs [i] = ((AbstractVariable) arguments [i]).getInnerValue ();
+                }
             }
             v = getDebugger().invokeMethod (
                 (JPDAThreadImpl) thread,
@@ -979,7 +983,7 @@ public class AbstractObjectVariable extends AbstractVariable implements ObjectVa
             Field[] ch = new Field [k];
             for (i = 0; i < k; i++) {
                 Value v = (Value) l.get (i);
-                ch [i] = (v instanceof ObjectReference) ?
+                ch [i] = (v == null || v instanceof ObjectReference) ?
                     new ObjectArrayFieldVariable (
                         getDebugger(), 
                         (ObjectReference) v, 
