@@ -97,13 +97,13 @@ import org.netbeans.modules.debugger.jpda.jdi.ValueWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.VirtualMachineWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.request.EventRequestManagerWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.request.EventRequestWrapper;
+import org.netbeans.modules.debugger.jpda.spi.StrataProvider;
 import org.netbeans.modules.debugger.jpda.util.Executor;
-import org.netbeans.modules.debugger.jpda.util.JPDAUtils;
 import org.netbeans.modules.debugger.jpda.util.Operator;
 import org.netbeans.spi.debugger.jpda.EditorContext.MethodArgument;
 import org.netbeans.spi.debugger.jpda.EditorContext.Operation;
-import org.openide.ErrorManager;
 import org.openide.util.Exceptions;
+import org.openide.util.Mutex;
 import org.openide.util.NbBundle;
 
 
@@ -146,13 +146,32 @@ public class CallStackFrameImpl implements CallStackFrame {
     }
 
     // public interface ........................................................
+    
+    private final ThreadLocal<Boolean> getLineNumberLoopControl = new ThreadLocal<Boolean>();
         
     /**
     * Returns line number of this frame in this callstack.
     *
     * @return Returns line number of this frame in this callstack.
     */
-    public synchronized int getLineNumber (String struts) {
+    public int getLineNumber (String struts) {
+        Boolean looping = getLineNumberLoopControl.get();
+        if (looping != null && looping) {
+            return getLineNumberDefault(struts);
+        }
+        StrataProvider strataProvider = getStrataProvider();
+        if (strataProvider == null) {
+            return getLineNumberDefault(struts);
+        }
+        getLineNumberLoopControl.set(Boolean.TRUE);
+        try {
+            return strataProvider.getStrataLineNumber(this, struts);
+        } finally {
+            getLineNumberLoopControl.remove();
+        }
+    }
+    
+    private synchronized int getLineNumberDefault (String struts) {
         if (!valid && sfLocation == null) return 0;
         try {
             Location l = getStackFrameLocation();
@@ -204,7 +223,7 @@ public class CallStackFrameImpl implements CallStackFrame {
     */
     public synchronized String getClassName () {
         if (!valid && sfLocation == null) return "";
-        assert !java.awt.EventQueue.isDispatchThread();
+        assert !Mutex.EVENT.isReadAccess();
         try {
             Location l = getStackFrameLocation();
             return ReferenceTypeWrapper.name(LocationWrapper.declaringType(l));
@@ -242,8 +261,11 @@ public class CallStackFrameImpl implements CallStackFrame {
     *
     * @return name of default stratum
     */
+    @Override
     public synchronized String getDefaultStratum () {
-        if (!valid && sfLocation == null) return "";
+        if (!valid && sfLocation == null) {
+            return "";
+        }
         if (stratum == null) {
             initStrata();
         }
@@ -255,8 +277,11 @@ public class CallStackFrameImpl implements CallStackFrame {
     *
     * @return name of default stratum
     */
+    @Override
     public synchronized List<String> getAvailableStrata () {
-        if (!valid && sfLocation == null) return Collections.emptyList();
+        if (!valid && sfLocation == null) {
+            return Collections.emptyList();
+        }
         if (availableStrata == null) {
             initStrata();
         }
@@ -264,6 +289,18 @@ public class CallStackFrameImpl implements CallStackFrame {
     }
     
     private synchronized void initStrata() {
+        StrataProvider strataProvider = getStrataProvider();
+        if (strataProvider != null) {
+            String ds = strataProvider.getDefaultStratum(this);
+            if (ds != null) {
+                List<String> as = strataProvider.getAvailableStrata(this);
+                if (as != null) {
+                    this.stratum = ds;
+                    this.availableStrata = as;
+                    return ;
+                }
+            }
+        }
         String s;
         List<String> as;
         try {
@@ -313,6 +350,42 @@ public class CallStackFrameImpl implements CallStackFrame {
         this.stratum = s;
         this.availableStrata = as;
     }
+    
+    private StrataProvider getStrataProvider() {
+        final List<? extends StrataProvider> providers = debugger.getSession().lookup(null, StrataProvider.class);
+        if (providers.isEmpty()) {
+            return null;
+        }
+        if (providers.size() == 1) {
+            return providers.get(0);
+        }
+        return new StrataProvider() {
+            @Override
+            public String getDefaultStratum(CallStackFrameImpl csf) {
+                for (StrataProvider sp : providers) {
+                    String defaultStratum = sp.getDefaultStratum(csf);
+                    if (defaultStratum != null) {
+                        return defaultStratum;
+                    }
+                }
+                return null;
+            }
+            @Override
+            public List<String> getAvailableStrata(CallStackFrameImpl csf) {
+                for (StrataProvider sp : providers) {
+                    List<String> availableStrata1 = sp.getAvailableStrata(csf);
+                    if (availableStrata1 != null) {
+                        return availableStrata1;
+                    }
+                }
+                return null;
+            }
+            @Override
+            public int getStrataLineNumber(CallStackFrameImpl csf, String stratum) {
+                return csf.getLineNumberDefault(stratum);
+            }
+        };
+    }
 
     /**
      * Returns the source debug extension.
@@ -353,7 +426,7 @@ public class CallStackFrameImpl implements CallStackFrame {
     */
     public synchronized String getSourceName (String stratum) throws AbsentInformationException {
         if (!valid && sfLocation == null) return "";
-        assert !java.awt.EventQueue.isDispatchThread();
+        assert !Mutex.EVENT.isReadAccess();
         try {
             Location l = getStackFrameLocation();
             return LocationWrapper.sourceName(l, stratum);
@@ -375,7 +448,7 @@ public class CallStackFrameImpl implements CallStackFrame {
      */
     public synchronized String getSourcePath (String stratum) throws AbsentInformationException {
         if (!valid && sfLocation == null) return "";
-        assert !java.awt.EventQueue.isDispatchThread();
+        assert !Mutex.EVENT.isReadAccess();
         try {
             Location l = getStackFrameLocation();
             return LocationWrapper.sourcePath(l, stratum);
@@ -521,12 +594,7 @@ public class CallStackFrameImpl implements CallStackFrame {
         }
     }
 
-    static boolean canFindOperationArguments() {
-        return JPDAUtils.IS_JDK_160_02;
-    }
-    
-    List<LocalVariable> findOperationArguments(Operation operation) {
-        if (!JPDAUtils.IS_JDK_160_02) return null; // Can evaluate methods after pop since JDK 1.6.0_02
+    public List<LocalVariable> findOperationArguments(Operation operation) {
         JPDADebuggerImpl debuggerImpl = (JPDADebuggerImpl) debugger;
         thread.accessLock.writeLock().lock();
         try {
@@ -550,7 +618,7 @@ public class CallStackFrameImpl implements CallStackFrame {
                 try {
                     frameCount = ThreadReferenceWrapper.frameCount0(tr);
                 } catch (IncompatibleThreadStateException itsex) {
-                    ErrorManager.getDefault().notify(itsex);
+                    Exceptions.printStackTrace(itsex);
                     return null;
                 }
 
@@ -645,7 +713,7 @@ public class CallStackFrameImpl implements CallStackFrame {
                     sf = ThreadReferenceWrapper.frames(tr, 0, 1).get(0);
                     arguments = getArgumentValues(sf);
                 } catch (IncompatibleThreadStateException itsex) {
-                    ErrorManager.getDefault().notify(itsex);
+                    Exceptions.printStackTrace(itsex);
                     return null;
                 } finally {
                     EventRequestManagerWrapper.deleteEventRequest(
@@ -657,7 +725,7 @@ public class CallStackFrameImpl implements CallStackFrame {
                             ThreadReferenceWrapper.popFrames(tr, sf);
                         }
                     } catch (IncompatibleThreadStateException itsex) {
-                        ErrorManager.getDefault().notify(itsex);
+                        Exceptions.printStackTrace(itsex);
                         return null;
                     } catch (NativeMethodExceptionWrapper nmex) {
                         return null;
@@ -679,7 +747,7 @@ public class CallStackFrameImpl implements CallStackFrame {
                                                                        session.getCurrentLanguage()),
                                 operation);
                     } catch (IncompatibleThreadStateException itsex) {
-                        ErrorManager.getDefault().notify(itsex);
+                        Exceptions.printStackTrace(itsex);
                         return null;
                     }
                     int n = arguments.size();
