@@ -65,6 +65,7 @@ import com.sun.jdi.ShortValue;
 import com.sun.jdi.StringReference;
 import com.sun.jdi.ThreadReference;
 import com.sun.jdi.Type;
+import com.sun.jdi.VMDisconnectedException;
 import com.sun.jdi.Value;
 import com.sun.jdi.VirtualMachine;
 import java.beans.PropertyVetoException;
@@ -72,7 +73,6 @@ import java.io.InvalidObjectException;
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
-import java.text.AttributedCharacterIterator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -92,9 +92,7 @@ import org.netbeans.modules.debugger.jpda.jdi.IllegalArgumentExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.InternalExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ObjectCollectedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ObjectReferenceWrapper;
-import org.netbeans.modules.debugger.jpda.jdi.PrimitiveValueWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ReferenceTypeWrapper;
-import org.netbeans.modules.debugger.jpda.jdi.StringReferenceWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.TypeComponentWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.TypeWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.UnsupportedOperationExceptionWrapper;
@@ -267,89 +265,74 @@ public class VariableMirrorTranslator {
                 }
             }
             Map<Field, Value> fieldValues = ObjectReferenceWrapper.getValues(value, fieldsToAskFor);
-            for (Field f : fieldValues.keySet()) {
-                String name = TypeComponentWrapper.name(f);
-                java.lang.reflect.Field field = getDeclaredOrInheritedField(clazz, name);
-                if (field == null) {
-                    logger.log(Level.CONFIG, "No Such Field({0}) of class {1}", new Object[]{name, clazz});
-                    return null;
-                }
-                field.setAccessible(true);
-                Value v = fieldValues.get(f);
-                try {
-                    if (v == null) {
-                        field.set(newInstance, null);
-                    } else {
-                        Object mv = mirrorsMap.get(v);
-                        if (mv == null) {
-                            mv = createMirrorObject(v, mirrorsMap);
-                        }
-                        if (mv != null) {
-                            field.set(newInstance, mv);
-                        } else {
-                            logger.log(Level.CONFIG, "Unable to translate field {0} of class {1}", new Object[]{name, clazz});
-                            return null;
-                        }
-                    }
-                } catch (IllegalAccessException ex) {
-                    logger.log(Level.CONFIG, "IllegalAccessException({0}) of field {1}", new Object[]{ex.getLocalizedMessage(), field});
-                    return null;
-                }
-            }
+            newInstance = setFieldsValues(newInstance, clazz, fieldValues, mirrorsMap);
             logger.log(Level.FINE, "  return {0}", newInstance);
             return newInstance;
         }
     }
     
+    private static Object setFieldsValues(Object newInstance, Class clazz, Map<Field, Value> fieldValues, Map<Value, Object> mirrorsMap) throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper {
+        for (Field f : fieldValues.keySet()) {
+            String name = TypeComponentWrapper.name(f);
+            java.lang.reflect.Field field = getDeclaredOrInheritedField(clazz, name);
+            if (field == null) {
+                logger.log(Level.CONFIG, "No Such Field({0}) of class {1}", new Object[]{name, clazz});
+                return null;
+            }
+            field.setAccessible(true);
+            Value v = fieldValues.get(f);
+            try {
+                if (v == null) {
+                    field.set(newInstance, null);
+                } else {
+                    Object mv = mirrorsMap.get(v);
+                    if (mv == null) {
+                        mv = createMirrorObject(v, mirrorsMap);
+                    }
+                    if (mv != null) {
+                        field.set(newInstance, mv);
+                    } else {
+                        logger.log(Level.CONFIG, "Unable to translate field {0} of class {1}", new Object[]{name, clazz});
+                        return null;
+                    }
+                }
+            } catch (IllegalAccessException ex) {
+                logger.log(Level.CONFIG, "IllegalAccessException({0}) of field {1}", new Object[]{ex.getLocalizedMessage(), field});
+                return null;
+            }
+        }
+        return newInstance;
+    }
+    
     private static Object createSpecialized(ObjectReference value, ReferenceType type,
                                             Class clazz, Map<Value, Object> mirrorsMap) throws InternalExceptionWrapper,
                                                                                                VMDisconnectedExceptionWrapper,
                                                                                                ObjectCollectedExceptionWrapper,
                                                                                                ClassNotPreparedExceptionWrapper {
         if (java.awt.Font.class.isAssignableFrom(clazz)) {
-            Value[] fieldValues = getFieldValues(value, type, "values", "name", "pointSize", "style");  // NOI18N
+            //Font.getAttributes();
+            Map<Field, Value> fieldValues = getFieldValues(value, type, "values", "name", "size", "pointSize", "style");  // NOI18N
             if (fieldValues == null) {
                 return NO_MIRROR;
             }
-            Value values = fieldValues[0];
-            Object attributeValues;
-            if (values == null) {
-                if (fieldValues[1] == null) {
-                    return NO_MIRROR;
-                }
-                String name = StringReferenceWrapper.value((StringReference) fieldValues[1]);
-                float pointSize = PrimitiveValueWrapper.floatValue((PrimitiveValue) fieldValues[2]);
-                int style = PrimitiveValueWrapper.intValue((PrimitiveValue) fieldValues[3]);
-                try {
-                    attributeValues = createFontAttributeValues(name, pointSize, style);
-                } catch (Exception ex) {
-                    logger.log(Level.INFO, name, ex);
-                    return NO_MIRROR;
-                }
-            } else {
-                attributeValues = createMirrorObject(values, mirrorsMap);
-                if (attributeValues == null) {
-                    return NO_MIRROR;
-                }
-            }
-            try {
-                Map<? extends AttributedCharacterIterator.Attribute, ?> attributesMap =
-                        (Map<? extends AttributedCharacterIterator.Attribute, ?>)
-                        Class.forName("sun.font.AttributeMap").                 // NOI18N
-                            getConstructor(attributeValues.getClass()).
-                                newInstance(attributeValues);
-                return new java.awt.Font(attributesMap);
-            } catch (Exception ex) {
-                logger.log(Level.INFO, "Creating AttributeMap", ex);            // NOI18N
+            Object fontInstance = createPristineInstanceOf(java.awt.Font.class);
+            if (fontInstance == null) {
                 return NO_MIRROR;
             }
+            mirrorsMap.put(value, fontInstance);
+            fontInstance = setFieldsValues(fontInstance, java.awt.Font.class, fieldValues, mirrorsMap);
+            if (fontInstance == null) {
+                return NO_MIRROR;
+            } else {
+                return fontInstance;
+            }
         } else if (java.net.URL.class.isAssignableFrom(clazz)) {
-            Value[] fieldValues = getFieldValues(value, type, "handler");  // NOI18N
+            Map<Field, Value> fieldValues = getFieldValues(value, type, "handler");  // NOI18N
             if (fieldValues == null) {
                 return NO_MIRROR;
             }
             // No URL without handler
-            for (Value v : fieldValues) {
+            for (Value v : fieldValues.values()) {
                 if (v == null) {
                     return NO_MIRROR;
                 }
@@ -360,29 +343,7 @@ public class VariableMirrorTranslator {
         }
     }
     
-    private static Object createFontAttributeValues(String name, float pointSize, int style) throws ClassNotFoundException, InstantiationException, IllegalAccessException, NoSuchMethodException, IllegalArgumentException, InvocationTargetException {
-        // AttributeValues attrValues = new AttributeValues();
-        Class attributeValuesClass = Class.forName("sun.font.AttributeValues"); // NOI18N
-        Object attrValues = attributeValuesClass.newInstance();
-                
-        // attrValues.setFamily(name);
-        attributeValuesClass.getMethod("setFamily", String.class).invoke(attrValues, name);     // NOI18N
-        
-        // attrValues.setSize(pointSize); // expects the float value.
-        attributeValuesClass.getMethod("setSize", Float.TYPE).invoke(attrValues, pointSize);    // NOI18N
-        
-        if ((style & java.awt.Font.BOLD) != 0) {
-            // attrValues.setWeight(2); // WEIGHT_BOLD
-            attributeValuesClass.getMethod("setWeight", Float.TYPE).invoke(attrValues, 2f);     // NOI18N
-        }
-        if ((style & java.awt.Font.ITALIC) != 0) {
-            // attrValues.setPosture(.2f); // POSTURE_OBLIQUE
-            attributeValuesClass.getMethod("setPosture", Float.TYPE).invoke(attrValues, .2f);   // NOI18N
-        }
-        return attrValues;
-    }
-    
-    private static Value[] getFieldValues(ObjectReference value, ReferenceType type, String... names) throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper, ObjectCollectedExceptionWrapper, ClassNotPreparedExceptionWrapper {
+    private static Map<Field, Value> getFieldValues(ObjectReference value, ReferenceType type, String... names) throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper, ObjectCollectedExceptionWrapper, ClassNotPreparedExceptionWrapper {
         final int n = names.length;
         List<Field> fieldsToAskFor = new ArrayList<Field>(n);
         for (String name : names) {
@@ -393,11 +354,7 @@ public class VariableMirrorTranslator {
             fieldsToAskFor.add(field);
         }
         Map<Field, Value> fieldValues = ObjectReferenceWrapper.getValues(value, fieldsToAskFor);
-        Value[] ret = new Value[n];
-        for (int i = 0; i < n; i++) {
-            ret[i] = fieldValues.get(fieldsToAskFor.get(i));
-        }
-        return ret;
+        return fieldValues;
     }
     
     private static boolean willInvokeMethods(boolean isObject, Class clazz) {
@@ -412,6 +369,9 @@ public class VariableMirrorTranslator {
                                                     InvalidTypeException, ClassNotLoadedException,
                                                     ClassNotPreparedExceptionWrapper, IllegalArgumentExceptionWrapper {
         VirtualMachine vm = debugger.getVirtualMachine();
+        if (vm == null) {
+            throw new VMDisconnectedExceptionWrapper(new VMDisconnectedException());
+        }
         Class clazz = mirror.getClass();
         JPDAThreadImpl currentThread;
         Lock lock;
