@@ -62,8 +62,6 @@ import javax.swing.plaf.basic.BasicSplitPaneUI;
 import javax.swing.plaf.basic.BasicSplitPaneDivider;
 import javax.swing.event.DocumentListener;
 import javax.swing.event.DocumentEvent;
-import javax.swing.event.AncestorListener;
-import javax.swing.event.AncestorEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.plaf.TextUI;
 import javax.swing.text.*;
@@ -111,7 +109,7 @@ import org.openide.util.WeakListeners;
  * 
  * @author Maros Sandor
  */
-public class EditableDiffView extends DiffControllerImpl implements DiffView, DocumentListener, AncestorListener, PropertyChangeListener, PreferenceChangeListener, ChangeListener {
+public class EditableDiffView extends DiffControllerImpl implements DiffView, DocumentListener, PropertyChangeListener, PreferenceChangeListener, ChangeListener {
 
     private static final int INITIAL_DIVIDER_SIZE = 32;
     private static final String CONTENT_TYPE_PLAIN = "text/plain";
@@ -184,13 +182,18 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
 
     private Integer askedLineLocation;
     private static final String PROP_SMART_SCROLLING_DISABLED = "diff.smartScrollDisabled"; //NOI18N
-    private static final RequestProcessor rp = new RequestProcessor("EditableDiffViewRP", 10);
+    static final RequestProcessor rp = new RequestProcessor("EditableDiffViewRP", 10);
     private static final Logger LOG = Logger.getLogger(EditableDiffView.class.getName());
 
     private static final String CONTENT_TYPE_DIFF = "text/x-diff"; //NOI18N
     private final JPanel searchContainer;
     private static final String PROP_SEARCH_CONTAINER = "diff.search.container"; //NOI18N
     private final Object DIFFING_LOCK = new Object();
+    private final String name1;
+    private final String name2;
+    private boolean sourcesInitialized;
+    private boolean viewAdded;
+    private boolean addedToHierarchy;
 
     public EditableDiffView (final StreamSource ss1, final StreamSource ss2) {
         this(ss1, ss2, false);
@@ -205,6 +208,8 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         if (title2 == null) title2 = NbBundle.getMessage(EditableDiffView.class, "CTL_DiffPanel_NoTitle"); // NOI18N
         String mimeType1 = ss1.getMIMEType();
         String mimeType2 = ss2.getMIMEType();
+        name1 = ss1.getName();
+        name2 = ss2.getName();
         if (mimeType1 == null) mimeType1 = mimeType2;
         if (mimeType2 == null) mimeType2 = mimeType1;
         binaryDiff = mimeType1 == null || mimeType2 == null || mimeType1.equals("application/octet-stream") || mimeType2.equals("application/octet-stream");        
@@ -212,12 +217,28 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         actionsEnabled = ss2.isEditable();
         diffMarkprovider = new EditableDiffMarkProvider();        
 
-        view = new JPanel(new BorderLayout(0, 0));
+        view = new JPanel(new BorderLayout(0, 0)) {
+
+            @Override
+            public void addNotify () {
+                super.addNotify();
+                viewAdded();
+            }
+
+            @Override
+            public void removeNotify () {
+                viewRemoved();
+                super.removeNotify();
+            }
+            
+        };
         searchContainer = new JPanel();
         searchContainer.setLayout(new BoxLayout(searchContainer, BoxLayout.Y_AXIS));
         view.add(searchContainer, BorderLayout.PAGE_END);
         if (enhancedView) {
-            view.add(jTabbedPane = new JTabbedPane(JTabbedPane.TOP), BorderLayout.CENTER);
+            jTabbedPane = new JTabbedPane(JTabbedPane.TOP);
+            jTabbedPane.putClientProperty("diff-view-mode-switcher", true);
+            view.add(jTabbedPane, BorderLayout.CENTER);
         } else {
             jTabbedPane = null;
             view.add(jSplitPane1, BorderLayout.CENTER);
@@ -284,50 +305,76 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
                     jEditorPane2.getEditorPane().setEditorKit(editorKit);
                     repairTextUI(jEditorPane2.getEditorPane());
                     jEditorPane2.getEditorPane().putClientProperty("usedByCloneableEditor", Boolean.TRUE); //NOI18N
-                    
-                    try {
-                        setSource1(ss1);
-                    } catch (IOException ioex) {
-                        Logger.getLogger(EditableDiffView.class.getName()).log(Level.INFO, "Diff source 1 unavailable", ioex); //NOI18N
-                    }
-                    try {
-                        setSource2(ss2);
-                    } catch (IOException ioex) {
-                        Logger.getLogger(EditableDiffView.class.getName()).log(Level.INFO, "Diff source 2 unavailable", ioex); //NOI18N
-                    }
 
                     if (jTabbedPane != null) {
                         textualEditorPane.setEditorKit(CloneableEditorSupport.getEditorKit(CONTENT_TYPE_DIFF));
                         repairTextUI(textualEditorPane);
                         setTextualContent();
                     }
-                    
-                    if (!secondSourceAvailable) {
-                        filePanel2.remove(jEditorPane2);
-                        NoContentPanel ncp = new NoContentPanel(NbBundle.getMessage(EditableDiffView.class,
-                                secondSourceUnsupportedTextUI ? "CTL_DiffPanel_UnsupportedTextUI" : "CTL_DiffPanel_NoContent")); // NOI18N
-                        ncp.setPreferredSize(new Dimension(jEditorPane1.getPreferredSize().width, ncp.getPreferredSize().height));
-                        filePanel2.add(ncp);
-                        actionsEnabled = false;
-                    }
-                    if (!firstSourceAvailable) {
-                        filePanel1.remove(jEditorPane1);
-                        NoContentPanel ncp = new NoContentPanel(NbBundle.getMessage(EditableDiffView.class,
-                                firstSourceUnsupportedTextUI ? "CTL_DiffPanel_UnsupportedTextUI" : "CTL_DiffPanel_NoContent")); // NOI18N
-                        ncp.setPreferredSize(new Dimension(jEditorPane2.getPreferredSize().width, ncp.getPreferredSize().height));
-                        filePanel1.add(ncp);
-                        actionsEnabled = false;
-                    }
-                    adjustPreferredSizes();
 
-                    JTextComponent leftEditor = jEditorPane1.getEditorPane();
-                    JTextComponent rightEditor = jEditorPane2.getEditorPane();
-                    if (rightEditor.isEditable()) {
-                        setBackgroundColorForNonEditable(leftEditor, rightEditor);
-                    }
-                    if ((rightEditor.getBackground().getRGB() & 0xFFFFFF) == 0) {
-                        colorLines   = Color.WHITE;
-                    }
+                    manager = new DiffViewManager(EditableDiffView.this);
+                    
+                    rp.post(new Runnable() {
+
+                        @Override
+                        public void run () {
+                            final Document doc1 = getSourceDocument(ss1);
+                            final Document doc2 = getSourceDocument(ss2);
+                            EventQueue.invokeLater(new Runnable() {
+                                
+                                @Override
+                                public void run () {
+                                    try {
+                                        setSource1(ss1, doc1);
+                                    } catch (IOException ioex) {
+                                        Logger.getLogger(EditableDiffView.class.getName()).log(Level.INFO, "Diff source 1 unavailable", ioex); //NOI18N
+                                    }
+                                    try {
+                                        setSource2(ss2, doc2);
+                                    } catch (IOException ioex) {
+                                        Logger.getLogger(EditableDiffView.class.getName()).log(Level.INFO, "Diff source 2 unavailable", ioex); //NOI18N
+                                    }
+
+                                    if (!secondSourceAvailable) {
+                                        filePanel2.remove(jEditorPane2);
+                                        NoContentPanel ncp = new NoContentPanel(NbBundle.getMessage(EditableDiffView.class,
+                                                secondSourceUnsupportedTextUI ? "CTL_DiffPanel_UnsupportedTextUI" : "CTL_DiffPanel_NoContent")); // NOI18N
+                                        ncp.setPreferredSize(new Dimension(jEditorPane1.getPreferredSize().width, ncp.getPreferredSize().height));
+                                        filePanel2.add(ncp);
+                                        actionsEnabled = false;
+                                    }
+                                    if (!firstSourceAvailable) {
+                                        filePanel1.remove(jEditorPane1);
+                                        NoContentPanel ncp = new NoContentPanel(NbBundle.getMessage(EditableDiffView.class,
+                                                firstSourceUnsupportedTextUI ? "CTL_DiffPanel_UnsupportedTextUI" : "CTL_DiffPanel_NoContent")); // NOI18N
+                                        ncp.setPreferredSize(new Dimension(jEditorPane2.getPreferredSize().width, ncp.getPreferredSize().height));
+                                        filePanel1.add(ncp);
+                                        actionsEnabled = false;
+                                    }
+                                    adjustPreferredSizes();
+
+                                    JTextComponent leftEditor = jEditorPane1.getEditorPane();
+                                    JTextComponent rightEditor = jEditorPane2.getEditorPane();
+                                    if (rightEditor.isEditable()) {
+                                        setBackgroundColorForNonEditable(leftEditor, rightEditor);
+                                    }
+                                    if ((rightEditor.getBackground().getRGB() & 0xFFFFFF) == 0) {
+                                        colorLines   = Color.WHITE;
+                                    }
+                                    
+                                    manager.init();
+                                    
+                                    sourcesInitialized = true;
+                                    if (viewAdded) {
+                                        addListeners();
+                                        refreshDiff(100);
+                                    }
+                                }
+                                
+                            });
+                        }
+                        
+                    });
                 }
             };
             if (SwingUtilities.isEventDispatchThread()) {
@@ -344,19 +391,9 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
                     + ", editableDocument:" + editableDocument + ", editableCookie:" + editableCookie + ", editorUndoRedo:" + editorUndoRedo, e);
         }
 
-        if (binaryDiff) {
+        if (binaryDiff || canceled) {
             return;
         }
-        
-        view.addAncestorListener(this);
-
-        manager = new DiffViewManager(this);
-        manager.init();
-        if (canceled) {
-            Thread.currentThread().interrupt();
-        } else {
-            refreshDiff(100);
-        }
     }
 
     private void initializeTabPane (StreamSource ss1, StreamSource ss2) {
@@ -571,18 +608,15 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         if (modifiedDocument != null) modifiedDocument.removeDocumentListener(this);
     }
     
-    @Override
-    public void ancestorAdded(AncestorEvent event) {
+    private void viewAdded () {
         DiffModuleConfig.getDefault().getPreferences().addPreferenceChangeListener(this);
-        expandFolds();
-        initGlobalSizes();
-        addChangeListeners();
-        addDocumentListeners();
-        refreshDiff(50);        
-
-        if (editableCookie == null) return;
-        refreshEditableDocument();
-        editableCookie.addPropertyChangeListener(this);
+        addedToHierarchy = true;
+        if (sourcesInitialized) {
+            addListeners();
+            refreshDiff(50);
+        } else {
+            viewAdded = true;
+        }
     }
 
     private void refreshEditableDocument() {
@@ -602,12 +636,17 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         editableDocument.addDocumentListener(this);
     }
 
-    @Override
-    public void ancestorRemoved(AncestorEvent event) {
-        DiffModuleConfig.getDefault().getPreferences().removePreferenceChangeListener(this);
-        removeDocumentListeners();
-        if (editableCookie != null) {
-            editableCookie.removePropertyChangeListener(this);
+    private void viewRemoved () {
+        viewAdded = false;
+        if (addedToHierarchy) {
+            addedToHierarchy = false;
+            DiffModuleConfig.getDefault().getPreferences().removePreferenceChangeListener(this);
+            if (sourcesInitialized) {
+                removeDocumentListeners();
+                if (editableCookie != null) {
+                    editableCookie.removePropertyChangeListener(this);
+                }
+            }
         }
     }
 
@@ -617,10 +656,6 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         diffChanged();  // trigger re-calculation of hightlights in case diff stays the same
         refreshDiff(20);
     }
-    
-    @Override
-    public void ancestorMoved(AncestorEvent event) {
-    }
 
     @Override
     public void insertUpdate(DocumentEvent e) {
@@ -755,6 +790,17 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         return boldStroke;
     }
 
+    private void addListeners () {
+        expandFolds();
+        initGlobalSizes();
+        addChangeListeners();
+        addDocumentListeners();
+
+        if (editableCookie == null) return;
+        refreshEditableDocument();
+        editableCookie.addPropertyChangeListener(this);
+    }
+
     class DiffSplitPaneUI extends BasicSplitPaneUI {
 
         final DiffSplitPaneDivider splitPaneDivider;
@@ -1092,49 +1138,52 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         PropertyChangeListener list = new java.beans.PropertyChangeListener() { // NOI18N
             @Override
             public void propertyChange(java.beans.PropertyChangeEvent evt) {
-                javax.swing.SwingUtilities.invokeLater(new Runnable() {
-                    @Override
-                    public void run() {
-                        diffChanged();
-                        initGlobalSizes();
-                        jEditorPane1.onUISettingsChanged();
-                        getComponent().revalidate();
-                        getComponent().repaint();
-                    }
-                });
+                if ("font".equals(evt.getPropertyName())) {
+                    javax.swing.SwingUtilities.invokeLater(new Runnable() {
+                        @Override
+                        public void run() {
+                            diffChanged();
+                            initGlobalSizes();
+                            jEditorPane1.onUISettingsChanged();
+                            getComponent().revalidate();
+                            getComponent().repaint();
+                        }
+                    });
+                }
             }
         };
         propertyChangeListeners.put(jEditorPane1.getEditorPane(), list);
-        jEditorPane1.getEditorPane().addPropertyChangeListener("font", WeakListeners.propertyChange(list, jEditorPane1.getEditorPane())); //NOI18N
+        jEditorPane1.getEditorPane().addPropertyChangeListener(WeakListeners.propertyChange(list, jEditorPane1.getEditorPane())); //NOI18N
         list = new java.beans.PropertyChangeListener() { // NOI18N
             @Override
             public void propertyChange(java.beans.PropertyChangeEvent evt) {
-                javax.swing.SwingUtilities.invokeLater(new Runnable() {
-                    @Override
-                    public void run() {
-                        diffChanged();
-                        initGlobalSizes();
-                        jEditorPane2.onUISettingsChanged();
-                        getComponent().revalidate();
-                        getComponent().repaint();
-                    }
-                });
+                if ("font".equals(evt.getPropertyName())) {
+                    javax.swing.SwingUtilities.invokeLater(new Runnable() {
+                        @Override
+                        public void run() {
+                            diffChanged();
+                            initGlobalSizes();
+                            jEditorPane2.onUISettingsChanged();
+                            getComponent().revalidate();
+                            getComponent().repaint();
+                        }
+                    });
+                }
             }
         };
         propertyChangeListeners.put(jEditorPane2.getEditorPane(), list);
-        jEditorPane2.getEditorPane().addPropertyChangeListener("font", WeakListeners.propertyChange(list, jEditorPane2.getEditorPane())); //NOI18N
+        jEditorPane2.getEditorPane().addPropertyChangeListener(WeakListeners.propertyChange(list, jEditorPane2.getEditorPane())); //NOI18N
     }
 
     private synchronized void diffChanged() {
         diffSerial++;   // we need to re-compute decorations, font size changed
     }
 
-    private void setSource1(StreamSource ss) throws IOException {
+    private void setSource1 (StreamSource ss, Document sdoc) throws IOException {
         firstSourceAvailable = false; 
         EditorKit kit = jEditorPane1.getEditorPane().getEditorKit();
         if (kit == null) throw new IOException("Missing Editor Kit"); // NOI18N
 
-        Document sdoc = getSourceDocument(ss);
         baseDocument = sdoc;
         Document doc = sdoc != null ? sdoc : kit.createDefaultDocument();
         if (!Boolean.TRUE.equals(skipFile)) {
@@ -1201,12 +1250,11 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         return sdoc;
     }
 
-    private void setSource2(StreamSource ss) throws IOException {
+    private void setSource2 (StreamSource ss, Document sdoc) throws IOException {
         secondSourceAvailable = false;
         EditorKit kit = jEditorPane2.getEditorPane().getEditorKit();
         if (kit == null) throw new IOException("Missing Editor Kit"); // NOI18N
         
-        Document sdoc = getSourceDocument(ss);
         modifiedDocument = sdoc;
         if (sdoc != null && ss.isEditable()) {
             DataObject dao = (DataObject) sdoc.getProperty(Document.StreamDescriptionProperty);
@@ -1309,6 +1357,9 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
     }
 
     private TextualDiffRefreshTask textualRefreshTask;
+    @NbBundle.Messages({
+        "Diff.dev_null=/dev/null"
+    })
     private class TextualDiffRefreshTask implements Cancellable {
 
         final StyledDocument out;
@@ -1354,8 +1405,8 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
             Reader r1 = null;
             Reader r2 = null;
             
-            if (differences == null) {
-                differences = computeDiff();
+            if (differences == null || !firstSourceAvailable || !secondSourceAvailable) {
+                differences = computeDiff(true);
             }
 
             try {
@@ -1374,7 +1425,10 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
                 if (isCanceled()) {
                     return;
                 }
-                TextDiffVisualizer.TextDiffInfo info = new TextDiffVisualizer.TextDiffInfo(fileLabel1.getText(), fileLabel2.getText(), null, null, r1, r2, differences);
+                TextDiffVisualizer.TextDiffInfo info = new TextDiffVisualizer.TextDiffInfo(
+                        firstSourceAvailable ? "a/" + name1 : Bundle.Diff_dev_null(),
+                        secondSourceAvailable ? "b/" + name2 : Bundle.Diff_dev_null(),
+                        null, null, r1, r2, differences);
                 info.setContextMode(true, 3);
                 final String diffText = TextDiffVisualizer.differenceToUnifiedDiffText(info);
                 if (isCanceled()) {
@@ -1472,7 +1526,7 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         @Override
         public void run() {
             synchronized (DIFFING_LOCK) {
-                final Difference[] differences = computeDiff();
+                final Difference[] differences = computeDiff(false);
                 if (textualRefreshTask != null) {
                     textualRefreshTask.refresh(differences);
                 }
@@ -1484,6 +1538,7 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
                             diffChanged();
                         }
                         if (getDifferenceIndex() >= diffs.length) updateCurrentDifference(null);
+                        view.revalidate();
                         support.firePropertyChange(DiffController.PROP_DIFFERENCES, null, null);
                         jEditorPane1.setCurrentDiff(diffs);
                         jEditorPane2.setCurrentDiff(diffs);
@@ -1503,7 +1558,7 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
         }
     }
 
-    private Difference[] computeDiff () {
+    private Difference[] computeDiff (boolean includeUnavailable) {
 
         if(editableDocument != null) { 
             // refresh fo before computing the diff, external changes might not have been recognized in some setups
@@ -1524,12 +1579,12 @@ public class EditableDiffView extends DiffControllerImpl implements DiffView, Do
             }
         }
 
-        if (!secondSourceAvailable || !firstSourceAvailable) {
+        if (!includeUnavailable && (!secondSourceAvailable || !firstSourceAvailable)) {
             return NO_DIFFERENCES;
         }
 
-        Reader first = getReader(jEditorPane1.getEditorPane().getDocument());
-        Reader second = getReader(jEditorPane2.getEditorPane().getDocument());
+        Reader first = includeUnavailable && !firstSourceAvailable ? new StringReader("") : getReader(jEditorPane1.getEditorPane().getDocument());
+        Reader second = includeUnavailable && !secondSourceAvailable ? new StringReader("") : getReader(jEditorPane2.getEditorPane().getDocument());
         if (first == null || second == null) {
             return NO_DIFFERENCES;
         }
