@@ -45,7 +45,6 @@ import com.jcraft.jsch.Channel;
 import com.jcraft.jsch.JSch;
 import com.jcraft.jsch.JSchException;
 import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.io.IOException;
 import java.util.AbstractList;
 import java.util.ArrayList;
@@ -53,7 +52,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
@@ -100,22 +98,24 @@ public final class ConnectionManager {
     }
     private static final java.util.logging.Logger log = Logger.getInstance();
     // Actual sessions pools. One per host
-    private static final ConcurrentHashMap<ExecutionEnvironment, JSchChannelsSupport> channelsSupport = new ConcurrentHashMap<ExecutionEnvironment, JSchChannelsSupport>();
-    private static List<ConnectionListener> connectionListeners = new CopyOnWriteArrayList<ConnectionListener>();
+    private static final ConcurrentHashMap<ExecutionEnvironment, JSchChannelsSupport> channelsSupport = new ConcurrentHashMap<>();
+    private static List<ConnectionListener> connectionListeners = new CopyOnWriteArrayList<>();
     private static final Object channelsSupportLock = new Object();
-    private static HashMap<ExecutionEnvironment, ConnectToAction> connectionActions = new HashMap<ExecutionEnvironment, ConnectToAction>();
+    private static HashMap<ExecutionEnvironment, ConnectToAction> connectionActions = new HashMap<>();
     private static final ConcurrentHashMap<ExecutionEnvironment, JSch> jschPool =
-            new ConcurrentHashMap<ExecutionEnvironment, JSch>();
+            new ConcurrentHashMap<>();
     private final ConcurrentHashMap<ExecutionEnvironment, JSchConnectionTask> connectionTasks =
-            new ConcurrentHashMap<ExecutionEnvironment, JSchConnectionTask>();
+            new ConcurrentHashMap<>();
     private static final boolean UNIT_TEST_MODE = Boolean.getBoolean("nativeexecution.mode.unittest"); // NOI18N
     // Instance of the ConnectionManager
     private static final ConnectionManager instance = new ConnectionManager();
     private final ConnectionContinuation DEFAULT_CC;
-    private final AbstractList<ExecutionEnvironment> recentConnections = new ArrayList<ExecutionEnvironment>();
+    private final AbstractList<ExecutionEnvironment> recentConnections = new ArrayList<>();
 
     private final ConnectionWatcher connectionWatcher;
     final int connectionWatcherInterval;
+    
+    private final SlowListenerDetector slowConnectionListenerDetector;
 
     static {
         ConnectionManagerAccessor.setDefault(new ConnectionManagerAccessorImpl());
@@ -129,6 +129,21 @@ public final class ConnectionManager {
     }
 
     private ConnectionManager() {
+        
+        int timeout = Integer.getInteger(
+                "nativeexecution.slow.connection.listener.timeout", 100); //NOI18N
+        Level level;
+        try {
+            level = Level.parse(System.getProperty("nativeexecution.slow.connection.listener.level", "FINE")); //NOI18N
+        } catch (IllegalArgumentException ex) {
+            level = Level.FINE;
+        }
+        if (timeout > 0 && log.isLoggable(level)) {
+            slowConnectionListenerDetector = new SlowListenerDetector(timeout, log, level);
+        } else {
+            slowConnectionListenerDetector = null;
+        }
+
         // init jsch logging
 
         if (log.isLoggable(Level.FINEST)) {
@@ -185,7 +200,7 @@ public final class ConnectionManager {
 
     public List<ExecutionEnvironment> getRecentConnections() {
         synchronized (recentConnections) {
-            return Collections.unmodifiableList(new ArrayList<ExecutionEnvironment>(recentConnections));
+            return Collections.unmodifiableList(new ArrayList<>(recentConnections));
         }
     }
 
@@ -241,7 +256,13 @@ public final class ConnectionManager {
         }
         // No need to lock - use thread-safe collection
         for (ConnectionListener connectionListener : connectionListeners) {
+            if (slowConnectionListenerDetector != null) {
+                slowConnectionListenerDetector.start("ConnectionListener.connected"); //NOI18N
+            }
             connectionListener.connected(execEnv);
+            if (slowConnectionListenerDetector != null) {
+                slowConnectionListenerDetector.stop();
+            }
         }
         updateRecentConnectionsList(execEnv);
     }
@@ -252,7 +273,13 @@ public final class ConnectionManager {
         }
         // No need to lock - use thread-safe collection
         for (ConnectionListener connectionListener : connectionListeners) {
+            if (slowConnectionListenerDetector != null) {
+                slowConnectionListenerDetector.start("ConnectionListener.disconnected"); //NOI18N
+            }
             connectionListener.disconnected(execEnv);
+            if (slowConnectionListenerDetector != null) {
+                slowConnectionListenerDetector.stop();
+            }
         }
     }
 
@@ -265,6 +292,16 @@ public final class ConnectionManager {
      * localhost environment. false otherwise.
      */
     public boolean isConnectedTo(final ExecutionEnvironment execEnv) {
+        return isConnectedTo(execEnv, true);
+    }
+
+    /**
+     * @param  checkHostInfo determines whether to check host info availability.
+     * There was a very small time frame when host was in fact connected, but host info was not yet put into cache (issue #252922)
+     * Due to the issue #252922 we make ConnectionManager.isConnected() return FALSE while in this period.
+     * But internally we need to distinguish whether a host is really connected and just host info is not yet made available.
+     */
+    /*package*/ boolean isConnectedTo(final ExecutionEnvironment execEnv, boolean checkHostInfo) {
         if (execEnv.isLocal()) {
             return true;
         }
@@ -276,7 +313,11 @@ public final class ConnectionManager {
         // balloon "Need to connect to..." appears several seconds before host is going "red" :)
         if (support != null) {
             if (support.isConnected()) {
-                return true;
+                if (checkHostInfo) {
+                    return HostInfoUtils.isHostInfoAvailable(execEnv);
+                } else {
+                    return true;
+                }
             } else {
                 if (connectionWatcher != null) {
                     connectionWatcher.scheduleNow();
@@ -372,7 +413,16 @@ public final class ConnectionManager {
         }
 
         if (!UNIT_TEST_MODE) {
-            initiateConnection(env, jsch);
+            try {
+                initiateConnection(env, jsch);
+            } catch (IOException e) {
+                if (MiscUtils.isJSCHTooLongException(e)) {
+                    MiscUtils.showJSCHTooLongNotification(env.getDisplayName());
+                }
+                if (!(e.getCause() instanceof JSchException)) {
+                    throw e;
+                }
+            }
         } else {
             // Attempt to workaround "Auth fail" in tests, see IZ 190458
             // We try to reconnect up to 10 times if "Auth fail" exception happens
@@ -383,9 +433,6 @@ public final class ConnectionManager {
                     initiateConnection(env, jsch);
                     return;
                 } catch (IOException e) {
-                    if (MiscUtils.isJSCHTooLongException(e)) {
-                        MiscUtils.showJSCHTooLongNotification(env.getDisplayName());
-                    }
                     if (!(e.getCause() instanceof JSchException)) {
                         throw e;
                         }
@@ -443,7 +490,8 @@ public final class ConnectionManager {
                 }
             }
 
-            HostInfo hostInfo = HostInfoUtils.getHostInfo(env);
+            log.log(Level.FINEST, "Getting host info for {0}", env); // NOI18N
+            HostInfo hostInfo = HostInfoUtils.getHostInfo(env, true);
             log.log(Level.FINE, "New connection established: {0} - {1}", new String[]{env.toString(), hostInfo.getOS().getName()}); // NOI18N
 
             fireConnected(env);
@@ -766,7 +814,7 @@ public final class ConnectionManager {
          * Guarded by channelsSupportLock.
          * Contains list of connections that were already recognized as broken
          */
-        private final Set<ExecutionEnvironment> brokenConnections = new HashSet<ExecutionEnvironment>();
+        private final Set<ExecutionEnvironment> brokenConnections = new HashSet<>();
 
         private final RequestProcessor.Task myTask;
 
@@ -778,7 +826,7 @@ public final class ConnectionManager {
         public void run() {
             try {
                 // fast check without locking
-                List<ExecutionEnvironment> candidates = new ArrayList<ExecutionEnvironment>();
+                List<ExecutionEnvironment> candidates = new ArrayList<>();
                 for (JSchChannelsSupport cs : channelsSupport.values()) {
                     if (!cs.isConnected()) {
                         candidates.add(cs.getExecutionEnvironment());
