@@ -44,9 +44,11 @@ package org.netbeans.modules.remote.impl.fileoperations.spi;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
+import java.net.ConnectException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.ArrayList;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ExecutionException;
@@ -57,8 +59,11 @@ import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.NativeProcessBuilder;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.FileInfoProvider;
-import org.netbeans.modules.nativeexecution.api.util.FileInfoProvider.SftpIOException;
 import org.netbeans.modules.nativeexecution.api.util.MacroMap;
+import org.netbeans.modules.remote.impl.RemoteLogger;
+import org.netbeans.modules.remote.impl.fs.DirEntry;
+import org.netbeans.modules.remote.impl.fs.RemoteDirectory;
+import org.netbeans.modules.remote.impl.fs.RemoteExceptions;
 import org.netbeans.modules.remote.impl.fs.RemoteFileObject;
 import org.netbeans.modules.remote.impl.fs.RemoteFileObjectBase;
 import org.netbeans.modules.remote.impl.fs.RemoteFileSystem;
@@ -66,6 +71,7 @@ import org.netbeans.modules.remote.impl.fs.RemoteFileSystemManager;
 import org.netbeans.modules.remote.impl.fs.RemoteFileSystemTransport;
 import org.netbeans.modules.remote.impl.fs.RemoteFileSystemUtils;
 import org.netbeans.modules.remote.impl.fs.RemoteFileUrlMapper;
+import org.netbeans.modules.remote.impl.fs.RemotePlainFile;
 import org.netbeans.spi.extexecution.ProcessBuilderFactory;
 import org.netbeans.spi.extexecution.ProcessBuilderImplementation;
 import org.openide.filesystems.FileObject;
@@ -94,7 +100,7 @@ abstract public class FileOperationsProvider {
         private static final boolean USE_CACHE;
         static {
             String text = System.getProperty("rfs.vcs.cache");
-            USE_CACHE = (text == null) ? true : Boolean.parseBoolean(text);
+            USE_CACHE = false;//(text == null) ? true : Boolean.parseBoolean(text);
         }
 
         protected FileOperations(FileSystem fs) {
@@ -126,20 +132,50 @@ abstract public class FileOperationsProvider {
             return path;
         }
 
+        private RemoteFileObject getFileObject(FileProxyO file) {
+            String path = PathUtilities.normalizeUnixPath(file.getPath());
+            RemoteFileObjectBase cached = fileSystem.getFactory().getCachedFileObject(path);
+            RemoteFileObject fo;
+            if (cached != null && cached.isValid()) {
+                fo = cached.getOwnerFileObject();
+            } else {
+                fo = fileSystem.findResource(path);
+            }
+            return fo;
+        }
+        
         protected boolean isDirectory(FileProxyO file) {
+            if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                RemoteFileObject fo = getFileObject(file);
+                return (fo == null || ! fo.isValid()) ? false : fo.isFolder();
+            }
             if (USE_CACHE) {
                 Boolean res = fileSystem.vcsSafeIsDirectory(file.getPath());
                 if (res != null) {
                     return res.booleanValue();
                 }
             }
+            RemoteFileObjectBase beingCreated = fileSystem.getBeingCreated();
+            if (beingCreated != null) {
+                if (beingCreated.getPath().equals(file.getPath())) {
+                    if (beingCreated instanceof RemotePlainFile) {
+                        return false;
+                    } else if (beingCreated instanceof RemoteDirectory) {
+                        return true;
+                    }
+                }
+            }
+            
             if (!ConnectionManager.getInstance().isConnectedTo(getExecutionEnvironment())) {
                 return false;
             }
             try {
-                FileInfoProvider.StatInfo statInfo = RemoteFileSystemTransport.stat(env, file.getPath());
-                return statInfo.isDirectory(); 
-            } catch (InterruptedException ex) {
+                DirEntry entry = RemoteFileSystemTransport.stat(env, file.getPath());
+                return entry.isDirectory(); 
+            } catch (ConnectException ex) {
+                RemoteLogger.finest(ex);
+            } catch (InterruptedException | IOException ex) {
+                RemoteLogger.finest(ex);
             } catch (ExecutionException ex) {
                 if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
                     return false;
@@ -150,6 +186,10 @@ abstract public class FileOperationsProvider {
         }
         
         protected long lastModified(FileProxyO file) {
+            if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                RemoteFileObject fo = getFileObject(file);
+                return (fo == null || !fo.isValid()) ? -1 : fo.lastModified().getTime();
+            }
             if (USE_CACHE) {
                 Long res = fileSystem.vcsSafeLastModified(file.getPath());
                 if (res != null) {
@@ -160,9 +200,12 @@ abstract public class FileOperationsProvider {
                 return -1;
             }
             try {
-                FileInfoProvider.StatInfo statInfo = RemoteFileSystemTransport.stat(env, file.getPath());
-                return statInfo.getLastModified().getTime();
-            } catch (InterruptedException ex) {
+                DirEntry entry = RemoteFileSystemTransport.stat(env, file.getPath());
+                return entry.getLastModified().getTime();
+            } catch (ConnectException ex) {
+                RemoteLogger.finest(ex);
+            } catch (InterruptedException | IOException ex) {
+                RemoteLogger.finest(ex);
             } catch (ExecutionException ex) {
                 if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
                     return -1;
@@ -173,6 +216,10 @@ abstract public class FileOperationsProvider {
         }
 
         protected boolean isFile(FileProxyO file) {
+            if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                RemoteFileObject fo = getFileObject(file);
+                return (fo == null || !fo.isValid()) ? false : fo.isData();
+            }
             if (USE_CACHE) {
                 Boolean res = fileSystem.vcsSafeIsFile(file.getPath());
                 if (res != null) {
@@ -183,9 +230,12 @@ abstract public class FileOperationsProvider {
                 return false;
             }
             try {
-                FileInfoProvider.StatInfo statInfo = RemoteFileSystemTransport.stat(env, file.getPath());
-                return statInfo.isPlainFile(); 
-            } catch (InterruptedException ex) {
+                DirEntry entry = RemoteFileSystemTransport.stat(env, file.getPath());
+                return entry.isPlainFile(); 
+            } catch (ConnectException ex) {
+                RemoteLogger.finest(ex);
+            } catch (InterruptedException | IOException ex) {
+                RemoteLogger.finest(ex);
             } catch (ExecutionException ex) {
                 if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
                     return false;
@@ -196,13 +246,20 @@ abstract public class FileOperationsProvider {
         }
         
         protected boolean canWrite(FileProxyO file) {
+            if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                RemoteFileObject fo = getFileObject(file);
+                return (fo == null || !fo.isValid()) ? false : fo.canWrite();
+            }
             if (!ConnectionManager.getInstance().isConnectedTo(getExecutionEnvironment())) {
                 return false;
             }
             try {
-                FileInfoProvider.StatInfo statInfo = RemoteFileSystemTransport.stat(env, file.getPath());
-                return statInfo.canWrite(env); 
-            } catch (InterruptedException ex) {
+                DirEntry entry = RemoteFileSystemTransport.stat(env, file.getPath());
+                return entry.canWrite();
+            } catch (ConnectException ex) {
+                RemoteLogger.finest(ex);
+            } catch (InterruptedException | IOException ex) {
+                RemoteLogger.finest(ex);
             } catch (ExecutionException ex) {
                 if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
                     return false;
@@ -213,10 +270,14 @@ abstract public class FileOperationsProvider {
         }
         
         protected FileObject getRoot() {
-            RemoteFileSystem fs = RemoteFileSystemManager.getInstance().getFileSystem(env);
+            RemoteFileSystem fs = getFileSystem();
             return fs.getRoot();
         }
         
+        protected RemoteFileSystem getFileSystem() {
+            return RemoteFileSystemManager.getInstance().getFileSystem(env);
+        }
+        
         protected String getPath(FileProxyO file) {
             return file.getPath();
         }
@@ -226,34 +287,74 @@ abstract public class FileOperationsProvider {
         }
 
         protected boolean exists(FileProxyO file) {
+            if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                RemoteFileObject fo = getFileObject(file);
+                return fo != null && fo.isValid();
+            }
             if (USE_CACHE) {
                 Boolean res = fileSystem.vcsSafeExists(file.getPath());
                 if (res != null) {
                     return res.booleanValue();
                 }
             }
+            return existsSafe(file);
+        }
+
+        protected boolean existsSafe(FileProxyO file) {
             if (!ConnectionManager.getInstance().isConnectedTo(getExecutionEnvironment())) {
                 return false;
             }
             try {
                 // shouldn't we use stat instead of lstat?
-                FileInfoProvider.StatInfo statInfo = RemoteFileSystemTransport.lstat(
+                DirEntry entry = RemoteFileSystemTransport.lstat(
                         getExecutionEnvironment(), file.getPath());
-                return statInfo != null;
-            } catch (InterruptedException ex) {
+                return entry != null;
+            } catch (ConnectException ex) {
+                RemoteLogger.finest(ex);
+            } catch (InterruptedException | IOException ex) {
+                RemoteLogger.finest(ex);
             } catch (ExecutionException ex) {
                 if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
                     return false;
                 }
-                System.err.println("Exception on file "+file.getPath());
-                ex.printStackTrace(System.err);
+                RemoteLogger.finest(ex);
             }
             return false;
         }
 
         protected FileObject toFileObject(FileProxyO path) {
+            RemoteFileObjectBase cachedFileObject = fileSystem.getFactory().getCachedFileObject(path.getPath());
+            if (cachedFileObject != null && cachedFileObject.isValid()) {
+                return cachedFileObject.getOwnerFileObject();
+            }            
             FileObject root = getRoot();
-            return root.getFileObject(path.getPath());
+            FileObject fo = root.getFileObject(path.getPath());
+            if (fo == null && existsSafe(path)) {
+                String parent = path.getPath();
+                LinkedList<String> stack = new LinkedList<>();
+                while(true) {
+                    parent = PathUtilities.getDirName(parent);
+                    if (parent == null) {
+                        return null;
+                    }
+                    stack.addLast(parent);
+                    FileObject parentFO = root.getFileObject(parent);
+                    if (parentFO != null && parentFO.isValid()) {
+                        break;
+                    }
+                }
+                while(!stack.isEmpty()) {
+                    parent = stack.removeLast();
+                    FileObject parentFO = root.getFileObject(parent);
+                    if (parentFO != null && parentFO.isValid()) {
+                        parentFO.refresh();
+                    } else {
+                        return null;
+                    }
+                }
+                fo = root.getFileObject(path.getPath());
+            }
+            return fo;
         }
 
         protected InputStream getInputStream(FileObject fo, boolean checkLock) throws FileNotFoundException {
@@ -266,6 +367,18 @@ abstract public class FileOperationsProvider {
 
         protected String[] list(FileProxyO file) {
             if (isDirectory(file)) {
+                if (RemoteVcsSupportUtil.USE_FS && !fileSystem.isInsideVCS()) {
+                    RemoteFileObject fo = getFileObject(file);
+                    if (fo == null) {
+                        return null;
+                    }
+                    RemoteFileObject[] children = fo.getImplementor().getChildren();
+                    String[] names = new String[children.length];
+                    for (int i = 0; i < children.length; i++) {
+                        names[i] = children[i].getNameExt();
+                    }
+                    return names;
+                }                
                 Future<FileInfoProvider.StatInfo[]> stat = FileInfoProvider.ls(env, file.getPath());
                 try {
                     FileInfoProvider.StatInfo[] statInfo = stat.get();
@@ -292,23 +405,33 @@ abstract public class FileOperationsProvider {
         }
         
         protected void refreshFor(FileProxyO ... files) {
-            List<RemoteFileObjectBase> roots = new ArrayList<RemoteFileObjectBase>();
+            List<RemoteFileObjectBase> roots = new ArrayList<>();
             for(FileProxyO f : files) {
                 RemoteFileObjectBase fo = findExistingParent(f.getPath());
-                if (fo != null) {
+                if (fo != null && fo.isValid()) {
                     roots.add(fo);
                 }
             }
-            for(RemoteFileObjectBase fo : roots) {
-                if (fo.isValid()) {
-                    fo.refresh(true);
+//            for(RemoteFileObjectBase fo : roots) {                
+//                fo.refresh(true);
+//            }
+            if (!roots.isEmpty()) {
+                RemoteFileSystem fs = roots.iterator().next().getFileSystem();
+                String[] paths = new String[roots.size()];
+                for (int i = 0; i < roots.size(); i++) {
+                    paths[i] = roots.get(i).getPath();
+                }
+                try {
+                    RemoteVcsSupportUtil.refreshFor(fs, paths);
+                } catch (IOException ex) {
+                    RemoteLogger.fine(ex);
                 }
             }
         }
         
         private RemoteFileObjectBase findExistingParent(String path) {
             while(true) {
-                RemoteFileObject fo = RemoteFileSystemManager.getInstance().getFileSystem(env).findResource(path);
+                RemoteFileObject fo = getFileSystem().findResource(path);
                 if (fo != null) {
                     return fo.getImplementor();
                 }
@@ -336,6 +459,7 @@ abstract public class FileOperationsProvider {
         }
 
         @Override
+        @SuppressWarnings("AccessingNonPublicFieldOfAnotherObject")
         public boolean equals(Object obj) {
             if (obj == null) {
                 return false;
@@ -379,7 +503,11 @@ abstract public class FileOperationsProvider {
         }
 
         @Override
-        public Process createProcess(String executable, String workingDirectory, List<String> arguments, List<String> paths, Map<String, String> environment, boolean redirectErrorStream) throws IOException {
+        public Process createProcess(String executable, String workingDirectory, List<String> arguments, List<String> paths, Map<String, String> environment, boolean redirectErrorStream) 
+                throws ConnectException, IOException {
+            if (!ConnectionManager.getInstance().isConnectedTo(env)) {
+                throw RemoteExceptions.createConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
+            }
             NativeProcessBuilder pb = NativeProcessBuilder.newProcessBuilder(env);
             pb.setExecutable(executable).setWorkingDirectory(workingDirectory).setArguments(arguments.toArray(new String[arguments.size()]));
             MacroMap mm = MacroMap.forExecEnv(env);
@@ -426,6 +554,7 @@ abstract public class FileOperationsProvider {
         }
 
         @Override
+        @SuppressWarnings("AccessingNonPublicFieldOfAnotherObject")
         public boolean equals(Object obj) {
             if (obj == null) {
                 return false;
