@@ -122,7 +122,7 @@ public final class RemoteFileObject extends FileObject implements Serializable {
 
     // <editor-fold desc="Moved from RemoteFileObjectFile.">
     
-    transient private ThreadLocal<AtomicInteger> magic = new ThreadLocal<AtomicInteger>() {
+    private final transient ThreadLocal<AtomicInteger> magic = new ThreadLocal<AtomicInteger>() {
 
         @Override
         protected AtomicInteger initialValue() {
@@ -375,7 +375,7 @@ public final class RemoteFileObject extends FileObject implements Serializable {
         FileStatistics.getInstance(fileSystem).logPath(getPath());
         if (!getImplementor().hasCache()) {
             if (isMimeResolving()) {
-                if (!MIME_SNIFFING) {
+                if (!MIME_SNIFFING || getSize() == 0) {
                     return new InputStream() {
                         @Override
                         public int read() throws IOException {
@@ -393,6 +393,16 @@ public final class RemoteFileObject extends FileObject implements Serializable {
         return getImplementor().getInputStream(true);
     }
 
+    public InputStream getInputStream(int maxSize) throws FileNotFoundException {
+        if (maxSize <= MagicCache.BUF_LENGTH) {
+            byte[] b = getImplementor().getMagic();
+            if (b != null) {
+                return new ByteArrayInputStream(b);
+            }
+        }
+        return getInputStream();
+    }
+
     @Override
     public RemoteFileObject getFileObject(String relativePath) {
         return getFileObject(relativePath, new HashSet<String>());
@@ -470,6 +480,28 @@ public final class RemoteFileObject extends FileObject implements Serializable {
     public void addFileChangeListener(FileChangeListener fcl) {
         getImplementor().addFileChangeListener(fcl);
     }
+    
+    @Override
+    public boolean isSymbolicLink() {
+        return getImplementor().isSymbolicLink();
+    }
+
+    @Override
+    public FileObject readSymbolicLink() {
+        RemoteFileObjectBase target = getImplementor().readSymbolicLink();
+        return (target == null) ? null : target.getOwnerFileObject();
+    }
+
+    @Override
+    public String readSymbolicLinkPath() {
+        return getImplementor().readSymbolicLinkPath();
+    }
+
+    @Override
+    public FileObject getCanonicalFileObject() throws IOException {
+        return RemoteFileSystemUtils.getCanonicalFileObject(this);
+    }
+    
     // </editor-fold>
     
    /* Java serialization*/ Object writeReplace() throws ObjectStreamException {
