@@ -41,6 +41,7 @@
  */
 package org.netbeans.modules.remote.impl.fs;
 
+import java.awt.GraphicsEnvironment;
 import java.awt.Image;
 import java.awt.event.WindowEvent;
 import java.awt.event.WindowFocusListener;
@@ -48,6 +49,7 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InterruptedIOException;
@@ -56,6 +58,7 @@ import java.io.ObjectOutputStream;
 import java.lang.ref.WeakReference;
 import java.net.ConnectException;
 import java.util.*;
+import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -63,13 +66,16 @@ import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import java.util.logging.Level;
 import javax.swing.SwingUtilities;
+import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.modules.dlight.libs.common.PathUtilities;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.util.CommonTasksSupport;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionListener;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager.CancellationException;
+import org.netbeans.modules.nativeexecution.api.util.FileInfoProvider;
 import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
+import org.netbeans.modules.remote.actions.FastPasteAction;
 import org.netbeans.modules.remote.api.ui.ConnectionNotifier;
 import org.netbeans.modules.remote.impl.RemoteLogger;
 import org.netbeans.modules.remote.impl.fileoperations.spi.AnnotationProvider;
@@ -79,8 +85,15 @@ import org.netbeans.modules.remote.impl.fileoperations.spi.FilesystemInterceptor
 import org.netbeans.modules.remote.spi.FileSystemCacheProvider;
 import org.netbeans.modules.remote.spi.FileSystemProvider;
 import org.netbeans.modules.remote.spi.FileSystemProvider.FileSystemProblemListener;
+import org.netbeans.modules.remote.spi.RemoteFileSystemHintsProvider;
 import org.openide.actions.FileSystemRefreshAction;
 import org.openide.filesystems.*;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileStatusEvent;
+import org.openide.filesystems.FileStatusListener;
+import org.openide.filesystems.FileSystem;
+import org.openide.filesystems.ImageDecorator;
+import org.openide.filesystems.StatusDecorator;
 import org.openide.util.*;
 import org.openide.util.actions.SystemAction;
 import org.openide.util.io.NbObjectInputStream;
@@ -96,7 +109,6 @@ import org.openide.windows.WindowManager;
 @org.netbeans.api.annotations.common.SuppressWarnings("Se") // is it ever serialized?
 public final class RemoteFileSystem extends FileSystem implements ConnectionListener {
 
-    private static final SystemAction[] NO_SYSTEM_ACTIONS = new SystemAction[]{};
     private static final boolean ATTR_STATS = Boolean.getBoolean("remote.attr.stats");
 
     public static final String ATTRIBUTES_FILE_NAME = ".rfs_attr"; // NOI18N
@@ -121,15 +133,30 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     /** Directory synchronization statistics */
     private final AtomicInteger dirSyncCount = new AtomicInteger(0);
     private static final Object mainLock = new Object();
-    private static final Map<File, WeakReference<ReadWriteLock>> locks = new HashMap<File, WeakReference<ReadWriteLock>>();
+    private static final Map<File, WeakReference<ReadWriteLock>> locks = new HashMap<>();
     private final AtomicBoolean readOnlyConnectNotification = new AtomicBoolean(false);
+    private static final List<FileSystemProblemListener> globalProblemListeners = new CopyOnWriteArrayList<>();
     private final List<FileSystemProblemListener> problemListeners =
-            new ArrayList<FileSystemProblemListener>();
+            new ArrayList<>(globalProblemListeners);
     transient private final StatusImpl status = new StatusImpl();
-    private final LinkedHashSet<String> deleteOnExitFiles = new LinkedHashSet<String>();
-    private final ThreadLocal<RemoteFileObjectBase> beingRemoved = new ThreadLocal<RemoteFileObjectBase>();
-    private final ThreadLocal<RemoteFileObjectBase> externallyRemoved = new ThreadLocal<RemoteFileObjectBase>();
+    private final LinkedHashSet<String> deleteOnExitFiles = new LinkedHashSet<>();
+    private final ThreadLocal<RemoteFileObjectBase> beingRemoved = new ThreadLocal<>();
+    private final ThreadLocal<RemoteFileObjectBase> beingCreated = new ThreadLocal<>();
+    private final ThreadLocal<RemoteFileObjectBase> externallyRemoved = new ThreadLocal<>();
     private final RemoteFileZipper remoteFileZipper;
+    private final ThreadLocal<Integer> isInsideVCS = new ThreadLocal<>();
+
+    private final RequestProcessor.Task connectionTask;
+
+    /** 
+     * ConnectionTaskLock is now scheduled not only upon connection change, but from ctor as well
+     * (in order to get auto mounts). 
+     * The connectionChanged distinguishes these two cases
+     */
+    private volatile boolean connectionChanged;
+
+    /** @guarded by self */
+    private final List<String> autoMounts;
 
     /*package*/ RemoteFileSystem(ExecutionEnvironment execEnv) throws IOException {
         RemoteLogger.assertTrue(execEnv.isRemote());
@@ -145,7 +172,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
         cache = new File(filePrefix);
         if (!cache.exists() && !cache.mkdirs()) {
-            throw new IOException(NbBundle.getMessage(getClass(), "ERR_CreateDir", cache.getAbsolutePath()));
+            throw new IOException(NbBundle.getMessage(getClass(), "ERR_CreateDir", cache.getAbsolutePath())); // new IOException sic! (ctor)
         }
         this.rootDelegate = new RootFileObject(this.root = new RemoteFileObject(this), this, execEnv, cache); // NOI18N
         factory.register(rootDelegate);
@@ -169,21 +196,87 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
 
             @Override
             public void run() {
-                //WindowManager.getDefault().getMainWindow().addWindowFocusListener(focusListener);
-                WindowManager.getDefault().getMainWindow().addWindowFocusListener(windowFocusListener);
+                if (!GraphicsEnvironment.isHeadless()) {
+                    //WindowManager.getDefault().getMainWindow().addWindowFocusListener(focusListener);
+                    WindowManager.getDefault().getMainWindow().addWindowFocusListener(windowFocusListener);
+                }
             }
         });
+        connectionTask = new RequestProcessor("Connection and R/W change", 1).create(new ConnectionChangeRunnable()); //NOI18N;
+        connectionChanged = false; // volatile
+        connectionTask.schedule(0);
         ConnectionManager.getInstance().addConnectionListener(RemoteFileSystem.this);
         remoteFileZipper = new RemoteFileZipper(execEnv);
+        autoMounts = getFixedAutoMounts();
+    }
+
+    private List<String> getFixedAutoMounts() {
+        List<String> list = new ArrayList<>(Arrays.asList("/net", "/set", "/import", "/shared", "/home", "/ade_autofs", "/ade", "/workspace")); //NOI18N
+        String t = System.getProperty("remote.autofs.list"); //NOI18N
+        if (t != null) {
+            String[] paths = t.split(","); //NOI18N
+            for (String p : paths) {
+                if (p.startsWith("/")) { //NOI18N
+                    list.add(p);
+                }
+            }
+        }
+        return list;
+    }
+
+    public boolean isAutoMount(String path) {
+        synchronized (autoMounts) {
+            return autoMounts.contains(path);
+        }
+    }
+
+    public boolean isDirectAutoMountChild(String path) {
+        String parent = PathUtilities.getDirName(path);
+        if (parent != null && ! parent.isEmpty()) {
+            return isAutoMount(parent);
+        }
+        return false;
+    }
+
+    public static boolean isSniffing(String childName) {
+        if (childName != null) {
+            for (RemoteFileSystemHintsProvider hp : Lookup.getDefault().lookupAll(RemoteFileSystemHintsProvider.class)) {
+                if (hp.isSniffing(childName)) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
+    public boolean isInsideVCS() {
+        Integer currValue = isInsideVCS.get();        
+        int level = ((currValue == null) ? 0 : currValue.intValue());
+        return level > 0;
+    }
+
+    public void setInsideVCS(boolean value) {
+        Integer currValue = isInsideVCS.get();
+        int newValue = ((currValue == null) ? 0 : currValue.intValue()) + (value ? +1 : -1);
+        isInsideVCS.set(newValue);
     }
 
     void warmup(Collection<String> paths, FileSystemProvider.WarmupMode mode, Collection<String> extensions) {
+        if (!ConnectionManager.getInstance().isConnectedTo(execEnv)) {
+            RemoteLogger.fine("Warmup: no connection to host {0}", execEnv); //NOI18N
+            return;
+        }
         for (String path : paths) {
             // we still do this via RemoteFileObject (and eventually via RemoteDirectory)
             // since we need its own cahche files to be created first
             RemoteFileObject fo = findResource(path);
             if (fo == null) {
-                RemoteLogger.info("Warmup: can't find file object {0} at {1}", path, execEnv); //NOI18N
+                if (!ConnectionManager.getInstance().isConnectedTo(execEnv)) {
+                    RemoteLogger.info("Warmup: no connection to host while warmiong up {0} at {1}", path, execEnv); //NOI18N
+                    break;
+                } else {
+                    RemoteLogger.info("Warmup: can't find file object {0} at {1}", path, execEnv); //NOI18N
+                }
             } else {
                 fo.getImplementor().warmup(mode, extensions);
             }                        
@@ -198,36 +291,77 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         ConnectionManager.getInstance().removeConnectionListener(this);
     }
 
+    private class ConnectionChangeRunnable implements Runnable {
+
+        public ConnectionChangeRunnable() {
+        }
+
+        @Override
+        public void run() {
+            if (connectionChanged) {
+                if (ConnectionManager.getInstance().isConnectedTo(execEnv)) {
+                    refreshManager.scheduleRefreshOnConnect();
+                }
+                for (RemoteFileObjectBase fo : factory.getCachedFileObjects()) {
+                    fo.connectionChanged();
+                }
+            }
+            if (ConnectionManager.getInstance().isConnectedTo(execEnv)) {
+                maintainAutoMounts();
+            }
+        }
+
+        private void maintainAutoMounts() {
+            long time = System.currentTimeMillis();
+            RemoteLogger.fine("Getting automount list for {0}...", execEnv); //NOI18N
+            AutoMountsProvider amp = new AutoMountsProvider(execEnv);
+            if (amp.analyze()) {
+                List<String> newAutoMounts = amp.getAutoMounts();
+                synchronized (autoMounts) {
+                    autoMounts.clear();
+                    autoMounts.addAll(newAutoMounts);
+                }
+                if (RemoteLogger.isLoggable(Level.FINE)) {
+                    RemoteLogger.fine("Getting automount list for {0} took {1} ms", //NOI18N
+                            execEnv, System.currentTimeMillis() - time);
+                    for (String path : newAutoMounts) {
+                        RemoteLogger.fine("\t{0}", path);
+                    }
+                }
+            }
+        }
+    }
+
     @Override
     public void connected(ExecutionEnvironment env) {
-        readOnlyConnectNotification.compareAndSet(true, false);
         if (execEnv.equals(env)) {
-            Collection<RemoteFileObjectBase> cachedFileObjects = factory.getCachedFileObjects();            
-            refreshManager.scheduleRefreshOnConnect();
-            for (RemoteFileObjectBase fo : cachedFileObjects) {
-                fo.connectionChanged();
-            }
+            readOnlyConnectNotification.compareAndSet(true, false);
+            connectionChanged = true; // volatile
+            connectionTask.schedule(0);
         }
     }
 
     @Override
     public void disconnected(ExecutionEnvironment env) {
-        readOnlyConnectNotification.compareAndSet(true, false);
         if (execEnv.equals(env)) {
-            for (RemoteFileObjectBase fo : factory.getCachedFileObjects()) {
-                fo.connectionChanged();
-            }
+            readOnlyConnectNotification.compareAndSet(true, false);
+            connectionChanged = true; // volatile
+            connectionTask.schedule(0);
         }
         if (ATTR_STATS) { dumpAttrStat(); }
     }
     
-    /*package*/ ExecutionEnvironment getExecutionEnvironment() {
+    public ExecutionEnvironment getExecutionEnvironment() {
         return execEnv;
     }
 
     public RemoteFileObjectFactory getFactory() {
         return factory;
     }
+    
+    public int getCachedFileObjectsCount() {
+        return factory.getCachedFileObjectsCount();
+    }
 
     public RefreshManager getRefreshManager() {
         return refreshManager;
@@ -252,7 +386,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             ReadWriteLock result = (ref == null) ? null : ref.get();
             if (result == null) {
                 result = new ReentrantReadWriteLock();
-                locks.put(file, new WeakReference<ReadWriteLock>(result));
+                locks.put(file, new WeakReference<>(result));
             }
             return result;
         }
@@ -322,11 +456,14 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             }
             if (tmpDir != null && tmpDir.isFolder() && tmpDir.isValid()) {
                 return tmpDir;
+            } else {
+                throw RemoteExceptions.createIOException(
+                        NbBundle.getMessage(RemoteFileSystem.class, "EXC_CantFindTemp")); //NOI18N
             }
         } catch (CancellationException ex) {
-            //
+            throw RemoteExceptions.createIOException(
+                    NbBundle.getMessage(RemoteFileSystem.class, "EXC_CantFindTemp", ex)); //NOI18N
         }
-        throw new IOException("Cannot find temporary folder"); // NOI18N
     }
     
     @Override
@@ -354,10 +491,11 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
                 }
             }
         }
-        throw new IOException("Cannot create temporary file"); // NOI18N
+        throw RemoteExceptions.createIOException(
+                NbBundle.getMessage(RemoteFileSystem.class, "EXC_CantCantCreateTemp")); // NOI18N
     }
     
-    public RemoteFileObjectBase findResourceImpl(String name, Set<String> antiloop) {
+    public RemoteFileObjectBase findResourceImpl(String name, @NonNull Set<String> antiloop) {
         if (name.isEmpty() || name.equals("/")) {  // NOI18N
             return getRoot().getImplementor();
         } else {
@@ -367,11 +505,6 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     }
     
 
-    @Override
-    public SystemAction[] getActions() {
-        return NO_SYSTEM_ACTIONS;
-    }
-
     public void addPendingFile(RemoteFileObjectBase fo) {
         remoteFileSupport.addPendingFile(fo);
         fireProblemListeners(fo.getPath());
@@ -405,7 +538,30 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             fileOtputStream = new FileOutputStream(attr);
             table.store(fileOtputStream, "Set attribute "+attrName); // NOI18N
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            // See issues #254952, #249548: FileNotFoundException: .rfs_attr
+            // It can happen that parent  was removed; 
+            // if that's the case, then don't report this via Exceptions.printStackTrace
+            // If it's not, we'd better report since I think this should never happen
+            boolean report = true;
+            StringBuilder sb = new StringBuilder();
+            sb.append("Can not set attribute for ").append(file) // NOI18N
+                    .append("; attr. cache is ").append(attr.getAbsolutePath()); // NOI18N
+            if (ex instanceof FileNotFoundException) {
+                File attrParentFile = attr.getParentFile();
+                if (attrParentFile != null) {
+                    boolean parentExists = attrParentFile.exists();
+                    sb.append("; attr. cache parent exists ? ").append(parentExists); // NOI18N
+                    if (!parentExists) {
+                        report = false;
+                    }
+                }
+            }
+            IOException ioEx = new IOException(sb.toString(), ex);
+            if (report) {
+                Exceptions.printStackTrace(ioEx);
+            } else {
+                ioEx.printStackTrace(System.err);
+            }
         } finally {
             if (fileOtputStream != null) {
                 try {
@@ -435,7 +591,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
     }
 
-    private static final Map<String, AttrStat> attrStats = new TreeMap<String, AttrStat> ();
+    private static final Map<String, AttrStat> attrStats = new TreeMap<> ();
 
     private static void logAttrName(String name, boolean write) {
         synchronized(attrStats) {
@@ -460,7 +616,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     /*package*/ void dumpAttrStat() {
         Map<String, AttrStat> toDump;
         synchronized(attrStats) {
-            toDump= new TreeMap<String, AttrStat>(attrStats);
+            toDump= new TreeMap<>(attrStats);
         }
         System.out.printf("\n\nDumping attributes statistics (%d elements)\n\n", toDump.size()); // NOI18N
         for (Map.Entry<String, AttrStat> entry : toDump.entrySet()) {
@@ -495,6 +651,8 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
         if (attrName.equals(FileObject.DEFAULT_LINE_SEPARATOR_ATTR)) {
             return "\n"; // NOI18N
+        } else if (attrName.equals(FileObject.DEFAULT_PATHNAME_SEPARATOR_ATTR)) {
+            return "/"; // NOI18N
         } else if (attrName.equals(READONLY_ATTRIBUTES)) {
             return Boolean.FALSE;
         } else if (attrName.equals("isRemoteAndSlow")) { // NOI18N
@@ -510,7 +668,12 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             if (RemoteFileObjectBase.USE_VCS) {
                 FilesystemInterceptor interceptor = FilesystemInterceptorProvider.getDefault().getFilesystemInterceptor(this);
                 if (interceptor != null) {
-                    return interceptor.getAttribute(FilesystemInterceptorProvider.toFileProxy(file.getOwnerFileObject()), attrName);
+                    try {
+                        setInsideVCS(true);
+                        return interceptor.getAttribute(FilesystemInterceptorProvider.toFileProxy(file.getOwnerFileObject()), attrName);
+                    } finally {
+                        setInsideVCS(false);
+                    }
                 }
             }
         }
@@ -525,7 +688,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         if (parent != null) {
             File attr = getAttrFile(parent);
             Properties table = readProperties(attr);
-            List<String> res = new ArrayList<String>();
+            List<String> res = new ArrayList<>();
             Enumeration<Object> keys = table.keys();
             String prefix = file.getNameExt()+"["; // NOI18N
             while(keys.hasMoreElements()) {
@@ -645,6 +808,13 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
     }
 
+    public static void addGlobalFileSystemProblemListener(FileSystemProblemListener listener) {
+        globalProblemListeners.add(listener);
+        for (RemoteFileSystem fs : RemoteFileSystemManager.getInstance().getAllFileSystems()) {
+            fs.addFileSystemProblemListener(listener);
+        }
+    }
+    
     public void addFileSystemProblemListener(FileSystemProblemListener listener) {
         synchronized (problemListeners) {
             problemListeners.add(listener);
@@ -663,7 +833,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     private void fireProblemListeners(String path) {
         List<FileSystemProblemListener> listenersCopy;
         synchronized (problemListeners) {
-            listenersCopy = new ArrayList<FileSystemProblemListener>(problemListeners);
+            listenersCopy = new ArrayList<>(problemListeners);
         }
         for (FileSystemProblemListener l : listenersCopy) {
             if (path == null) {
@@ -674,15 +844,16 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
     }
 
-    @Override
+//    @Override -- overrides at runtime
     public final SystemAction[] getActions(final Set<FileObject> foSet) {
         SystemAction[] result = status.getActions (foSet);
         SystemAction refreshAction = isManualRefresh() ? null :  FileSystemRefreshAction.get(FileSystemRefreshAction.class);                 
         if (result == null) {
-            return (refreshAction == null) ? result : append(result, refreshAction);
+            result = (refreshAction == null) ? new SystemAction[] {} : new SystemAction[] { refreshAction };
         } else {
-            return (refreshAction == null) ? new SystemAction[] {} : new SystemAction[] { refreshAction };
-        }        
+            result = (refreshAction == null) ? result : append(result, refreshAction);
+        }
+        return append(result, FastPasteAction.get(FastPasteAction.class));
     }
 
     private static boolean isManualRefresh() {
@@ -697,7 +868,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     }
 
     @Override
-    public Status getStatus() {
+    public StatusDecorator getDecorator() {
         return status;
     }
     
@@ -720,7 +891,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
     private void releaseResources() {
     	ArrayList<String> toBeDeleted;
         synchronized(deleteOnExitFiles) {
-        	toBeDeleted = new ArrayList<String>(deleteOnExitFiles);
+        	toBeDeleted = new ArrayList<>(deleteOnExitFiles);
         }
     	Collections.reverse(toBeDeleted);
         for (String filename : toBeDeleted) {
@@ -735,6 +906,15 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         beingRemoved.set(fo);
     }
 
+    /*package*/ void setBeingCreated(RemoteFileObjectBase fo) {
+        beingCreated.set(fo);
+    }
+    
+    /** Be very CAUCIOUS when using this FO - it can be in process of VCS operations  */
+    public RemoteFileObjectBase getBeingCreated() {
+        return beingCreated.get();
+    }
+
     /*package*/ void setExternallyRemoved(RemoteFileObjectBase fo) {
         externallyRemoved.set(fo);
     }
@@ -750,6 +930,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         return fo;
     }
     
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // Three state
     public Boolean vcsSafeIsDirectory(String path) {
         path = PathUtilities.normalizeUnixPath(path);
         RemoteFileObjectBase removed = externallyRemoved.get();
@@ -789,6 +970,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
     }
 
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // Three state
     public Boolean vcsSafeIsFile(String path) {
         path = PathUtilities.normalizeUnixPath(path);
         RemoteFileObjectBase removed = externallyRemoved.get();
@@ -813,6 +995,41 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }            
     }
 
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // Three state
+    public Boolean vcsSafeIsSymbolicLink(String path) {
+        path = PathUtilities.normalizeUnixPath(path);
+        RemoteFileObjectBase removed = externallyRemoved.get();
+        if (removed != null && removed.getPath().equals(path)) {
+            // for an object that is just detected as externally removed
+            // it doesn't make sense to ask remote host whether it is directory
+            return removed.getType() == FileInfoProvider.StatInfo.FileType.SymbolicLink;
+        }
+        RemoteFileObjectBase fo = vcsSafeGetFileObject(path);
+        if (fo == null) {
+            return null;
+        } else {
+            return fo.getType() == FileInfoProvider.StatInfo.FileType.SymbolicLink;
+        }            
+    }
+
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // Three state
+    public Boolean vcsSafeCanonicalPathDiffers(String path) {
+        path = PathUtilities.normalizeUnixPath(path);
+        RemoteFileObjectBase removed = externallyRemoved.get();
+        if (removed != null && removed.getPath().equals(path)) {
+            // for an object that is just detected as externally removed
+            // it doesn't make sense to ask remote host whether it is directory
+            return removed instanceof RemoteLinkBase;
+        }
+        RemoteFileObjectBase fo = vcsSafeGetFileObject(path);
+        if (fo == null) {
+            return null;
+        } else {
+            return fo instanceof RemoteLinkBase;
+        }            
+    }
+
+    @org.netbeans.api.annotations.common.SuppressWarnings("NP") // Three state
     public Boolean vcsSafeExists(String path) {
         path = PathUtilities.normalizeUnixPath(path);
         RemoteFileObjectBase fo = vcsSafeGetFileObject(path);
@@ -855,7 +1072,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         }
     }
 
-    private final class StatusImpl implements FileSystem.HtmlStatus, LookupListener, FileStatusListener {
+    private final class StatusImpl implements StatusDecorator, ImageDecorator, LookupListener, FileStatusListener {
 
         /** result with providers */
         private final Lookup.Result<AnnotationProvider> annotationProviders;
@@ -873,9 +1090,9 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             Collection<? extends AnnotationProvider> add;
 
             if (previousProviders != null) {
-                add = new HashSet<AnnotationProvider>(now);
+                add = new HashSet<>(now);
                 add.removeAll(previousProviders);
-                HashSet<AnnotationProvider> toRemove = new HashSet<AnnotationProvider>(previousProviders);
+                HashSet<AnnotationProvider> toRemove = new HashSet<>(previousProviders);
                 toRemove.removeAll(now);
                 for (AnnotationProvider ap : toRemove) {
                     ap.removeFileStatusListener(this);
@@ -979,7 +1196,12 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
         public Object getAttribute(String attrName) {
             if (FileOperationsProvider.ATTRIBUTE.equals(attrName)) {
                 if (USE_VCS) {
-                    return FileOperationsProvider.getDefault().getFileOperations(getFileSystem());
+                    try {
+                        //getFileSystem().setInsideVCS(true);
+                        return FileOperationsProvider.getDefault().getFileOperations(getFileSystem());
+                    } finally {
+                        //getFileSystem().setInsideVCS(false);
+                    }
                 }
             }
             return super.getAttribute(attrName);
@@ -999,9 +1221,7 @@ public final class RemoteFileSystem extends FileSystem implements ConnectionList
             } catch (ConnectException ex) {
                 RemoteLogger.getInstance().log(Level.INFO, NbBundle.getMessage(getClass(), "RemoteFileSystemNotifier.ERROR", execEnv), ex);
                 ConnectionNotifier.addTask(execEnv, this);
-            } catch (InterruptedException ex) {
-                RemoteLogger.finest(ex);
-            } catch (InterruptedIOException ex) {
+            } catch (InterruptedException | InterruptedIOException ex) {
                 RemoteLogger.finest(ex);
             } catch (IOException ex) {
                 RemoteLogger.getInstance().log(Level.INFO, NbBundle.getMessage(getClass(), "RemoteFileSystemNotifier.ERROR", execEnv), ex);
