@@ -49,6 +49,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.io.StringWriter;
 import java.net.ConnectException;
 import java.util.Set;
 import java.util.StringTokenizer;
@@ -59,11 +60,10 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Condition;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.logging.Level;
-import org.netbeans.modules.dlight.libs.common.DLightLibsCommonLogger;
+import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.modules.dlight.libs.common.PathUtilities;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.util.CommonTasksSupport;
-import org.netbeans.modules.nativeexecution.api.util.CommonTasksSupport.UploadStatus;
 import org.netbeans.modules.nativeexecution.api.util.ConnectionManager;
 import org.netbeans.modules.nativeexecution.api.util.FileInfoProvider.StatInfo.FileType;
 import org.netbeans.modules.remote.impl.RemoteLogger;
@@ -71,8 +71,7 @@ import org.netbeans.modules.remote.impl.fileoperations.spi.FilesystemInterceptor
 import org.openide.filesystems.FileAlreadyLockedException;
 import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileLock;
-import org.openide.filesystems.FileObject;
-import org.openide.util.Exceptions;
+import org.openide.util.NbBundle;
 
 /**
  *
@@ -84,7 +83,7 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
     
     private final char fileTypeChar;
 //    private SoftReference<CachedRemoteInputStream> fileContentCache = new SoftReference<CachedRemoteInputStream>(null);
-    private SimpleRWLock rwl = new SimpleRWLock();
+    private final SimpleRWLock rwl = new SimpleRWLock();
     
     /*package*/ RemotePlainFile(RemoteFileObject wrapper, RemoteFileSystem fileSystem, ExecutionEnvironment execEnv, 
             RemoteDirectory parent, String remotePath, File cache, FileType fileType) {
@@ -108,16 +107,19 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
     }
 
     @Override
-    public final RemoteFileObject getFileObject(String name, String ext, Set<String> antiLoop) {
+    public final RemoteFileObject getFileObject(String name, String ext, @NonNull Set<String> antiLoop) {
         return null;
     }
 
     @Override
-    public RemoteFileObject getFileObject(String relativePath, Set<String> antiLoop) {
+    public RemoteFileObject getFileObject(String relativePath, @NonNull Set<String> antiLoop) {
         // taken from FileObject.getFileObject(String relativePath)
         if (relativePath.startsWith("/")) { //NOI18N
             relativePath = relativePath.substring(1);
         }
+        if (!relativePath.equals(".") && !relativePath.contains("..") && !relativePath.contains("/")) { // NOI18N
+            return null;
+        }
         RemoteFileObject res = this.getOwnerFileObject();
         StringTokenizer st = new StringTokenizer(relativePath, "/"); //NOI18N
         while ((res != null) && st.hasMoreTokens()) {
@@ -225,9 +227,11 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
 
         private final InputStream is;
         private boolean closed;
+        private final Runnable postClose;
 
-        public InputStreamWrapper(InputStream is) {
+        public InputStreamWrapper(InputStream is, Runnable postClose) {
             this.is = is;
+            this.postClose = postClose;
         }
 
         @Override
@@ -249,7 +253,7 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
                 is.close();
                 closed = true;
             } finally {
-                rwl.readUnlock();
+                postClose.run();
             }
         }
 
@@ -328,49 +332,69 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
             if (RemoteLogger.getInstance().isLoggable(Level.FINEST) &&
                     ConnectionManager.getInstance().isConnectedTo(getExecutionEnvironment()) &&
                     !getCache().exists() &&  getOwnerFileObject().isMimeResolving()) {
-                DLightLibsCommonLogger.assertFalse(true, "Shouldn't come here in MIME resolved mode"); //NOI18N
+                new Exception("Shouldn't come here in MIME resolved mode " + this).printStackTrace(System.err); //NOI18N
             }
 
-            RemoteFileSystemUtils.getCanonicalParent(this).ensureChildSync(this);
-
             if (!checkLock) {
-                return new FileInputStream(getCache());
+                // we can NOT call ensureChildSync without a lock - this leads to #248449
+                // and can eventually cause user data loss
+                File cache = getCache();
+                if (cache.exists()) {
+                    return new FileInputStream(cache);
+                } else {
+                    // Should we just return an empty stream?
+                    final File tmpCache = File.createTempFile(getName().length() < 3 ? getName() + "___" : getName(), getExt()); //NOI18N
+                    StringWriter errorWriter = new StringWriter();
+                    Future<Integer> task = CommonTasksSupport.downloadFile(getPath(), getExecutionEnvironment(), tmpCache.getAbsolutePath(), errorWriter);
+                    int rc = task.get().intValue();
+                    if (rc != 0) {
+                        throw RemoteExceptions.createIOException(NbBundle.getMessage(RemoteDirectory.class,
+                                "EXC_CanNotDownload", getDisplayName(tmpCache.getAbsolutePath()), errorWriter.toString())); //NOI18N
+                    }
+                    return new InputStreamWrapper(new FileInputStream(tmpCache), new Runnable() {
+                        @Override
+                        public void run() {
+                            tmpCache.delete();
+                        }
+                    });
+                }
             } else if (rwl.tryReadLock()) {
-                return new InputStreamWrapper(new FileInputStream(getCache()));
+                RemoteFileSystemUtils.getCanonicalParent(this).ensureChildSync(this);
+                return new InputStreamWrapper(new FileInputStream(getCache()), new Runnable() {
+                    @Override
+                    public void run() {
+                        rwl.readUnlock();
+                    }
+                });
             } else {
                 throw new FileAlreadyLockedException("Cannot read from locked file: " + this);  //NOI18N
             }
 
             //getParent().ensureChildSync(this);
-        } catch (ConnectException ex) {
+        } catch (ConnectException | CancellationException ex) {
+            // TODO: do we need this with CancelletionException? 
+            // unfortunately CancellationException is RuntimeException, so I'm not sure
             return new ByteArrayInputStream(new byte[]{});
-        } catch (IOException ex) {
+        } catch (IOException | InterruptedException | ExecutionException ex) {
             throw newFileNotFoundException(ex);
-        } catch (InterruptedException ex) {
-            throw newFileNotFoundException(ex);
-        } catch (ExecutionException ex) {
-            throw newFileNotFoundException(ex);
-        } catch (CancellationException ex) {
-            // TODO: do we need this? unfortunately CancellationException is RuntimeException, so I'm not sure
-            return new ByteArrayInputStream(new byte[]{});
         }
     }
 
     private FileNotFoundException newFileNotFoundException(Exception cause) {
-        FileNotFoundException ex = new FileNotFoundException(cause.getLocalizedMessage()); //NOI18N
-        ex.initCause(cause);
-        Exceptions.attachLocalizedMessage(ex, cause.getLocalizedMessage());
-        return ex;
+        return RemoteExceptions.createFileNotFoundException(NbBundle.getMessage(RemotePlainFile.class, 
+                "EXC_DoesNotExistXX", cause.getLocalizedMessage()), cause); //NOI18N
     }
 
     @Override
     public RemoteFileObject createDataImpl(String name, String ext, RemoteFileObjectBase orig) throws IOException {
-        throw new IOException("Plain file can not have children"); // NOI18N
+        throw RemoteExceptions.createIOException(NbBundle.getMessage(RemotePlainFile.class, 
+                "EXC_PlainFileChildren", getDisplayName())); // NOI18N
     }
 
     @Override
     public RemoteFileObject createFolderImpl(String name, RemoteFileObjectBase orig) throws IOException {
-        throw new IOException("Plain file can not have children"); // NOI18N
+        throw RemoteExceptions.createIOException(NbBundle.getMessage(RemotePlainFile.class, 
+                "EXC_PlainFileChildren", getDisplayName())); // NOI18N
     }
 
     @Override
@@ -380,17 +404,21 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
             interceptor = FilesystemInterceptorProvider.getDefault().getFilesystemInterceptor(getFileSystem());
             if (interceptor != null) {
                 if (!canWriteImpl(orig)) {
-                    throw new IOException("Cannot lock " + this); // NOI18N
+                    throw RemoteExceptions.createIOException(NbBundle.getMessage(RemotePlainFile.class, 
+                            "EXC_CannotLockReadOnlyFile", this.getDisplayName())); // NOI18N
                 }
             }
         }
         FileLock lock = super.lockImpl(orig);
         if (interceptor != null) {
+            getFileSystem().setInsideVCS(true);
             try {
                 interceptor.fileLocked(FilesystemInterceptorProvider.toFileProxy(orig.getOwnerFileObject()));
             } catch (IOException ex){
                 lock.releaseLock();
                 throw ex;
+            } finally {
+                getFileSystem().setInsideVCS(false);
             }
         }
         return lock;
@@ -417,29 +445,80 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
     protected OutputStream getOutputStreamImpl(FileLock lock, RemoteFileObjectBase orig) throws IOException {
         try {
             if (!isValid()) {
-                throw new FileNotFoundException("FileObject " + this + " is not valid."); //NOI18N
+                throw RemoteExceptions.createFileNotFoundException(NbBundle.getMessage(RemotePlainFile.class, 
+                        "EXC_InvalidFO", getDisplayName())); //NOI18N
             }
             FilesystemInterceptorProvider.FilesystemInterceptor interceptor = null;
             if (USE_VCS) {
                 interceptor = FilesystemInterceptorProvider.getDefault().getFilesystemInterceptor(getFileSystem());
             }
             if (rwl.tryWriteLock()) {
-                return new DelegateOutputStream(interceptor, orig, this);
+                // setInsideVCS() is inside
+                return new DelegateOutputStream(interceptor, orig);
             } else {
                 throw new FileAlreadyLockedException("Cannot write to locked file: " + this);  //NOI18N
             }
         } catch (InterruptedException ex) {
-            throw new IOException(ex);
-    }
+            throw RemoteExceptions.createInterruptedIOException(ex.getLocalizedMessage(), ex); // NOI18N
+        }
     }
 
     @Override
-    protected void refreshImpl(boolean recursive, Set<String> antiLoop, 
-    boolean expected, RefreshMode refreshMode)
+    public void refreshImpl(boolean recursive, Set<String> antiLoop, 
+            boolean expected, RefreshMode refreshMode)
             throws ConnectException, IOException, InterruptedException, CancellationException, ExecutionException {
         if (refreshMode != RefreshMode.FROM_PARENT && Boolean.valueOf(System.getProperty("cnd.remote.refresh.plain.file", "true"))) { //NOI18N
             long time = System.currentTimeMillis();
-            getParent().refreshImpl(false, antiLoop, expected, refreshMode);
+            final DirEntry oldEntry = getParent().getDirEntry(getNameExt());
+            boolean refreshParent = false;
+            boolean updateStat = false;
+            boolean fireChangedRO = false;
+            boolean removeCache = false;
+            DirEntry newEntry = null;
+            try {
+                newEntry = RemoteFileSystemTransport.lstat(getExecutionEnvironment(), getPath());
+            } catch (ExecutionException ex) {
+                if (!RemoteFileSystemUtils.isFileNotFoundException(ex)) {
+                    throw ex;
+                }
+            }
+            if (newEntry == null || oldEntry == null || !oldEntry.isValid()) {
+                refreshParent = true;
+            } else {
+                // oldEntry != null && oldEntry.isValid
+                assert newEntry.getName().equals(oldEntry.getName());
+                if (oldEntry.isSameType(newEntry)) {
+                   if (!newEntry.isSameLastModified(oldEntry)) {
+                       updateStat = true;
+                       removeCache = true;
+                   } else if (newEntry.getSize() != oldEntry.getSize()) {
+                       updateStat = true;
+                       removeCache = true;
+                   } else if (newEntry.getDevice() != oldEntry.getDevice()) {
+                       updateStat = true;
+                       removeCache = true;
+                   } else if (newEntry.getINode()!= oldEntry.getINode()) {
+                       updateStat = true;
+                       removeCache = true;
+                   } 
+                   if (!newEntry.isSameAccess(oldEntry)) {
+                       updateStat = true;
+                       // removeCache stays as it was: 
+                       // of only r/o-r/w chanegd, no need to remove cache
+                       fireChangedRO = true;
+                   }
+                } else {
+                    refreshParent = true;
+                }
+            }
+            if (refreshParent) {
+                getParent().refreshImpl(false, antiLoop, expected, refreshMode);            
+            } else if (updateStat) {
+                if (removeCache) {
+                    getCache().delete();
+                }
+                updateStatAndSendEvents(newEntry, fireChangedRO);
+            }
             RemoteLogger.getInstance().log(Level.FINE, "Refreshing {0} took {1} ms", new Object[] { getPath(), System.currentTimeMillis() - time });
         }
     }
@@ -449,18 +528,35 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
         return FileType.fromChar(fileTypeChar);
     }
 
-    private static class DelegateOutputStream extends OutputStream {
+    private void updateStatAndSendEvents(DirEntry dirEntry, boolean fireChangedRO) {
+        getParent().updateStat(this, dirEntry);
+        FileEvent ev = new FileEvent(getOwnerFileObject(), getOwnerFileObject(), false, dirEntry.getLastModified().getTime());
+        getOwnerFileObject().fireFileChangedEvent(getListeners(), ev);
+        RemoteDirectory parent = getParent();
+        if (parent != null) {
+            ev = new FileEvent(parent.getOwnerFileObject(), getOwnerFileObject(), false, dirEntry.getLastModified().getTime());
+            parent.getOwnerFileObject().fireFileChangedEvent(parent.getListeners(), ev);
+            if (fireChangedRO) {
+                fireReadOnlyChangedEvent();
+            }
+        }
+    }
+
+    private class DelegateOutputStream extends OutputStream {
 
         private final FileOutputStream delegate;
         private boolean closed;
-        private final RemotePlainFile file;
 
-        public DelegateOutputStream(FilesystemInterceptorProvider.FilesystemInterceptor interceptor, RemoteFileObjectBase orig, RemotePlainFile file) throws IOException {
+        public DelegateOutputStream(FilesystemInterceptorProvider.FilesystemInterceptor interceptor, RemoteFileObjectBase orig) throws IOException {
             if (interceptor != null) {
-                interceptor.beforeChange(FilesystemInterceptorProvider.toFileProxy(orig.getOwnerFileObject()));
+                try {
+                    getFileSystem().setInsideVCS(true);
+                    interceptor.beforeChange(FilesystemInterceptorProvider.toFileProxy(orig.getOwnerFileObject()));
+                } finally {
+                    getFileSystem().setInsideVCS(false);
+                }
             }
-            this.file = file;
-            delegate = new FileOutputStream(file.getCache());
+            delegate = new FileOutputStream(RemotePlainFile.this.getCache());
         }
 
         @Override
@@ -468,6 +564,11 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
             delegate.write(b, off, len);
         }
 
+        @Override
+        public void write(byte[] b) throws IOException {
+            delegate.write(b);
+        }
+
         @Override
         public void write(int b) throws IOException {
             delegate.write(b);
@@ -480,54 +581,38 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
             }
             try {
                 delegate.close();
-                file.setPendingRemoteDelivery(true);
+                RemotePlainFile.this.setPendingRemoteDelivery(true);
 
                 String pathToRename, pathToUpload;
 
-                if (file.getParent().canWrite()) {
+                if (RemotePlainFile.this.getParent().canWrite()) {
                     // that's what emacs does:
-                    pathToRename = file.getPath();
+                    pathToRename = RemotePlainFile.this.getPath();
                     pathToUpload = PathUtilities.getDirName(pathToRename) +
                             "/#" + PathUtilities.getBaseName(pathToRename) + "#"; //NOI18N
                 } else {
-                    ExecutionEnvironment env = file.getExecutionEnvironment();
+                    ExecutionEnvironment env = RemotePlainFile.this.getExecutionEnvironment();
                     if (!ConnectionManager.getInstance().isConnectedTo(env)) {
-                        throw new ConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
+                        throw RemoteExceptions.createConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
                     }
                     pathToRename = null;
-                    pathToUpload = file.getPath(); //NOI18N
+                    pathToUpload = RemotePlainFile.this.getPath(); //NOI18N
                 }
-
-                CommonTasksSupport.UploadParameters params = new CommonTasksSupport.UploadParameters(
-                        file.getCache(), file.getExecutionEnvironment(), pathToUpload, pathToRename, -1, false, null);
-                Future<UploadStatus> task = CommonTasksSupport.uploadFile(params);
                 try {
-                    UploadStatus uploadStatus = task.get();
-                    if (uploadStatus.isOK()) {
-                        RemoteLogger.getInstance().log(Level.FINEST, "WritingQueue: uploading {0} succeeded", this);
-                        file.getParent().updateStat(file, uploadStatus.getStatInfo());
-                        FileEvent ev = new FileEvent(file.getOwnerFileObject(), file.getOwnerFileObject(), false, uploadStatus.getStatInfo().getLastModified().getTime());
-                        file.getOwnerFileObject().fireFileChangedEvent(file.getListeners(), ev);
-                        RemoteDirectory parent = file.getParent();
-                        if (parent != null) {
-                            ev = new FileEvent(parent.getOwnerFileObject(), file.getOwnerFileObject(), false, uploadStatus.getStatInfo().getLastModified().getTime());
-                            parent.getOwnerFileObject().fireFileChangedEvent(parent.getListeners(), ev);
-                        }
-                    } else {
-                        RemoteLogger.getInstance().log(Level.FINEST, "WritingQueue: uploading {0} failed", this);
-                        file.setPendingRemoteDelivery(false);
-                        throw new IOException(uploadStatus.getError() + " " + uploadStatus.getExitCode()); //NOI18N
-                    }
+                    DirEntry dirEntry = RemoteFileSystemTransport.uploadAndRename(
+                            RemotePlainFile.this.getExecutionEnvironment(), RemotePlainFile.this.getCache(), pathToUpload, pathToRename);                    
+                    updateStatAndSendEvents(dirEntry, false);
                 } catch (InterruptedException ex) {
                     throw newIOException(ex);
                 } catch (ExecutionException ex) {
                     //Exceptions.printStackTrace(ex); // should never be the case - the task is done
-                    if (!ConnectionManager.getInstance().isConnectedTo(file.getExecutionEnvironment())) {
-                        file.getFileSystem().addPendingFile(file);
-                        throw new ConnectException(ex.getMessage());
+                    if (!ConnectionManager.getInstance().isConnectedTo(RemotePlainFile.this.getExecutionEnvironment())) {
+                        RemotePlainFile.this.getFileSystem().addPendingFile(RemotePlainFile.this);
+                        throw RemoteExceptions.createConnectException(ex.getMessage());
                     } else {
                         if (RemoteFileSystemUtils.isFileNotFoundException(ex)) {
-                            throw new FileNotFoundException(file.getPath());
+                            throw RemoteExceptions.createFileNotFoundException(NbBundle.getMessage(RemotePlainFile.class, 
+                                    "EXC_DoesNotExist", RemotePlainFile.this.getDisplayName())); //NOI18N
                         } else if (ex.getCause() instanceof IOException) {
                             throw (IOException) ex.getCause();
                         } else {
@@ -537,13 +622,14 @@ public final class RemotePlainFile extends RemoteFileObjectBase {
                 }
                 closed = true;
             } finally {
-                file.rwl.writeUnlock();
+                RemotePlainFile.this.rwl.writeUnlock();
             }
         }
 
         private IOException newIOException(Exception cause) {
-            return new IOException("Error uploading " + file.getPath() + " to " + file.getExecutionEnvironment() + ':' + //NOI18N
-                    cause.getMessage(), cause);
+            return RemoteExceptions.createIOException(NbBundle.getMessage(RemotePlainFile.class,
+                    "EXC_ErrorUploading", RemotePlainFile.this.getCache().getAbsolutePath(), RemotePlainFile.this.getExecutionEnvironment(), // NOI18N
+                    cause.getMessage()), cause);
         }
 
         @Override
