@@ -56,6 +56,7 @@ import java.nio.charset.Charset;
 import java.text.ParseException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
@@ -79,10 +80,15 @@ import org.netbeans.modules.nativeexecution.api.util.MacroExpanderFactory;
 import org.netbeans.modules.nativeexecution.api.util.ProcessUtils;
 import org.netbeans.modules.remote.impl.RemoteLogger;
 import org.netbeans.modules.remote.impl.fs.RefreshManager;
+import org.netbeans.modules.remote.impl.fs.RemoteExceptions;
 import org.netbeans.modules.remote.impl.fs.RemoteFileSystemManager;
 import org.netbeans.modules.remote.impl.fs.RemoteFileSystemUtils;
+import org.netbeans.modules.remote.impl.fs.ui.RemoteNotifier;
+import org.netbeans.modules.remote.spi.FileSystemProvider;
 import org.openide.modules.InstalledFileLocator;
 import org.openide.util.Exceptions;
+import org.openide.util.NbBundle;
+import org.openide.util.NbPreferences;
 import org.openide.util.RequestProcessor;
 
 /**
@@ -93,11 +99,11 @@ import org.openide.util.RequestProcessor;
 
     private static final boolean SUPPRESS_STDERR = Boolean.parseBoolean(System.getProperty("remote.fs_server.suppress.stderr", "true"));
     private static final Map<ExecutionEnvironment, FSSDispatcher> instances = 
-            new HashMap<ExecutionEnvironment, FSSDispatcher>();
+            new HashMap<>();
     private static final Object instanceLock = new Object();
     
     private final ExecutionEnvironment env;
-    private final Map<Integer, FSSResponse> responses = new LinkedHashMap<Integer, FSSResponse>();
+    private final Map<Integer, FSSResponse> responses = new LinkedHashMap<>();
     private final Object responseLock = new Object();
 
     private static final String USER_DEFINED_SERVER_PATH = System.getProperty("remote.fs_server.path");
@@ -121,15 +127,18 @@ import org.openide.util.RequestProcessor;
     private final AtomicInteger attempts = new AtomicInteger();
     private static final int MAX_ATTEMPTS = Integer.getInteger("remote.fs_server.attempts", 3); // NOI18N
     
-    private final AtomicReference<String> lastErrorMessage = new AtomicReference<String>();
+    private final AtomicReference<String> lastErrorMessage = new AtomicReference<>();
     
     private volatile boolean cleanupUponStart = false;
     
-    private static final String MIN_SERVER_VERSION = "1.2.1"; // NOI18N
+    private volatile FileSystemProvider.AccessCheckType accessCheckType;
+    
+    private static final String MIN_SERVER_VERSION = "1.7.0"; // NOI18N
     
     private FSSDispatcher(ExecutionEnvironment env) {
         this.env = env;
         traceName = "fs_server[" + env + ']'; // NOI18N
+        accessCheckType = restoreAccessCheckType();
     }
     
     public void setCleanupUponStart(boolean cleanup) {
@@ -157,7 +166,9 @@ import org.openide.util.RequestProcessor;
     }
 
     public void connected() {
-        RP.post(new ConnectTask());
+        if (RemoteFileSystemManager.getInstance().getFileSystem(env).getRoot().getImplementor().hasCache()) {
+            RP.post(new ConnectTask());
+        }
     }
 
     /*package*/ void requestRefreshCycle(String path) {
@@ -181,6 +192,55 @@ import org.openide.util.RequestProcessor;
         }
     }
 
+    private void sendAccessTypeChangeRequest(FileSystemProvider.AccessCheckType accessCheckType) {
+        String option;
+        switch (accessCheckType) {
+            case FAST:
+                option = "access=fast"; //NOI18N
+                break;
+            case FULL:
+                option = "access=full"; //NOI18N
+                break;
+            default:
+                throw new IllegalArgumentException("Unexpected access check type" + accessCheckType.name()); //NOI18N
+        }
+        
+        FSSRequest req = new FSSRequest(FSSRequestKind.FS_REQ_OPTION, option, true);
+        FsServer server = getServer();
+        if (server != null) {
+            sendRequest(server.getWriter(), req);
+        }
+    }
+
+    private static FileSystemProvider.AccessCheckType restoreAccessCheckType() {
+        FileSystemProvider.AccessCheckType result = FileSystemProvider.AccessCheckType.FAST;
+        String name = NbPreferences.forModule(FSSDispatcher.class).get("accessCheckType", result.name()); // NOI18N
+        if (name != null) {
+            try {
+                result = FileSystemProvider.AccessCheckType.valueOf(name);
+            } catch (IllegalArgumentException ex) {
+                Exceptions.printStackTrace(ex);
+            }
+        }
+        return result;
+    }
+
+    private static void storeAccessCheckType(FileSystemProvider.AccessCheckType accessCheckType) {
+        NbPreferences.forModule(FSSDispatcher.class).put("accessCheckType", accessCheckType.name()); // NOI18N
+    }
+
+    public void setAccessCheckType(FileSystemProvider.AccessCheckType accessCheckType) {
+        storeAccessCheckType(accessCheckType);
+        this.accessCheckType = accessCheckType;
+        if (getServer() != null) {
+            sendAccessTypeChangeRequest(accessCheckType);
+        }
+    }
+
+    FileSystemProvider.AccessCheckType getAccessCheckType() {
+        return accessCheckType;
+    }
+
     private class RefreshTask implements Runnable {
         
         private final String path;
@@ -221,12 +281,14 @@ import org.openide.util.RequestProcessor;
                     return;
                 }
                 BufferedReader reader = server.getReader();
+                String prevLine = null;
                 String line;
                 while ((line = reader.readLine()) != null) {
                     if (line.isEmpty()) {
-                        RemoteLogger.info("error: empty line for " + traceName);
+                        RemoteLogger.fine("error: empty line for {0} prev.line was {1}" ,traceName, prevLine);
                         continue;
                     }
+                    prevLine = line;
                     Buffer buf = new Buffer(line);
                     char respKind = buf.getChar();
                     int respId = buf.getInt();
@@ -243,7 +305,7 @@ import org.openide.util.RequestProcessor;
                         synchronized (responseLock) {
                             FSSResponse response = responses.get(respId);
                             if (response == null) {
-                                RemoteLogger.info("skipping {0} response #{1}: {2}",
+                                RemoteLogger.fine("skipping {0} response #{1}: {2}",
                                         traceName, respId, line);
                             } else {
                                 response.addPackage(FSSResponseKind.fromChar(respKind), line);
@@ -251,6 +313,17 @@ import org.openide.util.RequestProcessor;
                         }
                     }
                 }
+                Collection<FSSResponse> respCopy;
+                synchronized (responseLock) {
+                    respCopy = new ArrayList<>(responses.values());
+                    responses.clear();
+                }                
+                ExecutionException ex = new ExecutionException(
+                        RemoteExceptions.createConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env)));
+
+                for (FSSResponse resp : respCopy) {
+                    resp.failed(ex);
+                }
                 NativeProcess process = server.getProcess();
                 if (!ProcessUtils.isAlive(process)) {
                     int rc = process.waitFor();                    
@@ -346,6 +419,8 @@ import org.openide.util.RequestProcessor;
             srv = getOrCreateServer();
         } catch (ConnectionManager.CancellationException ex) {
             throw new java.util.concurrent.CancellationException(ex.getMessage());
+        } catch (ConnectException ex) {
+            throw ex; // that's normal, transport still valid, just disconnect occurred
         } catch (IOException ex) {
             setInvalid(false);
             throw ex;
@@ -432,7 +507,8 @@ import org.openide.util.RequestProcessor;
                 }
             } else {
                 String toExpand = "$osname-$platform" + // NOI18N
-                        ((osFamily == HostInfo.OSFamily.LINUX) ? "${_isa}" : ""); // NOI18N
+                        ((osFamily == HostInfo.OSFamily.LINUX && 
+                        hostInfo.getCpuFamily() != HostInfo.CpuFamily.SPARC) ? "${_isa}" : ""); // NOI18N
                 platformPath = macroExpander.expandPredefinedMacros(toExpand);
             }
             toolPath += "bin/" + platformPath + "/fs_server"; //NOI18N
@@ -446,7 +522,7 @@ import org.openide.util.RequestProcessor;
             ConnectionManager.CancellationException, InterruptedException, ExecutionException {
 
         if (!ConnectionManager.getInstance().isConnectedTo(env)) {
-            throw new ConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
+            throw RemoteExceptions.createConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
         }
 
         String toolPath;
@@ -497,7 +573,7 @@ import org.openide.util.RequestProcessor;
             }
             if (server == null) {
                 if (!ConnectionManager.getInstance().isConnectedTo(env)) {
-                    throw new ConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
+                    throw RemoteExceptions.createConnectException(RemoteFileSystemUtils.getConnectExceptionMessage(env));
                 }
                 String path = checkServerSetup();
                 server = new FsServer(path);
@@ -524,10 +600,11 @@ import org.openide.util.RequestProcessor;
             if (state == NativeProcess.State.FINISHED) {
                 //int rc = server.getProcess().waitFor();
                 //if (rc == FSSExitCodes.FAILURE_LOCKING_LOCK_FILE) {
-                throw new InitializationException(lastErrorMessage.get());
+                throw new InitializationException(createInitializerExceptionMessage());
                 //}
             }
         } else {
+            RemoteLogger.fine("Reading handshake response from {0}:{1} -> {2}", env, server.path, line);
             Buffer buf = new Buffer(line);
             char respKind = buf.getChar();
             RemoteLogger.assertTrue(respKind == FSSResponseKind.FS_RSP_SERVER_INFO.getChar());
@@ -535,9 +612,32 @@ import org.openide.util.RequestProcessor;
             RemoteLogger.assertTrue(respId == infoReq.getId());
             String rest = buf.getRest().trim();
             checkVersions(MIN_SERVER_VERSION, rest);
+            if (accessCheckType != FileSystemProvider.AccessCheckType.FULL) {
+                sendAccessTypeChangeRequest(accessCheckType);
+            }
         }
     }
-    
+
+    private String createInitializerExceptionMessage() {
+        StringBuilder sb = new StringBuilder();
+        sb.append("fs_server failed at ").append(env.toString()).append(' '); //NOI18N
+        if (HostInfoUtils.isHostInfoAvailable(env)) {
+            try {
+                HostInfo hi = HostInfoUtils.getHostInfo(env);
+                sb.append('(').append(hi.getOS().getName()).append(' ').append(hi.getCpuFamily()).append(' ');
+                sb.append(" - ").append(hi.getOS().getVersion()).append(')'); // NOI18N
+            } catch (ConnectionManager.CancellationException | IOException ex) {
+                Exceptions.printStackTrace(ex); // never occurs
+            }
+        }
+        NativeProcess process = server.getProcess();
+        if (process != null) {
+            sb.append(" rc=").append(process.exitValue()).append(' '); // NOI18N
+        }
+        sb.append(' ').append(lastErrorMessage.get());
+        return sb.toString();
+    }
+
     /** 
      * Checks versions in format N.N.N where N a number that has 1 or more digits 
      */
@@ -620,7 +720,7 @@ import org.openide.util.RequestProcessor;
             this.path = path;
             NativeProcessBuilder processBuilder = NativeProcessBuilder.newProcessBuilder(env);
             processBuilder.setExecutable(this.path);            
-            List<String> argsList = new ArrayList<String>();
+            List<String> argsList = new ArrayList<>();
             argsList.add("-t"); // NOI18N
             argsList.add("4"); // NOI18N
             argsList.add("-p"); // NOI18N
@@ -639,6 +739,11 @@ import org.openide.util.RequestProcessor;
             }
             if (cleanupUponStart) {
                 argsList.add("-c"); // NOI18N
+            } else {
+                if (!RemoteFileSystemManager.getInstance().getFileSystem(env).getRoot().getImplementor().hasCache()) {
+                    // there is no cache locally => clean remote cache as well
+                    argsList.add("-c"); // NOI18N
+                }
             }
             if (SERVER_THREADS > 0 ) {
                 argsList.add("-t"); // NOI18N
@@ -651,7 +756,26 @@ import org.openide.util.RequestProcessor;
                     ? Charset.forName("UTF-8") // NOI18N
                     : Charset.defaultCharset();
             writer = new PrintWriter(new OutputStreamWriter(process.getOutputStream(), charset));
-            reader = new BufferedReader(new InputStreamReader(process.getInputStream(), charset));
+
+            InputStream inputStream = process.getInputStream();
+            //Thread.sleep(100);
+            int available = inputStream.available();
+            if (available > 0) {
+                StringBuilder sb = new StringBuilder();
+                while ((available = inputStream.available()) > 0) {
+                    byte[] buffer = new byte[available];
+                    int cnt = inputStream.read(buffer);
+                    String line = new String(buffer, charset);
+                    sb.append(line).append('\n');
+                }
+                RemoteLogger.finest("Warning: got the following without any request on {0} startup: \n{1}\n", env, sb); //NOI18N
+                RemoteNotifier.notifyError(
+                        NbBundle.getMessage(FSSDispatcher.class, "EchoInProfile_Title", env.getDisplayName()),
+                        NbBundle.getMessage(FSSDispatcher.class, "EchoInProfile_Details", env.getDisplayName()));
+            }
+
+
+            reader = new BufferedReader(new InputStreamReader(inputStream, charset));
             if (RemoteFileSystemUtils.isUnitTestMode()) {
                 StringBuilder sb = new StringBuilder("launching ").append(path).append(' '); // NOI18N
                 for (String p : args) {
@@ -707,7 +831,7 @@ import org.openide.util.RequestProcessor;
             ps.printf("\t[pid=%d] state=%s ", pid,  process.getState()); //NOI18N
             try {
                 ProcessStatusEx exitStatusEx = process.getExitStatusEx();
-                ps.printf("\trc=%d signalled=%b termSignal=%d ", //NOI18N
+                ps.printf("\trc=%d signalled=%b termSignal=%s ", //NOI18N
                         exitStatusEx.getExitCode(),
                         exitStatusEx.ifSignalled(),
                         exitStatusEx.termSignal());
