@@ -72,9 +72,9 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
     // The following two methods are copy-paste from org.netbeans.modules.remote.impl.fileoperations.spi.FileOperationsProvider
     // They are used for emulation refresh method used in ADE plugin
     private void refreshFor(String... paths) {
-        List<RemoteFileObjectBase> roots = new ArrayList<RemoteFileObjectBase>();
+        List<RemoteFileObjectBase> roots = new ArrayList<>();
         for (String path : paths) {
-            RemoteFileObjectBase fo = findExistingParent(path);
+            RemoteFileObjectBase fo = findExistingFileObjectOrParent(path);
             if (fo != null) {
                 roots.add(fo);
             }
@@ -86,7 +86,7 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
         }
     }
 
-    private RemoteFileObjectBase findExistingParent(String path) {
+    private RemoteFileObjectBase findExistingFileObjectOrParent(String path) {
         while (true) {
             RemoteFileObject fo = RemoteFileSystemManager.getInstance().getFileSystem(execEnv).findResource(path);
             if (fo != null) {
@@ -121,8 +121,9 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
             ProcessUtils.ExitStatus res = ProcessUtils.execute(execEnv, "sh", "-c", script);
             assertEquals("Error executing script \"" + script + "\": " + res.error, 0, res.exitCode);
 
-            FileObject baseDirFO = getFileObject(baseDir);
-            FileObject dataFileFO = getFileObject(baseDirFO, dataFile);
+            final FileObject baseDirFO = getFileObject(baseDir);
+            assertTrue("FileObject should be readable: " + baseDirFO, baseDirFO.canRead());
+            final FileObject dataFileFO = getFileObject(baseDirFO, dataFile);
             int hashCode = dataFileFO.hashCode();
             assertFalse("FileObject should not be writable: " + dataFileFO.getPath(), dataFileFO.canWrite());
 
@@ -167,13 +168,13 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
             ProcessUtils.ExitStatus res = ProcessUtils.execute(execEnv, "sh", "-c", script);
             assertEquals("Error executing script \"" + script + "\": " + res.error, 0, res.exitCode);
 
-            FileObject baseDirFO = getFileObject(baseDir);
-            FileObject dirLinkFO = getFileObject(baseDirFO, dirLink);
-            FileObject dataFileFO = getFileObject(dirLinkFO, dataFile);
+            final FileObject baseDirFO = getFileObject(baseDir);
+            final FileObject dirLinkFO = getFileObject(baseDirFO, dirLink);
+            final FileObject dataFileFO = getFileObject(dirLinkFO, dataFile);
 
             assertTrue("FileObject should be readable: " + dataFileFO.getPath(), dataFileFO.canRead());
             CharSequence readContent = readFile(dataFileFO);
-            assertEquals("File content differ", content1, readContent.toString());
+            assertEquals("File content differ", content1 + "\n", readContent.toString());
 
             script =
                     "cd " + baseDir + ";"
@@ -185,7 +186,7 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
             refreshFor(dataFileFO.getPath());
             assertTrue("FileObject should be readable: " + dataFileFO.getPath(), dataFileFO.canRead());
             readContent = readFile(dataFileFO);
-            assertEquals("File content differ", content2, readContent.toString());
+            assertEquals("File content differ", content2 + '\n', readContent.toString());
 
         } finally {
             removeRemoteDirIfNotNull(baseDir);
@@ -269,10 +270,8 @@ public class RemoteLinksTestCase extends RemoteFileTestBase {
             ProcessUtils.ExitStatus res = ProcessUtils.execute(execEnv, "sh", "-c", script);
             assertEquals("Error executing script \"" + script + "\": " + res.error, 0, res.exitCode);
 
-            FileObject realFO, linkFO;
-            
-            realFO = getFileObject(realFile);
-            linkFO = getFileObject(linkFile);
+            final FileObject realFO = getFileObject(realFile);
+            final FileObject linkFO = getFileObject(linkFile);
 
             assertTrue("FileObject should be writable: " + linkFO.getPath(), linkFO.canWrite());
             String content = "a quick brown fox...";
