@@ -99,6 +99,7 @@ public final class FileChooserBuilder {
         public abstract void setCurrentDirectory(FileObject dir);
         public abstract FileObject getSelectedFileObject();
         public abstract FileObject[] getSelectedFileObjects();
+        public abstract ExecutionEnvironment getExecutionEnvironment();
         
         /** 
          * Very close to getHomeDirectory, but isn't quite the same:
@@ -149,7 +150,7 @@ public final class FileChooserBuilder {
             if(isAcceptAllFileFilterUsed()) {
                 addChoosableFileFilter(getAcceptAllFileFilter());
             }
-    }        
+        }        
         
         
     }
@@ -164,7 +165,7 @@ public final class FileChooserBuilder {
     public FileChooserBuilder(ExecutionEnvironment env) {
         this.env = env;
     }
-    
+
     public JFileChooserEx createFileChooser(Callable<String> selectedPath) {
         if (env.isLocal()) {
             return new LocalFileChooserImpl(selectedPath);
@@ -248,6 +249,11 @@ public final class FileChooserBuilder {
             }
         }
 
+        @Override
+        public ExecutionEnvironment getExecutionEnvironment() {
+            return ExecutionEnvironmentFactory.getLocal();
+        }
+
         @Override
         public String getHomePath() {
             return System.getProperty("user.home");
@@ -290,6 +296,10 @@ public final class FileChooserBuilder {
         }
 
         private FileDialog createFileDialog(Component parentComponent, File currentDirectory) {
+            if (getFileSelectionMode() == FILES_AND_DIRECTORIES) {
+                //FileDialog does not support selection of files and directories
+                return null;
+            }
             boolean dirsOnly = getFileSelectionMode() == DIRECTORIES_ONLY;
             if (!Boolean.getBoolean("nb.native.filechooser")) { //NOI18N
                 return null;
@@ -385,6 +395,11 @@ public final class FileChooserBuilder {
                 return result.toArray(new FileObject[result.size()]);
             }
         }
+
+        @Override
+        public ExecutionEnvironment getExecutionEnvironment() {
+            return env;
+        }
         
         @Override
         public String getHomePath() {
