@@ -45,12 +45,13 @@ package org.netbeans.modules.remote.spi;
 import java.io.File;
 import java.io.FileFilter;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.URI;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.concurrent.Callable;
 import java.util.logging.Level;
+import org.netbeans.modules.dlight.libs.common.DLightLibsCommonLogger;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.remote.support.RemoteLogger;
@@ -61,6 +62,7 @@ import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
+import org.openide.util.NbBundle;
 import org.openide.util.Parameters;
 import org.openide.util.Utilities;
 
@@ -75,6 +77,55 @@ public final class FileSystemProvider {
         void problemOccurred(FileSystem fileSystem, String path);
         void recovered(FileSystem fileSystem);
     }
+
+    public static final class Stat {
+
+        public final long inode;
+        public final long device;
+
+        private Stat(long device, long inode) {
+            this.inode = inode;
+            this.device = device;
+        }
+
+        public static Stat create(long  device, long inode) {
+            return new Stat(device, inode);
+        }
+
+        public static Stat createInvalid() {
+            return new Stat(-1, -1);
+        }
+
+        public boolean isValid() {
+            return inode >= 0;
+        }
+
+        @Override
+        public String toString() {
+            return "Stat(" + "dev=" + device + ",ino=" + device + ')'; //NOI18N
+        }
+    }
+
+    public enum AccessCheckType {
+        FAST,
+        FULL;
+        public String getDisplayName() {
+            switch (this) {
+                case FAST:
+                    return NbBundle.getMessage(FileSystemProvider.class, "AccessType_Fast");
+                case FULL:
+                    return NbBundle.getMessage(FileSystemProvider.class, "AccessType_Full");
+                default:
+                    throw new IllegalArgumentException("Unexpected access type: " + this); //NOI18N
+            }
+        }
+
+        @Override
+        public String toString() {
+            return getDisplayName();
+        }        
+    }
+    
     // create own copy of lookup to avoid performance issues in ProxyLookup.LazyCollection.iterator()
     private static final  Collection<FileSystemProviderImplementation> ALL_PROVIDERS =
             new ArrayList<FileSystemProviderImplementation>(Lookup.getDefault().lookupAll(FileSystemProviderImplementation.class));
@@ -415,7 +466,11 @@ public final class FileSystemProvider {
         for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
             if (provider.isMine(fileSystem)) {
                 absPath = provider.normalizeAbsolutePath(absPath, fileSystem);
-                provider.addRecursiveListener(listener, fileSystem, absPath, recurseInto, interrupter);
+                try {
+                    provider.addRecursiveListener(listener, fileSystem, absPath, recurseInto, interrupter);
+                } catch (Throwable e) {
+                    DLightLibsCommonLogger.printStackTraceOnce(e, Level.INFO, true);
+                }
                 return;
             }
         }
@@ -426,7 +481,11 @@ public final class FileSystemProvider {
         for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
             if (provider.isMine(fileSystem)) {
                 absPath = provider.normalizeAbsolutePath(absPath, fileSystem);
-                provider.removeRecursiveListener(listener, fileSystem, absPath);
+                try {
+                    provider.removeRecursiveListener(listener, fileSystem, absPath);
+                } catch (Throwable e) {
+                    DLightLibsCommonLogger.printStackTraceOnce(e, Level.INFO, true);
+                }
                 return;
             }
         }
@@ -475,6 +534,12 @@ public final class FileSystemProvider {
         }
     }
     
+    public static void addFileSystemProblemListener(FileSystemProblemListener listener) {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            provider.addFileSystemProblemListener(listener);
+        }
+    }
+
     public static void addFileSystemProblemListener(FileSystemProblemListener listener, FileSystem fileSystem) {
         for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
             if (provider.isMine(fileSystem)) {
@@ -535,6 +600,57 @@ public final class FileSystemProvider {
         }
     }
 
+    public static InputStream getInputStream(FileObject fo, int maxSize) throws IOException {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            if (provider.isMine(fo)) {
+                return provider.getInputStream(fo, maxSize);
+            }
+        }
+        return fo.getInputStream();
+    }
+
+
+    public static boolean canSetAccessCheckType(ExecutionEnvironment execEnv) {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            if (provider.isMine(execEnv)) {
+                return provider.canSetAccessCheckType(execEnv);
+            }
+        }
+        noProvidersWarning(execEnv);
+        return false;
+    }
+
+    public static void setAccessCheckType(ExecutionEnvironment execEnv, AccessCheckType accessCheckType) {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            if (provider.isMine(execEnv)) {
+                provider.setAccessCheckType(execEnv, accessCheckType);
+                return;
+            }
+        }
+        noProvidersWarning(execEnv);
+    }
+
+    public static Stat getStat(FileObject fo) {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            if (provider.isMine(fo)) {
+                return provider.getStat(fo);
+            }
+        }
+        noProvidersWarning(fo);
+        return Stat.createInvalid();
+    }
+
+    /** can be null if provider does not support this or no providers found */
+    public static AccessCheckType getAccessCheckType(ExecutionEnvironment execEnv) {
+        for (FileSystemProviderImplementation provider : ALL_PROVIDERS) {
+            if (provider.isMine(execEnv)) {
+                return provider.getAccessCheckType(execEnv);
+            }
+        }
+        noProvidersWarning(execEnv);
+        return null;
+    }
+
     private static void noProvidersWarning(Object object) {
         if (RemoteLogger.getInstance().isLoggable(Level.FINE)) {        
             if (RemoteLogger.getInstance().isLoggable(Level.FINEST)) {
