@@ -46,6 +46,7 @@ import java.beans.PropertyVetoException;
 import java.io.File;
 import java.io.FileFilter;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -53,11 +54,16 @@ import java.net.URL;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
+import java.security.AccessController;
+import java.security.PrivilegedActionException;
+import java.security.PrivilegedExceptionAction;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.concurrent.Callable;
 import java.util.logging.Level;
+import java.util.zip.Adler32;
+import java.util.zip.Checksum;
 import org.netbeans.modules.dlight.libs.common.DLightLibsCommonLogger;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
@@ -86,6 +92,7 @@ import org.openide.util.lookup.ServiceProvider;
 public final class LocalFileSystemProvider implements FileSystemProviderImplementation {
     private static final String FILE_PROTOCOL = "file"; // NOI18N
     private static final String FILE_PROTOCOL_PREFIX = "file:"; // NOI18N
+    private static final Path ROOT_PATH = Paths.get("/"); // NOI18N
 
     private FileSystem rootFileSystem = null;
     private final Map<String, LocalFileSystem> nonRootFileSystems = new HashMap<String, LocalFileSystem>();
@@ -435,6 +442,10 @@ public final class LocalFileSystemProvider implements FileSystemProviderImplemen
     public void addFileSystemProblemListener(FileSystemProblemListener listener, FileSystem fileSystem) {
     }
 
+    @Override
+    public void addFileSystemProblemListener(FileSystemProblemListener listener) {
+    }
+
     @Override
     public void removeFileSystemProblemListener(FileSystemProblemListener listener, FileSystem fileSystem) {
     }
@@ -464,9 +475,67 @@ public final class LocalFileSystemProvider implements FileSystemProviderImplemen
     }
 
     @Override
-    public String resolveLink(FileObject fo) throws IOException {
-        Path filePath = Paths.get(fo.toURI());
-        Path linkPath = Files.readSymbolicLink(filePath);
-        return linkPath.toFile().getAbsolutePath();
-    }    
+    public String resolveLink(final FileObject fo) throws IOException {
+        final Path filePath = Paths.get(fo.toURI());
+        if (Files.isSymbolicLink(filePath)) {
+            try {
+                return AccessController.doPrivileged(new PrivilegedExceptionAction<String>() {
+                    @Override
+                    public String run() throws IOException {
+                        Path linkPath = Files.readSymbolicLink(filePath);
+                        if (!linkPath.isAbsolute()) {
+                            linkPath = filePath.getParent().resolve(linkPath).normalize();
+                        }
+                        return linkPath.toFile().getAbsolutePath();
+                    }
+                });
+            } catch (PrivilegedActionException ex) {
+                ex.printStackTrace(System.err);
+            }
+        }
+        return null;
+    }
+
+    @Override
+    public InputStream getInputStream(FileObject fo, int maxSize) throws IOException {
+        return fo.getInputStream();
+    }
+
+    @Override
+    public boolean canSetAccessCheckType(ExecutionEnvironment execEnv) {
+        return false;
+    }
+
+    @Override
+    public void setAccessCheckType(ExecutionEnvironment execEnv, FileSystemProvider.AccessCheckType accessCheckType) {
+    }
+
+    @Override
+    public FileSystemProvider.AccessCheckType getAccessCheckType(ExecutionEnvironment execEnv) {
+        return null;
+    }
+
+    @Override
+    public FileSystemProvider.Stat getStat(FileObject fo) {
+        if (Utilities.isWindows()) {
+            Checksum cs = new Adler32();
+            String path = fo.getPath();
+            for (int i = 0; i < path.length(); i++) {
+                cs.update(path.charAt(i));
+            }
+            return FileSystemProvider.Stat.create(Long.MIN_VALUE, cs.getValue());
+        } else {
+            Path path = ROOT_PATH.resolve(fo.getPath());
+            if (Files.exists(path)) {
+                try {
+                    long st_ino = ((Number)Files.getAttribute(path, "unix:ino")).longValue(); //NOI18N
+                    long st_dev = ((Number)Files.getAttribute(path, "unix:dev")).longValue(); //NOI18N
+                    return FileSystemProvider.Stat.create(st_dev, st_ino);
+                } catch (IOException ex) {
+                    RemoteLogger.finest(ex);
+                }
+            }
+        }
+        return FileSystemProvider.Stat.createInvalid();
+    }
 }
