@@ -39,19 +39,22 @@
  *
  * Portions Copyrighted 2011 Sun Microsystems, Inc.
  */
-
 package org.netbeans.modules.dlight.terminal.action;
 
 import java.awt.Component;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.IOException;
+import java.net.ConnectException;
+import java.util.Arrays;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import javax.swing.Action;
 import javax.swing.Icon;
 import javax.swing.JButton;
@@ -60,6 +63,7 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import org.netbeans.lib.terminalemulator.Term;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.nativeexecution.api.HostInfo;
 import org.netbeans.modules.nativeexecution.api.NativeProcess;
 import org.netbeans.modules.nativeexecution.api.NativeProcessBuilder;
@@ -72,6 +76,8 @@ import org.netbeans.modules.nativeexecution.api.util.HostInfoUtils;
 import org.netbeans.modules.terminal.api.IONotifier;
 import org.netbeans.modules.terminal.api.IOTerm;
 import org.netbeans.modules.terminal.api.IOVisibility;
+import org.netbeans.modules.terminal.support.TerminalPinSupport;
+import org.netbeans.modules.terminal.support.TerminalPinSupport.TerminalCreationDetails;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.Exceptions;
@@ -82,17 +88,21 @@ import org.openide.util.WeakListeners;
 import org.openide.windows.IOContainer;
 import org.openide.windows.IOProvider;
 import org.openide.windows.InputOutput;
+import org.openide.windows.OutputEvent;
+import org.openide.windows.OutputListener;
+import org.openide.windows.OutputWriter;
 
 /**
  *
  * @author Vladimir Voskresensky
  */
 public final class TerminalSupportImpl {
+
     private static final RequestProcessor RP = new RequestProcessor("Terminal Action RP", 100); // NOI18N
 
     private TerminalSupportImpl() {
     }
-    
+
     public static Component getToolbarPresenter(Action action) {
         JButton button = new JButton(action);
         button.setBorderPainted(false);
@@ -110,45 +120,118 @@ public final class TerminalSupportImpl {
         return button;
     }
     
+    
+    /**
+     * Creates new Terminal tab. Method must be called from UI Thread.
+     * @param ioContainer parent tabbed container
+     * @param io io will be reused if this value is not null, if null the new one will be created 
+     * (<code>ioProvider.getIO(tabTitle, null, ioContainer)</code>)
+     * @param tabTitle tab title
+     * @param env execution environment
+     * @param dir Terminal tries to cd into this dir when connected
+     * @param silentMode produces output on errors if true
+     * @param pwdFlag try to set title to 'user@host - ${PWD}' every time ${PWD} changes.
+     */
     public static void openTerminalImpl(
             final IOContainer ioContainer,
             final String tabTitle,
             final ExecutionEnvironment env,
             final String dir,
             final boolean silentMode,
-            final boolean pwdFlag) {
-        final IOProvider term = IOProvider.get("Terminal"); // NOI18N
-        if (term != null) {
+            final boolean pwdFlag,
+            final long termId) {
+        final IOProvider ioProvider = IOProvider.get("Terminal"); // NOI18N
+        if (ioProvider != null) {
+            final AtomicReference<InputOutput> ioRef = new AtomicReference<InputOutput>();
+            // Create a tab in EDT right after we call the method, don't let this 
+            // work to be done in RP in asynchronous manner. We need this to
+            // save tab order 
+            InputOutput io = ioProvider.getIO(tabTitle, null, ioContainer);
+            ioRef.set(io);
             final AtomicBoolean destroyed = new AtomicBoolean(false);
-            Runnable runnable = new Runnable() {
+            
+            final Runnable runnable = new Runnable() {
+                private final Runnable delegate = new Runnable() {
+                    @Override
+                    public void run() {
+                        if (SwingUtilities.isEventDispatchThread()) {
+                            ioContainer.requestActive();
+                        } else {
+                            doWork();
+                        }
+                    }
+                };
+
+                private final HyperlinkAdapter retryLink = new HyperlinkAdapter() {
+                    @Override
+                    public void outputLineAction(OutputEvent ev) {
+                        RP.post(delegate);
+                    }
+                };
 
                 @Override
                 public void run() {
-                    if (SwingUtilities.isEventDispatchThread()) {
-                        ioContainer.requestActive();
-                    } else {
-                        doWork();
-                    }
+                    delegate.run();
                 }
 
                 private void doWork() {
+                    boolean verbose = env.isRemote(); // can use silentMode instead
+                    OutputWriter out = ioRef.get().getOut();
+                    
+                    long id = TerminalPinSupport.getDefault().createPinDetails(TerminalCreationDetails.create(IOTerm.term(ioRef.get()), termId, env.getDisplayName(), pwdFlag));
+                    
                     if (!ConnectionManager.getInstance().isConnectedTo(env)) {
                         try {
+                            if (verbose) {
+                                out.println(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_ConnectingTo", env.getDisplayName() ));
+                            }
                             ConnectionManager.getInstance().connectTo(env);
                         } catch (IOException ex) {
                             if (!destroyed.get()) {
+                                if (verbose) {
+                                    try {
+                                        out.print(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_ConnectionFailed"));
+                                        out.println(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_Retry"), retryLink);
+                                    } catch (IOException ignored) {
+                                    }
+                                }
                                 String error = ex.getCause() == null ? ex.getMessage() : ex.getCause().getMessage();
                                 String msg = NbBundle.getMessage(TerminalSupportImpl.class, "TerminalAction.FailedToStart.text", error); // NOI18N
                                 DialogDisplayer.getDefault().notify(new NotifyDescriptor.Message(msg, NotifyDescriptor.ERROR_MESSAGE));
                             }
                             return;
                         } catch (CancellationException ex) {
+                            if (verbose) {
+                                try {
+                                    out.print(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_Canceled"));
+                                    out.println(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_Retry"), retryLink);
+                                } catch (IOException ignored) {
+                                }
+                            }
                             return;
                         }
                     }
 
                     final HostInfo hostInfo;
                     try {
+                        // There is still a chance of env being disconnected
+                        // (exception supressed in FetchHostInfoTask.compute)
+                        if (!ConnectionManager.getInstance().isConnectedTo(env)) {
+                            return;
+                        }
+
+                        try {
+                            if (dir != null && !HostInfoUtils.directoryExists(env, dir)) {
+                                // Displaying this message always, not just for remote envs.
+                                out.print(NbBundle.getMessage(TerminalSupportImpl.class, "LOG_DirNotExist", dir, env.getDisplayName()));
+                                return;
+                            }
+                        } catch (ConnectException ex) {
+                            Exceptions.printStackTrace(ex);
+                        } catch (InterruptedException ex) {
+                            Exceptions.printStackTrace(ex);
+                        }
+
                         hostInfo = HostInfoUtils.getHostInfo(env);
                         boolean isSupported = PtySupport.isSupportedFor(env);
                         if (!isSupported) {
@@ -173,13 +256,18 @@ public final class TerminalSupportImpl {
                         Exceptions.printStackTrace(ex);
                         return;
                     }
+                    
+                    if (verbose) {
+                        try {
+                            // Erase "log" in case we successfully connected to host
+                            out.reset();
+                        } catch (IOException ex) {
+                            // never thrown from TermOutputWriter
+                        }
+                    }
 
-                    final AtomicReference<InputOutput> ioRef = new AtomicReference<InputOutput>();
                     try {
-                        InputOutput io = term.getIO(tabTitle, null, ioContainer);
-                        ioRef.set(io);
-
-                        Term term = IOTerm.term(io);
+                        final Term term = IOTerm.term(ioRef.get());
                         // TODO: this is a temporary solution.
 
                         // Right now xterm emulation is not fully supported. (NB7.4)
@@ -196,17 +284,33 @@ public final class TerminalSupportImpl {
                         // clear env modified by NB. Let it be initialized by started shell process
                         npb.getEnvironment().put("LD_LIBRARY_PATH", "");// NOI18N
                         npb.getEnvironment().put("DYLD_LIBRARY_PATH", "");// NOI18N
+
                         
+                        
+                        final TerminalPinSupport support = TerminalPinSupport.getDefault();
+                        String envId = ExecutionEnvironmentFactory.toUniqueID(env);
+
                         npb.addNativeProcessListener(new NativeProcessListener(ioRef.get(), destroyed));
 
+                        /*
+                         * Was: echo -n \"\033]0;" + tabTitle + " `pwd`\007\""
+                         * Why changed:
+                         *  1. Flag "-n" is not always supported by different shells,
+                         *     so use printf instead. (Actually, if "-n" is not supported,
+                         *     almost always PROMPT_COMMAND won't be supported too. (ksh, for example).
+                         *  2. Now we use "033]3" (op_cwd) instead of "033]0" (op_win_title) 
+                         *     and let listeners decide what to do when cwd is changed.
+                         *  3. Removed a useless `pwd` call because cd has already updated
+                         *     $PWD and $OLDPWD variables.
+                         */
                         if (pwdFlag) {
-                            final String promptCommand = "echo -n \"\033]0;" + tabTitle + " `pwd`\007\"";   // NOI18N
+                            final String promptCommand = "printf \"\033]3;${PWD}\007\"";   // NOI18N
                             final String commandName = "PROMPT_COMMAND";                                    // NOI18N
                             String usrPrompt = npb.getEnvironment().get(commandName);
                             npb.getEnvironment().put(commandName,
                                     (usrPrompt == null)
-                                    ? promptCommand
-                                    : promptCommand + ';' + usrPrompt
+                                            ? promptCommand
+                                            : promptCommand + ';' + usrPrompt
                             );
                         }
 
@@ -219,6 +323,7 @@ public final class TerminalSupportImpl {
                         if (shell.endsWith("bash") || shell.endsWith("bash.exe")) { // NOI18N
                             npb.setArguments("--login"); // NOI18N
                         }
+                        
                         NativeExecutionDescriptor descr;
                         descr = new NativeExecutionDescriptor().controllable(true).frontWindow(true).inputVisible(true).inputOutput(ioRef.get());
                         descr.postExecution(new Runnable() {
@@ -226,6 +331,7 @@ public final class TerminalSupportImpl {
                             @Override
                             public void run() {
                                 ioRef.get().closeInputOutput();
+                                support.close(term);
                             }
                         });
                         NativeExecutionService es = NativeExecutionService.newService(npb, descr, "Terminal Emulator"); // NOI18N
@@ -236,7 +342,15 @@ public final class TerminalSupportImpl {
                         try {
                             // if terminal can not be started then ExecutionException should be thrown
                             // wait one second to see if terminal can not be started. otherwise it's OK to exit by TimeOut
-                            result.get(1, TimeUnit.SECONDS);
+
+                            // IG: I've increased the timeout from 1 to 10 seconds.
+                            // On slow hosts 1 sec was not enougth to get an error code from the pty
+                            // No work is done after this call, so this change should be safe.
+                            Integer rc = result.get(10, TimeUnit.SECONDS);
+                            if (rc != 0) {
+                                Logger.getLogger(TerminalSupportImpl.class.getName())
+                                        .log(Level.INFO, "{0}{1}", new Object[]{NbBundle.getMessage(TerminalSupportImpl.class, "LOG_ReturnCode"), rc});
+                            }
                         } catch (TimeoutException ex) {
                             // we should be there
                         } catch (InterruptedException ex) {
@@ -263,7 +377,7 @@ public final class TerminalSupportImpl {
             RP.post(runnable);
         }
     }
-
+    
     private final static class NativeProcessListener implements ChangeListener, PropertyChangeListener {
 
         private final AtomicReference<NativeProcess> processRef;
@@ -306,4 +420,19 @@ public final class TerminalSupportImpl {
             }
         }
     }
+    
+    private static class HyperlinkAdapter implements OutputListener{
+
+        @Override
+        public void outputLineSelected(OutputEvent ev) {
+        }
+
+        @Override
+        public void outputLineAction(OutputEvent ev) {
+        }
+
+        @Override
+        public void outputLineCleared(OutputEvent ev) {
+        }
+    }
 }
