@@ -70,6 +70,7 @@ import javax.swing.event.UndoableEditEvent;
 import javax.swing.event.UndoableEditListener;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.BadLocationException;
+import javax.swing.text.Caret;
 import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.Position;
@@ -143,6 +144,7 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
     
     /** Document for which this abbreviation detection was constructed. */
     private Document doc;
+    private DocumentListener weakDocL;
     
     /**
      * Offset after the last typed character of the collected abbreviation.
@@ -173,15 +175,14 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
         component.addCaretListener(this);
         doc = component.getDocument();
         if (doc != null) {
-            doc.addDocumentListener(this);
+            listenOnDoc();
         }
 
         String mimeType = DocumentUtilities.getMimeType(component);
         if (mimeType != null) {
             mimePath = MimePath.parse(mimeType);
             prefs = MimeLookup.getLookup(mimePath).lookup(Preferences.class);
-            weakPrefsListener = WeakListeners.create(PreferenceChangeListener.class, this, prefs);
-            prefs.addPreferenceChangeListener(weakPrefsListener);
+            prefs.addPreferenceChangeListener(WeakListeners.create(PreferenceChangeListener.class, this, prefs));
         }
         
         // Load the settings
@@ -201,12 +202,17 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
         });
         surroundsWithTimer.setRepeats(false);
     }
+    
+    private void listenOnDoc() {
+        weakDocL = WeakListeners.document(this, doc);
+        doc.addDocumentListener(weakDocL);
+    }
 
     private void uninstall() {
         assert component != null : "Can't call uninstall before the construction finished";
         component.removeCaretListener(this);
         if (doc != null) {
-            doc.addDocumentListener(this);
+            listenOnDoc();
         }
 
         component.removeKeyListener(this);
@@ -250,13 +256,14 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
 
     public void propertyChange(PropertyChangeEvent evt) {
         if ("document".equals(evt.getPropertyName())) { //NOI18N
-            if (doc != null) {
-                doc.removeDocumentListener(this);
+            if (doc != null && weakDocL != null) {
+                doc.removeDocumentListener(weakDocL);
+                weakDocL = null;
             }
             
             doc = component.getDocument();
             if (doc != null) {
-                doc.addDocumentListener(this);
+                listenOnDoc();
             }
 
             // unregister and destroy the old preferences (if we have any)
@@ -304,8 +311,7 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
     }
 
     private boolean isIgnoreModification() {
-        return Boolean.TRUE.equals(doc.getProperty(ABBREV_IGNORE_MODIFICATION_DOC_PROPERTY)) ||
-                !DocumentUtilities.isTypingModification(doc);
+        return Boolean.TRUE.equals(doc.getProperty(ABBREV_IGNORE_MODIFICATION_DOC_PROPERTY));
     }
     
     private boolean isAbbrevDisabled() {
@@ -437,24 +443,27 @@ public final class AbbrevDetection implements DocumentListener, PropertyChangeLi
     
     private void showSurroundWithHint() {
         try {
-            final Position pos = doc.createPosition(component.getCaretPosition());
-            RP.post(new Runnable() {
-                public void run() {
-                    final List<Fix> fixes = SurroundWithFix.getFixes(component);
-                    SwingUtilities.invokeLater(new Runnable() {
-                        public void run() {
-                            if (!fixes.isEmpty()) {
-                                errorDescription = ErrorDescriptionFactory.createErrorDescription(
-                                        Severity.HINT, SURROUND_WITH, surrounsWithFixes = fixes, doc, pos, pos);
+            final Caret caret = component.getCaret();
+            if (caret != null) {
+                final Position pos = doc.createPosition(caret.getDot());
+                RP.post(new Runnable() {
+                    public void run() {
+                        final List<Fix> fixes = SurroundWithFix.getFixes(component);
+                        SwingUtilities.invokeLater(new Runnable() {
+                            public void run() {
+                                if (!fixes.isEmpty()) {
+                                    errorDescription = ErrorDescriptionFactory.createErrorDescription(
+                                            Severity.HINT, SURROUND_WITH, surrounsWithFixes = fixes, doc, pos, pos);
 
-                                HintsController.setErrors(doc, SURROUND_WITH, Collections.singleton(errorDescription));
-                            } else {
-                                hideSurroundWithHint();
+                                    HintsController.setErrors(doc, SURROUND_WITH, Collections.singleton(errorDescription));
+                                } else {
+                                    hideSurroundWithHint();
+                                }
                             }
-                        }
-                    });
-                }
-            });
+                        });
+                    }
+                });
+            }
         } catch (BadLocationException ble) {
             Logger.getLogger("global").log(Level.WARNING, ble.getMessage(), ble);
         }
