@@ -114,7 +114,7 @@ CaretListener, KeyListener, FocusListener, ListSelectionListener, PropertyChange
     // -J-Dorg.netbeans.modules.editor.completion.CompletionImpl.level=FINE
     private static final Logger LOG = Logger.getLogger(CompletionImpl.class.getName());
     private static final boolean alphaSort = Boolean.getBoolean("org.netbeans.modules.editor.completion.alphabeticalSort"); // [TODO] create an option
-    private static final Object CT_HANDLER_DOC_PROPERTY = "code-template-insert-handler"; // NOI18N
+    private static final boolean NO_TAB_COMPLETION = Boolean.getBoolean("org.netbeans.modules.editor.completion.noTabCompletion");  //NOI18N
 
     private static final Logger UI_LOG = Logger.getLogger("org.netbeans.ui.editor.completion"); // NOI18N
 
@@ -686,12 +686,13 @@ CaretListener, KeyListener, FocusListener, ListSelectionListener, PropertyChange
                     || e.getKeyCode() == KeyEvent.VK_HOME || e.getKeyCode() == KeyEvent.VK_END) {
                 hideCompletion(false);                
             }
-            if (e.getKeyCode() == KeyEvent.VK_TAB && doc.getProperty(CT_HANDLER_DOC_PROPERTY) == null) {
+            if (e.getKeyCode() == KeyEvent.VK_TAB && e.getID() == KeyEvent.KEY_PRESSED) {
                 e.consume();
-                if (guardedPos) {
-                    Toolkit.getDefaultToolkit().beep();
-                } else if (compEditable && e.getID() == KeyEvent.KEY_PRESSED)
+                if (compEditable && !guardedPos) {
                     insertCommonPrefix();
+                } else {
+                    Toolkit.getDefaultToolkit().beep();
+                }
                 return;
             }
         }
@@ -821,7 +822,8 @@ CaretListener, KeyListener, FocusListener, ListSelectionListener, PropertyChange
             }
         }
         if (localCompletionResult != null) {
-            CharSequence commonText = null;
+            CompletionItem item = layout.getSelectedCompletionItem();
+            CharSequence commonText = item != null ? item.getInsertPrefix() : null;
             int anchorOffset = -1;
 outer:      for (Iterator it = localCompletionResult.getResultSets().iterator(); it.hasNext();) {
                 CompletionResultSetImpl resultSet = (CompletionResultSetImpl)it.next();
@@ -833,6 +835,7 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
                         else
                             anchorOffset = resultSet.getAnchorOffset();
                     }
+                    boolean caseSensitive = CompletionSettings.getInstance(c).completionCaseSensitive();
                     for (Iterator itt = resultItems.iterator(); itt.hasNext();) {
                         CharSequence text = ((CompletionItem)itt.next()).getInsertPrefix();
                         if (text == null) {
@@ -843,10 +846,17 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
                             commonText = text;
                         } else {
                             // Get the largest common part
-                            if (text.length() < commonText.length())
+                            if (text.length() < commonText.length()) {
                                 commonText = commonText.subSequence(0, text.length());
+                            }
                             for (int commonInd = 0; commonInd < commonText.length(); commonInd++) {
-                                if (text.charAt(commonInd) != commonText.charAt(commonInd)) {
+                                char textChar = text.charAt(commonInd);
+                                char commonTextChar = commonText.charAt(commonInd);
+                                if (!caseSensitive) {
+                                    textChar = Character.toLowerCase(textChar);
+                                    commonTextChar = Character.toLowerCase(commonTextChar);
+                                }
+                                if (textChar != commonTextChar) {
                                     if (commonInd == 0) {
                                         commonText = null;
                                         break outer; // no common text
@@ -860,8 +870,8 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
                 }
             }
             if (commonText != null && anchorOffset >= 0) {
-                int caretOffset = c.getSelectionStart();
-                if (caretOffset - anchorOffset < commonText.length()) {
+                int len = c.getSelectionStart() - anchorOffset;
+                if (len >= 0 && len < commonText.length()) {
 
                     Document doc = getActiveDocument();
                     BaseDocument baseDoc = null;
@@ -872,7 +882,7 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
                     if(baseDoc != null)
                         baseDoc.atomicLock();
                     try {
-                        doc.remove(anchorOffset, caretOffset - anchorOffset);
+                        doc.remove(anchorOffset, len);
                         doc.insertString(anchorOffset, commonText.toString(), null);
                     } catch (BadLocationException e) {
                     } finally {
@@ -882,8 +892,7 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
                     return;
                 }
             }
-            CompletionItem item = layout.getSelectedCompletionItem();
-            if (item != null)
+            if (item != null && !NO_TAB_COMPLETION)
                 item.defaultAction(c);
         }
     }
@@ -1075,16 +1084,38 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
             } catch (BadLocationException ble) {
             }
         }
+        int closestIdx = 0;
         if (prefix != null && prefix.length() > 0) {
+            int distance = Integer.MAX_VALUE;
             int idx = 0;
+            String prefLC = prefix.toLowerCase();
             for (CompletionItem item : items) {
                 CharSequence text = item.getInsertPrefix();
-                if (text != null && text.toString().startsWith(prefix))
-                    return idx;
+                int prio = item.getSortPriority() * 1000;
+                boolean isSmart = prio < 0;
+                String name = text != null ? text.toString() : null;
+                if (name != null) {
+                    for (String part : name.split("\\.")) {
+                        if (part.startsWith(prefix) && (!(item instanceof LazyCompletionItem) || ((LazyCompletionItem)item).accept())) {
+                            return idx;
+                        }
+                        int d = prio + getDistance(part.toLowerCase(), prefLC);
+                        if (part.toLowerCase().startsWith(prefLC)) {
+                            d -= 500;
+                        }
+                        if (d < distance) {
+                            distance = d;
+                            closestIdx = idx;
+                        }
+                        if (!isSmart) {
+                            break;
+                        }
+                    }
+                }
                 idx++;
             }
         }
-        return 0;
+        return closestIdx;
     }
 
     /**
@@ -1733,6 +1764,78 @@ outer:      for (Iterator it = localCompletionResult.getResultSets().iterator();
         }
     }
 
+      /** Computes distance between strings
+      * @param s First string
+      * @param t Second string
+      * @return Distance between the strings. (Number of changes which have to 
+      *         be done to get from <CODE>s</CODE> to <CODE>t</CODE>.
+      */
+    private static int getDistance(String s, String t) {
+        int d[][]; // matrix
+        int n; // length of s
+        int m; // length of t
+        int i; // iterates through s
+        int j; // iterates through t
+        char s_i; // ith character of s
+        char t_j; // jth character of t
+        int cost; // cost
+
+        // Step 1
+        n = s.length ();
+        m = t.length ();
+        if (n == 0) {
+          return m;
+        }
+        if (m == 0) {
+          return n;
+        }
+        d = new int[n+1][m+1];
+
+        // Step 2
+        for (i = 0; i <= n; i++) {
+          d[i][0] = i;
+        }
+        for (j = 0; j <= m; j++) {
+          d[0][j] = j;
+        }
+
+        // Step 3
+        for (i = 1; i <= n; i++) {
+          s_i = s.charAt (i - 1);
+
+          // Step 4
+          for (j = 1; j <= m; j++) {
+            t_j = t.charAt (j - 1);
+
+            // Step 5
+            if (s_i == t_j) {
+              cost = 0;
+            }
+            else {
+              cost = 1;
+            }
+
+            // Step 6
+            d[i][j] = min (d[i-1][j]+1, d[i][j-1]+1, d[i-1][j-1] + cost);
+          }
+        }
+
+        // Step 7
+        return d[n][m];        
+    }
+
+    private static int min (int a, int b, int c) {
+        int mi;
+        mi = a;
+        if (b < mi) {
+          mi = b;
+        }
+        if (c < mi) {
+          mi = c;
+        }
+        return mi;
+   }
+
     /**
      * Result holding list of completion result sets.
      * <br>
