@@ -153,7 +153,7 @@ public class CompletionJList extends JList {
         }
     }
     
-    void setData(List data) {
+    void setData(List data, int selectedIndex) {
         smartIndex = -1;
         if (data != null) {
             int itemCount = data.size();
@@ -181,11 +181,11 @@ public class CompletionJList extends JList {
                     break;
             }
             setFixedCellWidth(width);
-            ListModel lm = LazyListModel.create( new Model(data), CompletionImpl.filter, 1.0d, LocaleSupport.getString("completion-please-wait") ); //NOI18N
+            LazyListModel lm = LazyListModel.create( new Model(data), CompletionImpl.filter, 1.0d, LocaleSupport.getString("completion-please-wait") ); //NOI18N
             setModel(lm);
             
             if (itemCount > 0) {
-                setSelectedIndex(0);
+                setSelectedIndex(selectedIndex < 0 ? 0 : lm.findExternalIndex(selectedIndex));
             }
             int visibleRowCount = Math.min(itemCount, maxVisibleRowCount);
             setVisibleRowCount(visibleRowCount);
@@ -232,12 +232,23 @@ public class CompletionJList extends JList {
         JLabel orig = accessibleLabel;
         editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_ACTIVE_DESCENDANT_PROPERTY, accessibleLabel, accessibleFakeLabel);
         Object selectedValue = getSelectedValue();
-        String accName = selectedValue instanceof Accessible ? ((Accessible) selectedValue).getAccessibleContext().getAccessibleName() : selectedValue.toString();
-        accessibleLabel = new JLabel(LocaleSupport.getString("ACSN_CompletionView_SelectedItem") + accName); //NOI18N
-        editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_CHILD_PROPERTY, null, accessibleLabel);
-        editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_ACTIVE_DESCENDANT_PROPERTY, accessibleFakeLabel, accessibleLabel);
-        if (orig != null) {
-            editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_CHILD_PROPERTY, orig, null);
+        String accName = null;
+        if (selectedValue instanceof Accessible) {
+            AccessibleContext ac = ((Accessible) selectedValue).getAccessibleContext();
+            if (ac != null) {
+                accName = ac.getAccessibleName();
+            }
+        }
+        if (accName == null && selectedValue != null) {
+            accName = selectedValue.toString();
+        }
+        if (accName != null) {
+            accessibleLabel = new JLabel(LocaleSupport.getString("ACSN_CompletionView_SelectedItem") + accName); //NOI18N
+            editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_CHILD_PROPERTY, null, accessibleLabel);
+            editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_ACTIVE_DESCENDANT_PROPERTY, accessibleFakeLabel, accessibleLabel);
+            if (orig != null) {
+                editorAC.firePropertyChange(AccessibleContext.ACCESSIBLE_CHILD_PROPERTY, orig, null);
+            }
         }
     }
     
