@@ -434,8 +434,10 @@ AtomicLockListener, FoldHierarchyListener {
                         Utilities.annotateLoggable(e);
                     }
                     if (newCaretBounds != null) {
-                        LOG.log(Level.FINE, "updateCaretBounds: old={0}, new={1}, offset={2}",
-                                new Object[]{caretBounds, newCaretBounds, offset}); //NOI18N
+                        if (LOG.isLoggable(Level.FINE)) {
+                            LOG.log(Level.FINE, "updateCaretBounds: old={0}, new={1}, offset={2}",
+                                    new Object[]{caretBounds, newCaretBounds, offset}); //NOI18N
+                        }
                         caretBounds = newCaretBounds;
                         ret[0] = true;
                     }
@@ -945,6 +947,11 @@ AtomicLockListener, FoldHierarchyListener {
     protected void fireStateChanged() {
         Runnable runnable = new Runnable() {
             public @Override void run() {
+                // #252441: uninstallUI might detached the caret from component while this
+                // event was queued.
+                if (component == null || component.getCaret() != BaseCaret.this) {
+                    return;
+                }
                 Object listeners[] = listenerList.getListenerList();
                 for (int i = listeners.length - 2; i >= 0 ; i -= 2) {
                     if (listeners[i] == ChangeListener.class) {
