@@ -335,12 +335,13 @@ public class GlyphGutter extends JComponent implements Annotations.AnnotationsLi
             backgroundColor = UIManager.getColor("NbEditorGlyphGutter.background"); //NOI18N
         }
         if( null == backgroundColor ) {
-            if (backColor != null)
+            if (backColor != null) {
                 backgroundColor = backColor;
-            else
-                backgroundColor = defaultColoring.getBackColor();
+            }
+        }
+        if (backgroundColor != null) {
+            setBackground(backgroundColor);
         }
-
         if (lineColoring.getForeColor() != null)
             foreColor = lineColoring.getForeColor();
         else
@@ -359,7 +360,11 @@ public class GlyphGutter extends JComponent implements Annotations.AnnotationsLi
         if (tc != null) {
             Integer textZoom = (Integer) tc.getClientProperty(TEXT_ZOOM_PROPERTY);
             if (textZoom != null && textZoom != 0) {
-                lineFont = new Font(lineFont.getFamily(), lineFont.getStyle(), Math.max(lineFont.getSize() + textZoom, 2));
+                if (Math.max(lineFont.getSize() + textZoom, 2) == 2) {
+                    textZoom = -(lineFont.getSize()-2);
+                    tc.putClientProperty(TEXT_ZOOM_PROPERTY, textZoom);
+                }
+                lineFont = new Font(lineFont.getFamily(), lineFont.getStyle(), lineFont.getSize() + textZoom);                
             }
         }
         font = lineFont;
@@ -510,7 +515,7 @@ public class GlyphGutter extends JComponent implements Annotations.AnnotationsLi
         View rootView = Utilities.getDocumentView(component);
         if (rootView == null) return;
       
-        g.setColor(backgroundColor);
+        g.setColor(getBackground());
         g.fillRect(clip.x, clip.y, clip.width, clip.height);
         
         //painting gutter line
