@@ -259,18 +259,20 @@ public final class EditorFindSupport {
         final int so = startOffset;
         final int eo = endOffset;
         final ScheduledExecutorService executor = Executors.newSingleThreadScheduledExecutor();
+        currentResult = null;
         try {
             executor.submit(new Runnable() {
 
                 @Override
                 public void run() {
                     try {
-                        cacheContent = DocumentFinder.findBlocks(doc, so, eo, props, blocks);
+                        currentResult = DocumentFinder.findBlocks(doc, so, eo, props, blocks);
+                        cacheContent = currentResult.getFoundPositions();
                     } catch (BadLocationException ble) {
                         cacheContent = Arrays.copyOf(blocks, blocks.length);
-                        LOG.log(Level.WARNING, ble.getMessage(), ble);
+                        LOG.log(Level.INFO, ble.getMessage(), ble);
                     }
-
+                    
                 }
             }).get(TIME_LIMIT, TimeUnit.SECONDS);
         } catch (InterruptedException | ExecutionException | TimeoutException ex) {
@@ -278,6 +280,9 @@ public final class EditorFindSupport {
             org.netbeans.editor.Utilities.setStatusBoldText(getFocusedTextComponent(), NbBundle.getMessage(EditorFindSupport.class, "slow-search"));
             LOG.log(Level.INFO, ex.getMessage(), ex);
         }
+        if (currentResult != null && currentResult.hasErrorMsg()) {
+            org.netbeans.editor.Utilities.setStatusBoldText(getFocusedTextComponent(), currentResult.getErrorMsg());
+        }
         executor.shutdown();
 
         cachekey = newCacheKey;
@@ -343,14 +348,8 @@ public final class EditorFindSupport {
     
     public boolean incSearch(Map<String, Object> props, int caretPos) {
         props = getValidFindProperties(props);
-
-        // if regexp terminate incSearch
-        Boolean b = (Boolean)props.get(FIND_REG_EXP);
-        if (b !=null && b.booleanValue()){
-            return false;
-        }
         
-        b = (Boolean)props.get(FIND_INC_SEARCH);
+        Boolean b = (Boolean)props.get(FIND_INC_SEARCH);
         if (b != null && b.booleanValue()) { // inc search enabled
             JTextComponent comp = getFocusedTextComponent();
             
@@ -405,10 +404,11 @@ public final class EditorFindSupport {
                             );
                         }
                         Preferences prefs = MimeLookup.getLookup(MimePath.EMPTY).lookup(Preferences.class);
-                        if (prefs.get(SimpleValueNames.EDITOR_SEARCH_TYPE, "default").equals("closing")) // NOI18N
+                        if (prefs.get(SimpleValueNames.EDITOR_SEARCH_TYPE, "default").equals("closing")) { // NOI18N
                             ensureVisible(comp, pos, pos);
-                        else
+                        } else {
                             selectText(comp, pos, pos + len, back);
+                        }
                         return true;
                     }
                 }
@@ -558,11 +558,22 @@ public final class EditorFindSupport {
             int blockSearchStart = (blockStartPos != null) ? blockStartPos.getOffset() : -1;
             int blockSearchEnd = getBlockEndOffset();
 
+            boolean backSearch = Boolean.TRUE.equals(props.get(FIND_BACKWARD_SEARCH));
+            if (backSearch) {
+                blockSearchEnd = dotPos;
+                dotPos = 0;
+            }
             try {
                 FindReplaceResult result = findReplaceInBlock(replaceExp, c, dotPos, 
                         (blockSearch && blockSearchStart > -1) ? blockSearchStart : 0, 
-                        (blockSearch && blockSearchEnd > 0) ? blockSearchEnd : -1, 
+                        (blockSearch && blockSearchEnd > 0) ? blockSearchEnd : backSearch ? blockSearchEnd : -1, 
                         props, oppositeDir);
+                
+                if (result != null && result.hasErrorMsg()) {
+                    ComponentUtils.setStatusText(c, result.getErrorMsg());
+                    c.getCaret().setDot(c.getCaret().getDot());
+                    return null;
+                }
                 int[] blk = null; 
                 if (result != null){
                     blk = result.getFoundPositions();
@@ -635,7 +646,7 @@ public final class EditorFindSupport {
             while (true) {
                 //pos = doc.find(sf, startPos, back ? blockStartPos : blockEndPos);
                 final int off1 = startPos;
-                final int off2 = back ? blockStartPos : blockEndPos;
+                final int off2 = oppositeDir ? blockStartPos : blockEndPos;
                 currentResult = null;
                 try {
                     executor.submit(new Runnable() {
@@ -661,6 +672,10 @@ public final class EditorFindSupport {
                     executor.shutdown();
                     return null;
                 }
+                
+                if (currentResult.hasErrorMsg()) {
+                    return currentResult;
+                }
                 retFind = currentResult.getFoundPositions();
                 replaced = currentResult.getReplacedString();
                 if (retFind == null){
@@ -680,6 +695,7 @@ public final class EditorFindSupport {
 
                         //blockStartPos = startPos;
                         startPos = blockEndPos;
+                        blockEndPos = docLen;
                     } else {
                         //blockEndPos = startPos;
                         startPos = blockStartPos;
@@ -857,14 +873,13 @@ public final class EditorFindSupport {
 
                 int actualPos = wrapSearch ? 0 : c.getCaret().getDot();
 
-                int pos = (blockSearch && blockSearchStartOffset > -1) ? ( backSearch ? blockSearchEndOffset : blockSearchStartOffset) : (backSearch? 0 : actualPos); // actual position
-
+                int pos = (blockSearch && blockSearchStartOffset > -1) ?  blockSearchStartOffset : (backSearch? 0 : actualPos); // actual position
+                blockSearchEndOffset = getBlockEndOffset();
                 while (true) {
-                    blockSearchEndOffset = getBlockEndOffset();
                     FindReplaceResult result = findReplaceInBlock(replaceWithOriginal, c, pos,
                             (blockSearch && blockSearchStartOffset > -1) ? blockSearchStartOffset : startPosWholeSearch,
                             (blockSearch && blockSearchEndOffset > 0) ? blockSearchEndOffset : endPosWholeSearch,
-                            localProps, backSearch);
+                            localProps, false);
                     if (result == null){
                         break;
                     }
@@ -903,8 +918,14 @@ public final class EditorFindSupport {
                                 // Update position in original properties
                                 props.put(EditorFindSupport.FIND_BLOCK_SEARCH_START, blockSearchStartPos);
                             }
+                            blockSearchEndOffset = getBlockEndOffset();
                         }
                         pos = backSearch ? blk[0] : blk[0] + ((replaceWith != null) ? replaceWith.length() : 0);
+                        if (!wrapSearch && backSearch) {
+                            endPosWholeSearch = endPosWholeSearch < blk[0] ? endPosWholeSearch : blk[0];
+                            blockSearchEndOffset = blockSearchEndOffset < blk[0] ? blockSearchEndOffset : blk[0];
+                            pos = (blockSearch && blockSearchStartOffset > -1) ?  blockSearchStartOffset : 0;
+                        }
                         replacedCnt++;
                     }
                     // The following is lame attempt to break the loop: if
