@@ -64,6 +64,7 @@ import org.netbeans.modules.netserver.api.WebSocketServer;
 import org.netbeans.modules.web.browser.api.PageInspector;
 import org.netbeans.modules.web.browser.api.ResizeOption;
 import org.netbeans.modules.web.browser.api.ResizeOptions;
+import org.netbeans.modules.web.browser.api.WebBrowserFeatures;
 import org.netbeans.modules.web.browser.spi.ExternalModificationsSupport;
 import org.netbeans.modules.web.webkit.debugging.api.TransportStateException;
 import org.netbeans.modules.web.webkit.debugging.api.WebKitDebugging;
@@ -72,10 +73,10 @@ import org.netbeans.modules.web.webkit.debugging.spi.Response;
 import org.netbeans.modules.web.webkit.debugging.spi.ResponseCallback;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
-import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
+import org.openide.util.lookup.Lookups;
 import org.openide.util.lookup.ProxyLookup;
 
 
@@ -117,8 +118,7 @@ public final class ExternalBrowserPlugin {
             Thread shutdown = new Thread(){
                 @Override
                 public void run() {
-                    List<BrowserTabDescriptor> browserTabs = new ArrayList<BrowserTabDescriptor>(knownBrowserTabs);
-                    for (BrowserTabDescriptor tab : browserTabs) {
+                    for (BrowserTabDescriptor tab : knownBrowserTabs) {
                         tab.deinitialize();
                     }
                     server.stop();
@@ -219,8 +219,7 @@ public final class ExternalBrowserPlugin {
     }
 
     private void removeKey( SelectionKey key ) {
-        for(Iterator<BrowserTabDescriptor> iterator = knownBrowserTabs.iterator() ; iterator.hasNext() ; ) {
-            BrowserTabDescriptor browserTab = iterator.next();
+        for (BrowserTabDescriptor browserTab : knownBrowserTabs) {
             if (key.equals(browserTab.keyForFeature(FEATURE_ROS))) {
                 browserTab.deinitialize();
                 browserTab.browserImpl.wasClosed();
@@ -229,7 +228,7 @@ public final class ExternalBrowserPlugin {
             if (!browserTab.isAnyKeyRegistered()) {
                 // SelectionKey of the last feature (that was interested in this tab)
                 // was removed => we can forget this tab.
-                iterator.remove();
+                knownBrowserTabs.remove(browserTab);
             }
         }
     }
@@ -405,7 +404,7 @@ public final class ExternalBrowserPlugin {
          * @return version of NetBeans.
          */
         private String getNetBeansVersion() {
-            return "7.4"; // NOI18N
+            return "8.1"; // NOI18N
         }
 
         private void handleDebuggerDetached(Message message) {
@@ -470,13 +469,12 @@ public final class ExternalBrowserPlugin {
         }
         
         private boolean deinitializeTab(int tabId, boolean close) {
-            for(Iterator<BrowserTabDescriptor> iterator = knownBrowserTabs.iterator() ; iterator.hasNext() ; ) {
-                BrowserTabDescriptor browserTab = iterator.next();
+            for (BrowserTabDescriptor browserTab : knownBrowserTabs) {
                 if ( tabId == browserTab.tabID ) {
                     browserTab.deinitialize();
                     browserTab.disableReInitialization();
                     if (close) {
-                        iterator.remove();
+                        knownBrowserTabs.remove(browserTab);
                         browserTab.browserImpl.wasClosed();
                     }
                     return true;
@@ -539,7 +537,7 @@ public final class ExternalBrowserPlugin {
                 }
                 if (browserTab == null) {
                     // Tab not opened from the IDE => using a dummy ExtBrowserImpl
-                    ChromeBrowserImpl impl = new ChromeBrowserImpl(null, true) {
+                    ChromeBrowserImpl impl = new ChromeBrowserImpl(null, false) {
                         @Override
                         public void setURL(URL url) {
                             throw new UnsupportedOperationException();
@@ -549,20 +547,22 @@ public final class ExternalBrowserPlugin {
                         }
                     };
                     browserTab = new BrowserTabDescriptor(tabId, impl);
+                    impl.setBrowserTabDescriptor(browserTab);
+                    impl.initialize(new WebBrowserFeatures());
                     knownBrowserTabs.add(browserTab);
                 }
-                browserTab.registerKeyForFeature(PageInspector.MESSAGE_DISPATCHER_FEATURE_ID, key);
-                final Lookup context = browserTab.browserImpl.getLookup();
-                final Lookup projectContext = browserTab.browserImpl.getProjectContext();
-                RemoteScriptExecutor executor = context.lookup(RemoteScriptExecutor.class);
-                if (executor != null) {
-                    executor.activate();
-                }
+                final ChromeBrowserImpl browserImpl = browserTab.browserImpl;
+                final BrowserTabDescriptor tab = browserTab;
                 // Do not block WebSocket thread
                 RP.post(new Runnable() {
                     @Override
                     public void run() {
-                        inspector.inspectPage(new ProxyLookup(context, projectContext));
+                        if (!browserImpl.hasEnhancedMode()) {
+                            browserImpl.setTemporaryEnhancedMode(true);
+                        }
+                        tab.reEnableReInitialization();
+                        tab.init();
+                        inspector.inspectPage(new ProxyLookup(browserImpl.getLookup(), browserImpl.getProjectContext()));
                     }
                 });
             }
@@ -627,8 +627,7 @@ public final class ExternalBrowserPlugin {
             final String url = String.valueOf(resource.get("url"));
             final String type = String.valueOf(resource.get("type"));
             URL mainDocumentUrl = null;
-            for(Iterator<BrowserTabDescriptor> iterator = knownBrowserTabs.iterator() ; iterator.hasNext() ; ) {
-                BrowserTabDescriptor browserTab = iterator.next();
+            for (BrowserTabDescriptor browserTab : knownBrowserTabs) {
                 if (key.equals(browserTab.keyForFeature(FEATURE_ROS))) {
                     mainDocumentUrl = browserTab.browserImpl.getURL();
                 }
@@ -648,12 +647,14 @@ public final class ExternalBrowserPlugin {
         Map params = new HashMap();
         params.put( Message.TAB_ID, tabId );
         if (newURL != null) {
+            String url;
             try {
-                String u = reformatFileURL(newURL.toURI().toString());
-                params.put( "url", u ); // NOI18N
+                url = newURL.toURI().toASCIIString();
             } catch (URISyntaxException ex) {
-                Exceptions.printStackTrace(ex);
+                url = newURL.toExternalForm();
             }
+            url = reformatFileURL(url);
+            params.put("url", url); // NOI18N
         }
         Message msg = new Message( Message.MessageType.RELOAD, params);
         return msg.toStringValue();
@@ -715,7 +716,7 @@ public final class ExternalBrowserPlugin {
 
     }
 
-    private List<BrowserTabDescriptor> knownBrowserTabs = new ArrayList<BrowserTabDescriptor>();
+    private List<BrowserTabDescriptor> knownBrowserTabs = new CopyOnWriteArrayList<BrowserTabDescriptor>();
 
     /**
      * Descriptor of tab opened in the external browser.
@@ -857,7 +858,7 @@ public final class ExternalBrowserPlugin {
             }
 
             if (inspector != null && browserImpl.getBrowserFeatures().isPageInspectorEnabled()) {
-                inspector.inspectPage(new ProxyLookup(browserImpl.getLookup(), browserImpl.getProjectContext()));
+                inspector.inspectPage(new ProxyLookup(browserImpl.getLookup(), browserImpl.getProjectContext(), Lookups.fixed(browserImpl)));
             }
         }
 
@@ -896,6 +897,9 @@ public final class ExternalBrowserPlugin {
             }
             webkitDebugger.reset();
             transport.detach();
+            if (browserImpl.hasTemporaryEnhancedMode()) {
+                browserImpl.setTemporaryEnhancedMode(false);
+            }
         }
 
         /**
