@@ -50,6 +50,7 @@ import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Locale;
 import java.util.Map;
 import java.util.logging.Level;
@@ -87,6 +88,8 @@ import org.openide.util.Utilities;
  */
 public class ChromeManagerAccessor implements ExtensionManagerAccessor {
 
+    static final Logger LOGGER = Logger.getLogger(ChromeManagerAccessor.class.getName());
+
     private static final String NO_WEB_STORE_SWITCH=
             "netbeans.extbrowser.manual_chrome_plugin_install"; // NOI18N
 
@@ -104,12 +107,8 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
 
     static class ChromeExtensionManager extends AbstractBrowserExtensionManager {
 
-        private static final String LAST_USED = "\"last_used\":";               // NOI18N
-
         private static final String VERSION = "\"version\":";                   // NOI18N
 
-        private static final String STATE = "\"state\":";                       // NOI18N
-
         private static final String PLUGIN_PUBLIC_KEY =
             "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDgo89CrO8f/2srD2BGUP9+dG4I" +
             "kTC2D3gzEjXITaMaQgy8B4ObVpkA3bc27qc7HB9jhVj8P51aAETr89u+AvFgCeFt" +
@@ -128,6 +127,15 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
          */
         @Override
         public ExtensionManager.ExtensitionStatus isInstalled() {
+            // Allows to skip the detection of Chrome extension
+            String status = System.getProperty("netbeans.chrome.connector.status"); // NOI18N
+            if (status != null) {
+                try {
+                    return ExtensionManager.ExtensitionStatus.valueOf(status);
+                } catch (IllegalArgumentException iaex) {
+                    LOGGER.log(Level.INFO, iaex.getMessage(), iaex);
+                }
+            }
             while (true) {
                 ExtensionManager.ExtensitionStatus result = isInstalledImpl();
                 if (result == ExtensionManager.ExtensitionStatus.DISABLED) {
@@ -148,27 +156,34 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
 
         private ExtensionManager.ExtensitionStatus isInstalledImpl() {
             JSONObject preferences = findPreferences();
+            LOGGER.log(Level.FINE, "Chrome preferences: {0}", preferences);
             if (preferences == null) {
                 return ExtensionManager.ExtensitionStatus.MISSING;
             }
+            LOGGER.log(Level.FINE, "Chrome preferences -> extensions: {0}", preferences.get("extensions"));
             JSONObject extensions = (JSONObject)preferences.get("extensions");
             if (extensions == null) {
                 return ExtensionManager.ExtensitionStatus.MISSING;
             }
+            LOGGER.log(Level.FINE, "Chrome preferences -> extensions -> settings: {0}", extensions.get("settings"));
             JSONObject settings = (JSONObject)extensions.get("settings");
             if (settings == null) {
                 return ExtensionManager.ExtensitionStatus.MISSING;
             }
             for (Object item : settings.entrySet()) {
                 Map.Entry e = (Map.Entry)item;
-                JSONObject extension = (JSONObject)e.getValue();
-                if (extension != null) {
+                Object value = e.getValue();
+                LOGGER.log(Level.FINE, "Chrome preferences - extensions -> settings -> value/extension: {0}", value);
+                // #251250
+                if (value instanceof JSONObject) {
+                    JSONObject extension = (JSONObject) value;
                     String path = (String)extension.get("path");
-                    if (path != null && (path.indexOf("/extbrowser.chrome/plugins/chrome") != -1
-                            || path.indexOf("\\extbrowser.chrome\\plugins\\chrome") != -1))
+                    if (path != null && (path.contains("/extbrowser.chrome/plugins/chrome")
+                            || path.contains("\\extbrowser.chrome\\plugins\\chrome")))
                     {
                         return ExtensionManager.ExtensitionStatus.INSTALLED;
                     }
+                    LOGGER.log(Level.FINE, "Chrome preferences - extensions -> settings -> value/extension -> manifest: {0}", extension.get("manifest"));
                     JSONObject manifest = (JSONObject)extension.get("manifest");
                     if (manifest != null && PLUGIN_PUBLIC_KEY.equals((String)manifest.get("key"))) {
                         String version = (String)manifest.get("version");
@@ -188,6 +203,7 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
 
         private JSONObject findPreferences() {
             File defaultProfile = getDefaultProfile();
+            LOGGER.log(Level.FINE, "Chrome default profile: {0}", defaultProfile);
             if (defaultProfile == null) {
                 return null;
             }
@@ -200,6 +216,7 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
                     JSONObject preferences = Utils.readFile(prefs[0]);
                     if (preferences != null
                             && preferences.get("extensions") != null) { // NOI18N
+                        LOGGER.log(Level.FINE, "Chrome preferences file: {0}", prefs[0]);
                         return preferences;
                     }
                 }
@@ -257,6 +274,11 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
         protected String getCurrentPluginVersion(){
             File extensionFile = InstalledFileLocator.getDefault().locate(
                     EXTENSION_PATH,PLUGIN_MODULE_NAME, false);
+            if (extensionFile == null) {
+                Logger.getLogger(ChromeExtensionManager.class.getCanonicalName()).
+                    info("Could not find chrome extension in installation directory!"); // NOI18N
+                return null;
+            }
             String content = Utils.readZip( extensionFile, "manifest.json");    // NOI18N
             int index = content.indexOf(VERSION);
             if ( index == -1){
@@ -278,6 +300,7 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
 
         private File getDefaultProfile() {
             String[] userData = getUserData();
+            LOGGER.log(Level.FINE, "Chrome user data: {0}", Arrays.toString(userData));
             if ( userData != null ){
                 for (String dataDir : userData) {
                     File dir = new File(dataDir);
@@ -293,7 +316,9 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
                                 JSONObject profile = (JSONObject)localStateContent.get("profile");
                                 if (profile != null) {
                                     String prof = (String)profile.get("last_used");
-                                    if (prof != null) {
+                                    if (prof == null) {
+                                        guessDefault = true;
+                                    } else {
                                         prof = Utils.unquote(prof);
                                         File[] listFiles = dir.listFiles( new FileFinder(
                                                 prof , true));
@@ -365,7 +390,7 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
                 ExtensionManager.ExtensitionStatus currentStatus,
                 File extensionFile )
         {
-            String path = null;
+            String path;
             try {
                 path = extensionFile.getCanonicalPath();
             }
@@ -399,9 +424,7 @@ public class ChromeManagerAccessor implements ExtensionManagerAccessor {
                         return true;
                     }
                     ExtensitionStatus status = isInstalled();
-                    if ( status!= ExtensitionStatus.INSTALLED){
-                        continue;
-                    } else {
+                    if (status == ExtensitionStatus.INSTALLED){
                         return true;
                     }
                 } else {
