@@ -43,6 +43,9 @@
 package org.netbeans.api.extexecution;
 
 import java.nio.charset.Charset;
+import java.util.concurrent.Future;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.annotations.common.CheckReturnValue;
 import org.netbeans.api.annotations.common.NonNull;
@@ -53,7 +56,7 @@ import org.netbeans.spi.extexecution.open.OptionOpenHandler;
 import org.openide.windows.InputOutput;
 
 /**
- * Descriptor for the execution environment. Describes the runtime attributes
+ * Descriptor for the execution service. Describes the runtime attributes
  * of the {@link ExecutionService}.
  * <p>
  * <i>Thread safety</i> of this class depends on type of objects passed to its
@@ -66,6 +69,8 @@ import org.openide.windows.InputOutput;
  */
 public final class ExecutionDescriptor {
 
+    private static final Logger LOGGER = Logger.getLogger(ExecutionDescriptor.class.getName());
+
     // TODO provide constants for common descriptors (are there any?)
 
     private final Runnable preExecution;
@@ -95,13 +100,19 @@ public final class ExecutionDescriptor {
     private final LineConvertorFactory errConvertorFactory;
 
     private final InputProcessorFactory outProcessorFactory;
+    
+    private final InputProcessorFactory2 outProcessorFactory2;
 
     private final InputProcessorFactory errProcessorFactory;
+    
+    private final InputProcessorFactory2 errProcessorFactory2;
 
     private final InputOutput inputOutput;
 
     private final RerunCondition rerunCondition;
 
+    private final RerunCallback rerunCallback;
+
     private final String optionsPath;
 
     private final Charset charset;
@@ -128,9 +139,12 @@ public final class ExecutionDescriptor {
         this.outConvertorFactory = data.outConvertorFactory;
         this.errConvertorFactory = data.errConvertorFactory;
         this.outProcessorFactory = data.outProcessorFactory;
+        this.outProcessorFactory2 = data.outProcessorFactory2;
         this.errProcessorFactory = data.errProcessorFactory;
+        this.errProcessorFactory2 = data.errProcessorFactory2;
         this.inputOutput = data.inputOutput;
         this.rerunCondition = data.rerunCondition;
+        this.rerunCallback = data.rerunCallback;
         this.optionsPath = data.optionsPath;
         this.charset = data.charset;
         this.noReset = data.noReset;
@@ -388,9 +402,46 @@ public final class ExecutionDescriptor {
      * <p>
      * Note that {@link ExecutionService} automatically uses
      * the printing processor created by
-     * {@link org.netbeans.api.extexecution.input.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * {@link org.netbeans.api.extexecution.print.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
      * or
-     * {@link org.netbeans.api.extexecution.input.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * {@link org.netbeans.api.extexecution.print.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * (in case {@link #outLineBased(boolean)} is configured to <code>true</code>)
+     * if there is no configured factory.
+     * <p>
+     * The default (not configured) value is <code>null</code>.
+     * <p>
+     * All other properties of the returned descriptor are inherited from
+     * <code>this</code>.
+     *
+     * @param outProcessorFactory factory for standard output processor,
+     *             <code>null</code> allowed
+     * @return new descriptor with configured factory for additional
+     *             processor to use for standard output
+     * @deprecated use {@link #outProcessorFactory(org.netbeans.api.extexecution.ExecutionDescriptor.InputProcessorFactory2)}
+     */
+    @NonNull
+    @CheckReturnValue
+    public ExecutionDescriptor outProcessorFactory(@NullAllowed InputProcessorFactory outProcessorFactory) {
+        DescriptorData data = new DescriptorData(this);
+        return new ExecutionDescriptor(data.outProcessorFactory(outProcessorFactory));
+    }
+
+    InputProcessorFactory getOutProcessorFactory() {
+        return outProcessorFactory;
+    }
+    
+    /**
+     * Returns a descriptor with configured factory for standard output
+     * processor. The factory is used by {@link ExecutionService} to create
+     * additional processor for standard output. <i>The configured value will
+     * be ignored if you previously configured processor via deprecated
+     * {@link #outProcessorFactory(org.netbeans.api.extexecution.ExecutionDescriptor.InputProcessorFactory)}.</i>
+     * <p>
+     * Note that {@link ExecutionService} automatically uses
+     * the printing processor created by
+     * {@link org.netbeans.api.extexecution.print.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * or
+     * {@link org.netbeans.api.extexecution.print.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
      * (in case {@link #outLineBased(boolean)} is configured to <code>true</code>)
      * if there is no configured factory.
      * <p>
@@ -406,13 +457,16 @@ public final class ExecutionDescriptor {
      */
     @NonNull
     @CheckReturnValue
-    public ExecutionDescriptor outProcessorFactory(@NullAllowed InputProcessorFactory outProcessorFactory) {
+    public ExecutionDescriptor outProcessorFactory(@NullAllowed InputProcessorFactory2 outProcessorFactory) {
+        if (this.outProcessorFactory != null) {
+            LOGGER.log(Level.WARNING, "The factory will be ignored as legacy InputProcessorFactory is already defined");
+        }
         DescriptorData data = new DescriptorData(this);
         return new ExecutionDescriptor(data.outProcessorFactory(outProcessorFactory));
     }
 
-    InputProcessorFactory getOutProcessorFactory() {
-        return outProcessorFactory;
+    InputProcessorFactory2 getOutProcessorFactory2() {
+        return outProcessorFactory2;
     }
 
     /**
@@ -422,9 +476,46 @@ public final class ExecutionDescriptor {
      * <p>
      * Note that {@link ExecutionService} automatically uses
      * the printing processor created by
-     * {@link org.netbeans.api.extexecution.input.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * {@link org.netbeans.api.extexecution.print.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
      * or
-     * {@link org.netbeans.api.extexecution.input.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * {@link org.netbeans.api.extexecution.print.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * (in case {@link #errLineBased(boolean)} is configured to <code>true</code>)
+     * if there is no configured factory.
+     * <p>
+     * The default (not configured) value is <code>null</code>.
+     * <p>
+     * All other properties of the returned descriptor are inherited from
+     * <code>this</code>.
+     *
+     * @param errProcessorFactory factory for standard error output processor,
+     *             <code>null</code> allowed
+     * @return new descriptor with configured factory for additional
+     *             processor to use for standard error output
+     * @deprecated use {@link #errProcessorFactory(org.netbeans.api.extexecution.ExecutionDescriptor.InputProcessorFactory2)}
+     */
+    @NonNull
+    @CheckReturnValue
+    public ExecutionDescriptor errProcessorFactory(@NullAllowed InputProcessorFactory errProcessorFactory) {
+        DescriptorData data = new DescriptorData(this);
+        return new ExecutionDescriptor(data.errProcessorFactory(errProcessorFactory));
+    }
+
+    InputProcessorFactory getErrProcessorFactory() {
+        return errProcessorFactory;
+    }
+    
+    /**
+     * Returns a descriptor with configured factory for standard error output
+     * processor. The factory is used by {@link ExecutionService} to create
+     * additional processor for standard error output. <i>The configured value will
+     * be ignored if you previously configured processor via deprecated
+     * {@link #errProcessorFactory(org.netbeans.api.extexecution.ExecutionDescriptor.InputProcessorFactory)}.</i>
+     * <p>
+     * Note that {@link ExecutionService} automatically uses
+     * the printing processor created by
+     * {@link org.netbeans.api.extexecution.print.InputProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
+     * or
+     * {@link org.netbeans.api.extexecution.print.LineProcessors#printing(org.openide.windows.OutputWriter, org.netbeans.api.extexecution.print.LineConvertor, boolean)}
      * (in case {@link #errLineBased(boolean)} is configured to <code>true</code>)
      * if there is no configured factory.
      * <p>
@@ -440,13 +531,16 @@ public final class ExecutionDescriptor {
      */
     @NonNull
     @CheckReturnValue
-    public ExecutionDescriptor errProcessorFactory(@NullAllowed InputProcessorFactory errProcessorFactory) {
+    public ExecutionDescriptor errProcessorFactory(@NullAllowed InputProcessorFactory2 errProcessorFactory) {
+        if (this.errProcessorFactory != null) {
+            LOGGER.log(Level.WARNING, "The factory will be ignored as legacy InputProcessorFactory is already defined");
+        }
         DescriptorData data = new DescriptorData(this);
         return new ExecutionDescriptor(data.errProcessorFactory(errProcessorFactory));
     }
 
-    InputProcessorFactory getErrProcessorFactory() {
-        return errProcessorFactory;
+    InputProcessorFactory2 getErrProcessorFactory2() {
+        return errProcessorFactory2;
     }
 
     /**
@@ -571,6 +665,7 @@ public final class ExecutionDescriptor {
      *
      * @param rerunCondition rerun condition, <code>null</code> allowed
      * @return new descriptor with configured rerun condition
+     * @see #rerunCallback(org.netbeans.api.extexecution.ExecutionDescriptor.RerunCallback)
      */
     @NonNull
     @CheckReturnValue
@@ -583,6 +678,31 @@ public final class ExecutionDescriptor {
         return rerunCondition;
     }
 
+    /**
+     * Returns a descriptor with configured rerun callback. The callback
+     * is invoked when the execution is triggered by the rerun action.
+     * <p>
+     * The default (not configured) value is <code>null</code>.
+     * <p>
+     * All other properties of the returned descriptor are inherited from
+     * <code>this</code>.
+     *
+     * @param rerunCallback rerun callback, <code>null</code> allowed
+     * @return new descriptor with configured rerun callback
+     * @see #rerunCondition(org.netbeans.api.extexecution.ExecutionDescriptor.RerunCondition) 
+     * @since 1.46
+     */
+    @NonNull
+    @CheckReturnValue
+    public ExecutionDescriptor rerunCallback(@NullAllowed ExecutionDescriptor.RerunCallback rerunCallback) {
+        DescriptorData data = new DescriptorData(this);
+        return new ExecutionDescriptor(data.rerunCallback(rerunCallback));
+    }
+
+    RerunCallback getRerunCallback() {
+        return rerunCallback;
+    }
+
     /**
      * Returns a descriptor with configured options path. If configured
      * value is not <code>null</code> the {@link ExecutionService} will
@@ -671,8 +791,25 @@ public final class ExecutionDescriptor {
 
     }
 
+    /**
+     * Provides a callback to be invoked when rerun action is invoked.
+     *
+     * @since 1.46
+     */
+    public interface RerunCallback {
+
+        /**
+         * Called when rerun action is invoked.
+         *
+         * @param task the task created by the rerun action
+         */
+        void performed(Future<Integer> task);
+
+    }
+
     /**
      * Factory creating the input processor.
+     * @deprecated use {@link InputProcessorFactory2}
      */
     public interface InputProcessorFactory {
 
@@ -687,9 +824,26 @@ public final class ExecutionDescriptor {
         InputProcessor newInputProcessor(@NonNull InputProcessor defaultProcessor);
 
     }
+    
+    /**
+     * Factory creating the input processor.
+     */
+    public interface InputProcessorFactory2 {
+
+        /**
+         * Creates and returns new input processor.
+         *
+         * @param defaultProcessor default processor created by
+         *             infrastructure that is printing chars to the output window
+         * @return new input processor
+         */
+        @NonNull
+        org.netbeans.api.extexecution.base.input.InputProcessor newInputProcessor(@NonNull org.netbeans.api.extexecution.base.input.InputProcessor defaultProcessor);
+
+    }
 
     /**
-     * Factory creating the line covertor.
+     * Factory creating the line convertor.
      */
     public interface LineConvertorFactory {
 
@@ -732,13 +886,19 @@ public final class ExecutionDescriptor {
         private LineConvertorFactory errConvertorFactory;
 
         private InputProcessorFactory outProcessorFactory;
+        
+        private InputProcessorFactory2 outProcessorFactory2;
 
         private InputProcessorFactory errProcessorFactory;
+        
+        private InputProcessorFactory2 errProcessorFactory2;
 
         private InputOutput inputOutput;
 
         private ExecutionDescriptor.RerunCondition rerunCondition;
 
+        private ExecutionDescriptor.RerunCallback rerunCallback;
+
         private String optionsPath;
 
         private Charset charset;
@@ -764,6 +924,7 @@ public final class ExecutionDescriptor {
             this.errProcessorFactory = descriptor.errProcessorFactory;
             this.inputOutput = descriptor.inputOutput;
             this.rerunCondition = descriptor.rerunCondition;
+            this.rerunCallback = descriptor.rerunCallback;
             this.optionsPath = descriptor.optionsPath;
             this.charset = descriptor.charset;
             this.noReset = descriptor.noReset;
@@ -823,11 +984,21 @@ public final class ExecutionDescriptor {
             this.outProcessorFactory = outProcessorFactory;
             return this;
         }
+        
+        public DescriptorData outProcessorFactory(InputProcessorFactory2 outProcessorFactory) {
+            this.outProcessorFactory2 = outProcessorFactory;
+            return this;
+        }
 
         public DescriptorData errProcessorFactory(InputProcessorFactory errProcessorFactory) {
             this.errProcessorFactory = errProcessorFactory;
             return this;
         }
+        
+        public DescriptorData errProcessorFactory(InputProcessorFactory2 errProcessorFactory) {
+            this.errProcessorFactory2 = errProcessorFactory;
+            return this;
+        }
 
         public DescriptorData outConvertorFactory(LineConvertorFactory convertorFactory) {
             this.outConvertorFactory = convertorFactory;
@@ -854,6 +1025,11 @@ public final class ExecutionDescriptor {
             return this;
         }
 
+        public DescriptorData rerunCallback(ExecutionDescriptor.RerunCallback rerunCallback) {
+            this.rerunCallback = rerunCallback;
+            return this;
+        }
+
         public DescriptorData optionsPath(String optionsPath) {
             this.optionsPath = optionsPath;
             return this;
