@@ -56,6 +56,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.*;
 import javax.swing.border.TitledBorder;
+import javax.swing.event.ChangeListener;
 import javax.swing.event.ListSelectionListener;
 import javax.swing.event.TableModelListener;
 import javax.swing.event.TreeModelListener;
@@ -534,6 +535,11 @@ public class FormUtils
         if (o.getClass() == Font.class || o.getClass() == FontUIResource.class) {
             return o;
         }
+
+        if (o instanceof ImageIcon) {
+            return o; // no need to clone images
+        }
+
         // Issue 49973 & 169933
         if (o.getClass() == TitledBorder.class) {
             TitledBorder border = (TitledBorder)o;
@@ -624,8 +630,21 @@ public class FormUtils
                     tableModel.addTableModelListener(listener);
                 }
             }
+        } // note TableModelEditor.NbTableModel takes care of its serialization
+        if (o instanceof AbstractSpinnerModel) {
+            AbstractSpinnerModel spinnerModel = (AbstractSpinnerModel) o;
+            ChangeListener[] listeners = spinnerModel.getChangeListeners();
+            for (ChangeListener l : listeners) {
+                spinnerModel.removeChangeListener(l);
+            }
+            try {
+                return cloneBeanInstance(o, null, formModel);
+            } finally {
+                for (ChangeListener l : listeners) {
+                    spinnerModel.addChangeListener(l);
+                }
+            }
         }
-        // note TableModelEditor.NbTableModel takes care of its serialization
 
         if (o instanceof Serializable) {
             return cloneBeanInstance(o, null, formModel);
@@ -1011,6 +1030,43 @@ public class FormUtils
         return method;
     }
 
+    /**
+     * @param metacomp
+     * @return the type parameters value set for given component, without enclosing < >
+     */
+    public static String getTypeParameters(RADComponent metacomp) {
+        if (metacomp != null) {
+            String typeParams = (String) metacomp.getAuxValue(JavaCodeGenerator.AUX_TYPE_PARAMETERS);
+            if (typeParams != null && typeParams.startsWith("<") && typeParams.endsWith(">")) { // NOI18N
+                return typeParams.substring(1, typeParams.length()-1);
+            }
+            return typeParams;
+        }
+        return null;
+    }
+
+    /**
+     * @param property
+     * @param needType
+     * @return the type parameters code to be used for generating a property code that uses the same type parameters as the component class
+     */
+    public static String getTypeParametersCode(RADProperty property, boolean needType) {
+        if (property != null) {
+            RADComponent metacomp = property.getRADComponent();
+            String typeParams = (String) metacomp.getAuxValue(JavaCodeGenerator.AUX_TYPE_PARAMETERS);
+            if (!needType && typeParams != null && typeParams.length() > 0) {
+                FormDataObject formDO = FormEditor.getFormDataObject(metacomp.getFormModel());
+                if (formDO == null || ClassPathUtils.isJava7ProjectPlatform(formDO.getPrimaryFile())) {
+                    return "<>"; // NOI18N
+                }
+            }
+            if (typeParams != null) {
+                return typeParams;
+            }
+        }
+        return "";
+    }
+
     public static void setupEditorPane(javax.swing.JEditorPane editor, FileObject srcFile, int ccPosition) {
         FormServices services = Lookup.getDefault().lookup(FormServices.class);
         services.setupCodeEditorPane(editor, srcFile, ccPosition);
