@@ -126,7 +126,7 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
     /**
      * Caret of the target text component.
      */
-    private final Caret caret;
+    private Caret caret;
 
     /**
      * Caret batch timer launched on receiving
@@ -266,7 +266,6 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
         this.editorUI = Utilities.getEditorUI(target);
         this.foldHierarchy = FoldHierarchy.get(editorUI.getComponent());
         this.doc = editorUI.getDocument();
-        this.caret = textComponent.getCaret();
         setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
         elementAnnotationsSubstitute = "";                              //NOI18N
         if (textComponent instanceof JEditorPane) {
@@ -419,7 +418,11 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
 //        }
                 
         // lazy listener registration
-        caret.addChangeListener(this);
+        caret = textComponent.getCaret();
+        if (caret != null) {
+            caret.addChangeListener(this);
+        }
+        textComponent.addPropertyChangeListener(this);
         this.caretTimer = new Timer(500, this);
         caretTimer.setRepeats(false);
 
@@ -1032,6 +1035,10 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
      * @return the preferred width of this component
      */
     private int getBarWidth() {
+        JTextComponent component = editorUI.getComponent();
+        if (component == null) {
+            return 0;
+        }
         String longestString = "";  // NOI18N
         if (elementAnnotations == null) {
             longestString = elementAnnotationsSubstitute;
@@ -1048,7 +1055,7 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
             }
         }
         char[] data = longestString.toCharArray();
-        int w = getGraphics().getFontMetrics(editorUI.getComponent().getFont()).charsWidth(data, 0,  data.length);
+        int w = getGraphics().getFontMetrics(component.getFont()).charsWidth(data, 0,  data.length);
         return w + 4 + (isKenai() ? 18 : 0);
     }
 
@@ -1077,8 +1084,11 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
     private void release() {
         editorUI.removePropertyChangeListener(this);
         textComponent.removeComponentListener(this);
+        textComponent.removePropertyChangeListener(this);
         doc.removeDocumentListener(this);
-        caret.removeChangeListener(this);
+        if (caret != null) {
+            caret.removeChangeListener(this);
+        }
         if (caretTimer != null) {
             caretTimer.removeActionListener(this);
         }
@@ -1328,6 +1338,18 @@ final class AnnotationBar extends JComponent implements Accessible, PropertyChan
     public void propertyChange(PropertyChangeEvent evt) {
         if (evt == null) return;
         String id = evt.getPropertyName();
+        if (evt.getSource() == textComponent) {
+            if ("caret".equals(id)) {
+                if (caret != null) {
+                    caret.removeChangeListener(this);
+                }
+                caret = textComponent.getCaret();
+                if (caret != null) {
+                    caret.addChangeListener(this);
+                }
+            }
+            return;
+        }
         if (EditorUI.COMPONENT_PROPERTY.equals(id)) {  // NOI18N
             if (evt.getNewValue() == null){
                 // component deinstalled, lets uninstall all isteners
