@@ -83,6 +83,7 @@ import org.netbeans.modules.git.ui.actions.GitAction;
 import org.netbeans.modules.git.ui.branch.CherryPickAction;
 import org.netbeans.modules.git.ui.repository.RepositoryInfo;
 import org.netbeans.modules.git.utils.GitUtils;
+import org.netbeans.modules.git.utils.JGitUtils;
 import org.netbeans.modules.versioning.hooks.GitHook;
 import org.netbeans.modules.versioning.hooks.GitHookContext;
 import org.netbeans.modules.versioning.hooks.GitHookContext.LogEntry;
@@ -129,6 +130,9 @@ public class CommitAction extends SingleRepositoryAction {
     }
 
     @Override
+    @NbBundle.Messages({
+        "# {0} - counted context", "# {1} - current branch", "CTL_CommitPanel.title={0} - {1}"
+    })
     protected void performAction (final File repository, final File[] roots, final VCSContext context) {
         RepositoryInfo info = RepositoryInfo.getInstance(repository);
         info.refresh();
@@ -138,6 +142,7 @@ public class CommitAction extends SingleRepositoryAction {
         final GitRepositoryState state = info.getRepositoryState();
         final GitUser user = identifyUser(repository);
         final String mergeCommitMessage = getMergeCommitMessage(repository, state);
+        final String title = Bundle.CTL_CommitPanel_title(Utils.getContextDisplayName(context), info.getActiveBranch().getName());
         EventQueue.invokeLater(new Runnable() {
             @Override
             public void run() {
@@ -146,7 +151,7 @@ public class CommitAction extends SingleRepositoryAction {
                         ? GitCommitPanelMerged.create(roots, repository, user, mergeCommitMessage)
                         : GitCommitPanel.create(roots, repository, user, isFromGitView(context));
                 VCSCommitTable<GitLocalFileNode> table = panel.getCommitTable();
-                boolean ok = panel.open(context, new HelpCtx("org.netbeans.modules.git.ui.commit.CommitAction")); //NOI18N
+                boolean ok = panel.open(context, new HelpCtx("org.netbeans.modules.git.ui.commit.CommitAction"), title); //NOI18N
 
                 if (ok) {
                     final List<GitLocalFileNode> commitFiles = table.getCommitFiles();
@@ -354,6 +359,9 @@ public class CommitAction extends SingleRepositoryAction {
 
         private GitRevisionInfo commit (Collection<File> commitCandidates, String message, GitUser author, GitUser commiter, boolean amend) throws GitException {
             try {
+                if (!JGitUtils.isUserSetup(getRepositoryRoot()) && askToPersistUser(author)) {
+                    JGitUtils.persistUser(getRepositoryRoot(), author);
+                }
                 GitRevisionInfo info = getClient().commit(
                         state == GitRepositoryState.MERGING_RESOLVED || state == GitRepositoryState.CHERRY_PICKING_RESOLVED
                                 ? new File[0] : commitCandidates.toArray(new File[commitCandidates.size()]),
@@ -370,6 +378,21 @@ public class CommitAction extends SingleRepositoryAction {
             GitUtils.printInfo(sb, info);
             getLogger().outputLine(sb.toString());
         }
+
+        @NbBundle.Messages({
+            "LBL_CommitAction.askToPersistAuthor.title=Set Repository User",
+            "# {0} - author",
+            "MSG_CommitAction.askToPersistAuthor=Repository does not have fully specified user yet.\n\n"
+                    + "Do you want to set {0} as the default author?"
+        })
+        private boolean askToPersistUser (GitUser author) {
+            return DialogDisplayer.getDefault().notify(new NotifyDescriptor.Confirmation(
+                    Bundle.MSG_CommitAction_askToPersistAuthor(author.toString()),
+                    Bundle.LBL_CommitAction_askToPersistAuthor_title(),
+                    NotifyDescriptor.YES_NO_OPTION,
+                    NotifyDescriptor.QUESTION_MESSAGE
+            )) == NotifyDescriptor.YES_OPTION;
+        }
     }    
 
     private static void refreshFS (final Collection<File> filesToRefresh) {
