@@ -99,6 +99,8 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
 
     private final File[] files;
     private final Set<File> toResolve;
+    private String newLineString;
+    private static final String SYSTEM_LINE_SEPARATOR = System.getProperty("line.separator");
 
     public ResolveConflictsExecutor(File[] files) {
         super();
@@ -152,6 +154,8 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         
         File f3 = new File(folder, TMP_PREFIX + "result-" + file.getName()); //NOI18N
         f3.deleteOnExit();
+        
+        newLineString = Utils.getLineEnding(fo, lock);
 
         Charset encoding = FileEncodingQuery.getEncoding(fo);
         final Difference[] diffs = copyParts(true, file, f1, true, encoding);
@@ -186,7 +190,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         final StreamSource result = new MergeResultWriterInfo(f1, f2, f3, file, mimeType,
                                                               originalLeftFileRevision,
                                                               originalRightFileRevision,
-                                                              fo, lock, encoding);
+                                                              fo, lock, encoding, newLineString);
         EventQueue.invokeLater(new Runnable() {
             @Override
             public void run() {
@@ -223,7 +227,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
             }
             return sb.toString();
         } catch (GitException ex) {
-            LOG.log(Level.INFO, null, ex);
+            LOG.log(Level.FINE, null, ex);
             return commit;
         }
     }
@@ -343,7 +347,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
                     }
                     if (!leftPart) {
                         w.write(lineText);
-                        w.newLine();
+                        w.write(newLineString);
                     }
                     isChangeRight = !isChangeRight;
                     continue;
@@ -362,12 +366,12 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
                         continue;
                     }
                 } else if (line.endsWith(CHANGE_DELIMETER) && !line.endsWith(CHANGE_DELIMETER + CHANGE_DELIMETER.charAt(0))) {
-                    String lineText = line.substring(0, line.length() - CHANGE_DELIMETER.length()) + "\n"; // NOI18N
+                    String lineText = line.substring(0, line.length() - CHANGE_DELIMETER.length()) + newLineString; // NOI18N
                     if (isChangeLeft) {
                         text1.append(lineText);
                         if (leftPart) {
                             w.write(lineText);
-                            w.newLine();
+                            w.write(newLineString);
                         }
                         isChangeLeft = false;
                         isChangeRight = true;
@@ -377,7 +381,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
                         text2.append(lineText);
                         if (!leftPart) {
                             w.write(lineText);
-                            w.newLine();
+                            w.write(newLineString);
                         }
                         isChangeRight = false;
                         isChangeLeft = true;
@@ -388,10 +392,10 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
                 }
                 if (!isChangeLeft && !isChangeRight || leftPart == isChangeLeft) {
                     w.write(line);
-                    w.newLine();
+                    w.write(newLineString);
                 }
-                if (isChangeLeft) text1.append(line).append("\n"); // NOI18N
-                if (isChangeRight) text2.append(line).append("\n"); // NOI18N
+                if (isChangeLeft) text1.append(line).append(newLineString); // NOI18N
+                if (isChangeRight) text2.append(line).append(newLineString); // NOI18N
                 if (generateDiffs) {
                     if (isChangeLeft) i++;
                     else if (isChangeRight) j++;
@@ -433,7 +437,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
                 if (desc != null) {
                     boolean remove = desc.getType() == Type.BOTH_DELETED;
                     if (desc.getType() == Type.DELETED_BY_THEM || desc.getType() == Type.DELETED_BY_US) {
-                        ResolveTreeConflictPanel panel = new ResolveTreeConflictPanel(e.getKey(), desc.getType());
+                        ResolveTreeConflictPanel panel = new ResolveTreeConflictPanel(e.getKey(), e.getValue().getRelativePath(), desc.getType());
                         final JButton resolveButton = new JButton();
                         Mnemonics.setLocalizedText(resolveButton, NbBundle.getMessage(ResolveConflictsExecutor.class, "LBL_TreeConflict_ResolveButton.title")); //NOI18N
                         DialogDescriptor dd = new DialogDescriptor(panel, NbBundle.getMessage(ResolveConflictsExecutor.class, "LBL_TreeConflict.title"), //NOI18N
@@ -490,11 +494,13 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         private FileObject fo;
         private FileLock lock;
         private Charset encoding;
+        private final String newLineString;
         
         public MergeResultWriterInfo(File tempf1, File tempf2, File tempf3,
                                      File outputFile, String mimeType,
                                      String leftFileRevision, String rightFileRevision,
-                                     FileObject fo, FileLock lock, Charset encoding) {
+                                     FileObject fo, FileLock lock, Charset encoding,
+                                     String newLineString) {
             this.tempf1 = tempf1;
             this.tempf2 = tempf2;
             this.tempf3 = tempf3;
@@ -504,6 +510,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
             this.rightFileRevision = rightFileRevision;
             this.fo = fo;
             this.lock = lock;
+            this.newLineString = newLineString;
             if (encoding == null) {
                 encoding = FileEncodingQuery.getEncoding(FileUtil.toFileObject(tempf1));
             }
@@ -540,16 +547,16 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         public Writer createWriter(Difference[] conflicts) throws IOException {
             Writer w;
             if (fo != null) {
-                w = new OutputStreamWriter(fo.getOutputStream(lock), encoding);
+                w = new LineEndingFilterWriter(new OutputStreamWriter(fo.getOutputStream(lock), encoding), newLineString);
             } else {
-                w = new OutputStreamWriter(new FileOutputStream(outputFile), encoding);
+                w = new LineEndingFilterWriter(new OutputStreamWriter(new FileOutputStream(outputFile), encoding), newLineString);
             }
             if (conflicts == null || conflicts.length == 0) {
                 fileToRepairEntriesOf = outputFile;
                 return w;
             } else {
                 return new MergeConflictFileWriter(w, fo, conflicts,
-                                                   leftFileRevision, rightFileRevision);
+                                                   leftFileRevision, rightFileRevision, newLineString);
             }
         }
         
@@ -574,7 +581,7 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         }
 
         private void repairEntries (File file) {
-            SystemAction.get(MarkResolvedAction.class).performAction(VCSContext.forNodes(new AbstractNode[] { new AbstractNode(Children.LEAF, Lookups.fixed(file)) }));
+            SystemAction.get(MarkResolvedAction.class).performAction(GitUtils.getContextForFile(file));
         }
     }
     
@@ -586,14 +593,16 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         private String leftName;
         private String rightName;
         private FileObject fo;
+        private final String newLineString;
         
         public MergeConflictFileWriter(Writer delegate, FileObject fo,
                                        Difference[] conflicts, String leftName,
-                                       String rightName) throws IOException {
+                                       String rightName, String newLineString) throws IOException {
             super(delegate);
             this.conflicts = conflicts;
             this.leftName = leftName;
             this.rightName = rightName;
+            this.newLineString = newLineString;
             this.lineNumber = 1;
             this.currentConflict = 0;
             if (lineNumber == conflicts[currentConflict].getFirstStart()) {
@@ -605,8 +614,11 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         
         @Override
         public void write(String str) throws IOException {
+            if (!SYSTEM_LINE_SEPARATOR.equals(newLineString)) {
+                str = str.replaceAll(SYSTEM_LINE_SEPARATOR, newLineString);
+            }
             super.write(str);
-            lineNumber += numChars('\n', str);
+            lineNumber += numChars(newLineString, str);
             if (currentConflict < conflicts.length && lineNumber >= conflicts[currentConflict].getFirstStart()) {
                 writeConflict(conflicts[currentConflict]);
                 currentConflict++;
@@ -614,26 +626,42 @@ public class ResolveConflictsExecutor extends GitProgressSupport {
         }
         
         private void writeConflict(Difference conflict) throws IOException {
-            super.write(CHANGE_LEFT + leftName + "\n"); // NOI18N
+            super.write(CHANGE_LEFT + leftName + newLineString); // NOI18N
             super.write(conflict.getFirstText());
-            super.write(CHANGE_DELIMETER + "\n"); // NOI18N
+            super.write(CHANGE_DELIMETER + newLineString); // NOI18N
             super.write(conflict.getSecondText());
-            super.write(CHANGE_RIGHT + rightName + "\n"); // NOI18N
+            super.write(CHANGE_RIGHT + rightName + newLineString); // NOI18N
         }
         
-        private static int numChars(char c, String str) {
+        private static int numChars(String s, String str) {
             int n = 0;
-            for (int pos = str.indexOf(c); pos >= 0 && pos < str.length(); pos = str.indexOf(c, pos + 1)) {
+            for (int pos = str.indexOf(s); pos >= 0 && pos < str.length(); pos = str.indexOf(s, pos + 1)) {
                 n++;
             }
             return n;
         }
         
-        @Override
         public void close() throws IOException {
             super.close();
             if (fo != null) fo.refresh(true);
         }
     }
+
+    private static class LineEndingFilterWriter extends FilterWriter {
+        private final String lineEnding;
+
+        public LineEndingFilterWriter (OutputStreamWriter outputStreamWriter, String lineEnding) {
+            super(outputStreamWriter);
+            this.lineEnding = lineEnding;
+        }
+        
+        @Override
+        public void write(String str) throws IOException {
+            if (!SYSTEM_LINE_SEPARATOR.equals(lineEnding)) {
+                str = str.replaceAll(SYSTEM_LINE_SEPARATOR, lineEnding);
+            }
+            super.write(str);
+        }
+    }
 }
 
