@@ -51,12 +51,14 @@ import java.io.IOException;
 import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
 import java.util.Set;
 import java.util.WeakHashMap;
@@ -70,11 +72,14 @@ import org.netbeans.libs.git.GitBranch;
 import org.netbeans.libs.git.GitException;
 import org.netbeans.libs.git.GitRemoteConfig;
 import org.netbeans.libs.git.GitRepositoryState;
+import org.netbeans.libs.git.GitRevisionInfo;
 import org.netbeans.libs.git.GitTag;
+import org.netbeans.libs.git.SearchCriteria;
 import org.netbeans.modules.git.Git;
 import org.netbeans.modules.git.client.GitClient;
 import org.netbeans.modules.git.utils.GitUtils;
 import org.netbeans.modules.git.utils.JGitUtils;
+import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
 /**
@@ -107,6 +112,14 @@ public class RepositoryInfo {
      * fired when a set of known remotes changes (a remote is added, removed, etc.). Old and new values are instances of {@link Map}&lt;String, GitRemoteConfig&gt;.
      */
     public static final String PROPERTY_REMOTES = "prop.remotes"; //NOI18N
+    /**
+     * fired when a git stash state changes. Old and new values are instances of {@link List}&lt;GitRevisionInfo&gt;.
+     */
+    public static final String PROPERTY_STASH = "prop.stashes"; //NOI18N
+    /**
+     * fired when the tracking info for the current branch changes.
+     */
+    public static final String PROPERTY_TRACKING_INFO = "prop.trackingInfo"; //NOI18N
 
     private final Reference<File> rootRef;
     private static final WeakHashMap<File, RepositoryInfo> cache = new WeakHashMap<File, RepositoryInfo>(5);
@@ -118,6 +131,7 @@ public class RepositoryInfo {
     private final Map<String, GitBranch> branches;
     private final Map<String, GitTag> tags;
     private final Map<String, GitRemoteConfig> remotes;
+    private final List<GitRevisionInfo> stashes;
 
     private GitBranch activeBranch;
     private GitRepositoryState repositoryState;
@@ -126,6 +140,7 @@ public class RepositoryInfo {
     private NBGitConfig nbConfig;
     private static final String NETBEANS_CONFIG_FILE = "nbconfig"; //NOI18N
     private PushMode pushMode = PushMode.ASK;
+    private TrackingInfo trackingInfo;
     
     private RepositoryInfo (File root) {
         this.rootRef = new WeakReference<File>(root);
@@ -133,8 +148,10 @@ public class RepositoryInfo {
         this.branches = new LinkedHashMap<String, GitBranch>();
         this.tags = new HashMap<String, GitTag>();
         this.remotes = new HashMap<String, GitRemoteConfig>();
+        this.stashes = new ArrayList<>();
         this.activeBranch = GitBranch.NO_BRANCH_INSTANCE;
         this.repositoryState = GitRepositoryState.SAFE;
+        this.trackingInfo = new TrackingInfo(activeBranch);
         propertyChangeSupport = new PropertyChangeSupport(this);
     }
 
@@ -199,10 +216,12 @@ public class RepositoryInfo {
                     } catch (GitException ex) {
                         LOG.log(logged.add(root.getAbsolutePath() + ex.getMessage()) ? Level.INFO : Level.FINE, null, ex);
                     }
+                    refreshStashes(client);
                     GitRepositoryState newState = client.getRepositoryState(GitUtils.NULL_PROGRESS_MONITOR);
                     // now set new values and fire events when needed
                     setActiveBranch(newBranches);
                     setRepositoryState(newState);
+                    updateTracking(client);
                 } finally {
                     List<PropertyChangeEvent> events = eventsToFire.get();
                     for (PropertyChangeEvent e : events) {
@@ -244,6 +263,30 @@ public class RepositoryInfo {
         }
     }
 
+    /**
+     * Do NOT call from EDT
+     * @return
+     */
+    public List<GitRevisionInfo> refreshStashes () throws GitException {
+        assert !java.awt.EventQueue.isDispatchThread();
+        GitClient client = null;
+        try {
+            File root = rootRef.get();
+            if (root == null) {
+                LOG.log(Level.WARNING, "refreshRemotes (): root is null, it has been collected in the meantime"); //NOI18N
+            } else {
+                LOG.log(Level.FINE, "refreshRemotes (): starting for {0}", root); //NOI18N
+                client = Git.getInstance().getClient(root);
+                refreshStashes(client);
+            }
+        } finally {
+            if (client != null) {
+                client.release();
+            }
+        }
+        return new ArrayList<>(stashes);
+    }
+
     public NBGitConfig getNetbeansConfig () {
         return getNetbeansConfig(rootRef.get());
     }
@@ -333,6 +376,22 @@ public class RepositoryInfo {
         }
     }
 
+    private void setStashes (List<GitRevisionInfo> newStashes) {
+        List<GitRevisionInfo> oldStash;
+        boolean changed = false;
+        synchronized (stashes) {
+            oldStash = new ArrayList<>(stashes);
+            if (!equals(oldStash, newStashes)) {
+                stashes.clear();
+                stashes.addAll(newStashes);
+                changed = true;
+            }
+        }
+        if (changed) {
+            firePropertyChange(new PropertyChangeEvent(this, PROPERTY_STASH, Collections.unmodifiableList(oldStash), Collections.unmodifiableList(new ArrayList<>(newStashes))));
+        }
+    }
+
     public void addPropertyChangeListener (PropertyChangeListener listener) {
         propertyChangeSupport.addPropertyChangeListener(listener);
     }
@@ -375,6 +434,12 @@ public class RepositoryInfo {
         }
     }
 
+    public List<GitRevisionInfo> getStashes () {
+        synchronized (stashes) {
+            return new ArrayList<>(stashes);
+        }
+    }
+
     public static void refreshAsync (File repositoryRoot) {
         RepositoryInfo info = null;
         synchronized (cache) {
@@ -411,6 +476,21 @@ public class RepositoryInfo {
         }
         return retval;
     }
+
+    private static boolean equals (List<GitRevisionInfo> oldList, List<GitRevisionInfo> newList) {
+        boolean retval = oldList.size() == newList.size();
+        if (retval) {
+            for (ListIterator<GitRevisionInfo> itOld = oldList.listIterator(), itNew = newList.listIterator(); itOld.hasNext();) {
+                GitRevisionInfo oldInfo = itOld.next();
+                GitRevisionInfo newInfo = itNew.next();
+                if (!oldInfo.getRevision().equals(newInfo.getRevision())) {
+                    retval = false;
+                    break;
+                }
+            }
+        }
+        return retval;
+    }
     
     private static boolean equalsBranches (Map<String, GitBranch> oldBranches, Map<String, GitBranch> newBranches) {
         boolean retval = oldBranches.size() == newBranches.size() && oldBranches.keySet().equals(newBranches.keySet());
@@ -465,6 +545,10 @@ public class RepositoryInfo {
         setRemotes(newRemotes);
     }
 
+    private void refreshStashes (GitClient client) throws GitException {
+        setStashes(Arrays.asList(client.stashList(GitUtils.NULL_PROGRESS_MONITOR)));
+    }
+
     private boolean refreshIfNotLocked () {
         File root = rootRef.get();
         if (root != null && GitUtils.isRepositoryLocked(root)) {
@@ -483,6 +567,10 @@ public class RepositoryInfo {
             propertyChangeSupport.firePropertyChange(event);
         }
     }
+
+    public TrackingInfo getTracking () {
+        return trackingInfo;
+    }
     
     public static enum PushMode {
         UPSTREAM,
@@ -503,6 +591,55 @@ public class RepositoryInfo {
         return pushMode;
     }
 
+    private void updateTracking (GitClient client) {
+        TrackingInfo old = getTracking();
+        GitBranch currBranch = getActiveBranch();
+        if (old.needsUpdate(currBranch)) {
+            TrackingInfo newInfo;
+            String id = currBranch.getId();
+            GitBranch trackedBranch = currBranch.getTrackedBranch();
+            if (trackedBranch == null || id.equals(trackedBranch.getId())) {
+                newInfo = new TrackingInfo(currBranch);
+            } else {
+                try {
+                    String trackedId = trackedBranch.getId();
+                    GitRevisionInfo info = client.getCommonAncestor(new String[] { id, trackedId }, GitUtils.NULL_PROGRESS_MONITOR);
+                    if (info == null) {
+                        // no base???
+                        newInfo = new TrackingInfo(currBranch);
+                    } else {
+                        SearchCriteria critIn = new SearchCriteria();
+                        critIn.setRevisionFrom(info.getRevision());
+                        critIn.setRevisionTo(trackedId);
+                        SearchCriteria critOut = new SearchCriteria();
+                        critOut.setRevisionFrom(info.getRevision());
+                        critOut.setRevisionTo(id);
+                        int revsIn, revsOut;
+                        if (info.getRevision().equals(id)) {
+                            // incoming
+                            revsIn = client.log(critIn, false, GitUtils.NULL_PROGRESS_MONITOR).length - 1; // -1 is required because search returns also the from commit
+                            revsOut = 0;
+                        } else if (info.getRevision().equals(trackedId)) {
+                            // outgoing
+                            revsIn = 0;
+                            revsOut = client.log(critOut, false, GitUtils.NULL_PROGRESS_MONITOR).length - 1; // -1 is required because search returns also the from commit
+                        } else {
+                            // merge
+                            revsIn = client.log(critIn, false, GitUtils.NULL_PROGRESS_MONITOR).length - 1;
+                            revsOut = client.log(critOut, false, GitUtils.NULL_PROGRESS_MONITOR).length - 1;
+                        }
+                        newInfo = new TrackingInfo(currBranch, revsIn, revsOut);
+                    }
+                } catch (GitException ex) {
+                    LOG.log(Level.INFO, null, ex);
+                    newInfo = new TrackingInfo(currBranch);
+                }
+            }
+            trackingInfo = newInfo;
+            firePropertyChange(new PropertyChangeEvent(this, PROPERTY_TRACKING_INFO, old, newInfo));
+        }
+    }
+
     private static class RepositoryRefreshTask implements Runnable {
         @Override
         public void run() {
@@ -613,4 +750,77 @@ public class RepositoryInfo {
             
         }
     }
+    
+    @NbBundle.Messages({
+        "CTL_TrackingInfo.inSync=in sync with upstream branch",
+        "# {0} - number of outgoing commits",
+        "CTL_TrackingInfo.out={0} outgoing {0,choice,1#commit|1<commits}",
+        "# {0} - number of incoming commits",
+        "CTL_TrackingInfo.in={0} incoming {0,choice,1#commit|1<commits}",
+        "# {0} - number of outgoing commits", "# {1} - number of incoming commits",
+        "CTL_TrackingInfo.inout={0} outgoing, {1} incoming {1,choice,1#commit|1<commits}"
+    })
+    public static class TrackingInfo {
+        
+        private final String currentId;
+        private final String trackedId;
+        private final int commitsIn;
+        private final int commitsOut;
+        
+        private TrackingInfo (GitBranch branch) {
+            currentId = branch.getId();
+            GitBranch tracked = branch.getTrackedBranch();
+            trackedId = tracked == null ? "" : tracked.getId();
+            if (currentId.equals(trackedId)) {
+                commitsIn = 0;
+                commitsOut = 0;
+            } else {
+                commitsIn = -1;
+                commitsOut = -1;
+            }
+        }
+
+        private TrackingInfo (GitBranch branch, int revsIn, int revsOut) {
+            currentId = branch.getId();
+            trackedId = branch.getTrackedBranch().getId();
+            commitsIn = revsIn;
+            commitsOut = revsOut;
+        }
+
+        private boolean needsUpdate (GitBranch branch) {
+            boolean retval = false;
+            GitBranch tracked = branch.getTrackedBranch();
+            if (!currentId.equals(branch.getId())) {
+                retval = true;
+            } else if (!trackedId.equals(tracked == null ? "" : tracked.getId())) {
+                retval = true;
+            }
+            return retval;
+        }
+
+        public int getIncomingCommits () {
+            return commitsIn;
+        }
+
+        public int getOutgoingCommits () {
+            return commitsOut;
+        }
+
+        public boolean isKnown () {
+            return commitsIn >= 0;
+        }
+        
+        public String getDescription () {
+            if (commitsIn == 0 && commitsOut == 0) {
+                return Bundle.CTL_TrackingInfo_inSync();
+            } else if (commitsOut == 0) {
+                return Bundle.CTL_TrackingInfo_in(commitsIn);
+            } else if (commitsIn == 0) {
+                return Bundle.CTL_TrackingInfo_out(commitsOut);
+            } else {
+                return Bundle.CTL_TrackingInfo_inout(commitsOut, commitsIn);
+            }
+        }
+
+    }
 }
