@@ -306,22 +306,6 @@ public final class GitUtils {
     // cached not sharable files and folders
     private static final Map<File, Set<String>> notSharable = Collections.synchronizedMap(new HashMap<File, Set<String>>(5));
 
-    public static boolean isFromRepository (File repository, File file) {
-        Git git = Git.getInstance();
-        File fileRepository = git.getRepositoryRoot(file);
-        // the file is from the given repository if it is
-        
-        if (repository.equals(fileRepository)) {
-            // either normal file in the repository
-            return true;
-        } else if (file.equals(fileRepository) && repository.equals(git.getRepositoryRoot(file.getParentFile()))) {
-            // or a gitlink inside the repository
-            return true;
-        } else {
-            return false;
-        }
-    }
-
     public static String parseRemoteHeadFromFetch (String fetchRefSpec) {
         if (fetchRefSpec.startsWith("+")) { //NOI18N
             fetchRefSpec = fetchRefSpec.substring(1);
@@ -439,7 +423,7 @@ public final class GitUtils {
      * @param roots root files
      * @return repository roots
      */
-    public static Set<File> getRepositoryRoots (Set<File> roots) {
+    public static Set<File> getRepositoryRoots (Collection<File> roots) {
         Set<File> ret = new HashSet<File>();
 
         // filter managed roots
@@ -876,6 +860,7 @@ public final class GitUtils {
     private static final String REF_PUSHSPEC_PATTERN = "refs/heads/{0}:refs/heads/{1}"; //NOI18N
     public static final String REF_PUSHSPEC_DEL_PREFIX = ":refs/heads/"; //NOI18N
     private static final String REF_TAG_PUSHSPEC_PATTERN = "refs/tags/{0}:refs/tags/{0}"; //NOI18N
+    private static final String REF_TAG_PUSHSPEC_PATTERN_FORCE = "+" + REF_TAG_PUSHSPEC_PATTERN; //NOI18N
 
     public static String getGlobalRefSpec (String remoteName) {
         return MessageFormat.format(REF_SPEC_GLOBAL_PATTERN, remoteName);
@@ -901,8 +886,10 @@ public final class GitUtils {
         return REF_PUSHSPEC_DEL_PREFIX + remoteRepositoryBranchName;
     }
 
-    public static String getPushTagRefSpec (String tagName) {
-        return MessageFormat.format(REF_TAG_PUSHSPEC_PATTERN, tagName);
+    public static String getPushTagRefSpec (String tagName, boolean forceUpdate) {
+        return MessageFormat.format(forceUpdate
+                ? REF_TAG_PUSHSPEC_PATTERN_FORCE
+                : REF_TAG_PUSHSPEC_PATTERN, tagName);
     }
 
     public static <T> T runWithoutIndexing (Callable<T> callable, List<File> files) throws GitException {
@@ -1074,7 +1061,7 @@ public final class GitUtils {
         }
     }
     
-    public static <T> void attachQuickSearch (List<T> items, JPanel panel, JList listComponent,
+    public static <T> QuickSearch attachQuickSearch (List<T> items, JPanel panel, JList listComponent,
             DefaultListModel model, SearchCallback<T> searchCallback) {
         final QuickSearchCallback callback = new QuickSearchCallback<T>(items, listComponent, model, searchCallback);
         final QuickSearch qs = QuickSearch.attach(panel, BorderLayout.SOUTH, callback);
@@ -1101,6 +1088,7 @@ public final class GitUtils {
                 qs.processKeyEvent(e);
             }
         });
+        return qs;
     }
 
     public static boolean isValidRefName (String refName) {
@@ -1115,6 +1103,25 @@ public final class GitUtils {
         return isValidRefName(PREFIX_R_HEADS + branchName);
     }
 
+    public static VCSContext getContextForFile (final File root) {
+        return getContextForFiles(new File[] { root });
+    }
+
+    public static VCSContext getContextForFiles (final File[] roots) {
+        Node[] nodes = new Node[roots.length];
+        for (int i = 0; i < roots.length; ++i) {
+            final File root = roots[i];
+            nodes[i] = new AbstractNode(Children.LEAF, Lookups.fixed(root)) {
+
+                @Override
+                public String getName () {
+                    return root.getName();
+                }
+            };
+        }
+        return VCSContext.forNodes(nodes);
+    }
+
     public static interface SearchCallback<T> {
         
         public boolean contains (T item, String needle);
