@@ -46,16 +46,16 @@ import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.glassfish.tools.ide.GlassFishStatus;
-import static org.glassfish.tools.ide.GlassFishStatus.OFFLINE;
-import static org.glassfish.tools.ide.GlassFishStatus.ONLINE;
-import static org.glassfish.tools.ide.GlassFishStatus.SHUTDOWN;
-import static org.glassfish.tools.ide.GlassFishStatus.STARTUP;
-import org.glassfish.tools.ide.TaskEvent;
-import org.glassfish.tools.ide.TaskState;
-import org.glassfish.tools.ide.TaskStateListener;
-import org.glassfish.tools.ide.data.GlassFishServer;
-import org.glassfish.tools.ide.data.GlassFishStatusTask;
+import org.netbeans.modules.glassfish.tooling.GlassFishStatus;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.OFFLINE;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.ONLINE;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.SHUTDOWN;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.STARTUP;
+import org.netbeans.modules.glassfish.tooling.TaskEvent;
+import org.netbeans.modules.glassfish.tooling.TaskState;
+import org.netbeans.modules.glassfish.tooling.TaskStateListener;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishServer;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishStatusTask;
 import org.netbeans.modules.glassfish.common.status.WakeUpStateListener;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
 import org.openide.util.NbBundle;
