@@ -42,6 +42,19 @@
 
 package org.netbeans.modules.glassfish.common;
 
+import org.netbeans.modules.glassfish.tooling.admin.CommandRedeploy;
+import org.netbeans.modules.glassfish.tooling.admin.CommandRestartDAS;
+import org.netbeans.modules.glassfish.tooling.admin.CommandUndeploy;
+import org.netbeans.modules.glassfish.tooling.admin.CommandDeploy;
+import org.netbeans.modules.glassfish.tooling.admin.CommandDisable;
+import org.netbeans.modules.glassfish.tooling.admin.CommandSetProperty;
+import org.netbeans.modules.glassfish.tooling.admin.ResultMap;
+import org.netbeans.modules.glassfish.tooling.admin.CommandGetProperty;
+import org.netbeans.modules.glassfish.tooling.admin.Command;
+import org.netbeans.modules.glassfish.tooling.admin.CommandEnable;
+import org.netbeans.modules.glassfish.tooling.admin.ServerAdmin;
+import org.netbeans.modules.glassfish.tooling.admin.ResultString;
+import org.netbeans.modules.glassfish.tooling.admin.CommandListComponents;
 import java.io.File;
 import java.io.IOException;
 import java.net.InetSocketAddress;
@@ -53,17 +66,16 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.event.ChangeListener;
-import org.glassfish.tools.ide.GlassFishIdeException;
-import org.glassfish.tools.ide.GlassFishStatus;
-import static org.glassfish.tools.ide.GlassFishStatus.OFFLINE;
-import static org.glassfish.tools.ide.GlassFishStatus.SHUTDOWN;
-import static org.glassfish.tools.ide.GlassFishStatus.STARTUP;
-import org.glassfish.tools.ide.TaskEvent;
-import org.glassfish.tools.ide.TaskState;
-import org.glassfish.tools.ide.TaskStateListener;
-import org.glassfish.tools.ide.admin.*;
-import org.glassfish.tools.ide.data.GlassFishServerStatus;
-import org.glassfish.tools.ide.utils.Utils;
+import org.netbeans.modules.glassfish.tooling.GlassFishIdeException;
+import org.netbeans.modules.glassfish.tooling.GlassFishStatus;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.OFFLINE;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.SHUTDOWN;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.STARTUP;
+import org.netbeans.modules.glassfish.tooling.TaskEvent;
+import org.netbeans.modules.glassfish.tooling.TaskState;
+import org.netbeans.modules.glassfish.tooling.TaskStateListener;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishServerStatus;
+import org.netbeans.modules.glassfish.tooling.utils.Utils;
 import org.netbeans.modules.glassfish.common.nodes.actions.RefreshModulesCookie;
 import org.netbeans.modules.glassfish.common.utils.Util;
 import org.netbeans.modules.glassfish.spi.*;
@@ -663,10 +675,14 @@ public class CommonServerSupport
     public Future<ResultString> deploy(final TaskStateListener stateListener,
             final File application, final String name, final String contextRoot,
             final Map<String, String> properties, final File[] libraries) {
-        return ServerAdmin.<ResultString>exec(instance, new CommandDeploy(
-                name, Util.computeTarget(instance.getProperties()),
-                application, contextRoot, properties, libraries
-                ), null, new TaskStateListener[] {stateListener});
+        try {
+            return ServerAdmin.<ResultString>exec(instance, new CommandDeploy(
+                    name, Util.computeTarget(instance.getProperties()),
+                    application, contextRoot, properties, libraries
+            ), null, new TaskStateListener[]{stateListener});
+        } finally {
+            refreshChildren();
+        }
     }
 
     @Override
@@ -705,10 +721,14 @@ public class CommonServerSupport
         if (resourcesChanged) {
             properties.put("preserveAppScopedResources", "true");
         }
-        return ServerAdmin.<ResultString>exec(instance, new CommandRedeploy(
-                name, Util.computeTarget(instance.getProperties()),
-                contextRoot, properties, libraries,
-                url != null && url.contains("ee6wc")), stateListener);
+        try {
+            return ServerAdmin.<ResultString>exec(instance, new CommandRedeploy(
+                    name, Util.computeTarget(instance.getProperties()),
+                    contextRoot, properties, libraries,
+                    url != null && url.contains("ee6wc")), stateListener);
+        } finally {
+            refreshChildren();
+        }
     }
 
     @Override
@@ -1239,4 +1259,12 @@ public class CommonServerSupport
         return LOCALHOST.equals(retVal) ? nameOfLocalhost : retVal; // NOI18N
     }
 
+    private void refreshChildren() {
+        GlassfishInstance instance = getInstance();
+        RefreshModulesCookie cookie = instance.getFullNode().getLookup().lookup(RefreshModulesCookie.class);
+        if (cookie != null) {
+            cookie.refresh(null, null);
+        }
+    }
+
 }
