@@ -50,11 +50,11 @@ import java.util.concurrent.TimeoutException;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.JComponent;
-import org.glassfish.tools.ide.TaskState;
-import org.glassfish.tools.ide.data.GlassFishAdminInterface;
-import org.glassfish.tools.ide.data.GlassFishServer;
-import org.glassfish.tools.ide.data.GlassFishVersion;
-import org.glassfish.tools.ide.utils.ServerUtils;
+import org.netbeans.modules.glassfish.tooling.TaskState;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishAdminInterface;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishServer;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishVersion;
+import org.netbeans.modules.glassfish.tooling.utils.ServerUtils;
 import org.netbeans.api.java.platform.JavaPlatform;
 import org.netbeans.api.java.platform.JavaPlatformManager;
 import org.netbeans.api.keyring.Keyring;
@@ -657,7 +657,7 @@ public class GlassfishInstance implements ServerInstanceImplementation,
 
             for (int i = 0; i < instanceFOs.length; i++) {
                 if (url.equals(instanceFOs[i].getAttribute(GlassfishModule.URL_ATTR))
-                        && !GlassfishInstanceProvider.GLASSFISH_AUTOREGISTERED_INSTANCE.equals(instanceFOs[i].getName())) {
+                        && !instanceFOs[i].getName().startsWith(GlassfishInstanceProvider.GLASSFISH_AUTOREGISTERED_INSTANCE)) {
                     instanceFO = instanceFOs[i];
                 }
             }
@@ -727,7 +727,7 @@ public class GlassfishInstance implements ServerInstanceImplementation,
       * <p/>
       * This is always version of local GlassFish related to JavaEE platform,
       * even when registered domain is remote. */
-    private transient volatile GlassFishVersion version;
+    private final GlassFishVersion version;
 
     /** Process information of local running server started from IDE.
      *  <p/>
@@ -742,7 +742,7 @@ public class GlassfishInstance implements ServerInstanceImplementation,
     private transient InstanceContent ic;
     private transient Lookup localLookup;
     private transient Lookup full;
-    final private transient Lookup.Result<GlassfishModuleFactory>
+    private final transient Lookup.Result<GlassfishModuleFactory>
             lookupResult = Lookups.forPath(Util.GF_LOOKUP_PATH).lookupResult(
             GlassfishModuleFactory.class);;
     private transient Collection<? extends GlassfishModuleFactory>
@@ -753,6 +753,9 @@ public class GlassfishInstance implements ServerInstanceImplementation,
     // API instance
     private ServerInstance commonInstance;
     private GlassfishInstanceProvider instanceProvider;
+
+    // GuardedBy("lookupResult")
+    private Node fullNode;
     
     ////////////////////////////////////////////////////////////////////////////
     // Constructors                                                           //
@@ -1704,7 +1707,12 @@ public class GlassfishInstance implements ServerInstanceImplementation,
     @Override
     public Node getFullNode() {
         Logger.getLogger("glassfish").finer("Creating GF Instance node [FULL]"); // NOI18N
-        return new Hk2InstanceNode(this, true);
+        synchronized (lookupResult) {
+            if (fullNode == null) {
+                fullNode = new Hk2InstanceNode(this, true);
+            }
+            return fullNode;
+        }
     }
 
     @Override
@@ -1767,19 +1775,12 @@ public class GlassfishInstance implements ServerInstanceImplementation,
             return false;
         }
         // Domain name can be null so we shall avoid NPE.
-        boolean domainName = (
-                getDomainName() == null && other.getDomainName() == null)
-                || ((getDomainName() != null && other.getDomainName() != null)
-                && getDomainName().equals(other.getDomainName()));
+        boolean domainName = Objects.equals(getDomainName(), other.getDomainName());
         // Domains root can be null so we shall avoid NPE.
-        boolean domainsRoot = (
-                getDomainsRoot() == null && other.getDomainsRoot() == null)
-                || ((getDomainsRoot() != null && other.getDomainsRoot() != null)
-                && getDomainsRoot().equals(other.getDomainsRoot()));
+        boolean domainsRoot = Objects.equals(getDomainsRoot(), other.getDomainsRoot());
         return domainName && domainsRoot
-                && getDeployerUri().replace("127.0.0.1", "localhost").
-                equals(other.getDeployerUri().replace("127.0.0.1", "localhost"))
-                && getDomainName().equals(other.getDomainName()) 
+                && getDeployerUri().replace("127.0.0.1", "localhost")
+                        .equals(other.getDeployerUri().replace("127.0.0.1", "localhost"))
                 && getHttpPort().equals(other.getHttpPort());
     }
 
