@@ -58,10 +58,10 @@ import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.swing.Action;
-import org.glassfish.tools.ide.server.FetchLog;
-import org.glassfish.tools.ide.server.FetchLogEvent;
-import org.glassfish.tools.ide.server.FetchLogEventListener;
-import org.glassfish.tools.ide.server.FetchLogPiped;
+import org.netbeans.modules.glassfish.tooling.server.FetchLog;
+import org.netbeans.modules.glassfish.tooling.server.FetchLogEvent;
+import org.netbeans.modules.glassfish.tooling.server.FetchLogEventListener;
+import org.netbeans.modules.glassfish.tooling.server.FetchLogPiped;
 import org.netbeans.api.server.ServerInstance;
 import org.netbeans.modules.glassfish.common.actions.*;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
@@ -354,6 +354,7 @@ public class LogViewMgr {
 
         if (force) {
             lastVisibleCheck = 0;
+            io.select();
         }
 
         // If the user happened to close the OutputWindow TopComponent, reopen it.
