@@ -48,25 +48,25 @@ import java.util.Map;
 import java.util.concurrent.Future;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.glassfish.tools.ide.GlassFishIdeException;
-import org.glassfish.tools.ide.GlassFishStatus;
-import static org.glassfish.tools.ide.GlassFishStatus.OFFLINE;
-import static org.glassfish.tools.ide.GlassFishStatus.ONLINE;
-import static org.glassfish.tools.ide.GlassFishStatus.SHUTDOWN;
-import static org.glassfish.tools.ide.GlassFishStatus.STARTUP;
-import static org.glassfish.tools.ide.GlassFishStatus.UNKNOWN;
-import org.glassfish.tools.ide.TaskEvent;
-import org.glassfish.tools.ide.TaskState;
-import org.glassfish.tools.ide.TaskStateListener;
-import org.glassfish.tools.ide.admin.CommandGetProperty;
-import org.glassfish.tools.ide.admin.CommandRestartDAS;
-import org.glassfish.tools.ide.admin.CommandSetProperty;
-import org.glassfish.tools.ide.admin.CommandStopDAS;
-import org.glassfish.tools.ide.admin.ResultMap;
-import org.glassfish.tools.ide.admin.ResultString;
-import org.glassfish.tools.ide.data.GlassFishServerStatus;
-import org.glassfish.tools.ide.utils.NetUtils;
-import org.glassfish.tools.ide.utils.ServerUtils;
+import org.netbeans.modules.glassfish.tooling.GlassFishIdeException;
+import org.netbeans.modules.glassfish.tooling.GlassFishStatus;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.OFFLINE;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.ONLINE;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.SHUTDOWN;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.STARTUP;
+import static org.netbeans.modules.glassfish.tooling.GlassFishStatus.UNKNOWN;
+import org.netbeans.modules.glassfish.tooling.TaskEvent;
+import org.netbeans.modules.glassfish.tooling.TaskState;
+import org.netbeans.modules.glassfish.tooling.TaskStateListener;
+import org.netbeans.modules.glassfish.tooling.admin.CommandGetProperty;
+import org.netbeans.modules.glassfish.tooling.admin.CommandRestartDAS;
+import org.netbeans.modules.glassfish.tooling.admin.CommandSetProperty;
+import org.netbeans.modules.glassfish.tooling.admin.CommandStopDAS;
+import org.netbeans.modules.glassfish.tooling.admin.ResultMap;
+import org.netbeans.modules.glassfish.tooling.admin.ResultString;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishServerStatus;
+import org.netbeans.modules.glassfish.tooling.utils.NetUtils;
+import org.netbeans.modules.glassfish.tooling.utils.ServerUtils;
 import static org.netbeans.modules.glassfish.common.BasicTask.START_TIMEOUT;
 import static org.netbeans.modules.glassfish.common.BasicTask.STOP_TIMEOUT;
 import static org.netbeans.modules.glassfish.common.BasicTask.TIMEUNIT;
