@@ -82,10 +82,10 @@ import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 import javax.swing.table.DefaultTableModel;
 import javax.swing.table.TableCellRenderer;
-import org.glassfish.tools.ide.data.GlassFishServer;
-import org.glassfish.tools.ide.utils.JavaUtils;
-import org.glassfish.tools.ide.utils.OsUtils;
-import org.glassfish.tools.ide.utils.ServerUtils;
+import org.netbeans.modules.glassfish.tooling.data.GlassFishServer;
+import org.netbeans.modules.glassfish.tooling.utils.JavaUtils;
+import org.netbeans.modules.glassfish.tooling.utils.OsUtils;
+import org.netbeans.modules.glassfish.tooling.utils.ServerUtils;
 import org.netbeans.modules.j2ee.sun.dd.impl.verifier.Appclient;
 import org.netbeans.modules.j2ee.sun.dd.impl.verifier.Application;
 import org.netbeans.modules.j2ee.sun.dd.impl.verifier.Connector;
@@ -211,16 +211,16 @@ public class VerifierSupport extends TopComponent {
         }
         
         // Build verifier execution arguments.
-        String verifierArgs[] = {"-ra", "-d" , dir.getAbsolutePath(), fileName};
+        String verifierArgs[] = {"-ra", "-d" , "\"" + dir.getAbsolutePath() + "\"", "\"" + fileName + "\""}; // NOI18N
         StringBuilder sb = new StringBuilder();
-        sb.append(JavaUtils.VM_CLASSPATH_OPTION).append(' ');
+        sb.append(JavaUtils.VM_CLASSPATH_OPTION).append(" \""); // NOI18N
         sb.append(embeddedStaticShellJar).append(File.pathSeparatorChar);
         sb.append(verifierJar).append(File.pathSeparatorChar);
         sb.append(javaHelpJar);
-        sb.append(' ');
+        sb.append("\" "); // NOI18N
         sb.append(ServerUtils.VERIFIER_MAIN_CLASS);
         for (String arg : verifierArgs) {
-            sb.append(' ');
+            sb.append(' '); // NOI18N
             sb.append(arg);
         }
         String[] args = OsUtils.parseParameters(javaVmExe, sb.toString());
