@@ -473,7 +473,9 @@ public class ASTUtils {
                 TokenSequence<GroovyTokenId> ts = LexUtilities.getPositionedSequence(doc, startOffset);
                 if (ts != null) {
                     Token<GroovyTokenId> token = ts.token();
-                    if (token != null && token.id() == GroovyTokenId.IDENTIFIER && TokenUtilities.endsWith(identifier, token.text())) {
+                    if (token != null && token.id() == GroovyTokenId.IDENTIFIER
+                            && ( TokenUtilities.textEquals(identifier, token.text())
+                            || TokenUtilities.endsWith(identifier, "." + token.text()) ) ) {
                         result[0] = computeRange(ts, token);
                         return;
                     }
