@@ -58,7 +58,9 @@ import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.lang.model.element.AnnotationMirror;
@@ -70,12 +72,14 @@ import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.ElementFilter;
 import javax.swing.text.Position;
 import org.netbeans.api.java.source.CancellableTask;
-import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.ClasspathInfo;
+import org.netbeans.api.java.source.CompilationController;
+import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource;
+import org.netbeans.api.java.source.SourceUtils;
 import org.netbeans.api.java.source.TreeMaker;
 import org.netbeans.api.java.source.TreePathHandle;
 import org.netbeans.api.java.source.WorkingCopy;
-import org.netbeans.modules.j2ee.jpa.refactoring.JPARefactoring;
 import org.netbeans.modules.refactoring.api.Problem;
 import org.openide.loaders.DataObject;
 import org.openide.loaders.DataObjectNotFoundException;
@@ -83,8 +87,8 @@ import org.openide.text.CloneableEditorSupport;
 import org.openide.cookies.EditorCookie;
 import org.netbeans.modules.refactoring.spi.RefactoringElementsBag;
 import org.openide.filesystems.FileObject;
-import org.netbeans.modules.j2ee.jpa.refactoring.RefactoringUtil;
 import org.netbeans.modules.refactoring.api.RenameRefactoring;
+import org.netbeans.modules.refactoring.java.spi.JavaRefactoringPlugin;
 import org.netbeans.modules.refactoring.spi.SimpleRefactoringElementImplementation;
 import org.openide.text.PositionBounds;
 import org.openide.util.Exceptions;
@@ -95,7 +99,7 @@ import org.openide.util.lookup.Lookups;
  * Handles usage search of attribute used in mappedBy
  * @author Sergey Petrov
  */
-public final class RelationshipMappingRename implements JPARefactoring {
+public final class RelationshipMappingRename extends JavaRefactoringPlugin {
     
     private final RenameRefactoring rename;
     private final static Logger LOG = Logger.getLogger(RelationshipMappingRename.class.getName());
@@ -105,100 +109,141 @@ public final class RelationshipMappingRename implements JPARefactoring {
     }
     
     @Override
-    public Problem prepare(RefactoringElementsBag refactoringElementsBag) {
-        Problem result = null;
-        TreePathHandle handle = rename.getRefactoringSource().lookup(TreePathHandle.class);
-        if (handle == null) { 
+    public Problem preCheck() {
+        return null;
+    }
+
+    @Override
+    public Problem fastCheckParameters() {
+        return null;
+    }
+    
+    @Override
+    public Problem checkParameters() {
+        return null;
+    }
+
+    @Override
+    protected JavaSource getJavaSource(Phase p) {
+        return null;
+    }
+    
+    @Override
+    public Problem prepare(final RefactoringElementsBag refactoringElementsBag) {
+        final TreePathHandle handle = rename.getRefactoringSource().lookup(TreePathHandle.class);
+        if (handle == null) {
             return null;
         }
-        if(handle.getKind() == Kind.VARIABLE) {
-            Element resElement = handle.resolveElement(RefactoringUtil.getCompilationInfo(handle, rename));
-            VariableElement var = (VariableElement) resElement;
-            Element mainEntTmp = var.getEnclosingElement();
-            TypeElement mainEnt = mainEntTmp instanceof TypeElement ? (TypeElement)mainEntTmp : null;
-            if(mainEnt == null) {
-                return null;
-            }
-            List<? extends AnnotationMirror> ans = var.getAnnotationMirrors();
-            boolean checkFoMappedBy = false;
-            for(AnnotationMirror an:ans){
-                String tp = an.getAnnotationType().toString();
-                if("javax.persistence.ManyToOne".equals(tp) || "javax.persistence.ManyToMany".equals(tp)) {//NOI18N
-                    checkFoMappedBy = true;
-                    break;
-                }
-            }
-            if(checkFoMappedBy){
-                TypeMirror tm = var.asType();
-                TypeElement oppEntEl = RefactoringUtil.getCompilationInfo(handle, rename).getElements().getTypeElement(tm.toString());
-                if(oppEntEl!=null) {
-                    for (VariableElement field : ElementFilter.fieldsIn(oppEntEl.getEnclosedElements())) {
-                        String fqn = field.asType().toString();
-                        if(fqn.endsWith("<"+mainEnt+">") && fqn.startsWith("java.util.")){//it's 99% some generic collection
-                            ans = field.getAnnotationMirrors();
-                            for(AnnotationMirror an : ans){
-                                String tp = an.getAnnotationType().toString();
-                                if("javax.persistence.OneToMany".equals(tp) || "javax.persistence.ManyToMany".equals(tp)) {//NOI18N
-                                    for(ExecutableElement el : an.getElementValues().keySet()) {
-                                        if(el.getSimpleName().toString().equals("mappedBy")) {
-                                            if(an.getElementValues().get(el).getValue().toString().equals(var.getSimpleName().toString())) {
-                                                FileObject fo;
-                                                try {
-                                                    //it's usage
-                                                     fo = RefactoringUtil.getTreePathHandle(field.getSimpleName().toString(), oppEntEl.toString(), handle.getFileObject()).getFileObject();
-                                                } catch (IOException ex) {
-                                                    LOG.log(Level.INFO, "Can't get fileobject.", ex);//NOI18N
-                                                    continue;
-                                                }
-                                                TreePathHandle ph;
-                                                try {
-                                                    ph = RefactoringUtil.getTreePathHandle(field.getSimpleName().toString(), oppEntEl.toString(), handle.getFileObject());
-                                                } catch (IOException ex) {
-                                                    LOG.log(Level.INFO, "Can't get tree path handle.", ex);//NOI18N
-                                                    continue;
-                                                }
-                                                CompilationInfo ci = RefactoringUtil.getCompilationInfo(ph, rename);
-                                                TreePath tree = ph.resolve(ci);
-                                                CompilationUnitTree unit = tree.getCompilationUnit();
-                                                Tree t= tree.getLeaf();
-                                                List<? extends AnnotationTree> aList = ((VariableTree)t).getModifiers().getAnnotations();
-                                                AnnotationTree at0 = null;
-                                                for(AnnotationTree at:aList)
-                                                {
-                                                    for(ExpressionTree et:at.getArguments())
-                                                    {
-                                                        if(et instanceof AssignmentTree)
-                                                        {
-                                                            AssignmentTree ast = ((AssignmentTree)et);
-                                                            if(ast.toString().startsWith("mappedBy")){//NOI18N
-                                                                t = ast.getExpression();
-                                                                at0 = at;
-                                                                break;
+        if (handle.getKind() == Kind.VARIABLE) {
+            final ClasspathInfo cpInfo = getClasspathInfo(rename);
+            final Set<ElementHandle<TypeElement>> set = new HashSet<ElementHandle<TypeElement>>();
+            JavaSource source = JavaSource.create(cpInfo, new FileObject[]{handle.getFileObject()});
+            try {
+                source.runUserActionTask(new CancellableTask<CompilationController>() {
+                    @Override
+                    public void cancel() {
+                    }
+                    @Override
+                    public void run(CompilationController ci) throws Exception {
+                        ci.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
+                        Element resElement = handle.resolveElement(ci);
+                        VariableElement var = (VariableElement) resElement;
+                        Element mainEntTmp = var.getEnclosingElement();
+                        TypeElement mainEnt = mainEntTmp instanceof TypeElement ? (TypeElement) mainEntTmp : null;
+                        if (mainEnt == null) {
+                            return;
+                        }
+                        List<? extends AnnotationMirror> ans = var.getAnnotationMirrors();
+                        boolean checkFoMappedBy = false;
+                        for (AnnotationMirror an : ans) {
+                            String tp = an.getAnnotationType().toString();
+                            if ("javax.persistence.ManyToOne".equals(tp) || "javax.persistence.ManyToMany".equals(tp)) {//NOI18N
+                                checkFoMappedBy = true;
+                                break;
+                            }
+                        }
+                        if (checkFoMappedBy) {
+                            TypeMirror tm = var.asType();
+                            TypeElement oppEntEl = ci.getElements().getTypeElement(tm.toString());
+                            if (oppEntEl != null) {
+
+                            } else {
+                                LOG.log(Level.INFO, "Can't resolve {0}", tm.toString());//NOI18N
+                            }
+                        }
+                    }
+                }, false);
+                for (final ElementHandle<TypeElement> elHandle : set) {
+                    FileObject fo = SourceUtils.getFile(elHandle, cpInfo);
+                    JavaSource usage = JavaSource.create(cpInfo, fo);
+                    usage.runUserActionTask(new CancellableTask<CompilationController>() {
+                        @Override
+                        public void cancel() {
+                        }
+
+                        @Override
+                        public void run(CompilationController ci) throws Exception {
+                            ci.toPhase(JavaSource.Phase.RESOLVED);
+                            Element resElement = handle.resolveElement(ci);
+                            VariableElement var = (VariableElement) resElement;
+                            Element mainEntTmp = var != null ? var.getEnclosingElement() : null;
+                            TypeElement mainEnt = mainEntTmp instanceof TypeElement ? (TypeElement) mainEntTmp : null;
+                            if (mainEnt == null) {
+                                return;
+                            }
+                            TypeElement oppEntEl = elHandle.resolve(ci);
+                            for (VariableElement field : ElementFilter.fieldsIn(oppEntEl.getEnclosedElements())) {
+                                String fqn = field.asType().toString();
+                                if (fqn.endsWith("<" + mainEnt + ">") && fqn.startsWith("java.util.")) { //it's 99% some generic collection
+                                    List<? extends AnnotationMirror> ans = field.getAnnotationMirrors();
+                                    for (AnnotationMirror an : ans) {
+                                        String tp = an.getAnnotationType().toString();
+                                        if ("javax.persistence.OneToMany".equals(tp) || "javax.persistence.ManyToMany".equals(tp)) {//NOI18N
+                                            for (ExecutableElement el : an.getElementValues().keySet()) {
+                                                if (el.getSimpleName().toString().equals("mappedBy")) {
+                                                    if (an.getElementValues().get(el).getValue().toString().equals(var.getSimpleName().toString())) {
+                                                        FileObject fo;
+                                                        ElementHandle<VariableElement> elHandle = ElementHandle.create(field);
+                                                        fo = SourceUtils.getFile(elHandle, cpInfo);
+                                                        //it's usage
+                                                        TreePath path = ci.getTrees().getPath(field);
+                                                        if (path == null || fo == null) {
+                                                            LOG.log(Level.INFO, "Can''t get fileobject.{0} : {1}", new Object[]{path, fo});//NOI18N
+                                                            continue;
+                                                        }
+                                                        CompilationUnitTree unit = path.getCompilationUnit();
+                                                        Tree t = path.getLeaf();
+                                                        List<? extends AnnotationTree> aList = ((VariableTree) t).getModifiers().getAnnotations();
+                                                        AnnotationTree at0 = null;
+                                                        for (AnnotationTree at : aList) {
+                                                            for (ExpressionTree et : at.getArguments()) {
+                                                                if (et instanceof AssignmentTree) {
+                                                                    AssignmentTree ast = ((AssignmentTree) et);
+                                                                    if (ast.toString().startsWith("mappedBy")) {//NOI18N
+                                                                        t = ast.getExpression();
+                                                                        at0 = at;
+                                                                        break;
+                                                                    }
+                                                                }
                                                             }
                                                         }
+                                                        SourcePositions sp = ci.getTrees().getSourcePositions();
+                                                        sp.getStartPosition(unit, t);
+                                                        refactoringElementsBag.add(rename, new RelationshipAnnotationRenameRefactoringElement(fo, field, at0, an, var.getSimpleName().toString(), (int) sp.getStartPosition(unit, t), (int) sp.getEndPosition(unit, t)));
                                                     }
                                                 }
-                                                SourcePositions sp = ci.getTrees().getSourcePositions();
-                                                sp.getStartPosition(unit, t);
-                                                if(fo!=null) {
-                                                    refactoringElementsBag.add(rename, new RelationshipAnnotationRenameRefactoringElement(fo, field, at0, an, var.getSimpleName().toString(), (int)sp.getStartPosition(unit, t), (int)sp.getEndPosition(unit, t)));
-                                                }
                                             }
                                         }
                                     }
                                 }
                             }
                         }
-                    }
-                } else {
-                    LOG.log(Level.INFO, "Can't resolve {0}", tm.toString());//NOI18N
+                    }, false);
                 }
+            } catch (IOException ex) {
+                Exceptions.printStackTrace(ex);
             }
         }
-        return result;
-    }
-        @Override
-    public Problem preCheck() {
         return null;
     }
         
