@@ -119,6 +119,8 @@ public class PUDataObject extends XmlMultiViewDataObject {
      */ 
     static final String PERSISTENCE_UNIT_ADDED_OR_REMOVED = "persistence_unit_added_or_removed"; //NOI18N
 
+    protected boolean changedFromUI;
+    
     /**
      * Creates a new instance of PUDataObject.
      */
@@ -161,8 +163,12 @@ public class PUDataObject extends XmlMultiViewDataObject {
     public static XmlMultiViewElement createXmlMultiViewElement(Lookup lookup) {
         return new XmlMultiViewElement(lookup.lookup(XmlMultiViewDataObject.class));
     }
-        
-    
+
+    @Override
+    protected int associateLookup() {
+        return 1;
+    }
+
     /**
      * Saves the document.
      * @see EditorCookie#saveDocument
@@ -418,6 +424,14 @@ public class PUDataObject extends XmlMultiViewDataObject {
         modelSynchronizer.requestUpdateData();
     }
 
+    public boolean isChangedFromUI() {
+        return changedFromUI;
+    }
+
+    public void setChangedFromUI(boolean changedFromUI) {
+        this.changedFromUI=changedFromUI;
+    }
+
     /**
      * it's used if need to update
      * @param unit
