@@ -48,7 +48,6 @@ import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
-import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
@@ -56,7 +55,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
-import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Properties;
 import java.util.jar.JarFile;
@@ -77,17 +75,16 @@ import org.netbeans.api.java.platform.JavaPlatformManager;
 import org.netbeans.modules.j2ee.deployment.common.api.Version;
 import org.netbeans.modules.j2ee.deployment.plugins.api.InstanceProperties;
 import org.netbeans.modules.j2ee.weblogic9.deploy.WLDeploymentManager;
+import org.netbeans.modules.weblogic.common.api.WebLogicLayout;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
 import org.openide.util.Utilities;
-import org.openide.xml.XMLUtil;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
-import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 
 /**
@@ -96,17 +93,6 @@ import org.xml.sax.SAXException;
  */
 public final class WLPluginProperties {
 
-    public static final String WEBLOGIC_JAR = "server/lib/weblogic.jar"; // NOI18N
-    
-    private static final Collection EXPECTED_FILES = new ArrayList();
-
-
-    static {
-        EXPECTED_FILES.add("common"); // NOI18N
-        EXPECTED_FILES.add("server/bin"); // NOI18N
-        EXPECTED_FILES.add(WEBLOGIC_JAR);    
-    }
-    
     private static final Logger LOGGER = Logger.getLogger(WLPluginProperties.class.getName());
 
     private static final String CONFIG_XML = "config/config.xml"; //NOI18N
@@ -114,15 +100,14 @@ public final class WLPluginProperties {
     // additional properties that are stored in the InstancePropeties object
     public static final String SERVER_ROOT_ATTR = "serverRoot";        // NOI18N
     public static final String DOMAIN_ROOT_ATTR = "domainRoot";        // NOI18N
-    //public static final String IS_LOCAL_ATTR = "isLocal";              // NOI18N
     public static final String HOST_ATTR = "host";                     // NOI18N
     public static final String PORT_ATTR = "port";                     // NOI18N
     public static final String REMOTE_ATTR = "remote";                 // NOI18N
+    public static final String SECURED_ATTR = "secured";               // NOI18N
     public static final String DEBUGGER_PORT_ATTR = "debuggerPort";    // NOI18N
-    public static final String ADMIN_SERVER_NAME= "adminName";      // NOI18N
     public static final String DOMAIN_NAME = "domainName";          // NOI18N
-    public static final String PRODUCTION_MODE = "productionMode";  // NOI18N
-    public static final String DOMAIN_VERSION = "domainVersion";  // NOI18N
+    public static final String REMOTE_DEBUG_ENABLED = "remoteDebug"; // NOI18N
+    public static final String PROXY_ENABLED = "proxy_enabled"; // NOI18N
 
     public static final String VENDOR   = "vendor";                 // NOI18N
     public static final String JAVA_OPTS="java_opts";               // NOI18N
@@ -162,21 +147,6 @@ public final class WLPluginProperties {
     private static final Pattern SHELL_DEFAULT_VENDOR_PATTERN = 
         Pattern.compile("\\s*(export)?\\s*JAVA_VENDOR\\s*=(.*)");
     
-    private static final Pattern LISTEN_ADDRESS_PATTERN = 
-        Pattern.compile("(?:[a-z]+\\:)?listen-address");            // NOI18N
-
-    private static final Pattern LISTEN_PORT_PATTERN = 
-        Pattern.compile("(?:[a-z]+\\:)?listen-port");               // NOI18N
-
-    private static final Pattern NAME_PATTERN = 
-        Pattern.compile("(?:[a-z]+\\:)?name");                      // NOI18N
-    
-    private static final  Pattern SERVER_PATTERN = 
-        Pattern.compile("(?:[a-z]+\\:)?server");                    // NOI18N
-    
-    private static final  Pattern ADMIN_SERVER_PATTERN = 
-        Pattern.compile("(?:[a-z]+\\:)?admin-server-name");         // NOI18N
-
     private static final String DOMAIN_LIST = "common/nodemanager/nodemanager.domains"; // NOI18N
 
     private static final String DOMAIN_REGISTRY = "domain-registry.xml"; // NOI18N
@@ -208,6 +178,9 @@ public final class WLPluginProperties {
     @CheckForNull
     public static FileObject getDomainConfigFileObject(WLDeploymentManager manager) {
         String domainDir = manager.getInstanceProperties().getProperty(WLPluginProperties.DOMAIN_ROOT_ATTR);
+        if (domainDir == null) {
+            return null;
+        }
         return getDomainConfigFileObject(new File(domainDir));
     }
 
@@ -229,8 +202,7 @@ public final class WLPluginProperties {
             // may happen during the registration
             return null;
         }
-        return FileUtil.normalizeFile(new File(domainDir + File.separator
-                + "config" + File.separator + "config.xml")); // NOI18N
+        return WebLogicLayout.getDomainConfigFile(new File(domainDir));
     }
 
     @CheckForNull
@@ -289,16 +261,10 @@ public final class WLPluginProperties {
         String server = (String) manager.getInstanceProperties().getProperty(WLPluginProperties.SERVER_ROOT_ATTR);
         if (server != null) {
             File serverFile = new File(server);
-            return getWeblogicJar(serverFile);
+            return WebLogicLayout.getWeblogicJar(serverFile);
         }
         return null;
-    }
-    
-    @NonNull
-    public static File getWeblogicJar(File serverFile) {
-        File weblogicJar = FileUtil.normalizeFile(new File(serverFile, WEBLOGIC_JAR));
-        return weblogicJar;
-    }    
+    }   
     
     /**
      * Gets the list of registered domains according to the given server
@@ -317,147 +283,6 @@ public final class WLPluginProperties {
         return result.toArray(new String[result.size()]);
     }
     
-    /**
-     * Returns map of server domain configuration properties red from config.xml file.
-     * Only properties required for the moment are returned.  
-     * Method implementation should be extended for additional properties. 
-     * return server configuration properties 
-     */
-    public static Properties getDomainProperties(String domainPath) {
-        Properties properties = new Properties();
-        String configPath = domainPath + "/config/config.xml"; // NOI18N
-
-        // init the input stream for the file and the w3c document object
-        InputStream inputStream = null;
-        Document document = null;
-
-        try {
-            // open the stream from the instances config file
-            File config = new File(configPath);
-            if (!config.exists()){
-                LOGGER.log(Level.FINE, "Domain config file "
-                        + "is not found. Probably server configuration was "
-                        + "changed externally"); // NOI18N
-                return properties;
-            }
-            inputStream = new FileInputStream(config);
-
-            // parse the document
-            document = DocumentBuilderFactory.newInstance()
-                    .newDocumentBuilder().parse(inputStream);
-
-            // get the root element
-            Element root = document.getDocumentElement();
-
-            // get the child nodes
-            NodeList children = root.getChildNodes();
-
-            String adminServer = null;
-            LinkedHashMap<String, ServerDescriptor> servers = new LinkedHashMap<String, ServerDescriptor>();
-            // for each child
-            for (int j = 0; j < children.getLength(); j++) {
-                Node child = children.item(j);
-                if ("name".equals(child.getNodeName())) {
-                    String domainName = child.getFirstChild().getNodeValue();
-                    properties.put(DOMAIN_NAME, domainName);
-                } else if ("domain-version".equals(child.getNodeName())) {
-                    String domainVersion = child.getFirstChild().getNodeValue();
-                    properties.put(DOMAIN_VERSION, domainVersion);
-                } else if ("production-mode-enabled".equals(child.getNodeName())) {
-                    String isEnabled = child.getFirstChild().getNodeValue();
-                    properties.put(PRODUCTION_MODE, "true".equals( isEnabled ));
-                } else if (ADMIN_SERVER_PATTERN.matcher(child.getNodeName()).matches()) {
-                    adminServer = child.getFirstChild().getNodeValue();
-                // if the child's name equals 'server' get its children
-                // and iterate over them
-                } else if (SERVER_PATTERN.matcher(child.getNodeName()).matches()) {
-                    NodeList nl = child.getChildNodes();
-
-                    // declare the server's name/host/port
-                    String name = ""; // NOI18N
-                    String port = ""; // NOI18N
-                    String host = ""; // NOI18N
-
-                    // iterate over the children
-                    for (int k = 0; k < nl.getLength(); k++) {
-                        Node ch = nl.item(k);
-
-                        // if the child's name equals 'name' fetch the
-                        // instance's name
-                        if (NAME_PATTERN.matcher(ch.getNodeName()).matches()) {
-                            name = ch.getFirstChild().getNodeValue();
-                        }
-
-                        // if the child's name equals 'listen-port' fetch the
-                        // instance's port
-                        if (LISTEN_PORT_PATTERN.matcher(ch.getNodeName())
-                                .matches())
-                        {
-                            port = ch.getFirstChild().getNodeValue();
-                        }
-
-                        // if the child's name equals 'listen-address' fetch the
-                        // instance's host
-                        if (LISTEN_ADDRESS_PATTERN.matcher(ch.getNodeName())
-                                .matches())
-                        {
-                            if (ch.hasChildNodes()) {
-                                host = ch.getFirstChild().getNodeValue();
-                            }
-                        }
-                    }
-
-                    if (port != null) {
-                        port = port.trim();
-                    }
-
-                    // if all the parameters were fetched successfully add
-                    // them to the result
-                    if ((name != null) && (!name.equals(""))) { // NOI18N
-                        // address and port have minOccurs=0 and are missing in
-                        // 90 examples server
-                        port = (port == null || port.equals("")) // NOI18N
-                        ? Integer.toString(WLDeploymentFactory.DEFAULT_PORT)
-                                : port;
-                        host = (host == null || host.equals("")) ? "localhost" // NOI18N
-                                : host;
-                        
-                        servers.put(name, new ServerDescriptor(host, port, name));
-                    }
-                }
-            }
-            ServerDescriptor admin = null;
-            if (adminServer != null) {
-                admin = servers.get(adminServer);
-            }
-            if (admin == null && !servers.isEmpty()) {
-                admin = servers.entrySet().iterator().next().getValue();
-            }
-            if (admin != null) {
-                properties.put(PORT_ATTR, admin.getPort());
-                properties.put(HOST_ATTR, admin.getHost());
-                properties.put(ADMIN_SERVER_NAME, admin.getName());
-            }
-        } catch (FileNotFoundException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } catch (IOException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } catch (ParserConfigurationException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } catch (SAXException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } finally {
-            try {
-                if (inputStream != null) {
-                    inputStream.close();
-                }
-            } catch (IOException e) {
-                LOGGER.log(Level.INFO, null, e);
-            }
-        }
-        return properties;
-    }
-    
     @CheckForNull
     public static String getDefaultPlatformHome() {
         Collection<FileObject> instFolders = JavaPlatformManager.getDefault().
@@ -476,6 +301,12 @@ public final class WLPluginProperties {
         String sunJavaHome = null; 
         properties.put(JAVA_HOME, javaHomeVendors);
 
+        // for remote instances domain is null
+        if (domainPath == null) {
+            javaHomeVendors.put("", getDefaultPlatformHome());
+            return properties;
+        }
+
         try {
             String setDomainEnv = domainPath + (Utilities.isWindows() ? "/bin/setDomainEnv.cmd" : "/bin/setDomainEnv.sh"); // NOI18N
             File file = new File(setDomainEnv);
@@ -483,11 +314,10 @@ public final class WLPluginProperties {
                 LOGGER.log(Level.INFO, "Domain environment "
                         + "setup {0} is not found. Probably server configuration was "
                         + "changed externally", setDomainEnv); // NOI18N
-                // FIXME DWP could be the web profile
                 javaHomeVendors.put("", getDefaultPlatformHome());
                 return properties;
             }
-            BufferedReader reader = new BufferedReader(new FileReader(file));
+            BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8"));
             try {
                 String line;
                 String vendorName = null;
@@ -582,27 +412,6 @@ public final class WLPluginProperties {
         return NbPreferences.forModule(WLPluginProperties.class);
     }
 
-    public static boolean isGoodServerLocation(File candidate){
-        if (null == candidate ||
-                !candidate.exists() ||
-                !candidate.canRead() ||
-                !candidate.isDirectory()  ||
-                !hasRequiredChildren(candidate, EXPECTED_FILES)) {
-            return false;
-        }
-        return true;
-    }
-
-    /**
-     * Checks whether the server root contains weblogic.jar of version 9, 10 or 11.
-     */
-    public static boolean isSupportedVersion(Version version) {
-        return version != null && (Integer.valueOf(9).equals(version.getMajor())
-                    || Integer.valueOf(10).equals(version.getMajor())
-                    || Integer.valueOf(11).equals(version.getMajor())
-                    || Integer.valueOf(12).equals(version.getMajor()));
-    }
-
     public static File[] getClassPath(WLDeploymentManager manager) {
         File serverRoot = WLPluginProperties.getServerRoot(manager, true);
         if (serverRoot == null) {
@@ -610,7 +419,7 @@ public final class WLPluginProperties {
             return new File[] {};
         }
 
-        File weblogicJar = WLPluginProperties.getWeblogicJar(serverRoot);
+        File weblogicJar = WebLogicLayout.getWeblogicJar(serverRoot);
         if (!weblogicJar.exists()) {
             LOGGER.log(Level.INFO, "File {0} does not exist for {1}",
                     new Object[] {weblogicJar.getAbsolutePath(), manager.getUri()});
@@ -670,7 +479,7 @@ public final class WLPluginProperties {
     }
 
     public static Version getServerVersion(File serverRoot) {
-        File weblogicJar = WLPluginProperties.getWeblogicJar(serverRoot);
+        File weblogicJar = WebLogicLayout.getWeblogicJar(serverRoot);
         if (!weblogicJar.exists()) {
             return null;
         }
@@ -701,36 +510,6 @@ public final class WLPluginProperties {
         return null;
     }
 
-    public static Version getDomainVersion(InstanceProperties props) {
-        // Domain config file
-        File config = getDomainConfigFile(props);
-
-        // Check if the file exists
-        if (config == null || !config.exists()) {
-            return null;
-        }
-
-        try {
-            InputSource source = new InputSource(new FileInputStream(config));
-            Document d = XMLUtil.parse(source, false, false, null, null);
-
-            // Retrieve domain version
-            if (d.getElementsByTagName("domain-version").getLength() > 0) {
-                String strVersion = d.getElementsByTagName("domain-version").item(0).getTextContent();
-                return  strVersion != null ? Version.fromJsr277OrDottedNotationWithFallback(strVersion) : null;
-            }
-
-        } catch(FileNotFoundException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } catch(IOException e) {
-            LOGGER.log(Level.INFO, null, e);
-        } catch(SAXException e) {
-            LOGGER.log(Level.INFO, null, e);
-        }
-
-        return null;
-    }
-
     @CheckForNull
     public static File getMiddlewareHome(File platformRootFile) {
         String mwHome = WLProductProperties.getMiddlewareHome(platformRootFile);
@@ -772,7 +551,7 @@ public final class WLPluginProperties {
         // read the list file line by line fetching out the domain paths
         try {
             // create a new reader for the FileInputStream
-            lnr = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
+            lnr = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8")); // NOI18N
 
             // read the lines
             String line;
@@ -929,31 +708,4 @@ public final class WLPluginProperties {
             return new JvmVendor(value, value);
         }
     }
-    
-    private static class ServerDescriptor {
-        
-        private final String host;
-        
-        private final String port;
-        
-        private final String name;
-
-        public ServerDescriptor(String host, String port, String name) {
-            this.host = host;
-            this.port = port;
-            this.name = name;
-        }
-
-        public String getHost() {
-            return host;
-        }
-
-        public String getName() {
-            return name;
-        }
-
-        public String getPort() {
-            return port;
-        }
-    }
 }
