@@ -45,6 +45,7 @@ package org.netbeans.modules.j2ee.weblogic9.deploy;
 
 import java.io.File;
 import java.io.InputStream;
+import java.lang.ref.WeakReference;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.Locale;
@@ -52,11 +53,13 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.CopyOnWriteArrayList;
@@ -91,10 +94,14 @@ import org.netbeans.modules.j2ee.deployment.plugins.api.InstanceProperties;
 import org.netbeans.modules.j2ee.deployment.plugins.spi.DeploymentContext;
 import org.netbeans.modules.j2ee.deployment.plugins.spi.DeploymentManager2;
 import org.netbeans.modules.j2ee.weblogic9.ProgressObjectSupport;
+import org.netbeans.modules.j2ee.weblogic9.ServerLogManager;
+import org.netbeans.modules.j2ee.weblogic9.VersionBridge;
 import org.netbeans.modules.j2ee.weblogic9.WLConnectionSupport;
+import org.netbeans.modules.j2ee.weblogic9.WLDeploymentFactory;
 import org.netbeans.modules.j2ee.weblogic9.WLPluginProperties;
 import org.netbeans.modules.j2ee.weblogic9.WLProductProperties;
 import org.netbeans.modules.j2ee.weblogic9.j2ee.WLJ2eePlatformFactory;
+import org.netbeans.modules.weblogic.common.api.WebLogicConfiguration;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
@@ -119,6 +126,40 @@ public class WLDeploymentManager implements DeploymentManager2 {
 
     private static final RequestProcessor OBJECT_POLL_RP = new RequestProcessor("ProgressObject Poll", 1);
 
+    private static final InstanceProperties EMPTY_PROPERTIES = new InstanceProperties() {
+
+        @Override
+        public void setProperties(Properties props) throws IllegalStateException {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+        @Override
+        public void setProperty(String propname, String value) throws IllegalStateException {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+        @Override
+        public String getProperty(String propname) throws IllegalStateException {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+        @Override
+        public Enumeration propertyNames() throws IllegalStateException {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+        @Override
+        public DeploymentManager getDeploymentManager() {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+        @Override
+        public void refreshServerInstance() {
+            throw new IllegalStateException("Already removed InstanceProperties");
+        }
+
+    };
+
     static {
         if (DEBUG_JSR88) {
             System.setProperty("weblogic.deployer.debug", "all"); // NOI18N
@@ -130,13 +171,15 @@ public class WLDeploymentManager implements DeploymentManager2 {
     private final String port;
 
     private final WLProductProperties productProperties = new WLProductProperties(this);
-    
+
     private final WLSharedState mutableState;
 
+    private final WebLogicConfiguration config;
+
     private final boolean disconnected;
 
     /* GuardedBy("this") */
-    private InstanceProperties instanceProperties;
+    private WeakReference<InstanceProperties> instanceProperties;
 
     /* GuardedBy("this") */
     private DeploymentManager manager;
@@ -147,6 +190,9 @@ public class WLDeploymentManager implements DeploymentManager2 {
     /* GuardedBy("this") */
     private WLConnectionSupport connectionSupport;
 
+    /* GuardedBy("this") */
+    private ServerLogManager logManager;
+
     /* GuardedBy("this") */
     private Version serverVersion;
 
@@ -159,6 +205,9 @@ public class WLDeploymentManager implements DeploymentManager2 {
     /* GuardedBy("this") */
     private boolean proxyMisconfigured;
 
+    /* GuardedBy("this") */
+    private Boolean remote;
+
     public WLDeploymentManager(String uri, String host, String port,
             boolean disconnected, WLSharedState mutableState) {
         this.uri = uri;
@@ -166,6 +215,18 @@ public class WLDeploymentManager implements DeploymentManager2 {
         this.port = port;
         this.disconnected = disconnected;
         this.mutableState = mutableState;
+        this.config = createConfiguration();
+    }
+
+    public WebLogicConfiguration getCommonConfiguration() {
+        return config;
+    }
+
+    public synchronized ServerLogManager getLogManager() {
+        if (logManager == null) {
+            logManager = new ServerLogManager(this);
+        }
+        return logManager;
     }
 
     /**
@@ -189,9 +250,11 @@ public class WLDeploymentManager implements DeploymentManager2 {
         return port;
     }
 
-    public boolean isRemote() {
-        // TODO optimize
-        return Boolean.parseBoolean(getInstanceProperties().getProperty(WLPluginProperties.REMOTE_ATTR));
+    public synchronized boolean isRemote() {
+        if (remote == null) {
+            remote = Boolean.valueOf(getInstanceProperties().getProperty(WLPluginProperties.REMOTE_ATTR));
+        }
+        return remote;
     }
     
     @CheckForNull
@@ -219,9 +282,21 @@ public class WLDeploymentManager implements DeploymentManager2 {
      */
     public synchronized InstanceProperties getInstanceProperties() {
         if (instanceProperties == null) {
-            instanceProperties = InstanceProperties.getInstanceProperties(uri);
+            instanceProperties = new WeakReference<InstanceProperties>(InstanceProperties.getInstanceProperties(uri));
         }
-        return instanceProperties;
+        InstanceProperties ip = instanceProperties.get();
+        if (ip == null) {
+            ip = EMPTY_PROPERTIES;
+        }
+        return ip;
+    }
+
+    @CheckForNull
+    public synchronized InstanceProperties getRealInstanceProperties() {
+        if (instanceProperties == null) {
+            instanceProperties = new WeakReference<InstanceProperties>(InstanceProperties.getInstanceProperties(uri));
+        }
+        return instanceProperties.get();
     }
 
     @NonNull
@@ -256,14 +331,6 @@ public class WLDeploymentManager implements DeploymentManager2 {
         mutableState.setRestartNeeded(restartNeeded);
     }
 
-    public Process getServerProcess() {
-        return mutableState.getServerProcess();
-    }
-
-    public void setServerProcess(Process serverProcess) {
-        mutableState.setServerProcess(serverProcess);
-    }
-
     public WLProductProperties getProductProperties() {
         return productProperties;
     }
@@ -273,7 +340,7 @@ public class WLDeploymentManager implements DeploymentManager2 {
             return;
         }
         serverVersion = WLPluginProperties.getServerVersion(WLPluginProperties.getServerRoot(this, true));
-        domainVersion = WLPluginProperties.getDomainVersion(instanceProperties);
+        domainVersion = VersionBridge.getVersion(getCommonConfiguration().getDomainVersion());
     }
 
     private <T> T executeAction(final Action<T> action) throws Exception {
@@ -326,8 +393,9 @@ public class WLDeploymentManager implements DeploymentManager2 {
             Class helperClazz = Class.forName("weblogic.deploy.api.tools.SessionHelper", // NOI18N
                     false, Thread.currentThread().getContextClassLoader());
             Method m = helperClazz.getDeclaredMethod("getDeploymentManager", // NOI18N
-                    new Class[]{String.class, String.class, String.class, String.class});
-            Object o = m.invoke(null, new Object[]{host, port, username, password});
+                    new Class[]{String.class, String.class, String.class, String.class, String.class});
+            boolean secured = getCommonConfiguration().isSecured();
+            Object o = m.invoke(null, new Object[]{secured ? "t3s" : "t3", host, port, username, password});
             if (DeploymentManager.class.isAssignableFrom(o.getClass())) {
                 manager = (DeploymentManager) o;
                 return manager;
@@ -353,7 +421,7 @@ public class WLDeploymentManager implements DeploymentManager2 {
             throw new IllegalStateException("Deployment manager is disconnected");
         }
         CommandBasedDeployer wlDeployer = new CommandBasedDeployer(this);
-        return wlDeployer.deploy(target, file, file2, getHost(), getPort());
+        return wlDeployer.deploy(target, file, file2, getHost(), getPort(), getCommonConfiguration().isSecured());
     }
 
     @Override
@@ -365,7 +433,8 @@ public class WLDeploymentManager implements DeploymentManager2 {
         deployOptionalPackages(deployment.getRequiredLibraries());
 
         CommandBasedDeployer wlDeployer = new CommandBasedDeployer(this);
-        return wlDeployer.deploy(targets, deployment.getModuleFile(), deployment.getDeploymentPlan(), getHost(), getPort());
+        return wlDeployer.deploy(targets, deployment.getModuleFile(), deployment.getDeploymentPlan(),
+                getHost(), getPort(), getCommonConfiguration().isSecured());
     }
 
     public ProgressObject distribute(Target[] target, ModuleType moduleType, InputStream inputStream, InputStream inputStream0) throws IllegalStateException {
@@ -649,6 +718,7 @@ public class WLDeploymentManager implements DeploymentManager2 {
         }
     }
 
+    // FIXME this should handle failed packages and timeout or return po
     public void deployOptionalPackages(File[] optionalPackages) {
         CommandBasedDeployer wlDeployer = new CommandBasedDeployer(this);
         if (optionalPackages.length > 0) {
@@ -658,6 +728,64 @@ public class WLDeploymentManager implements DeploymentManager2 {
         }
     }
 
+    private static class InstancePropertiesCredentials implements WebLogicConfiguration.Credentials {
+
+        private final WeakReference<InstanceProperties> ip;
+
+        public InstancePropertiesCredentials(InstanceProperties ip) {
+            this.ip = new WeakReference<InstanceProperties>(ip);
+        }
+
+        @Override
+        public String getUsername() {
+            InstanceProperties real = ip.get();
+            if (real == null) {
+                throw new IllegalStateException("Already removed InstanceProperties");
+            }
+            return real.getProperty(InstanceProperties.USERNAME_ATTR);
+        }
+
+        @Override
+        public String getPassword() {
+            InstanceProperties real = ip.get();
+            if (real == null) {
+                throw new IllegalStateException("Already removed InstanceProperties");
+            }
+            return real.getProperty(InstanceProperties.PASSWORD_ATTR);
+        }
+
+    }
+
+    @NonNull
+    private WebLogicConfiguration createConfiguration() {
+        InstanceProperties ip = getInstanceProperties();
+        WebLogicConfiguration.Credentials credentials = new InstancePropertiesCredentials(ip);
+
+        String serverHome = ip.getProperty(WLPluginProperties.SERVER_ROOT_ATTR);
+        String domainHome = ip.getProperty(WLPluginProperties.DOMAIN_ROOT_ATTR);
+
+        final WebLogicConfiguration config;
+        if (isRemote()) {
+            String uri = ip.getProperty(InstanceProperties.URL_ATTR);
+            // it is guaranteed it is WL
+            String[] parts = uri.substring(WLDeploymentFactory.URI_PREFIX.length()).split(":");
+
+            String host = parts[0];
+            String port = parts.length > 1 ? parts[1] : "";
+            int realPort;
+            try {
+                realPort = Integer.parseInt(port);
+            } catch (NumberFormatException ex) {
+                realPort = 7001;
+            }
+            boolean secured = Boolean.valueOf(ip.getProperty(WLPluginProperties.SECURED_ATTR));
+            config = WebLogicConfiguration.forRemoteDomain(new File(serverHome), host, realPort, secured, credentials);
+        } else {
+            config = WebLogicConfiguration.forLocalDomain(new File(serverHome), new File(domainHome), credentials);
+        }
+        return config;
+    }
+
     // XXX these are just temporary methods - should be replaced once we will
     // use our own TargetModuleID populated via JMX
     private TargetModuleID[] translateTargetModuleIDsToPlugin(TargetModuleID[] ids) {
@@ -723,7 +851,7 @@ public class WLDeploymentManager implements DeploymentManager2 {
         }
         return po;
     }
-
+    
     private static interface Action<T> {
 
          T execute(DeploymentManager manager) throws ExecutionException;
@@ -745,15 +873,42 @@ public class WLDeploymentManager implements DeploymentManager2 {
         @Override
         public String getWebURL() {
             String url = moduleId.getWebURL();
+            boolean secured = getCommonConfiguration().isSecured();
+
             if (url != null && url.startsWith("/")) { // NOI18N
-                url = "http://" + getHost() + ":" + getPort() + url; // NOI18N
+                url = (secured ? "https://" : "http://") + getHost() + ":" + getPort() + url; // NOI18N
             }
+            // TODO perhaps web url should be configurable separately
+            //if (isRemote()) {
+                if (url != null && (url.startsWith("http://") || url.startsWith("https://"))) { // NOI18N
+                    // start after http:// or https://
+                    int start = url.indexOf("//");
+                    assert start > 0;
+                    int end = url.indexOf('/', start + 2); //NOI18N
+                    if (end < 0) {
+                        end = url.length();
+                    }
+                    url = (secured ? "https://" : "http://") + getHost() + ":" + getPort() + url.substring(end); // NOI18n
+                }
+            //}
             return url;
         }
 
         @Override
         public Target getTarget() {
-            return moduleId.getTarget();
+            Target delegate = moduleId.getTarget();
+            if (delegate == null) {
+                return null;
+            }
+            String target = delegate.getName();
+            // the target returned from server is "myserver/server"
+            if (target != null) {
+                int index = target.indexOf("/server"); // NOI18N
+                if (index >= 0) {
+                    return new WLTarget(target.substring(index));
+                }
+            }
+            return target == null ? delegate : new WLTarget(target);
         }
 
         @Override
