@@ -261,7 +261,8 @@ public class WLIncrementalDeployment extends IncrementalDeployment implements In
         }
 
         CommandBasedDeployer deployer = new CommandBasedDeployer(dm);
-        return deployer.directoryDeploy(target, name, dir, dm.getHost(), dm.getPort(), app.getType());
+        return deployer.directoryDeploy(target, name, dir, dm.getHost(), dm.getPort(),
+                dm.getCommonConfiguration().isSecured(), app.getType());
     }
 
     @Override
@@ -278,7 +279,7 @@ public class WLIncrementalDeployment extends IncrementalDeployment implements In
 
     @Override
     public boolean isDeployOnSaveSupported() {
-        return true;
+        return !dm.isRemote();
     }
 
     @Override
