@@ -94,6 +94,7 @@ import org.netbeans.modules.j2ee.weblogic9.WLPluginProperties;
 import org.netbeans.modules.j2ee.weblogic9.config.WLServerLibrarySupport;
 import org.netbeans.modules.j2ee.weblogic9.config.WLServerLibrarySupport.WLServerLibrary;
 import org.netbeans.modules.javaee.specs.support.api.JaxWs;
+import org.netbeans.modules.weblogic.common.api.WebLogicLayout;
 import org.netbeans.modules.websvc.wsstack.api.WSStack;
 import org.netbeans.modules.websvc.wsstack.spi.WSStackFactory;
 import org.netbeans.spi.project.libraries.LibraryImplementation;
@@ -152,12 +153,20 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
 
     private static final Version JDK7_SUPPORTED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.1.1"); // NOI18N
 
+    private static final Version JDK8_SUPPORTED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.1.3"); // NOI18N
+
     private static final Version JPA2_SUPPORTED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.1.1"); // NOI18N
-    
+
     private static final Version JPA21_SUPPORTED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.1.3"); // NOI18N
 
+    // since 12.2.1 there is no separate JPA jar
+    private static final Version JPA21_BUNDLED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.2.1"); // NOI18N
+
     private static final Version JAX_RS_SUPPORTED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.1.1"); // NOI18N
 
+    // since 12.2.1 there is no separate JPA jar
+    private static final Version JAX_RS_BUNDLED_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.2.1"); // NOI18N
+
     @Override
     public J2eePlatformImpl getJ2eePlatformImpl(DeploymentManager dm) {
         assert WLDeploymentManager.class.isAssignableFrom(dm.getClass()) : this + " cannot create platform for unknown deployment manager:" + dm;
@@ -177,7 +186,7 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
         List<URL> list = new ArrayList<URL>();
         try {
             // the WLS jar is intentional
-            File weblogicFile = new File(platformRoot, WLPluginProperties.WEBLOGIC_JAR);
+            File weblogicFile = WebLogicLayout.getWeblogicJar(platformRoot);
             if (weblogicFile.exists()) {
                 addFileToList(list, weblogicFile);
             }
@@ -286,7 +295,9 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
                                                 addFileToList(urls, f);
                                             }
                                         }
-                                    } else {
+                                    // for some reason there is deployable war in api.jar in 12.2.1
+                                    } else if (!(f.getPath().contains("deployable-libraries") // NOI18N
+                                            && f.getName().endsWith(".war"))) { // NOI18N
                                         addFileToList(urls, f);
                                     }
                                 }
@@ -311,10 +322,26 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
     private static void addPersistenceLibrary(List<URL> list, @NonNull File serverRoot,
             @NullAllowed File middleware, @NullAllowed J2eePlatformImplImpl j2eePlatform) throws MalformedURLException {
 
+        Version serverVersion;
+        if (j2eePlatform != null) {
+            serverVersion = j2eePlatform.dm.getServerVersion();
+        } else {
+            serverVersion = WLPluginProperties.getServerVersion(serverRoot);
+        }
+        if (serverVersion != null && JPA21_BUNDLED_SERVER_VERSION.isBelowOrEqual(serverVersion)) {
+            if (j2eePlatform != null) {
+                synchronized (j2eePlatform) {
+                    j2eePlatform.jpa2Available = true;
+                    j2eePlatform.jpa21Available = true;
+                }
+            }
+            return;
+        }
+
         boolean foundJpa21 = false;
         boolean foundJpa2 = false;
         boolean foundJpa1 = false;
-        
+
         for (Iterator<URL> it = list.iterator(); it.hasNext(); ) {
             URL archiveUrl = FileUtil.getArchiveFile(it.next());
             if (archiveUrl != null) {
@@ -346,12 +373,6 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
             File modules = getMiddlewareModules(middleware);
             if (modules.exists() && modules.isDirectory()) {
                 List<FilenameFilter> filters = new ArrayList<FilenameFilter>(2);
-                Version serverVersion;
-                if (j2eePlatform != null) {
-                    serverVersion = j2eePlatform.dm.getServerVersion();
-                } else {
-                    serverVersion = WLPluginProperties.getServerVersion(serverRoot);
-                }
                 
                 // we have to remove jpa2 jar otherwise we would have both jpa2 and jpa21 on classpath
                 if (serverVersion != null && JPA21_SUPPORTED_SERVER_VERSION.isBelowOrEqual(serverVersion) && foundJpa2) {    
@@ -427,7 +448,8 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
                     public boolean accept(File dir, String name) {
                         return ((JERSEY_PATTERN.matcher(name).matches() || JERSEY_PLAIN_PATTERN.matcher(name).matches())
                                 && serverVersion != null
-                                && JAX_RS_SUPPORTED_SERVER_VERSION.isBelowOrEqual(serverVersion))
+                                && JAX_RS_SUPPORTED_SERVER_VERSION.isBelowOrEqual(serverVersion)
+                                && !JAX_RS_BUNDLED_SERVER_VERSION.isBelowOrEqual(serverVersion))
                                         || GLASSFISH_JAXWS_PATTERN.matcher(name).matches();
                     }
                 };
@@ -459,7 +481,8 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
         }
     }
 
-    private static File getMiddlewareModules(File middleware) {
+    @NonNull
+    public static File getMiddlewareModules(File middleware) {
         File modules = new File(middleware, "modules"); // NOI18N
         if (!modules.exists() || !modules.isDirectory()) {
             modules = new File(new File(middleware, "oracle_common"), "modules"); // NOI18N
@@ -512,10 +535,13 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
 
             // Allow J2EE 1.4 Projects
             profiles.add(Profile.J2EE_14);
-            
+
             // Check for WebLogic Server 10x to allow Java EE 5 Projects
             Version version = dm.getDomainVersion();
-            
+            if (version == null) {
+                version = dm.getServerVersion();
+            }
+
             if (version != null) {
                 if (version.isAboveOrEqual(WLDeploymentFactory.VERSION_10)) {
                     profiles.add(Profile.JAVA_EE_5);
@@ -524,6 +550,10 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
                     profiles.add(Profile.JAVA_EE_6_FULL);
                     profiles.add(Profile.JAVA_EE_6_WEB);
                 }
+                if (version.isAboveOrEqual(WLDeploymentFactory.VERSION_1221)) {
+                    profiles.add(Profile.JAVA_EE_7_FULL);
+                    profiles.add(Profile.JAVA_EE_7_WEB);
+                }
             }
 
             domainChangeListener = new DomainChangeListener(this);
@@ -613,6 +643,9 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
                 if (serverVersion.isAboveOrEqual(JDK7_SUPPORTED_SERVER_VERSION)) {
                     versions.add("1.7"); // NOI18N
                 }
+                if (serverVersion.isAboveOrEqual(JDK8_SUPPORTED_SERVER_VERSION)) {
+                    versions.add("1.8"); // NOI18N
+                }
             }
             return versions;
         }
@@ -636,6 +669,10 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
 
         @Override
         public File getDomainHome() {
+            if (dm.isRemote()) {
+                return null;
+            }
+
             File domain = new File(dm.getInstanceProperties().getProperty(
                     WLPluginProperties.DOMAIN_ROOT_ATTR));
             
@@ -643,6 +680,7 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
             return domain;
         }
 
+        @NonNull
         @Override
         public File getServerHome() {
             File server = new File(getPlatformRoot());
@@ -670,10 +708,11 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
         public LibraryImplementation[] getLibraries(Set<ServerLibraryDependency> libraries) {
             // FIXME cache & listen for file changes
             String domainDir = dm.getInstanceProperties().getProperty(WLPluginProperties.DOMAIN_ROOT_ATTR);
-            assert domainDir != null;
+            assert domainDir != null || dm.isRemote();
             String serverDir = dm.getInstanceProperties().getProperty(WLPluginProperties.SERVER_ROOT_ATTR);
             assert serverDir != null;
-            WLServerLibrarySupport support = new WLServerLibrarySupport(new File(serverDir), new File(domainDir));
+            WLServerLibrarySupport support = new WLServerLibrarySupport(new File(serverDir),
+                    domainDir == null ? null : new File(domainDir));
 
             Map<ServerLibrary, List<File>> serverLibraries =  null;
             try {
@@ -879,9 +918,15 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
                 platform.defaultJpaProvider = null;
             }
 
-            Set<WLServerLibrary> tmpNewLibraries =
-                    new WLServerLibrarySupport(platform.dm).getDeployedLibraries();
-            Set<WLServerLibrary> tmpOldLibraries = null;
+            Set<WLServerLibrary> tmpNewLibraries;
+            // #249289 - deleted server may still listen until GCed
+            if (platform.dm.getRealInstanceProperties() != null) {
+                tmpNewLibraries = new WLServerLibrarySupport(platform.dm).getDeployedLibraries();
+            } else {
+                tmpNewLibraries = Collections.emptySet();
+            }
+
+            Set<WLServerLibrary> tmpOldLibraries;
             synchronized (this) {
                 tmpOldLibraries = new HashSet<WLServerLibrary>(oldLibraries);
                 oldLibraries = tmpNewLibraries;
@@ -917,7 +962,7 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
 
         private String defaultJPAProvider;
 
-        private String value;
+        private final StringBuilder value = new StringBuilder();
 
         private boolean start;
 
@@ -927,7 +972,7 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
 
         @Override
         public void startElement(String uri, String localName, String qName, org.xml.sax.Attributes attributes) throws SAXException {
-            value = null;
+            value.setLength(0);
             if ("default-jpa-provider".equals(qName)) { // NOI18N
                 start = true;
             }
@@ -940,14 +985,14 @@ public class WLJ2eePlatformFactory extends J2eePlatformFactory {
             }
 
             if ("default-jpa-provider".equals(qName)) { // NOI18N
-                defaultJPAProvider = value;
+                defaultJPAProvider = value.toString();
                 start = false;
             }
         }
 
         @Override
         public void characters(char[] ch, int start, int length) {
-            value = new String(ch, start, length);
+            value.append(ch, start, length);
         }
 
         public String getDefaultJPAProvider() {
