@@ -44,16 +44,17 @@ package org.netbeans.modules.j2ee.weblogic9.registration;
 
 import java.io.File;
 import java.io.IOException;
-import java.util.Properties;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.netbeans.modules.j2ee.deployment.common.api.Version;
 import org.netbeans.modules.j2ee.deployment.plugins.api.InstanceProperties;
 import org.netbeans.modules.j2ee.weblogic9.WLDeploymentFactory;
 import org.netbeans.modules.j2ee.weblogic9.WLPluginProperties;
 import org.netbeans.modules.j2ee.weblogic9.ui.wizard.WLInstantiatingIterator;
+import org.netbeans.modules.weblogic.common.api.DomainConfiguration;
+import org.netbeans.modules.weblogic.common.api.Version;
+import org.netbeans.modules.weblogic.common.api.WebLogicLayout;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.NbBundle;
@@ -64,15 +65,17 @@ import org.openide.util.Utilities;
  * directory. Designed to be called from installer.
  * <p>
  * Sample command line<br>
- * java -cp platform/core/core.jar:platform/lib/boot.jar:platform/lib/org-openide-modules.jar:platform/core/org-openide-filesystems.jar:platform/lib/org-openide-util.jar:platform/lib/org-openide-util-lookup.jar:enterprise/modules/org-netbeans-modules-j2eeapis.jar:enterprise/modules/org-netbeans-modules-j2eeserver.jar:enterprise/modules/org-netbeans-modules-j2ee-weblogic9.jar org.netbeans.modules.j2ee.weblogic9.registration.AutomaticRegistration %lt;clusterDir&gt; &lt;serverDir&gt; &lt;domainDir&gt; &lt;username&gt; &lt;password&gt;
+ * java -cp platform/core/core.jar:platform/core/core-base.jar:platform/lib/boot.jar:platform/lib/org-openide-modules.jar:platform/core/org-openide-filesystems.jar:platform/lib/org-openide-util.jar:platform/lib/org-openide-util-lookup.jar:platform/lib/org-openide-util-ui.jar:enterprise/modules/org-netbeans-modules-j2eeapis.jar:enterprise/modules/org-netbeans-modules-j2eeserver.jar:enterprise/modules/org-netbeans-modules-j2ee-weblogic9.jar:enterprise/modules/org-netbeans-modules-weblogic-common.jar org.netbeans.modules.j2ee.weblogic9.registration.AutomaticRegistration --add %lt;clusterDir&gt; &lt;serverDir&gt; &lt;domainDir&gt; &lt;username&gt; &lt;password&gt;
  *
  * @author Petr Hejl
- * @see #main(args)
+ * @see #main(java.lang.String[]) 
  */
 public class AutomaticRegistration {
 
     private static final Logger LOGGER = Logger.getLogger(AutomaticRegistration.class.getName());
 
+    private static Version JDK8_ONLY_SERVER_VERSION = Version.fromJsr277NotationWithFallback("12.2.1"); // NOI18N
+
     /**
      * Performs registration/uregistration of server instance. May also list
      * existing weblogic instances.
@@ -161,50 +164,42 @@ public class AutomaticRegistration {
             return 4;
         }
 
-        Version version = WLPluginProperties.getServerVersion(serverDir);
-        if (!WLPluginProperties.isSupportedVersion(version)) {
+        Version version = WebLogicLayout.getServerVersion(serverDir);
+        if (!WebLogicLayout.isSupportedVersion(version)) {
             LOGGER.log(Level.INFO, "Cannot register the default WebLogic server. "
                     + " The version " + version + " is not supported."); // NOI18N
             return 5;
         }
 
-        Properties properties = WLPluginProperties.getDomainProperties(domainDir.getAbsolutePath());
-        if (properties.isEmpty()) {
+        DomainConfiguration config = WebLogicLayout.getDomainConfiguration(domainDir.getAbsolutePath());
+        if (config == null) {
             LOGGER.log(Level.INFO, "Cannot register the default WebLogic server. "
                     + " The domain " + domainDirValue + " is not valid domain."); // NOI18N
             return 6;
         }
 
-        String name = properties.getProperty(WLPluginProperties.ADMIN_SERVER_NAME);
-        String port = properties.getProperty(WLPluginProperties.PORT_ATTR);
-        String host = properties.getProperty(WLPluginProperties.HOST_ATTR);
-        String domainName = properties.getProperty(WLPluginProperties.DOMAIN_NAME);
-        String versionString = properties.getProperty(WLPluginProperties.DOMAIN_VERSION);
-        Version domainVersion = versionString != null ? Version.fromJsr277OrDottedNotationWithFallback(versionString) : null;
-        Boolean isProductionMode = (Boolean) properties.get(WLPluginProperties.PRODUCTION_MODE);
-        if ((name != null) && (!name.equals(""))) { // NOI18N
-            // address and port have minOccurs=0 and are missing in 90
-            // examples server
-            port = (port == null || port.equals("")) // NOI18N
-            ? Integer.toString(WLDeploymentFactory.DEFAULT_PORT)
-                    : port;
-            host = (host == null || host.equals("")) ? "localhost" // NOI18N
-                    : host;
-        } else {
+        String name = config.getAdminServer();
+        int port = config.getPort();
+        String host = config.getHost();
+        String domainName = config.getName();
+        Version domainVersion = config.getVersion();
+        boolean isProductionMode = config.isProduction();
+        if (name == null) {
             LOGGER.log(Level.INFO, "Cannot register the default WebLogic server. "
                     + " The domain name is empty."); // NOI18N
             return 7;
         }
 
-        if (isProductionMode != null && isProductionMode.booleanValue()) {
+        if (isProductionMode) {
             LOGGER.log(Level.INFO, "Cannot register the default WebLogic server. "
                     + " The domain is in production mode."); // NOI18N
             return 8;
         }
 
+        // we do expand version string here because one may be 12.1.4.0 while the other may be 12.1.4.0.0
         if (domainVersion != null
                 && version != null
-                && !version.equals(domainVersion)) {
+                && !version.expand("0").equals(domainVersion.expand("0"))) { // NOI18N
             LOGGER.log(Level.INFO, "Cannot register the default WebLogic server. "
                     + " The domain version does not match the server version."); // NOI18N
             return 9;
@@ -231,7 +226,7 @@ public class AutomaticRegistration {
         String displayName = generateUniqueDisplayName(serverInstanceDir, version);
         boolean ok = registerServerInstanceFO(serverInstanceDir, url, displayName,
                 serverDir.getAbsolutePath(), domainDir.getAbsolutePath(), domainName,
-                port, username, password, javaOpts);
+                Integer.toString(port), username, password, javaOpts, version);
         if (ok) {
             return 0;
         } else {
@@ -343,7 +338,7 @@ public class AutomaticRegistration {
      */
     private static boolean registerServerInstanceFO(FileObject serverInstanceDir, String url,
             String displayName, String serverRoot, String domainRoot, String domainName,
-            String port, String username, String password, String javaOpts) {
+            String port, String username, String password, String javaOpts, Version version) {
 
         String name = FileUtil.findFreeFileName(serverInstanceDir, "weblogic_autoregistered_instance", null); // NOI18N
         FileObject instanceFO;
@@ -358,14 +353,20 @@ public class AutomaticRegistration {
             instanceFO.setAttribute(WLPluginProperties.DOMAIN_ROOT_ATTR, domainRoot);
             instanceFO.setAttribute(WLPluginProperties.DEBUGGER_PORT_ATTR,
                     WLInstantiatingIterator.DEFAULT_DEBUGGER_PORT);
+            instanceFO.setAttribute(WLPluginProperties.PROXY_ENABLED,
+                    WLInstantiatingIterator.DEFAULT_PROXY_ENABLED);
             instanceFO.setAttribute(WLPluginProperties.DOMAIN_NAME, domainName);
             instanceFO.setAttribute(WLPluginProperties.PORT_ATTR, port);
             if (javaOpts != null) {
                 instanceFO.setAttribute(WLPluginProperties.JAVA_OPTS, javaOpts);
             }
             if (Utilities.isMac()) {
-                instanceFO.setAttribute(WLPluginProperties.MEM_OPTS,
-                        WLInstantiatingIterator.DEFAULT_MAC_MEM_OPTS);
+                StringBuilder memOpts = new StringBuilder(WLInstantiatingIterator.DEFAULT_MAC_MEM_OPTS_HEAP);
+                if (version != null && !JDK8_ONLY_SERVER_VERSION.isBelowOrEqual(version)) {
+                    memOpts.append(' '); // NOI18N
+                    memOpts.append(WLInstantiatingIterator.DEFAULT_MAC_MEM_OPTS_PERM);
+                }
+                instanceFO.setAttribute(WLPluginProperties.MEM_OPTS, memOpts.toString());
             }
             return true;
         } catch (IOException e) {
