@@ -49,13 +49,19 @@
 package org.netbeans.modules.j2ee.weblogic9.ui.nodes;
 
 import java.awt.Font;
-import java.util.Properties;
+import javax.swing.event.AncestorEvent;
+import javax.swing.event.AncestorListener;
+import org.netbeans.api.progress.BaseProgressUtils;
 
 
 import org.netbeans.modules.j2ee.deployment.plugins.api.InstanceProperties;
 import org.netbeans.modules.j2ee.weblogic9.WLPluginProperties;
+import org.netbeans.modules.j2ee.weblogic9.WLTrustHandler;
 import org.netbeans.modules.j2ee.weblogic9.deploy.WLDeploymentManager;
 import org.netbeans.modules.j2ee.weblogic9.deploy.WLJpa2SwitchSupport;
+import org.netbeans.modules.weblogic.common.api.WebLogicConfiguration;
+import org.openide.DialogDisplayer;
+import org.openide.NotifyDescriptor;
 import org.openide.awt.Mnemonics;
 import org.openide.util.NbBundle;
 
@@ -104,34 +110,68 @@ class CustomizerGeneral extends javax.swing.JPanel {
         String domainRoot = manager.getInstanceProperties().getProperty( 
                 WLPluginProperties.DOMAIN_ROOT_ATTR);
         domainFolder.setText( domainRoot );
-        String domain = manager.getInstanceProperties().getProperty( WLPluginProperties.DOMAIN_NAME);
-        String port = manager.getInstanceProperties().getProperty( WLPluginProperties.PORT_ATTR);
-        Properties properties = null;
-        if ( domain== null || port == null ){
-            properties = WLPluginProperties.getDomainProperties(domainRoot);
+        String domain = manager.getInstanceProperties().getProperty(WLPluginProperties.DOMAIN_NAME);
+        String host = manager.getInstanceProperties().getProperty(WLPluginProperties.HOST_ATTR);
+        String port = manager.getInstanceProperties().getProperty(WLPluginProperties.PORT_ATTR);
+        String securedString = manager.getInstanceProperties().getProperty(WLPluginProperties.SECURED_ATTR);
+        Boolean secured = securedString == null ? null : Boolean.valueOf(securedString);
+        WebLogicConfiguration config = null;
+        if (domain == null || host == null || port == null || secured == null) {
+            config = manager.getCommonConfiguration();
         }
-        if ( domain == null ){
-            domain = properties.getProperty(WLPluginProperties.DOMAIN_NAME);
+        if (domain == null) {
+            domain = config.getDomainName();
         }
-        if ( port == null ){
-            port = properties.getProperty(WLPluginProperties.PORT_ATTR);
+        if (host == null) {
+            host = config.getHost();
         }
-        if ( domain!= null ) {
-            domainName.setText( domain );
+        if (port == null) {
+            port = Integer.toString(config.getPort());
         }
-        if ( port!= null){
-            serverPort.setText( port );
+        if (domain != null) {
+            domainName.setText(domain);
         }
-        
+        if (host != null) {
+            serverHost.setText(host);
+        }
+        if (port != null) {
+            serverPort.setText(port);
+        }
+        if (secured == null) {
+            secured = config.isSecured();
+        }
+
+        sslCheckBox.setSelected(secured);
+        certificateButton.setEnabled(sslCheckBox.isSelected());
+
         boolean statusVisible = support.isSwitchSupported();
         boolean buttonVisible = statusVisible
                 && !support.isEnabledViaSmartUpdate();
 
-        
         jpa2SwitchLabel.setVisible(statusVisible);
         jpa2Status.setVisible(statusVisible);
         jpa2SwitchButton.setVisible(buttonVisible);
         updateJpa2Status();
+
+        noteChangesLabel.setVisible(!manager.isRemote());
+
+        if (manager.isRemote()) {
+            addAncestorListener(new AncestorListener() {
+
+                @Override
+                public void ancestorRemoved(AncestorEvent event) {
+                    manager.getInstanceProperties().refreshServerInstance();
+                }
+
+                @Override
+                public void ancestorAdded(AncestorEvent event) {
+                }
+
+                @Override
+                public void ancestorMoved(AncestorEvent event) {
+                }
+            });
+        }
     }
 
     private void updateJpa2Status() {
@@ -164,11 +204,15 @@ class CustomizerGeneral extends javax.swing.JPanel {
         passwordField = new javax.swing.JPasswordField();
         showButton = new javax.swing.JButton();
         serverPortLabel = new javax.swing.JLabel();
-        NoteChangesLabel = new javax.swing.JLabel();
+        noteChangesLabel = new javax.swing.JLabel();
         serverPort = new javax.swing.JTextField();
         jpa2SwitchLabel = new javax.swing.JLabel();
         jpa2Status = new javax.swing.JLabel();
         jpa2SwitchButton = new javax.swing.JButton();
+        serverHostLabel = new javax.swing.JLabel();
+        serverHost = new javax.swing.JTextField();
+        sslCheckBox = new javax.swing.JCheckBox();
+        certificateButton = new javax.swing.JButton();
 
         domainNameLabel.setLabelFor(domainName);
         org.openide.awt.Mnemonics.setLocalizedText(domainNameLabel, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "LBL_CustomizerDomainName")); // NOI18N
@@ -198,7 +242,7 @@ class CustomizerGeneral extends javax.swing.JPanel {
         serverPortLabel.setLabelFor(serverPort);
         org.openide.awt.Mnemonics.setLocalizedText(serverPortLabel, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "LBL_ServerPort")); // NOI18N
 
-        org.openide.awt.Mnemonics.setLocalizedText(NoteChangesLabel, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "LBL_Note")); // NOI18N
+        org.openide.awt.Mnemonics.setLocalizedText(noteChangesLabel, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "LBL_Note")); // NOI18N
 
         serverPort.setEditable(false);
 
@@ -214,6 +258,21 @@ class CustomizerGeneral extends javax.swing.JPanel {
             }
         });
 
+        serverHostLabel.setLabelFor(serverHost);
+        org.openide.awt.Mnemonics.setLocalizedText(serverHostLabel, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "CustomizerGeneral.serverHostLabel.text")); // NOI18N
+
+        serverHost.setEditable(false);
+
+        org.openide.awt.Mnemonics.setLocalizedText(sslCheckBox, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "CustomizerGeneral.sslCheckBox.text")); // NOI18N
+        sslCheckBox.setEnabled(false);
+
+        org.openide.awt.Mnemonics.setLocalizedText(certificateButton, org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "CustomizerGeneral.certificateButton.text")); // NOI18N
+        certificateButton.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                certificateButtonActionPerformed(evt);
+            }
+        });
+
         javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
@@ -221,33 +280,42 @@ class CustomizerGeneral extends javax.swing.JPanel {
             .addGroup(layout.createSequentialGroup()
                 .addContainerGap()
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                    .addComponent(adminInfoLabel)
-                    .addComponent(NoteChangesLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                    .addComponent(noteChangesLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 489, Short.MAX_VALUE)
                     .addGroup(layout.createSequentialGroup()
                         .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                             .addComponent(domainNameLabel)
                             .addComponent(domainFolderLabel)
                             .addComponent(userNameLabel)
                             .addComponent(passwordLabel)
+                            .addComponent(serverHostLabel)
                             .addComponent(serverPortLabel))
-                        .addGap(18, 18, 18)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                         .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                            .addComponent(serverPort, javax.swing.GroupLayout.PREFERRED_SIZE, 55, javax.swing.GroupLayout.PREFERRED_SIZE)
-                            .addComponent(domainFolder, javax.swing.GroupLayout.DEFAULT_SIZE, 333, Short.MAX_VALUE)
-                            .addComponent(domainName, javax.swing.GroupLayout.DEFAULT_SIZE, 333, Short.MAX_VALUE)
+                            .addComponent(domainName)
+                            .addComponent(domainFolder)
                             .addGroup(layout.createSequentialGroup()
-                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
-                                    .addComponent(passwordField, javax.swing.GroupLayout.Alignment.LEADING)
-                                    .addComponent(userName, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 129, Short.MAX_VALUE))
+                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
+                                    .addGroup(layout.createSequentialGroup()
+                                        .addComponent(serverPort, javax.swing.GroupLayout.PREFERRED_SIZE, 55, javax.swing.GroupLayout.PREFERRED_SIZE)
+                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
+                                        .addComponent(sslCheckBox))
+                                    .addComponent(passwordField, javax.swing.GroupLayout.DEFAULT_SIZE, 160, Short.MAX_VALUE)
+                                    .addComponent(userName)
+                                    .addComponent(serverHost))
                                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                                    .addComponent(jpa2SwitchButton)
-                                    .addComponent(showButton))
-                                .addGap(65, 65, 65))))
+                                    .addComponent(certificateButton)
+                                    .addComponent(showButton)
+                                    .addComponent(jpa2SwitchButton))
+                                .addGap(0, 0, Short.MAX_VALUE))))
                     .addGroup(layout.createSequentialGroup()
-                        .addComponent(jpa2SwitchLabel)
-                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
-                        .addComponent(jpa2Status)))
+                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                            .addComponent(adminInfoLabel)
+                            .addGroup(layout.createSequentialGroup()
+                                .addComponent(jpa2SwitchLabel)
+                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
+                                .addComponent(jpa2Status)))
+                        .addGap(0, 0, Short.MAX_VALUE)))
                 .addContainerGap())
         );
         layout.setVerticalGroup(
@@ -272,17 +340,23 @@ class CustomizerGeneral extends javax.swing.JPanel {
                     .addComponent(passwordLabel)
                     .addComponent(passwordField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                     .addComponent(showButton))
-                .addGap(18, 18, 18)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
+                    .addComponent(serverHostLabel)
+                    .addComponent(serverHost, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                     .addComponent(serverPortLabel)
-                    .addComponent(serverPort, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
-                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                    .addComponent(serverPort, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                    .addComponent(sslCheckBox)
+                    .addComponent(certificateButton))
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                     .addComponent(jpa2SwitchLabel)
                     .addComponent(jpa2Status)
                     .addComponent(jpa2SwitchButton))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
-                .addComponent(NoteChangesLabel)
+                .addComponent(noteChangesLabel)
                 .addContainerGap())
         );
 
@@ -305,8 +379,8 @@ class CustomizerGeneral extends javax.swing.JPanel {
         showButton.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSD_ShowButton")); // NOI18N
         serverPortLabel.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSN_ServerPort")); // NOI18N
         serverPortLabel.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSD_ServerPort")); // NOI18N
-        NoteChangesLabel.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSN_Note")); // NOI18N
-        NoteChangesLabel.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSD_Note")); // NOI18N
+        noteChangesLabel.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSN_Note")); // NOI18N
+        noteChangesLabel.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(CustomizerGeneral.class, "ACSD_Note")); // NOI18N
         serverPort.getAccessibleContext().setAccessibleName(serverPortLabel.getAccessibleContext().getAccessibleName());
         serverPort.getAccessibleContext().setAccessibleDescription(serverPortLabel.getAccessibleContext().getAccessibleDescription());
     }// </editor-fold>//GEN-END:initComponents
@@ -343,11 +417,32 @@ class CustomizerGeneral extends javax.swing.JPanel {
         }
         updateJpa2Status();
     }//GEN-LAST:event_jpa2SwitchButtonActionPerformed
+
+    @NbBundle.Messages({
+        "MSG_ContactingServer=Contacting the server",
+        "MSG_ConnectionFailed=Could not connect to the server. It is either not running or not accessible at the moment."
+    })
+    private void certificateButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_certificateButtonActionPerformed
+        manager.getInstanceProperties().setProperty(WLTrustHandler.TRUST_EXCEPTION_PROPERTY, null);
+        BaseProgressUtils.showProgressDialogAndRun(new Runnable() {
+
+            @Override
+            public void run() {
+                boolean connected = WLTrustHandler.check(manager.getCommonConfiguration());
+                if (!connected) {
+                    NotifyDescriptor desc = new NotifyDescriptor.Message(Bundle.MSG_ConnectionFailed(),
+                            NotifyDescriptor.ERROR_MESSAGE);
+                    DialogDisplayer.getDefault().notify(desc);
+                }
+            }
+        }, Bundle.MSG_ContactingServer());
+
+    }//GEN-LAST:event_certificateButtonActionPerformed
     
 
     // Variables declaration - do not modify//GEN-BEGIN:variables
-    private javax.swing.JLabel NoteChangesLabel;
     private javax.swing.JLabel adminInfoLabel;
+    private javax.swing.JButton certificateButton;
     private javax.swing.JTextField domainFolder;
     private javax.swing.JLabel domainFolderLabel;
     private javax.swing.JTextField domainName;
@@ -355,11 +450,15 @@ class CustomizerGeneral extends javax.swing.JPanel {
     private javax.swing.JLabel jpa2Status;
     private javax.swing.JButton jpa2SwitchButton;
     private javax.swing.JLabel jpa2SwitchLabel;
+    private javax.swing.JLabel noteChangesLabel;
     private javax.swing.JPasswordField passwordField;
     private javax.swing.JLabel passwordLabel;
+    private javax.swing.JTextField serverHost;
+    private javax.swing.JLabel serverHostLabel;
     private javax.swing.JTextField serverPort;
     private javax.swing.JLabel serverPortLabel;
     private javax.swing.JButton showButton;
+    private javax.swing.JCheckBox sslCheckBox;
     private javax.swing.JTextField userName;
     private javax.swing.JLabel userNameLabel;
     // End of variables declaration//GEN-END:variables
