@@ -44,6 +44,7 @@ package org.netbeans.modules.j2ee.deployment.impl;
 
 import java.io.File;
 import java.io.IOException;
+import java.lang.ref.WeakReference;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -91,8 +92,6 @@ public final class DeployOnSaveManager {
 
         MODULE_UPDATED,
 
-        MODULE_HOT_SWAPPED,
-
         DEPLOYMENT_FAILED,
 
         SERVER_STATE_UNSUPPORTED
@@ -350,12 +349,12 @@ public final class DeployOnSaveManager {
     
     private static final class CompileOnSaveListener implements ArtifactsUpdated {
 
-        private final J2eeModuleProvider provider;
+        private final WeakReference<J2eeModuleProvider> provider;
 
         private final List<URL> registered;
 
         public CompileOnSaveListener(J2eeModuleProvider provider, List<URL> registered) {
-            this.provider = provider;
+            this.provider = new WeakReference<J2eeModuleProvider>(provider);
             this.registered = registered;
         }
 
@@ -364,7 +363,12 @@ public final class DeployOnSaveManager {
         }
 
         public void artifactsUpdated(Iterable<File> artifacts) {
-            J2eeModuleProvider.DeployOnSaveClassInterceptor interceptor = provider.getDeployOnSaveClassInterceptor();
+            J2eeModuleProvider realProvider = provider.get();
+            if (realProvider == null) {
+                return;
+            }
+
+            J2eeModuleProvider.DeployOnSaveClassInterceptor interceptor = realProvider.getDeployOnSaveClassInterceptor();
             Set<Artifact> realArtifacts = new HashSet<Artifact>();
             for (File file : artifacts) {
                 if (file != null) {
@@ -381,28 +385,31 @@ public final class DeployOnSaveManager {
                     LOGGER.log(Level.FINE, "Delivered compile artifact: {0}", artifact);
                 }
             }
-            DeployOnSaveManager.getDefault().submitChangedArtifacts(provider, realArtifacts);
+            DeployOnSaveManager.getDefault().submitChangedArtifacts(realProvider, realArtifacts);
         }
 
     }
 
     private static final class CopyOnSaveListener implements ArtifactListener {
 
-        private final J2eeModuleProvider provider;
+        private final WeakReference<J2eeModuleProvider> provider;
 
         public CopyOnSaveListener(J2eeModuleProvider provider) {
-            this.provider = provider;
+            this.provider = new WeakReference<J2eeModuleProvider>(provider);
         }
 
+        @Override
         public void artifactsUpdated(Iterable<Artifact> artifacts) {
             if (LOGGER.isLoggable(Level.FINE)) {
                 for (Artifact artifact : artifacts) {
                     LOGGER.log(Level.FINE, "Delivered copy artifact: {0}", artifact);
                 }
             }
-            DeployOnSaveManager.getDefault().submitChangedArtifacts(provider, artifacts);
+            J2eeModuleProvider realProvider = provider.get();
+            if (realProvider != null) {
+                DeployOnSaveManager.getDefault().submitChangedArtifacts(realProvider, artifacts);
+            }
         }
-
     }
 
     private class DeployTask implements Runnable {
@@ -546,6 +553,10 @@ public final class DeployOnSaveManager {
             // standard incremental deploy
             } else {
                 state = server.notifyArtifactsUpdated(provider, artifacts);
+                if (state == DeploymentState.SERVER_STATE_UNSUPPORTED
+                        && lastState == DeploymentState.MODULE_NOT_DEPLOYED) {
+                    state = DeploymentState.MODULE_NOT_DEPLOYED;
+                }
             }
 
             if (state == DeploymentState.MODULE_UPDATED) {
