@@ -403,6 +403,8 @@ public class ServerInstance implements Node.Cookie, Comparable {
                         reset();
                         setServerState(ServerInstance.STATE_STOPPED);
                     }
+                } catch (RuntimeException ex) {
+                    LOGGER.log(Level.INFO, null, ex);
                 } finally {
                     // safety catch - make sure that we are not still waiting
                     if (getServerState() == STATE_WAITING) {
@@ -1035,6 +1037,15 @@ public class ServerInstance implements Node.Cookie, Comparable {
      *         <code>false/code> otherwise.
      */
     public boolean isDebugSupported() {
+        StartServer ss = getStartServer();
+        if (ss == null) {
+            return false;
+        }
+        return ss.supportsStartDebugging(null) || ss.isDebuggable(null);
+    }
+
+    // XXX will be called from AWT
+    public boolean isDebugStartSupported() {
         StartServer ss = getStartServer();
         if (ss == null) {
             return false;
