@@ -112,6 +112,7 @@ import org.netbeans.spi.project.support.ant.PropertyUtils;
 import org.netbeans.spi.project.support.ant.ReferenceHelper;
 import org.netbeans.spi.java.project.support.ui.PackageView;
 import org.netbeans.spi.project.libraries.support.LibrariesSupport;
+import org.netbeans.spi.project.support.ant.ui.CustomizerUtilities;
 import org.netbeans.spi.project.ui.support.NodeList;
 import org.openide.filesystems.FileAttributeEvent;
 import org.openide.filesystems.FileChangeListener;
@@ -478,6 +479,27 @@ public final class LibrariesNode extends AbstractNode {
         return image;        
     }
 
+    private static void handlePCPMUnsupported (
+            @NonNull final SourceRoots sourceRoots,
+            @NonNull final UnsupportedOperationException e) {
+        final FileObject[] roots = sourceRoots.getRoots();
+        if (roots.length == 0) {
+            return;
+        }
+        final StringBuilder sb = new StringBuilder().
+                append("roots: ").
+                append(Arrays.toString(roots)).
+                append("\n").
+                append("urls: ").
+                append(Arrays.toString(sourceRoots.getRootURLs())).
+                append("\n").
+                append("props: ").
+                append(Arrays.toString(sourceRoots.getRootProperties())).
+                append("\n");
+        Exceptions.printStackTrace(
+            Exceptions.attachMessage(e, sb.toString()));
+    }
+
     //Static inner classes
     private static class LibrariesChildren extends Children.Keys<Key> implements PropertyChangeListener {
 
@@ -974,6 +996,8 @@ public final class LibrariesNode extends AbstractNode {
                         projectSourcesArtifact, ClassPath.COMPILE);
             } catch (IOException ioe) {
                 Exceptions.printStackTrace(ioe);
+            } catch (UnsupportedOperationException e) {
+                handlePCPMUnsupported(sources, e);
             }
         }
     }
@@ -994,8 +1018,9 @@ public final class LibrariesNode extends AbstractNode {
         @Override
         public void actionPerformed(ActionEvent e) {
             Set<Library> added = LibraryChooser.showDialog(
-                    refHelper.getProjectLibraryManager(), filter,
-                    refHelper.getLibraryChooserImportHandler());
+                    refHelper.getProjectLibraryManager(),
+                    filter,
+                    CustomizerUtilities.getLibraryChooserImportHandler(refHelper));
             if (added != null) {
                 addLibraries(added.toArray(new Library[added.size()]));
             }
@@ -1017,9 +1042,10 @@ public final class LibrariesNode extends AbstractNode {
                         projectSourcesArtifact, ClassPath.COMPILE);
             } catch (IOException ioe) {
                 Exceptions.printStackTrace(ioe);
+            } catch (UnsupportedOperationException e) {
+                handlePCPMUnsupported(sourceRoots, e);
             }
         }
-        
     }
 
     private static class AddFolderAction extends AbstractAction {
