@@ -94,8 +94,8 @@ import org.netbeans.api.java.source.support.CancellableTreePathScanner;
 import org.netbeans.api.java.source.support.ReferencesCount;
 import org.netbeans.api.java.source.ui.ElementIcons;
 import org.netbeans.api.progress.ProgressUtils;
-import org.netbeans.modules.java.editor.semantic.SemanticHighlighter;
 import org.netbeans.modules.editor.java.Utilities;
+import org.netbeans.modules.java.editor.base.imports.UnusedImports;
 import org.netbeans.modules.java.editor.codegen.GeneratorUtils;
 import org.netbeans.modules.java.editor.imports.ComputeImports.Pair;
 import org.openide.DialogDescriptor;
@@ -258,7 +258,7 @@ public class JavaFixAllImports {
         
         if (removeUnusedImports) {
             //compute imports to remove:
-            List<TreePathHandle> unusedImports = SemanticHighlighter.computeUnusedImports(wc);
+            List<TreePathHandle> unusedImports = UnusedImports.computeUnusedImports(wc);
             unusedImports.addAll(getImportsFromSamePackage(wc));
             someImportsWereRemoved = !unusedImports.isEmpty();
 
@@ -289,7 +289,8 @@ public class JavaFixAllImports {
     }
 
     private static ImportData computeImports(CompilationInfo info) {
-        Pair<Map<String, List<Element>>, Map<String, List<Element>>> candidates = new ComputeImports().computeCandidates(info);
+        ComputeImports imps = new ComputeImports(info);
+        Pair<Map<String, List<Element>>, Map<String, List<Element>>> candidates = imps.computeCandidates();
 
         Map<String, List<Element>> filteredCandidates = candidates.a;
         Map<String, List<Element>> notFilteredCandidates = candidates.b;
@@ -327,7 +328,7 @@ public class JavaFixAllImports {
                 int minImportanceLevel = Integer.MAX_VALUE;
 
                 for (Element e : filteredVars) {
-                    String displayName = ComputeImports.displayNameForImport(info, e);
+                    String displayName = imps.displayNameForImport(e);
                     Icon icon = ElementIcons.getElementIcon(e.getKind(), e.getModifiers());
                     data.variants[index][++i] = new CandidateDescription(displayName, icon, ElementHandle.create(e));
                     int level = Utilities.getImportanceLevel(info, referencesCount, e);
@@ -344,7 +345,7 @@ public class JavaFixAllImports {
                     if (filteredVars.contains(e))
                         continue;
 
-                    String displayName = NOT_VALID_IMPORT_HTML + ComputeImports.displayNameForImport(info, e);
+                    String displayName = NOT_VALID_IMPORT_HTML + imps.displayNameForImport(e);
                     Icon icon = ElementIcons.getElementIcon(e.getKind(), e.getModifiers());
                     data.variants[index][++i] = new CandidateDescription(displayName, icon, ElementHandle.create(e));
                     int level = Utilities.getImportanceLevel(info, referencesCount, e);
