@@ -45,13 +45,13 @@ package org.netbeans.modules.java.editor.javadoc;
 import com.sun.source.doctree.DocCommentTree;
 import com.sun.source.doctree.DocTree;
 import com.sun.source.doctree.DocTree.Kind;
+import com.sun.source.doctree.ParamTree;
 import com.sun.source.doctree.ReferenceTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.Scope;
 import com.sun.source.util.DocSourcePositions;
 import com.sun.source.util.DocTreePath;
 import com.sun.source.util.DocTreePathScanner;
-import com.sun.source.util.DocTreeScanner;
 import com.sun.source.util.DocTrees;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.Trees;
@@ -103,7 +103,8 @@ import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.modules.editor.java.JavaCompletionItem;
 import org.netbeans.modules.editor.java.LazyJavaCompletionItem;
-import org.netbeans.modules.editor.java.Utilities;
+import org.netbeans.modules.java.completion.Utilities;
+import org.netbeans.modules.java.editor.base.javadoc.JavadocCompletionUtils;
 import org.netbeans.spi.editor.completion.CompletionItem;
 import org.netbeans.spi.editor.completion.CompletionProvider;
 import org.netbeans.spi.editor.completion.CompletionResultSet;
@@ -555,13 +556,13 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         // complete type
         CharSequence cs = JavadocCompletionUtils.getCharSequence(jdctx.doc, start, end);
         StringBuilder sb = new StringBuilder();
-        jdctx.anchorOffset = start;
         for (int i = caretOffset - start - 1; i >= 0; i--) {
             char c = cs.charAt(i);
             if (c == '#') {
                 // complete class member
                 String prefix = sb.toString();
                 int substitutionOffset = caretOffset - sb.length();
+                jdctx.anchorOffset = substitutionOffset;
                 ExpressionTree classReference = jdctx.javac.getTreeUtilities().getReferenceClass(tag);
                 if (classReference == null) {
                     if (kind == Kind.VALUE) {
@@ -587,6 +588,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 String prefix = sb.toString();
                 String fqn = cs.subSequence(0, i).toString();
                 int substitutionOffset = caretOffset - sb.length();
+                jdctx.anchorOffset = substitutionOffset;
                 if (kind == Kind.THROWS) {
                     completeThrowsOrPkg(fqn, prefix, substitutionOffset, jdctx);
                 } else {
@@ -601,6 +603,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         String prefix = sb.toString();
         String fqn = null;
         int substitutionOffset = caretOffset - sb.length();
+        jdctx.anchorOffset = substitutionOffset;
         if (kind == Kind.THROWS) {
             completeThrowsOrPkg(fqn, prefix, substitutionOffset, jdctx);
         } else {
@@ -655,11 +658,12 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
     
     private void completeParamName(DocTreePath tag, String prefix, int substitutionOffset, JavadocContext jdctx) {
         if (EXECUTABLE.contains(jdctx.commentFor.getKind())) {
+            List<? extends DocTree> blockTags = jdctx.comment.getBlockTags();
             ExecutableElement method = (ExecutableElement) jdctx.commentFor;
             for (VariableElement param : method.getParameters()) {
                 String name = param.getSimpleName().toString();
-                
-                if (name.startsWith(prefix)) {
+
+                if (!containsParam(blockTags, name) && name.startsWith(prefix)) {
                     items.add(JavadocCompletionItem.createNameItem(name, substitutionOffset));
                 }
             }
@@ -669,7 +673,19 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
             completeTypeVarName(jdctx.commentFor, prefix, substitutionOffset);
         }
     }
-    
+
+    private boolean containsParam(List<? extends DocTree> blockTags, String name) {
+        for (DocTree blockTag : blockTags) {
+            if(blockTag.getKind() == Kind.PARAM) {
+                ParamTree param = (ParamTree) blockTag;
+                if(name.contentEquals(param.getName().getName())) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
     private void completeTypeVarName(Element forElement, String prefix, int substitutionOffset) {
         if (prefix.length() > 0) {
             if (prefix.charAt(0) == '<') {
@@ -801,6 +817,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         final Elements elements = controller.getElements();
         final Types types = controller.getTypes();
         final TreeUtilities tu = controller.getTreeUtilities();
+        final ElementUtilities eu = controller.getElementUtilities();
         TypeElement typeElem = type.getKind() == TypeKind.DECLARED ? (TypeElement)((DeclaredType)type).asElement() : null;
 //        final boolean isStatic = elem != null && (elem.getKind().isClass() || elem.getKind().isInterface() || elem.getKind() == TYPE_PARAMETER);
 //        final boolean isSuperCall = elem != null && elem.getKind().isField() && elem.getSimpleName().contentEquals(SUPER_KEYWORD);
@@ -831,7 +848,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                         String sn = e.getSimpleName().toString();
                         return Utilities.startsWith(sn, prefix) &&
                                 (Utilities.isShowDeprecatedMembers() || !elements.isDeprecated(e)) &&
-                                (!Utilities.isExcludeMethods() || !Utilities.isExcluded(Utilities.getElementName(e.getEnclosingElement(), true) + "." + sn)); //NOI18N
+                                (!Utilities.isExcludeMethods() || !Utilities.isExcluded(eu.getElementName(e.getEnclosingElement(), true) + "." + sn)); //NOI18N
 //                                &&
 //                                isOfKindAndType(((ExecutableType)asMemberOf(e, t, types)).getReturnType(), e, kinds, baseType, scope, trees, types) &&
 //                                (isSuperCall && e.getModifiers().contains(PROTECTED) || tu.isAccessible(scope, e, isSuperCall && enclType != null ? enclType : t)) &&
@@ -859,7 +876,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 case ENUM_CONSTANT:
                 case FIELD:
                     TypeMirror tm = type.getKind() == TypeKind.DECLARED ? types.asMemberOf((DeclaredType)type, e) : e.asType();
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement) e, tm, substitutionOffset, null, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement) e, tm, null, substitutionOffset, null, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false, -1, null));
                     break;
                 case CONSTRUCTOR:
                 case METHOD:
@@ -910,7 +927,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 case ENUM_CONSTANT:
                 case FIELD:
                     TypeMirror tm = type.getKind() == TypeKind.DECLARED ? types.asMemberOf((DeclaredType)type, e) : e.asType();
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement) e, tm, substitutionOffset, null, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement) e, tm, null, substitutionOffset, null, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false, -1, null));
                     break;
             }
         }
@@ -946,11 +963,11 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         for (Element e : controller.getElementUtilities().getLocalMembersAndVars(scope, acceptor)) {
             switch (e.getKind()) {
                 case ENUM_CONSTANT:
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, e.asType(), substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, e.asType(), null, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/, -1, null));
                     break;
                 case FIELD:
                     TypeMirror tm = asMemberOf(e, enclClass != null ? enclClass.asType() : null, types);
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, tm, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, tm, null, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/, -1, null));
                     break;
             }
         }
@@ -1043,12 +1060,12 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         for (Element e : controller.getElementUtilities().getLocalMembersAndVars(scope, acceptor)) {
             switch (e.getKind()) {
                 case ENUM_CONSTANT:
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, e.asType(), substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, e.asType(), null, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/, -1, null));
                     break;
                 case FIELD:
                     String name = e.getSimpleName().toString();
                     TypeMirror tm = asMemberOf(e, enclClass != null ? enclClass.asType() : null, types);
-                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, tm, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/, -1, null));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, tm, null, substitutionOffset, null, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/, -1, null));
                     break;
                 case CONSTRUCTOR:
                 case METHOD:
@@ -1191,6 +1208,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         Types types = controller.getTypes();
         Trees trees = controller.getTrees();
         TreeUtilities tu = controller.getTreeUtilities();
+        ElementUtilities eu = controller.getElementUtilities();
         TreePath docpath = srcEl != null ? trees.getPath(srcEl) : null;
         Scope scope = docpath != null ? trees.getScope(docpath) : tu.scopeFor(caretOffset);
         for(Element e : pe.getEnclosedElements()) {
@@ -1199,7 +1217,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                     if (Utilities.startsWith(name, prefix) && (Utilities.isShowDeprecatedMembers() || !elements.isDeprecated(e))
                         && trees.isAccessible(scope, (TypeElement)e)
                         && isOfKindAndType(e.asType(), e, kinds, baseType, scope, trees, types)
-                        && !Utilities.isExcluded(Utilities.getElementName(e, true))) {
+                        && !Utilities.isExcluded(eu.getElementName(e, true))) {
                         items.add(JavadocCompletionItem.createTypeItem(jdctx.javac, (TypeElement) e, substitutionOffset, null, elements.isDeprecated(e)/*, isOfSmartType(env, e.asType(), smartTypes)*/));
                 }
             }
@@ -1207,7 +1225,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
     }
         
     private boolean isOfKindAndType(TypeMirror type, Element e, EnumSet<ElementKind> kinds, TypeMirror base, Scope scope, Trees trees, Types types) {
-        if (kinds.contains(e.getKind())) {
+        if (type.getKind() != TypeKind.ERROR && kinds.contains(e.getKind())) {
             if (base == null)
                 return true;
             if (types.isSubtype(type, base))
