@@ -129,7 +129,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
     }
 
     public void testAddTemplate() {
-        final String abbrev = "test";        
+        final String abbrev = "mytest";        
         final String expandedText = "System.out.println(\"test\");";
         final String expandedRegExpText = ".*System\\.out\\.println\\(\"test\"\\);.*";
         CodeTemplatesOperator oper = null;
@@ -265,7 +265,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
         prepareEditorAndUseTemplate(6, 9, null, -1, abbrev, false, ".*String x;.*");
     }
 
-    public void testEditDescription() {
+    public void testEditDescription() {        
         final String abbrev = "iff";
         final String description = "condition";
         CodeTemplatesOperator oper = null;
@@ -276,8 +276,8 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
             oper.setDescription(description);        
         } finally {
             oper.ok();
-        }        
-        prepareEditorAndUseTemplate(6, 9, "int x;", 14, description, true, ".*if \\(true\\).*");
+        }                
+        prepareEditorAndUseTemplate(6, 9, "int x;", 14, description, true, ".*if \\(true\\).*");        
     }
 
     public void testRemoveAfterSorting() {
@@ -394,7 +394,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
 
     public void testSynchronizedBlock() {
         final String abbrev = "form";
-        String regExp = ".*for \\(Map.Entry<Object, Object> en \\: m\\.entrySet\\(\\)\\) \\{.*";
+        String regExp = ".*for \\(Map\\.Entry<Object, Object> en \\: m\\.entrySet\\(\\)\\) \\{.*";
         EditorOperator editor = null;
         try {
             openSourceFile("org.netbeans.test.java.editor.codetemplates", "Main");
@@ -416,7 +416,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
             assertEquals("Wrong end selection position", 199, jepo.getSelectionEnd());
             jepo.pressKey(KeyEvent.VK_TAB);
             assertEquals("Wrong start selection position ", 200, jepo.getSelectionStart());
-            assertEquals("Wrong end selection position", 206, jepo.getSelectionEnd());
+            assertEquals("Wrong end selection position", 203, jepo.getSelectionEnd());
         } finally {
             if (editor != null) {
                 editor.closeDiscard();
@@ -526,7 +526,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
             editor = new EditorOperator("Main");
             JEditorPaneOperator jepo = editor.txtEditorPane();
             editor.setCaretPosition(4, 1);
-            jepo.typeText("java.util.List<String> a;java.util.List<Integer> b;");
+            jepo.typeText("static java.util.List<String> a;static java.util.List<Integer> b;");
             useTemplateAt(editor, 6, 9, abbrev);
             jepo.pressKey(KeyEvent.VK_TAB);
             jepo.typeText("b");
@@ -593,6 +593,22 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
             editor.closeDiscard();
         }
     }
+    
+    public void testCodeTemplatesVariable() {        
+        final String abbrev = "variables";        
+        final String expandedText = "String a = \"${fqn currClassFQName} ${curM currMethodName} ${pkg currPackageName} ${name currClassName}\";";
+        final String expandedRegExpText = ".*String a = \"org\\.netbeans\\.test\\.java\\.editor\\.codetemplates\\.Main main org\\.netbeans\\.test\\.java\\.editor\\.codetemplates Main\";.*";
+        CodeTemplatesOperator oper = null;
+        try {
+            oper = CodeTemplatesOperator.invoke(true);
+            boolean selectTemplate = oper.switchLanguage("Java").addNewTemplate(abbrev).selectTemplate(abbrev);
+            assertTrue("Template with abbreviation " + abbrev + " not found", selectTemplate);
+            oper.setExtendedText(expandedText);
+        } finally {
+            oper.ok();
+        }
+        prepareEditorAndUseTemplate(6, 9, null, -1, abbrev, false, expandedRegExpText);
+    }
 
     public static Test suite() {
         return NbModuleSuite.create(
@@ -644,6 +660,7 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
 
         new EventTool().waitNoEvent(500);
         editor.pressKey(KeyEvent.VK_ENTER, KeyEvent.ALT_DOWN_MASK);
+        new EventTool().waitNoEvent(500);
         JListOperator jlo = new JListOperator(MainWindowOperator.getDefault());
         ListModel model = jlo.getModel();
         int i;
@@ -654,13 +671,16 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
                 hint = ((SurroundWithFix) item).getText();
             }
             if (hint.startsWith(blockTemplatePrefix + description)) {
+                System.out.println("Found at "+i+" position: "+hint);
                 break;
             }
         }
         if (i == model.getSize()) {
             fail("Template not found in the hint popup");
         }
+        new EventTool().waitNoEvent(2000);
         jlo.selectItem(i);
+        new EventTool().waitNoEvent(500);
     }
 
     /**
@@ -685,15 +705,15 @@ public class CodeTemplatesTest extends JavaEditorTestCase {
             if (text != null) {
                 editor.setCaretPosition(row, column);
                 editor.insert(text);
-            }
-            if (selectionEnd > -1) {
+            }            
+            if (selectionEnd > -1) {                
                 editor.select(row, column, selectionEnd);
             }
-            if (asHint) {
+            if (asHint) {                
                 invokeTemplateAsHint(editor, abbrev);
             } else {
                 useTemplateAt(editor, row, column, abbrev);
-            }
+            }            
             checkContentOfEditorRegexp(editor, expandedTextRegexp);
         } catch (Exception ex) {
             fail(ex);
