@@ -275,7 +275,8 @@ public abstract class AbstractApplyHintsRefactoringPlugin extends ProgressProvid
         private final Set<ModificationResult> enabledResults;
 
         private ModificationResultElement(FileObject parentFile, JavaFix jf, ModificationResult modification, Set<ModificationResult> enabledResults) {
-            PositionRef s = modification.getDifferences(parentFile).iterator().next().getStartPosition();
+            // FIXME - unwanted openide.text dependency
+            PositionRef s = (PositionRef)modification.getDifferences(parentFile).iterator().next().getStartPosition();
             this.bounds = new PositionBounds(s, s);
             this.displayText = jf.toEditorFix().getText();
             this.parentFile = parentFile;
@@ -329,6 +330,14 @@ public abstract class AbstractApplyHintsRefactoringPlugin extends ProgressProvid
 
         @Override
         protected String getNewFileContent() {
+            if (!isEnabled()) {
+                try {
+                    return parentFile.asText();
+                } catch (IOException ex) {
+                    LOG.log(Level.INFO, null, ex);
+                    return null;
+                }
+            }
             String result = newFileContent != null ? newFileContent.get() : null;
             if (result != null) return result;
             try {
