@@ -269,6 +269,15 @@ public class ArithmeticUtilities {
             }
             DeclaredType dt = (DeclaredType)target;
             TypeElement e = (TypeElement)dt.asElement();
+            if (enhanceProcessing) {
+                // accept null constant typecasted to anything as null
+                if (result == NULL) {
+                    return NULL;
+                } else if (result == NOT_NULL) {
+                    // some unspecified reference type...
+                    return result;
+                }
+            }
             String qn = e.getQualifiedName().toString();
             // type casts to String are permitted by JLS 15.28
             if ("java.lang.String".equals(qn)) { // NOI18N
@@ -277,16 +286,11 @@ public class ArithmeticUtilities {
                 // other typecasts are not lised in JLS 15.28
                 return null;
             }
-            
-            // accept null constant typecasted to anything as null
-            if (result == NULL) {
-                return NULL;
-            } else if (result == NOT_NULL) {
-                // some unspecified reference type...
-                return result;
-            }
             TypeMirror castee = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), node.getExpression()));
-            if (castee != null && info.getTypes().isAssignable(castee, target)) {
+            if (!Utilities.isValidType(castee)) {
+                return null;
+            }
+            if (info.getTypes().isAssignable(castee, target)) {
                 return result;
             }
             // a constant of primitive type may be casted / wrapped to the wrapper type
@@ -335,6 +339,9 @@ public class ArithmeticUtilities {
             }
             Object result = null;
             TypeMirror tm = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), node.getType()));
+            if (!Utilities.isValidType(tm)) {
+                return null;
+            }
             // casting to some non-char primitive type, perform unary numeric promotion JLS 5.6.1
             if (tm.getKind() != TypeKind.CHAR && op instanceof Character) {
                 op = Integer.valueOf(((Character)op).charValue());
@@ -425,7 +432,9 @@ public class ArithmeticUtilities {
          */
         private static Object resolveElementValue(CompilationInfo info, TreePath path, boolean enhanceProcessing) {
             Element el = info.getTrees().getElement(path);
-
+            if (el == null) {
+                return null;
+            }
             Map<Object, ElementValue> cache = getValueCache(info);
             ElementValue entry = cache.get(el);
             if (entry != null) {
@@ -555,7 +564,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() == rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         } else if (left instanceof Boolean && right instanceof Boolean) {
                             return left.equals(right);
@@ -566,7 +575,7 @@ public class ArithmeticUtilities {
                                         left == NULL ?  node.getRightOperand() : 
                                                         node.getLeftOperand()
                             ));
-                            if (m != null && !PRIMITIVE_KINDS.contains(m.getKind())) {
+                            if (Utilities.isValidType(m) && !PRIMITIVE_KINDS.contains(m.getKind())) {
                                 result = left == right;
                             }
                         }
@@ -585,7 +594,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() != rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         } else if (left instanceof Boolean && right instanceof Boolean) {
                             return left.equals(right);
@@ -593,7 +602,7 @@ public class ArithmeticUtilities {
                             // cannot accept primitives, boxing conversion does not apply
                             TypeMirror m = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), 
                                     left == NULL ? node.getRightOperand() : node.getLeftOperand()));
-                            if (m != null && !PRIMITIVE_KINDS.contains(m.getKind())) {
+                            if (Utilities.isValidType(m) && !PRIMITIVE_KINDS.contains(m.getKind())) {
                                 result = left != right;
                             }
                         }
@@ -612,7 +621,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() < rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -629,7 +638,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() <= rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -646,7 +655,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() > rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -663,7 +672,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() >= rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -681,7 +690,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() * rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -699,14 +708,14 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() / rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         boolean a = true;
                         boolean b = false;
                         boolean c = a & b;
                         break;
-
+                        
                     case REMAINDER:
                         if (left instanceof Number && right instanceof Number) {
                             Number ln = (Number)left;
@@ -720,7 +729,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() % rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -738,7 +747,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() - rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -752,7 +761,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() << rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -766,7 +775,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() >> rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -780,7 +789,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() >>> rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + ln.getClass() + ", right=" + rn.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -800,7 +809,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() + rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + left.getClass() + ", right=" + right.getClass());
+                                return null;
                             }
                         } else if (left instanceof String) {
                             if (right != NOT_NULL) {
@@ -833,7 +842,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() ^ rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + ln.getClass() + ", right=" + rn.getClass());
+                                return null;
                             }
                         } else if (left instanceof Boolean && right instanceof Boolean) {
                             result = ((Boolean)left) ^ ((Boolean)right);
@@ -849,7 +858,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() & rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + ln.getClass() + ", right=" + rn.getClass());
+                                return null;
                             }
                         } else if (left instanceof Boolean && right instanceof Boolean) {
                             result = ((Boolean)left) & ((Boolean)right);
@@ -865,7 +874,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(ln) || integerLike(rn)) {
                                 result = ln.intValue() | rn.intValue();
                             } else {
-                                throw new IllegalStateException("left=" + ln.getClass() + ", right=" + rn.getClass());
+                                return null;
                             }
                         } else if (left instanceof Boolean && right instanceof Boolean) {
                             result = ((Boolean)left) | ((Boolean)right);
@@ -912,7 +921,7 @@ public class ArithmeticUtilities {
                             } else if (integerLike(nop)) {
                                 result = -nop.intValue();
                             } else {
-                                throw new IllegalStateException("op=" + op.getClass());
+                                return null;
                             }
                         }
                         break;
@@ -933,6 +942,118 @@ public class ArithmeticUtilities {
         }
     }
     
+    /**
+     * Performs implicit conversion of a literal value to the target type.
+     * Returns {@code null} if the conversion is not possible (incovertible, lossy
+     * conversion etc).
+     * 
+     * @param val the value
+     * @param convertTo the target type
+     * @return new literal value
+     */
+    public static Object implicitConversion(CompilationInfo info, Object val, TypeMirror convertTo) {
+        if (!convertTo.getKind().isPrimitive()) {
+            if (Utilities.isPrimitiveWrapperType(convertTo)) {
+                convertTo = info.getTypes().unboxedType(convertTo);
+            } else {
+// possibly a String ?
+                if (val instanceof String && convertTo.getKind() == TypeKind.DECLARED) {
+                    Element el = info.getTypes().asElement(convertTo);
+                    if (el.getKind() == ElementKind.CLASS && ((TypeElement)el).getQualifiedName().contentEquals("java.lang.String")) {
+                        return val;
+                    }
+                }
+            return null;
+        }
+        }
+        switch (convertTo.getKind()) {
+            case BOOLEAN:
+                if (val instanceof Boolean) {
+                    return val;
+                } else {
+                    return null;
+                }
+            case BYTE: {
+                if (val instanceof Short || val instanceof Long || val instanceof Integer) {
+                    long l = ((Number)val).longValue();
+                    if (l >= 0 && l <= 0xff) {
+                        return (byte)l;
+                    }
+                } else if (val instanceof Character) {
+                    return (byte)((Character)val).charValue();
+                }
+                
+                return null;
+            }
+            case CHAR:
+                if (val instanceof Character) {
+                    return val;
+                } else if (val instanceof Short) {
+                    short n = (Short)val;
+                    if (n < (1 << 15)) {
+                        return Character.valueOf((char)n);
+                    }
+                } else if (val instanceof Integer) {
+                    int n = (Integer)val;
+                    if ( n < (1 << 16)) {
+                        return Character.valueOf((char)n);
+                    }
+                }
+                return null;
+                
+            case DOUBLE:
+                if (val instanceof Number) {
+                    return ((Number)val).doubleValue();
+                } else if (val instanceof Character) {
+                    return Double.valueOf((Character)val);
+                }
+                return null;
+            case FLOAT:
+                if (val instanceof Double) {
+                    return null;
+                }
+                if (val instanceof Number) {
+                    return ((Number)val).floatValue();
+                } else if (val instanceof Character) {
+                    return Double.valueOf((Character)val);
+                }
+                return null;
+                
+            case INT:
+                if (val instanceof Short || val instanceof Long || val instanceof Integer) {
+                    long l = ((Number)val).longValue();
+                    if (l >= Integer.MIN_VALUE && l <= Integer.MAX_VALUE) {
+                        return (int)l;
+                    }
+                } else if (val instanceof Character) {
+                    return (int)((Character)val);
+                }
+                return null;
+            case LONG:
+                if (val instanceof Character) {
+                    return (long)((Character)val).charValue();
+                } else if (val instanceof Double || val instanceof Float) {
+                    return null;
+                } else if (val instanceof Number) {
+                    return ((Number)val).longValue();
+                }
+                return null;
+                
+            case SHORT:
+                if (val instanceof Short || val instanceof Long || val instanceof Integer) {
+                    long l = ((Number)val).longValue();
+                    if (l >= Short.MIN_VALUE && l <= Short.MAX_VALUE) {
+                        return (short)l;
+        }
+                } else if (val instanceof Character) {
+                    return (short)((Character)val).charValue();
+    }
+                return null;
+            default:
+                return null;
+        }
+    }
+    
     private static final String CONST_EVAL_KEY = ArithmeticUtilities.class.getName();
     
     /**
