@@ -383,19 +383,21 @@ public class ConvertAnonymousToInner extends AbstractHint {
         TypeMirror superType = copy.getTrees().getTypeMirror(new TreePath(newClassToConvert, nct.getIdentifier()));
         Element superTypeElement = copy.getTrees().getElement(new TreePath(newClassToConvert, nct.getIdentifier()));
         
-        boolean isStaticContext = true;
+        boolean isStaticContext = targetElement != null && superTypeElement != null;
         Element currElement = superTypeElement;
-        while (currElement.getEnclosingElement().getKind() != ElementKind.PACKAGE) {
-            if (!currElement.getModifiers().contains(Modifier.STATIC)) {
-                isStaticContext = false;
-                break;
-            }
+        if (isStaticContext) {
+            while (currElement != null && currElement.getEnclosingElement().getKind() != ElementKind.PACKAGE) {
+                if (!currElement.getModifiers().contains(Modifier.STATIC)) {
+                    isStaticContext = false;
+                    break;
+                }
 
-            currElement = currElement.getEnclosingElement();
+                currElement = currElement.getEnclosingElement();
+            }
         }
         
         if (isStaticContext) {
-            while (targetElement.getEnclosingElement().getKind() != ElementKind.PACKAGE) {
+            while (targetElement != null && targetElement.getEnclosingElement().getKind() != ElementKind.PACKAGE) {
                 if (!targetElement.getModifiers().contains(Modifier.STATIC)) {
                     isStaticContext = false;
                     break;
@@ -452,7 +454,7 @@ public class ConvertAnonymousToInner extends AbstractHint {
                 ExecutableElement ee = (ExecutableElement) superConstructor;
                 TypeMirror nctTypes = copy.getTrees().getTypeMirror(newClassToConvert);
                 
-                if (nctTypes.getKind() == TypeKind.ERROR) {
+                if (!Utilities.isValidType(nctTypes)) {
                     // issue #236082: try again, but strip the parent statement; must reattribute the part of the tree
                     TreePath skipPath = new TreePath(parentPath, newClassToConvert.getLeaf());
                     copy.getTreeUtilities().attributeTree(newClassToConvert.getLeaf(), copy.getTrees().getScope(skipPath));
@@ -543,7 +545,7 @@ public class ConvertAnonymousToInner extends AbstractHint {
         
         ClassTree clazz = make.Class(classModifiers, newClassName, Collections.<TypeParameterTree>emptyList(), superTypeElement.getKind().isClass() ? superTypeTree : null, superTypeElement.getKind().isClass() ? Collections.<Tree>emptyList() : Collections.<Tree>singletonList(superTypeTree), members);
         
-        copy.rewrite(target, make.addClassMember(target, clazz));
+        copy.rewrite(target, make.addClassMember(target, copy.getTreeMaker().asReplacementOf(clazz, nct)));
 
         IdentifierTree classNameTree = make.Identifier(newClassName);
         NewClassTree nueNCT = make.NewClass(/*!!!*/null, Collections.<ExpressionTree>emptyList(), classNameTree, constrRealArguments, null);
