@@ -85,7 +85,7 @@ import org.netbeans.api.progress.ProgressUtils;
 import org.netbeans.editor.BaseAction;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.modules.editor.java.JavaKit;
-import org.netbeans.modules.java.editor.javadoc.JavadocImports;
+import org.netbeans.modules.java.editor.base.javadoc.JavadocImports;
 import org.netbeans.modules.parsing.api.ResultIterator;
 import org.netbeans.modules.parsing.api.Source;
 import org.netbeans.modules.parsing.api.UserTask;
@@ -133,7 +133,7 @@ public class OrganizeImports {
             int offset = diffs.get(0).getStartPosition().getOffset();
             CompilationUnitTree cu = context.getInfo().getCompilationUnit();
             for (ImportTree imp : cu.getImports()) {
-                if (sp.getStartPosition(cu, imp) >= offset)
+                if (sp.getEndPosition(cu, imp) >= offset)
                     return ErrorDescriptionFactory.forTree(context, imp, NbBundle.getMessage(OrganizeImports.class, "MSG_OragnizeImports"), fix); //NOI18N
             }
             return ErrorDescriptionFactory.forTree(context, context.getInfo().getCompilationUnit().getImports().get(0), NbBundle.getMessage(OrganizeImports.class, "MSG_OragnizeImports"), fix); //NOI18N
@@ -179,8 +179,8 @@ public class OrganizeImports {
             }
         }
         final CodeStyle cs = CodeStyle.getDefault(copy.getFileObject());
-        Set<Element> starImports = cs.countForUsingStarImport() < Integer.MAX_VALUE ? new HashSet<Element>() : null;
-        Set<Element> staticStarImports = cs.countForUsingStaticStarImport() < Integer.MAX_VALUE ? new HashSet<Element>() : null;
+        Set<Element> starImports = new HashSet<Element>();
+        Set<Element> staticStarImports = new HashSet<Element>();
         Set<Element> toImport = getUsedElements(copy, cu, starImports, staticStarImports);
         List<ImportTree> imps = new LinkedList<ImportTree>();  
         TreeMaker maker = copy.getTreeMaker();
@@ -190,22 +190,33 @@ public class OrganizeImports {
             toImport.addAll(addImports);
             imps.addAll(cu.getImports());
         } else if (!toImport.isEmpty() || isBulkMode) {
-            if (starImports != null || staticStarImports != null) {
-                Trees trees = copy.getTrees();
-                for (ImportTree importTree : cu.getImports()) {
-                    Tree qualIdent = importTree.getQualifiedIdentifier();
-                    if (qualIdent.getKind() == Tree.Kind.MEMBER_SELECT && "*".contentEquals(((MemberSelectTree)qualIdent).getIdentifier())) {
-                        if (importTree.isStatic()) {
-                            if (staticStarImports != null && staticStarImports.contains(trees.getElement(TreePath.getPath(cu, ((MemberSelectTree)qualIdent).getExpression()))))
-                                imps.add(maker.Import(qualIdent, true));
-                        } else {
-                            if (starImports != null && starImports.contains(trees.getElement(TreePath.getPath(cu, ((MemberSelectTree)qualIdent).getExpression()))))
-                                imps.add(maker.Import(qualIdent, false));
+            // track import star import scopes, so only one star import/scope appears in imps - #251977
+            Set<Element> starImportScopes = new HashSet<>();
+            Trees trees = copy.getTrees();
+            for (ImportTree importTree : cu.getImports()) {
+                Tree qualIdent = importTree.getQualifiedIdentifier();
+                if (qualIdent.getKind() == Tree.Kind.MEMBER_SELECT && "*".contentEquals(((MemberSelectTree)qualIdent).getIdentifier())) {
+                    ImportTree imp = null;
+                    Element importedScope = trees.getElement(TreePath.getPath(cu, ((MemberSelectTree)qualIdent).getExpression()));
+                    
+                    if (importTree.isStatic()) {
+                        if (staticStarImports != null && 
+                            staticStarImports.contains(importedScope) &&
+                            !starImportScopes.contains(importedScope)) {
+                            imp = maker.Import(qualIdent, true);
+                        }
+                    } else {
+                        if (starImports != null && 
+                            starImports.contains(importedScope) &&
+                            !starImportScopes.contains(importedScope)) {
+                            imp = maker.Import(qualIdent, false);
                         }
                     }
+                    if (imp != null) {
+                        starImportScopes.add(importedScope);
+                        imps.add(imp);
+                    }
                 }
-            } else {
-                imps = Collections.emptyList();
             }
         } else {
             return;
