@@ -137,6 +137,26 @@ public class NPECheck {
         return null;
     }
     
+    @TriggerPattern("for ($type $var : $expr) $stmts$")
+    public static ErrorDescription enhancedFor(HintContext ctx) {
+        TreePath colExpr = ctx.getVariables().get("$expr");
+        if (colExpr == null) {
+            return null;
+        }
+        State r =  computeExpressionsState(ctx).get(colExpr.getLeaf());
+        if (r == NULL || r == NULL_HYPOTHETICAL) {
+            String displayName = NbBundle.getMessage(NPECheck.class, "ERR_DereferencingNull");
+            
+            return ErrorDescriptionFactory.forName(ctx, ctx.getPath(), displayName);
+        }
+
+        if (r == State.POSSIBLE_NULL_REPORT) {
+            String displayName = NbBundle.getMessage(NPECheck.class, "ERR_PossiblyDereferencingNull");
+            
+            return ErrorDescriptionFactory.forName(ctx, ctx.getPath(), displayName);
+        }
+        return null;
+    }
     
     @TriggerPattern("$select.$variable")
     public static ErrorDescription memberSelect(HintContext ctx) {
@@ -588,6 +608,13 @@ public class NPECheck {
             if (isVariableElement(site) && wasNPE && (variable2State.get(site) == null || !variable2State.get(site).isNotNull())) {
                 variable2State.put((VariableElement) site, NOT_NULL_BE_NPE);
             }
+            // special case: if the memberSelect selects enum field = constant, it is never null.
+            if (site != null && site.getKind() == ElementKind.ENUM) {
+                Element enumConst = info.getTrees().getElement(getCurrentPath());
+                if (enumConst != null && enumConst.getKind() == ElementKind.ENUM_CONSTANT) {
+                    return State.NOT_NULL;
+                }
+            }
             
             return getStateFromAnnotations(info, info.getTrees().getElement(getCurrentPath()));
         }
@@ -855,6 +882,10 @@ public class NPECheck {
             if (e == null || !isVariableElement(e)) {
                 return State.POSSIBLE_NULL;
             }
+            if (e.getKind() == ElementKind.ENUM_CONSTANT) {
+                // enum constants are never null
+                return State.NOT_NULL;
+            }
             
             if (e != null) {
                 State s = variable2State.get(e);
