@@ -66,6 +66,7 @@ import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
 import javax.lang.model.element.Modifier;
+import javax.lang.model.element.TypeElement;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import org.netbeans.api.java.source.Task;
@@ -105,10 +106,17 @@ public class AddParameterOrLocalFix implements EnhancedFix {
                                   boolean parameter,
                                   int /*!!!Position*/ unresolvedVariable) {
         this.file = info.getFileObject();
-        if (type.getKind() == TypeKind.NULL) {
-            type = info.getElements().getTypeElement("java.lang.Object").asType(); // NOI18N
+        if (type.getKind() == TypeKind.NULL || type.getKind() == TypeKind.NONE) {
+            TypeElement te = info.getElements().getTypeElement("java.lang.Object"); // NOI18N
+            if (te != null) {
+                type = te.asType();
+                this.type = TypeMirrorHandle.create(type);
+            } else {
+                this.type = null;
+            }
+        } else {
+            this.type = TypeMirrorHandle.create(type);
         }
-        this.type = TypeMirrorHandle.create(type);
         this.name = name;
         this.parameter = parameter;
 
@@ -157,6 +165,9 @@ public class AddParameterOrLocalFix implements EnhancedFix {
                     MethodTree targetTree = (MethodTree) targetPath.getLeaf();
 
                     Element el = working.getTrees().getElement(targetPath);
+                    if (el == null) {
+                        return;
+                    }
                     int index = targetTree.getParameters().size();
 
                     if (el != null && (el.getKind() == ElementKind.METHOD || el.getKind() == ElementKind.CONSTRUCTOR)) {
@@ -254,6 +265,9 @@ public class AddParameterOrLocalFix implements EnhancedFix {
         final String name = ((IdentifierTree) tp.getLeaf()).getName().toString();
         
         final Element el = wc.getTrees().getElement(tp);
+        if (el == null) {
+            return;
+        }
         
         //find first usage of this (undeclared) variable:
         TreePath blockPath = findOutmostBlock(tp);
