@@ -45,6 +45,7 @@
 package org.netbeans.modules.java.hints.errors;
 
 import com.sun.source.tree.CompilationUnitTree;
+import com.sun.source.tree.IdentifierTree;
 import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.Tree;
@@ -64,12 +65,15 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.prefs.Preferences;
 import javax.lang.model.element.Element;
+import javax.lang.model.element.ElementKind;
 import javax.swing.text.Document;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.editor.mimelookup.MimeLookup;
 import org.netbeans.api.editor.mimelookup.MimePath;
+import org.netbeans.api.java.source.CodeStyle;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementHandle;
+import org.netbeans.api.java.source.ElementUtilities;
 import org.netbeans.api.java.source.GeneratorUtilities;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
@@ -114,8 +118,9 @@ public final class ImportClass implements ErrorRule<Void> {
     public ImportClass() {
     }
     
+    @Override
     public Set<String> getCodes() {
-        return new HashSet<String>(Arrays.asList(
+        return new HashSet<>(Arrays.asList(
                 "compiler.err.cant.resolve",
                 "compiler.err.cant.resolve.location",
                 "compiler.err.cant.resolve.location.args",
@@ -124,9 +129,9 @@ public final class ImportClass implements ErrorRule<Void> {
                 "compiler.err.not.def.public.cant.access"));
     }
     
+    @Override
     public List<Fix> run(final CompilationInfo info, String diagnosticKey, final int offset, TreePath treePath, Data<Void> data) {
         resume();
-
         int errorPosition = offset + 1; //TODO: +1 required to work OK, rethink
         
         if (errorPosition == (-1)) {
@@ -152,23 +157,32 @@ public final class ImportClass implements ErrorRule<Void> {
         }
         
         FileObject file = info.getFileObject();
+        boolean useFQN = false;
+        if (file != null) {
+                CodeStyle cs = CodeStyle.getDefault(file);
+                useFQN = cs.useFQNs();
+        }
         String simpleName = ident.text().toString();
-        Pair<List<Element>, List<Element>> candidates = getCandidateFQNs(info, file, simpleName, data);
+        ComputeImports imps = getCandidateFQNs(info, file, simpleName, data);
+        if (imps == null) {
+            return Collections.<Fix>emptyList();
+        }
+        List<Element> cands = imps.getCandidates(simpleName);
 
         //workaround for #118714 -- neverending import
         List<? extends ImportTree> imports = info.getCompilationUnit().getImports();
         for (ImportTree it : imports) {
             Element el = info.getTrees().getElement(new TreePath(new TreePath(new TreePath(info.getCompilationUnit()), it), it.getQualifiedIdentifier()));
 
-            if (candidates != null && el != null) {
-                List<Element> a = candidates.first();
+            if (el != null && cands != null) {
+                List<Element> a = cands;
                 if (a != null && a.contains(el)) {
                     return Collections.<Fix>emptyList();
                 }
             }
         }
 
-        if (isCancelled() || candidates == null) {
+        if (isCancelled()) {
             ErrorHintsProvider.LOG.log(Level.FINE, "ImportClassEnabler.cancelled."); //NOI18N
             
             return CreatorBasedLazyFixList.CANCELLED;
@@ -177,7 +191,10 @@ public final class ImportClass implements ErrorRule<Void> {
         String replaceSuffix = null;
         TreePath changePath = null;
 
-        if (path.getLeaf().getKind() == Kind.IMPORT) {
+        if (useFQN) {
+            changePath = path;
+            replaceSuffix = ""; // NOI18N
+        } else if (path.getLeaf().getKind() == Kind.IMPORT) {
             //for import package.*;, the error points to the import tree:
             Tree star = ((ImportTree) path.getLeaf()).getQualifiedIdentifier();
 
@@ -208,25 +225,30 @@ public final class ImportClass implements ErrorRule<Void> {
                 ErrorFixesFakeHint.FixKind.IMPORT_CLASS);
         boolean doOrganize = ErrorFixesFakeHint.isOrganizeAfterImportClass(prefs);
 
-        List<Element> filtered = candidates.first();
-        List<Element> unfiltered = candidates.second();
-        List<Fix> fixes = new ArrayList<Fix>();
+        List<Element> filtered = cands;
+        List<Element> unfiltered = imps.getRawCandidates(simpleName);
+        List<Fix> fixes = new ArrayList<>();
         
         if (unfiltered != null && filtered != null) {
             ReferencesCount referencesCount = ReferencesCount.get(info.getClasspathInfo());
-        
+            Set<String> uniq = new HashSet<>();
+            
             for (Element element : unfiltered) {
-                String fqn = ComputeImports.displayNameForImport(info, element);
+                String fqn = imps.displayNameForImport(element);
+                if (!uniq.add(fqn)) {
+                    continue;
+                }
                 StringBuilder sort = new StringBuilder();
                 
                 sort.append("0001#");
                 
                 boolean prefered = filtered.contains(element);
                 
-                if (prefered)
+                if (prefered) {
                     sort.append("A#");
-                else
+                } else {
                     sort.append("Z#");
+                }
                 
                 int order = Utilities.getImportanceLevel(info, referencesCount, element);
                 String orderString = Integer.toHexString(order);
@@ -235,8 +257,15 @@ public final class ImportClass implements ErrorRule<Void> {
                 sort.append(orderString);
                 sort.append('#');
                 sort.append(fqn);
-                
-                fixes.add(new FixImport(file, fqn, ElementHandle.create(element), sort.toString(), prefered, info, changePath, replaceSuffix, doOrganize));
+
+                ElementHandle<Element> eh = ElementHandle.create(element);
+                if (useFQN) {
+                    fixes.add(new UseFQN(info, file, fqn, eh, "Z#" + fqn, treePath, prefered, false));
+                    fixes.add(UseFQN.createShared(info, file, fqn, eh, fqn, treePath, prefered));
+                } else {
+                    fixes.add(new FixImport(file, fqn, ElementHandle.create(element), sort.toString(), 
+                            prefered, info, changePath, replaceSuffix, doOrganize));
+                }
             }
         }
         
@@ -245,6 +274,7 @@ public final class ImportClass implements ErrorRule<Void> {
         return fixes;
     }
     
+    @Override
     public synchronized void cancel() {
         ErrorHintsProvider.LOG.log(Level.FINE, "ImportClassEnabler.cancel called."); //NOI18N
         
@@ -255,10 +285,12 @@ public final class ImportClass implements ErrorRule<Void> {
         }
     }
     
+    @Override
     public String getId() {
         return ImportClass.class.getName();
     }
     
+    @Override
     public String getDisplayName() {
         return "Add Import Fix";
     }
@@ -284,69 +316,203 @@ public final class ImportClass implements ErrorRule<Void> {
         this.compImports = compImports;
     }
     
-    public Pair<List<Element>, List<Element>> getCandidateFQNs(CompilationInfo info, FileObject file, String simpleName, Data<Void> data) {
+    public ComputeImports getCandidateFQNs(CompilationInfo info, FileObject file, String simpleName, Data<Void> data) {
             //compute imports:
-            Map<String, List<String>> candidates = new HashMap<String, List<String>>();
-            ComputeImports imp = new ComputeImports();
-            
+            ComputeImports imp = new ComputeImports(info);
             setComputeImports(imp);
             
-            ComputeImports.Pair<Map<String, List<Element>>, Map<String, List<Element>>> rawCandidates = imp.computeCandidates(info);
-            
-            setComputeImports(null);
-            
-            if (isCancelled() || rawCandidates == null) {
+            ComputeImports.Pair<Map<String, List<Element>>, Map<String, List<Element>>> rawCandidates;
+            try {
+                imp = imp.computeCandidatesEx();
+            } finally {
+                setComputeImports(null);
+            }
+            if (isCancelled()) {
                 ErrorHintsProvider.LOG.log(Level.FINE, "ImportClassEnabler.getCandidateFQNs cancelled, returning."); //NOI18N
-                
                 return null;
             }
-            
-            for (String sn : rawCandidates.a.keySet()) {
-                List<String> c = new ArrayList<String>();
-                
-                for (Element te : rawCandidates.a.get(sn)) {
-                    c.add(Utilities.getElementName(te, true).toString());
-                }
-                
-                candidates.put(sn, c);
-            }
-            
-            Map<String, List<String>> notFilteredCandidates = new HashMap<String, List<String>>();
-            
-            for (String sn : rawCandidates.b.keySet()) {
-                List<String> c = new ArrayList<String>();
-                
-                for (Element te : rawCandidates.b.get(sn)) {
-                    c.add(Utilities.getElementName(te, true).toString());
-                }
-                
-                notFilteredCandidates.put(sn, c);
-            }
-            
-        List<Element> candList = rawCandidates.a.get(simpleName);
-        List<Element> notFilteredCandList = rawCandidates.b.get(simpleName);
-        
-        return Pair.<List<Element>, List<Element>>of(candList, notFilteredCandList);
+            return imp;
     }
     
-    static final class FixImport implements EnhancedFix {
-
+    @Messages("WRN_FileInvalid=Cannot resolve file - already deleted?")
+    static abstract class FixBase implements EnhancedFix {
+        static final Logger LOG = Logger.getLogger(FixImport.class.getName());
+        protected final String fqn;
+        protected final ElementHandle<Element> toImport;
+        protected final boolean isValid;
         private final FileObject file;
-        private final String fqn;
-        private final ElementHandle<Element> toImport;
         private final String sortText;
-        private final boolean isValid;
+
+        protected WorkingCopy copy;
+        
+        private FixBase(FileObject file, String fqn, ElementHandle<Element> toImport, String sortText, boolean isValid) {
+            this.isValid = isValid;
+            this.file = file;
+            this.fqn = fqn;
+            this.toImport = toImport;
+            this.sortText = sortText;
+        }
+        
+        protected abstract void perform();
+        protected abstract void performDoc(Document doc);
+    
+        public ChangeInfo implement() throws IOException {
+            JavaSource js = JavaSource.forFileObject(file);            
+            
+            Task task = new Task<WorkingCopy>() {
+                public void run(WorkingCopy copy) throws Exception {
+                    if (copy.toPhase(Phase.RESOLVED).compareTo(Phase.RESOLVED) < 0) {
+                        return;
+                    }
+                    FixBase.this.copy = copy;
+                    try {
+                        perform();
+                    } finally {
+                        FixBase.this.copy = null;
+                    }
+                }
+            };
+            if (js != null) {
+                js.runModificationTask(task).commit();
+            } else {
+                DataObject od;
+                
+                try {
+                    od = DataObject.find(file);
+                } catch (DataObjectNotFoundException donfe) {
+                    LOG.log(Level.INFO, null, donfe);
+                    StatusDisplayer.getDefault().setStatusText(Bundle.WRN_FileInvalid());
+                    return null;
+                }
+                
+                EditorCookie ec = od.getLookup().lookup(EditorCookie.class);
+                Document doc = ec != null ? ec.openDocument() : null;
+                if (doc != null) {
+                    performDoc(doc);
+                }
+            }
+            return null;
+        }
+
+        @Override
+        public int hashCode() {
+            return fqn.hashCode();
+        }
+        
+        @Override
+        public boolean equals(Object o) {
+            if (getClass().isInstance(o)) {
+                return fqn.equals(((FixBase) o).fqn);
+            }
+            return false;
+        }
+
+        @Override
+        public CharSequence getSortText() {
+            return sortText;
+        }
+    }
+    
+    static final class UseFQN extends FixBase {
+        private final boolean all;
+        
+        static UseFQN createShared(CompilationInfo info, 
+                FileObject file, 
+                String fqn, 
+                ElementHandle<Element> toImport, 
+                String sortText, TreePath replacePath, boolean isValid) {
+            
+            String k = UseFQN.class.getName() + "#" + fqn; // NOI18N
+            Object o = info.getCachedValue(k);
+            UseFQN inst;
+            if (o instanceof UseFQN) {
+                inst = (UseFQN)o;
+                inst.addTreePath(TreePathHandle.create(replacePath, info));
+            } else {
+                inst = new UseFQN(info, file, fqn, toImport, sortText, replacePath, isValid, true);
+                info.putCachedValue(k, inst, CompilationInfo.CacheClearPolicy.ON_TASK_END);
+            }
+            return inst;
+        }
+        
+        private final TreePathHandle replacePathHandle;
+        private final Collection<TreePathHandle> additionalLocations = new ArrayList<>();
+        private final String sn;
+        
+        public UseFQN(CompilationInfo info, FileObject file, String fqn, ElementHandle<Element> toImport, String sortText, TreePath replacePath, boolean isValid, 
+                boolean all) {
+            super(file, fqn, toImport, sortText, isValid);
+            this.sn = replacePath.getLeaf().toString();
+            this.replacePathHandle = TreePathHandle.create(replacePath, info);
+            this.all = all;
+        }
+        
+        void addTreePath(TreePathHandle toReplace) {
+            this.additionalLocations.add(toReplace);
+        }
+
+        @Override
+        protected void perform() {
+            TreePath replacePath = replacePathHandle.resolve(copy);
+
+            if (replacePath == null) {
+                Logger.getAnonymousLogger().warning(String.format("Attempt to change import for FQN: %s, but the import cannot be resolved in the current context", fqn));
+                return;
+            }
+            Element el = toImport.resolve(copy);
+            if (el == null) {
+                return;
+            }
+            CharSequence elFQN = copy.getElementUtilities().getElementName(el, true);
+            IdentifierTree id = copy.getTreeMaker().Identifier(elFQN);
+            copy.rewrite(replacePath.getLeaf(), id);
+            
+            for (TreePathHandle tph : additionalLocations) {
+                replacePath = tph.resolve(copy);
+                if (replacePath == null) {
+                    continue;
+                }
+                copy.rewrite(replacePath.getLeaf(), id);
+            }
+        }
+
+        @Override
+        protected void performDoc(Document doc) {
+            // ???
+        }
+        
+        public String getText() {
+            String displayName = all ? 
+                    NbBundle.getMessage(ImportClass.class, "Use_FQN_for_All_X", fqn, sn):
+                    NbBundle.getMessage(ImportClass.class, "Use_FQN_for_X", fqn);
+            if (isValid) {
+                return displayName;
+            } else {
+                return JavaFixAllImports.NOT_VALID_IMPORT_HTML + displayName;
+            }
+        }
+
+        @Override
+        public boolean equals(Object o) {
+            boolean x = super.equals(o);
+            if (x) {
+                x = ((UseFQN)o).all == all;
+            }
+            return x;
+        }
+        
+        
+    }
+    
+    static final class FixImport extends FixBase {
         private final @NullAllowed TreePathHandle replacePathHandle;
         private final @NullAllowed String suffix;
         private final boolean statik;
         private final boolean doOrganize;
         
-        public FixImport(FileObject file, String fqn, ElementHandle<Element> toImport, String sortText, boolean isValid, CompilationInfo info, @NullAllowed TreePath replacePath, @NullAllowed String replaceSuffix, boolean doOrganize) {
-            this.file = file;
-            this.fqn = fqn;
-            this.toImport = toImport;
-            this.sortText = sortText;
-            this.isValid = isValid;
+        public FixImport(FileObject file, String fqn, ElementHandle<Element> toImport, String sortText, boolean isValid, CompilationInfo info, @NullAllowed TreePath replacePath, @NullAllowed String replaceSuffix, 
+                boolean doOrganize) {
+            super(file, fqn, toImport, sortText, isValid);
             if (replacePath != null) {
                 this.replacePathHandle = TreePathHandle.create(replacePath, info);
                 this.suffix = replaceSuffix;
@@ -363,102 +529,60 @@ public final class ImportClass implements ErrorRule<Void> {
         }
 
         @Messages("Change_to_import_X=Change to import {1}{0}")
+        @Override
         public String getText() {
             String displayName = replacePathHandle == null ? NbBundle.getMessage(ImportClass.class, "Add_import_for_X", new Object[] {fqn}) : Bundle.Change_to_import_X(fqn + suffix, statik ? "static " : "");
-            if (isValid)
+            if (isValid) {
                 return displayName;
-            else
-                return JavaFixAllImports.NOT_VALID_IMPORT_HTML + displayName;
-        }
-
-        @Messages("WRN_FileInvalid=Cannot resolve file - already deleted?")
-        public ChangeInfo implement() throws IOException {
-            JavaSource js = JavaSource.forFileObject(file);            
-            
-            Task task = new Task<WorkingCopy>() {
-                    public void run(WorkingCopy copy) throws Exception {
-                        if (copy.toPhase(Phase.RESOLVED).compareTo(Phase.RESOLVED) < 0)
-                           return;
-
-                        //XXX:
-                        if (replacePathHandle != null) {
-                            TreePath replacePath = replacePathHandle.resolve(copy);
-
-                            if (replacePath == null) {
-                                Logger.getAnonymousLogger().warning(String.format("Attempt to change import for FQN: %s, but the import cannot be resolved in the current context", fqn));
-                                return;
-                            }
-
-                            copy.rewrite(replacePath.getLeaf(), copy.getTreeMaker().Identifier(fqn));
-
-                            return;
-                        }
-                  
-                        Element te = toImport.resolve(copy);
-                        
-                        if (te == null) {
-                            Logger.getAnonymousLogger().warning(String.format("Attempt to fix import for FQN: %s, which does not have a TypeElement in currect context", fqn));
-                            return ;
-                        }
-                        
-                        if (doOrganize) {
-                            OrganizeImports.doOrganizeImports(copy, Collections.singleton(te), false);
-                        } else {
-                            CompilationUnitTree cut = GeneratorUtilities.get(copy).addImports(
-                                copy.getCompilationUnit(),
-                                Collections.singleton(te)
-                            );                        
-                            copy.rewrite(copy.getCompilationUnit(), cut);
-                        }
-                    }
-                    
-            };
-
-            if (js != null) {
-                js.runModificationTask(task).commit();
             } else {
-                DataObject od;
-                
-                try {
-                    od = DataObject.find(file);
-                } catch (DataObjectNotFoundException donfe) {
-                    LOG.log(Level.INFO, null, donfe);
-                    StatusDisplayer.getDefault().setStatusText(Bundle.WRN_FileInvalid());
-                    return null;
-                }
-                
-                EditorCookie ec = od.getLookup().lookup(EditorCookie.class);
-                Document doc = ec != null ? ec.openDocument() : null;
-                String topLevelLanguageMIMEType = doc != null ? NbEditorUtilities.getMimeType(doc) : null;
-                if (topLevelLanguageMIMEType != null) {
-                    Lookup lookup = MimeLookup.getLookup(MimePath.get(topLevelLanguageMIMEType));
-                    Collection<? extends ImportProcessor> instances = lookup.lookupAll(ImportProcessor.class);
-
-                    for (ImportProcessor importsProcesor : instances) {
-                        importsProcesor.addImport(doc, fqn);
-                    }
-                }
+                return JavaFixAllImports.NOT_VALID_IMPORT_HTML + displayName;
             }
-            return null;
-        }
-        private static final Logger LOG = Logger.getLogger(FixImport.class.getName());
-        
-        @Override
-        public int hashCode() {
-            return fqn.hashCode();
-        }
-        
-        @Override
-        public boolean equals(Object o) {
-            if (o instanceof FixImport) {
-                return fqn.equals(((FixImport) o).fqn);
-            }
-            
-            return false;
         }
 
-        public CharSequence getSortText() {
-            return sortText;
+        @Override
+        protected void performDoc(Document doc) {
+            String topLevelLanguageMIMEType = doc != null ? NbEditorUtilities.getMimeType(doc) : null;
+            if (topLevelLanguageMIMEType != null) {
+                Lookup lookup = MimeLookup.getLookup(MimePath.get(topLevelLanguageMIMEType));
+                Collection<? extends ImportProcessor> instances = lookup.lookupAll(ImportProcessor.class);
+
+                for (ImportProcessor importsProcesor : instances) {
+                    importsProcesor.addImport(doc, fqn);
+                }
+            }
+        }
+
+        @Override
+        protected void perform() {
+            if (replacePathHandle != null) {
+                TreePath replacePath = replacePathHandle.resolve(copy);
+
+                if (replacePath == null) {
+                    Logger.getAnonymousLogger().warning(String.format("Attempt to change import for FQN: %s, but the import cannot be resolved in the current context", fqn));
+                    return;
+                }
+
+                copy.rewrite(replacePath.getLeaf(), copy.getTreeMaker().Identifier(fqn));
+
+                return;
+            }
+
+            Element te = toImport.resolve(copy);
+
+            if (te == null) {
+                Logger.getAnonymousLogger().warning(String.format("Attempt to fix import for FQN: %s, which does not have a TypeElement in currect context", fqn));
+                return ;
+            }
+
+            if (doOrganize) {
+                OrganizeImports.doOrganizeImports(copy, Collections.singleton(te), false);
+            } else {
+                CompilationUnitTree cut = GeneratorUtilities.get(copy).addImports(
+                    copy.getCompilationUnit(),
+                    Collections.singleton(te)
+                );                        
+                copy.rewrite(copy.getCompilationUnit(), cut);
+            }
         }
     }
 }
