@@ -149,9 +149,24 @@ import org.openide.text.PositionRef;
 import org.openide.util.Exceptions;
 
 import static com.sun.source.tree.Tree.Kind.*;
+import com.sun.tools.javac.api.JavacScope;
+import com.sun.tools.javac.api.JavacTaskImpl;
+import com.sun.tools.javac.code.Type;
+import com.sun.tools.javac.comp.Attr;
+import com.sun.tools.javac.comp.AttrContext;
+import com.sun.tools.javac.comp.Enter;
+import com.sun.tools.javac.comp.Env;
+import com.sun.tools.javac.tree.JCTree;
+import com.sun.tools.javac.util.JCDiagnostic;
+import com.sun.tools.javac.util.Log;
+import java.net.URI;
 import javax.lang.model.type.UnionType;
+import javax.tools.Diagnostic;
+import javax.tools.JavaFileObject;
+import javax.tools.SimpleJavaFileObject;
 import org.netbeans.api.java.source.CodeStyle;
 import org.netbeans.api.java.source.CodeStyleUtils;
+import org.netbeans.modules.java.source.JavaSourceAccessor;
 import org.openide.util.Pair;
 
 /**
@@ -479,13 +494,9 @@ public class Utilities {
             if (differences != null) {
                 for (Difference d : differences) {
                     if (d.getNewText() != null) { //to filter out possible removes
-                        final PositionRef start = d.getStartPosition();
-                        Document doc = start.getCloneableEditorSupport().getDocument();
+                        final Position start = d.getStartPosition();
+                        Document doc = d.openDocument();
 
-                        if (doc == null) {
-                            doc = start.getCloneableEditorSupport().openDocument();
-                        }
-                        
                         final Position[] pos = new Position[2];
                         final Document fdoc = doc;
                         
@@ -555,7 +566,8 @@ public class Utilities {
             if (tmirr != null)
                 return tmirr;
             else { //no extends, just '?'
-                return info.getElements().getTypeElement("java.lang.Object").asType(); // NOI18N
+                TypeElement te = info.getElements().getTypeElement("java.lang.Object"); // NOI18N
+                return te == null ? null : te.asType();
             }
                 
         }
@@ -936,19 +948,49 @@ public class Utilities {
             throw new IllegalStateException("Currently unsupported kind of tree: " + t.getKind()); // NOI18N
         }
     }
-
-    public static TreePath findEnclosingMethodOrConstructor(HintContext ctx, TreePath from) {
-        while (from != null && from.getLeaf().getKind() != Kind.METHOD && !TreeUtilities.CLASS_TREE_KINDS.contains(from.getLeaf().getKind())) {
+    
+    /**
+     * Finds the owner method, constructor, optionally initializer or lambda.
+     * The behaviour depends on the 'lambdaOrInitializer' parameter; if false,
+     * it will find the immediate owning method or constructor. If the code is
+     * NOT directly nested in a method or constructor (i.e. in a lambda, initializer),
+     * null is returned.
+     * <p/>
+     * If the parameter is true, the method is also able to return Lambda expression
+     * tree or initializer tree.
+     * <p/>
+     * At any rate, the search stops at class boundaries.
+     * 
+     * @param ctx the context
+     * @param from pat to start search from (upwards)
+     * @param lambdaOrInitializer also return lambdas or initializers if true.
+     * @return the direct owning executable block or {@code null} if the owning exec
+     * block does not satisfy the filter.
+     */
+    @SuppressWarnings({"AssignmentToMethodParameter", "NestedAssignment"})
+    public static TreePath findOwningExecutable(HintContext ctx, TreePath from, boolean lambdaOrInitializer) {
+        Tree.Kind k = null;
+        
+        OUTER: while (from != null && !(TreeUtilities.CLASS_TREE_KINDS.contains(k = from.getLeaf().getKind()))) {
+            switch (k) {
+                case METHOD:
+                    break OUTER;
+                case LAMBDA_EXPRESSION:
+                    return lambdaOrInitializer ? from : null;
+                case BLOCK: {
+                    TreePath par = from.getParentPath();
+                    Tree l = par.getLeaf();
+                    if (TreeUtilities.CLASS_TREE_KINDS.contains(l.getKind())) {
+                        return lambdaOrInitializer ? from : null;
+                    }
+                }
+            }
             from = from.getParentPath();
         }
-
-        if (from != null && from.getLeaf().getKind() == Kind.METHOD) {
-            return from;
-        }
-
-        return null;
+        return (from == null || k != Kind.METHOD) ?
+                null : from;
     }
-    
+
     /**
      * Finds the top-level block or expression that contains the 'from' path.
      * The result could be a 
@@ -993,7 +1035,7 @@ public class Utilities {
     }
 
     public static boolean isInConstructor(HintContext ctx) {
-        TreePath method = findEnclosingMethodOrConstructor(ctx, ctx.getPath());
+        TreePath method = findOwningExecutable(ctx, ctx.getPath(), false);
         if (method == null) return false;
         Element enclosingMethodElement = ctx.getInfo().getTrees().getElement(method);
         return (enclosingMethodElement != null &&
@@ -1055,6 +1097,9 @@ public class Utilities {
 
             if (tm.getKind() == TypeKind.NULL) {
                 tm = info.getElements().getTypeElement("java.lang.Object").asType(); // NOI18N
+                if (tm == null) {
+                    return null;
+                }
             }
 
             argumentTypes.add(tm);
@@ -1481,7 +1526,7 @@ public class Utilities {
 
         Element targetPackage = outterMostTarget.getEnclosingElement();
 
-        if (sourcePackage.equals(targetPackage)) {
+        if (sourcePackage != null && sourcePackage.equals(targetPackage)) {
             return Visibility.PACKAGE_PRIVATE;
         }
 
@@ -1662,6 +1707,49 @@ public class Utilities {
         }
     }
     
+    // -------------------------------------------------------------------------------------
+    // To be moved to java.source.base TreeUtilities
+    private static final class DummyJFO extends SimpleJavaFileObject {
+        private DummyJFO() {
+            super(URI.create("dummy.java"), JavaFileObject.Kind.SOURCE); // NOI18N
+        }
+        @Override
+        public CharSequence getCharContent(boolean ignoreEncodingErrors) throws IOException {
+            return "";
+        }
+    };
+
+    private static TypeMirror attributeTree(JavacTaskImpl jti, Tree tree, Scope scope, 
+            final List<Diagnostic<? extends JavaFileObject>> errors, @NullAllowed final Diagnostic.Kind filter) {
+        Log log = Log.instance(jti.getContext());
+        JavaFileObject prev = log.useSource(new DummyJFO());
+        Enter enter = Enter.instance(jti.getContext());
+        
+        Log.DiagnosticHandler discardHandler = new Log.DiscardDiagnosticHandler(log) {
+            private Diagnostic.Kind f = filter == null ? Diagnostic.Kind.ERROR : filter;
+            @Override
+            public void report(JCDiagnostic diag) {
+                if (diag.getKind().compareTo(f) >= 0) {
+                    errors.add(diag);
+                }
+            }            
+        };
+        try {
+            enter.shadowTypeEnvs(true);
+            Attr attr = Attr.instance(jti.getContext());
+            Env<AttrContext> env = ((JavacScope) scope).getEnv();
+            if (tree instanceof JCTree.JCExpression) {
+                return attr.attribExpr((JCTree) tree,env, Type.noType);
+            }
+            return attr.attribStat((JCTree) tree,env);
+        } finally {
+            log.useSource(prev);
+            log.popDiagnosticHandler(discardHandler);
+            enter.shadowTypeEnvs(false);
+        }
+    }
+    // -------------------------------------------------------------------------------------
+
     private static boolean resolveAlternativeInvocation(
             CompilationInfo ci, TreePath invPath, 
             TreePath origPath,
@@ -1699,6 +1787,17 @@ public class Utilities {
                 break;
             }
             switch (t.getKind()) {
+                case VARIABLE: {
+                    // the declaration is omitted so that the name will not clash
+                    // with existing names in the source
+                    // PENDING: what if tested expression is the initializer and
+                    // invalid typecast makes the value not assignable to the variable ?
+                    VariableTree vt = (VariableTree)t;
+                    if (vt.getInitializer() == previous) {
+                        breakPrev = true;
+                    }
+                    break;
+                }
                 case CONDITIONAL_EXPRESSION: {
                     // if the tree is the condition part, then we're done and the result is a boolean.
                     ConditionalExpressionTree ctree = (ConditionalExpressionTree)t;
@@ -1776,7 +1875,7 @@ public class Utilities {
         if (stPath == null) {
             return false;
         }
-        
+
         int baseIndex = (int)sp.getStartPosition(ci.getCompilationUnit(), exp.getLeaf());
         if (baseIndex < 0) {
             return false;
@@ -1805,10 +1904,12 @@ public class Utilities {
         } else {
             t = ci.getTreeUtilities().parseExpression(sb.toString(), nsp);
         }
-        
         Scope s = ci.getTreeUtilities().scopeFor(Math.max(0, expEndPos - 1));
-        ci.getTreeUtilities().attributeTree(t, s);
-        
+        List<Diagnostic<? extends JavaFileObject>> diags = new ArrayList<>();
+        attributeTree(JavaSourceAccessor.getINSTANCE().getJavacTask(ci), t, s, diags, null);
+        if (!diags.isEmpty()) {
+            return false;
+        }
         TreePath newPath = new TreePath(exp.getParentPath(), t);
         // path for the method invocation within the newly formed expression or statement.
         // the +1 ensures that we are inside the method invocation subtree (method has >= 1 char as ident)
@@ -1929,4 +2030,72 @@ public class Utilities {
         }
         return to.getKind().ordinal() < from.getKind().ordinal();
     }
+
+    /**
+     * Finds conflicting declarations of methods within type.
+     * Given a class `clazz' and a set of methods, finds possible conflicts in the class. For each method,
+     * the class is inspected for declarations with the same name, and the same erased types.
+     * <p/>
+     * Empty Map is returned if no conflicts are found.
+     * 
+     * @param clazz target class
+     * @param methods methods to check
+     * @return detected conflicts.
+     */
+    public static Map<? extends ExecutableElement, ? extends ExecutableElement>  findConflictingMethods(CompilationInfo info, TypeElement clazz, Iterable<? extends ExecutableElement> methods) {
+        final Map<Name, Collection<ExecutableElement>> currentByName = new HashMap<>();
+        Map<ExecutableElement, ExecutableElement> ret = new HashMap<>();
+        
+        for (Element e : clazz.getEnclosedElements()) {
+            if (e.getKind() != ElementKind.METHOD) {
+                continue;
+            }
+            ExecutableElement ee = (ExecutableElement)e;
+            Name n = ee.getSimpleName();
+            Collection<ExecutableElement> named = currentByName.get(n);
+            if (named == null) {
+                named = new ArrayList<>(3);
+                currentByName.put(n, named);
+            }
+            named.add(ee);
+        }
+        oneMethod: for(ExecutableElement method : methods) {
+            DeclaredType asMemberOf = (DeclaredType)clazz.asType();
+            ExecutableType et;
+            try {
+                et = (ExecutableType)info.getTypes().asMemberOf(asMemberOf, method);
+            } catch (IllegalArgumentException iae) {
+                continue;
+            }
+            Collection<ExecutableElement> candidates = currentByName.get(method.getSimpleName());
+            if (candidates != null) {
+                check: for (ExecutableElement e : candidates) {
+                    if (e.getKind() != ElementKind.METHOD) {
+                        continue;
+                    }
+                    ExecutableElement ee = (ExecutableElement)e;
+                    if (!ee.getSimpleName().equals(method.getSimpleName())) {
+                        continue;
+                    }
+                    if (ee.getParameters().size() != et.getParameterTypes().size()) {
+                        continue;
+                    }
+                    for (int i = 0; i < ee.getParameters().size(); i++) {
+                        TypeMirror t1 = ee.getParameters().get(i).asType();
+                        TypeMirror t2 = et.getParameterTypes().get(i);
+                        if (!info.getTypes().isSameType(
+                                info.getTypes().erasure(t1),
+                                info.getTypes().erasure(t2)
+                        )) {
+                            continue check;
+                        }
+                    }
+                    // skip
+                    ret.put(method, e);
+                }
+            }
+        }
+        return ret;
+    }
+
 }
