@@ -82,8 +82,10 @@ import javax.lang.model.element.Modifier;
 import javax.lang.model.element.Name;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.VariableElement;
+import javax.lang.model.type.ExecutableType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
+import javax.lang.model.util.ElementFilter;
 import javax.swing.JButton;
 import javax.swing.text.Document;
 import org.netbeans.api.java.source.CompilationInfo;
@@ -292,10 +294,38 @@ public final class IntroduceMethodFix extends IntroduceFixBase implements Fix {
             exceptionHandles.add(TypeMirrorHandle.create(tm));
         }
         AtomicBoolean allIfaces = new AtomicBoolean();
-        List<TargetDescription> targets = IntroduceExpressionBasedMethodFix.computeViableTargets(info, block, statementsToWrap, duplicates, cancel, allIfaces);
-        IntroduceMethodFix imf = new IntroduceMethodFix(info.getJavaSource(), h, params, additionaLocalTypes, additionaLocalNames, TypeMirrorHandle.create(returnType), returnAssignTo, declareVariableForReturnValue, exceptionHandles, exits, exitsFromAllBranches, statements[0], statements[1], 
-                duplicatesCount, scanner.getUsedTypeVars(), end, targets);
-        imf.setTargetIsInterface(allIfaces.get());
+        Map<TargetDescription, Set<String>> targets = new LinkedHashMap<>();
+        List<TargetDescription> viableTargets = IntroduceExpressionBasedMethodFix.computeViableTargets(info, block, statementsToWrap, duplicates, cancel, allIfaces);
+        IntroduceMethodFix imf = null;
+        if (viableTargets != null && !viableTargets.isEmpty()) {
+            for (TargetDescription target : viableTargets) {
+                if (target.type == null) {
+                    continue;
+                }
+                final TypeElement resolvedType = target.type.resolve(info);
+                if (resolvedType == null) {
+                    continue;
+                }
+                Set<String> cNames = new HashSet<>();
+                outer: for (ExecutableElement ee : ElementFilter.methodsIn(resolvedType.getEnclosedElements())) {
+                    List<? extends TypeMirror> pTypes = ((ExecutableType) ee.asType()).getParameterTypes();
+                    if (pTypes.size() == paramsVariables.size()) {
+                        Iterator<? extends TypeMirror> pTypesIt = pTypes.iterator();
+                        Iterator<VariableElement> pVarsIt = paramsVariables.iterator();
+                        while (pTypesIt.hasNext() && pVarsIt.hasNext()) {
+                            if (!info.getTypes().isSameType(pTypesIt.next(), pVarsIt.next().asType())) {
+                                continue outer;
+                            }
+                        }
+                        cNames.add(ee.getSimpleName().toString());
+                    }
+                }
+                targets.put(target, cNames);
+            }
+            imf = new IntroduceMethodFix(info.getJavaSource(), h, params, additionaLocalTypes, additionaLocalNames, TypeMirrorHandle.create(returnType), returnAssignTo, declareVariableForReturnValue, exceptionHandles, exits, exitsFromAllBranches, statements[0], statements[1], 
+                    duplicatesCount, scanner.getUsedTypeVars(), end, targets);
+            imf.setTargetIsInterface(allIfaces.get());
+        }
         return imf;
     }
 
@@ -404,9 +434,9 @@ public final class IntroduceMethodFix extends IntroduceFixBase implements Fix {
     private final int from;
     private final int to;
     private final List<TreePathHandle> typeVars;
-    private final List<TargetDescription> targets;
+    private final Map<TargetDescription, Set<String>> targets;
 
-    public IntroduceMethodFix(JavaSource js, TreePathHandle parentBlock, List<TreePathHandle> parameters, List<TypeMirrorHandle> additionalLocalTypes, List<String> additionalLocalNames, TypeMirrorHandle returnType, TreePathHandle returnAssignTo, boolean declareVariableForReturnValue, Set<TypeMirrorHandle> thrownTypes, List<TreePathHandle> exists, boolean exitsFromAllBranches, int from, int to, int duplicatesCount, List<TreePathHandle> typeVars, int offset, List<TargetDescription> targets) {
+    public IntroduceMethodFix(JavaSource js, TreePathHandle parentBlock, List<TreePathHandle> parameters, List<TypeMirrorHandle> additionalLocalTypes, List<String> additionalLocalNames, TypeMirrorHandle returnType, TreePathHandle returnAssignTo, boolean declareVariableForReturnValue, Set<TypeMirrorHandle> thrownTypes, List<TreePathHandle> exists, boolean exitsFromAllBranches, int from, int to, int duplicatesCount, List<TreePathHandle> typeVars, int offset, Map<TargetDescription, Set<String>> targets) {
         super(js, parentBlock, duplicatesCount, offset);
         this.parameters = parameters;
         this.additionalLocalTypes = additionalLocalTypes;
