@@ -50,6 +50,7 @@ import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.NewClassTree;
 import com.sun.source.tree.Scope;
+import com.sun.source.tree.StatementTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.VariableTree;
 import com.sun.source.util.TreePath;
@@ -63,6 +64,7 @@ import java.util.Set;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.Modifier;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.VariableElement;
 import javax.lang.model.type.DeclaredType;
@@ -91,6 +93,9 @@ public class ConvertToLambdaPreconditionChecker {
     private BlockTree singleStatementLambdaMethodBody = null;
     private boolean foundMemberReferenceCandidate = false;
     private boolean havePreconditionsBeenChecked = false;
+    private boolean foundRefToUninitializedVar = false;
+    private final Element ownerClass;
+    private final Element createdClass;
 
     public ConvertToLambdaPreconditionChecker(TreePath pathToNewClassTree, CompilationInfo info) {
 
@@ -99,10 +104,37 @@ public class ConvertToLambdaPreconditionChecker {
         this.info = info;
         this.types = info.getTypes();
 
+        Element el = info.getTrees().getElement(pathToNewClassTree);
+        if (el.getKind() == ElementKind.CONSTRUCTOR) {
+            createdClass = el.getEnclosingElement();
+        } else {
+            createdClass = null;
+        }
         this.lambdaMethodTree = getMethodFromFunctionalInterface(this.newClassTree);
         this.localScope = getScopeFromTree(this.pathToNewClassTree);
+        this.ownerClass = findFieldOwner();
     }
-
+    
+    /**
+     * Returns the class Element, if the pathToNewClassTree is a part of class field's
+     * init expression; otherwise null.
+     * @return 
+     */
+    private Element findFieldOwner() {
+        TreePath p = pathToNewClassTree.getParentPath();
+        while (p != null) {
+            Tree t = p.getLeaf();
+            if (t.getKind() == Tree.Kind.METHOD) {
+                // this is OK
+                return null;
+            } else if (t.getKind() == Tree.Kind.CLASS) {
+                return info.getTrees().getElement(p);
+            }
+            p = p.getParentPath();
+        }
+        return null;
+    }
+    
     private static MethodTree getMethodFromFunctionalInterface(NewClassTree newClassTree) {
         //ignore first member, which is a synthetic constructor call
         ClassTree classTree = newClassTree.getClassBody();
@@ -118,7 +150,8 @@ public class ConvertToLambdaPreconditionChecker {
                 && !foundRecursiveCall()
                 && !foundOverloadWhichMakesLambdaAmbiguous()
                 && !foundAssignmentToSupertype()
-                && !foundAssignmentToRawtype();
+                && !foundAssignmentToRawtype()
+                && !foundRefToUninitializedVar();
     }
     
     private void ensurePreconditionsAreChecked() {
@@ -132,10 +165,16 @@ public class ConvertToLambdaPreconditionChecker {
         }
     }
     
+    boolean foundRefToUninitializedVar() {
+        ensurePreconditionsAreChecked();
+        return foundRefToUninitializedVar;
+    }
+    
     public boolean passesFatalPreconditions() {
         return !foundRefToThisOrSuper() &&
                !foundRecursiveCall() &&
-               !foundErroneousTargetType();
+               !foundErroneousTargetType() && 
+               !foundRefToUninitializedVar();
     }
 
     public boolean needsCastToExpectedType() {
@@ -192,6 +231,11 @@ public class ConvertToLambdaPreconditionChecker {
 
     private class PreconditionScanner extends TreePathScanner<Tree, Trees> {
 
+        @Override
+        public Tree visitClass(ClassTree node, Trees p) {
+            return null;
+        }
+
         @Override
         public Tree visitMethod(MethodTree methodTree, Trees trees) {
 
@@ -216,8 +260,44 @@ public class ConvertToLambdaPreconditionChecker {
         public Tree visitIdentifier(IdentifierTree identifierTree, Trees trees) {
 
             //check for ref to 'this'
-            if (identifierTree.getName().contentEquals("this") || identifierTree.getName().contentEquals("super")) {
-                foundRefToThisOrSuper = true;
+             IDENT: if (identifierTree.getName().contentEquals("this") || identifierTree.getName().contentEquals("super")) {
+                Tree parent = getCurrentPath().getParentPath().getLeaf();
+                if (parent.getKind() == Tree.Kind.MEMBER_SELECT) {
+                    // something.this or something.super - resolve the type
+                    Element el = info.getTrees().getElement(getCurrentPath().getParentPath());
+                    if (el == createdClass) {
+                        foundRefToThisOrSuper = true;
+                    } else {
+                        // this.something or super.something, dereference
+                        TypeMirror m = info.getTrees().getTypeMirror(getCurrentPath());
+                        if (!Utilities.isValidType(m)) {
+                            // just to be sure
+                            foundRefToThisOrSuper = true;
+                        } else if (m.getKind() == TypeKind.DECLARED) {
+                            if (createdClass != null && 
+                                info.getTypes().isSubtype(createdClass.asType(), m)) {
+                                foundRefToThisOrSuper = true;
+                            }
+                        }
+                    }
+                } else {
+                    // unqualified this/super
+                    foundRefToThisOrSuper = true;
+                }
+            }
+            Element el = info.getTrees().getElement(getCurrentPath());
+            if (el != null && el.getKind() == ElementKind.FIELD) {
+                if (ownerClass == el.getEnclosingElement()) {
+                    if (!el.getModifiers().contains(Modifier.FINAL)) {
+                        foundRefToUninitializedVar = true;
+                    } else {
+                        // PENDING: shortcut: the field must be assigned 
+                        // in its initializer. It would more appropriate to check whether it
+                        // is definitively assigned before the lambda code - future enhancement
+                        VariableTree vt = (VariableTree)info.getTrees().getTree(el);
+                        foundRefToUninitializedVar |= vt.getInitializer() == null;
+                    }
+                }
             }
             return super.visitIdentifier(identifierTree, trees);
         }
@@ -234,9 +314,9 @@ public class ConvertToLambdaPreconditionChecker {
 
         @Override
         public Tree visitMethodInvocation(MethodInvocationTree methodInvocationTree, Trees trees) {
-
+            String nameSuggestion = org.netbeans.modules.editor.java.Utilities.varNameSuggestion(methodInvocationTree.getMethodSelect());
             //check for recursion
-            if (lambdaMethodTree.getName().contentEquals(org.netbeans.modules.editor.java.Utilities.varNameSuggestion(methodInvocationTree.getMethodSelect()))) {
+            if (nameSuggestion != null && lambdaMethodTree.getName().contentEquals(nameSuggestion)) {
                 ExpressionTree selector = getSelector(methodInvocationTree);
                 if (selector == null || (org.netbeans.modules.editor.java.Utilities.varNameSuggestion(selector) != null
                         && org.netbeans.modules.editor.java.Utilities.varNameSuggestion(selector).contentEquals("this"))) {
@@ -489,7 +569,7 @@ public class ConvertToLambdaPreconditionChecker {
     private void verifyTargetType() {
 
         TypeMirror expectedType = findExpectedType(pathToNewClassTree);
-        if (expectedType == null || expectedType.getKind() == TypeKind.ERROR) {
+        if (!Utilities.isValidType(expectedType)) {
             foundErroneousTargetType = true;
             return;
         }
