@@ -71,6 +71,7 @@ import javax.lang.model.type.PrimitiveType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.modules.java.hints.errors.Utilities;
 
 /**
  *
@@ -188,7 +189,9 @@ public class PreconditionsChecker {
      */
     private boolean isIterbale(ExpressionTree expression) {
         TypeMirror tm = workingCopy.getTrees().getTypeMirror(TreePath.getPath(workingCopy.getCompilationUnit(), expression));
-
+        if (!Utilities.isValidType(tm)) {
+            return false;
+        }
         if (tm.getKind() == TypeKind.ARRAY) {
             return false;
         } else {
@@ -301,7 +304,7 @@ public class PreconditionsChecker {
             }
             TreePath currentTreePath = this.getCurrentPath();
             Element el = trees.getElement(currentTreePath);
-            if (isExternalNEF(el, that)) {
+            if (el != null && isExternalNEF(el, that)) {
                 checkIfRefactorableMutation(currentTreePath, that);
             }
             return super.visitIdentifier(that, trees);
