@@ -129,8 +129,13 @@ public class Tiny {
 
 
     @Hint(displayName = "#DN_org.netbeans.modules.java.hints.perf.Tiny.stringEqualsEmpty", description = "#DESC_org.netbeans.modules.java.hints.perf.Tiny.stringEqualsEmpty", category="performance", enabled=false, suppressWarnings={"StringEqualsEmpty", "", "StringEqualsEmptyString"})
-    @TriggerPattern(value="$string.equals(\"\")",
-                    constraints=@ConstraintVariableType(variable="$string", type="java.lang.String"))
+    @TriggerPatterns({
+        @TriggerPattern(value="$string.equals(\"\")",
+                        constraints=@ConstraintVariableType(variable="$string", type="java.lang.String")),
+        
+        @TriggerPattern(value="$string.equalsIgnoreCase(\"\")",
+                        constraints=@ConstraintVariableType(variable="$string", type="java.lang.String"))
+    })
     public static ErrorDescription stringEqualsEmpty(HintContext ctx) {
         Fix f;
         if (ctx.getInfo().getSourceVersion().compareTo(SourceVersion.RELEASE_6) >= 0) {
