@@ -353,7 +353,11 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
                 return null;
             }
             // initializer and update operation can have any result type, including none
-            return Collections.singletonList(info.getElements().getTypeElement("java.lang.Void").asType()); // NOI18N
+            TypeElement tel = info.getElements().getTypeElement("java.lang.Void");
+            if (tel == null) {
+                return null;
+            }
+            return Collections.singletonList(tel.asType()); // NOI18N
         }
     }
 
@@ -405,7 +409,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
         }
         TypeMirror otherType = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), otherExpression));
         TypeMirror thisType = info.getTrees().getTypeMirror(getExpressionWithoutCasts());
-        if (otherType == null || thisType == null) {
+        if (!(Utilities.isValidType(otherType) && Utilities.isValidType(thisType))) {
             return null;
         }
 
@@ -522,8 +526,8 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
                                     break;
                                 case UNION:
                                     for (TypeMirror t : ((UnionType) ex).getAlternatives()) {
-                                        if (!result.contains(ex)) {
-                                            result.add(ex);
+                                        if (!result.contains(t)) {
+                                            result.add(t);
                                         }
                                     }
                                     break;
@@ -539,7 +543,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
             MethodTree mt = (MethodTree) parents.getLeaf();
             for (ExpressionTree etree : mt.getThrows()) {
                 TypeMirror m = info.getTrees().getTypeMirror(new TreePath(parents, etree));
-                if (!result.contains(m)) {
+                if (m != null && !result.contains(m)) {
                     result.add(m);
                 }
             }
@@ -578,7 +582,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
     public List<? extends TypeMirror> visitMethodInvocation(MethodInvocationTree node, Object p) {
         TypeMirror execType = info.getTrees().getTypeMirror(
                 new TreePath(getCurrentPath(), node.getMethodSelect()));
-        if (execType.getKind() != TypeKind.EXECUTABLE) {
+        if (execType == null || execType.getKind() != TypeKind.EXECUTABLE) {
             return null;
         }
         return visitMethodOrNew(node, p, node.getArguments(),
@@ -599,6 +603,9 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
             }
         } else {
             Element el = info.getTrees().getElement(getCurrentPath());
+            if (el == null) {
+                return null;
+            }
             if (theExpression.getLeaf() != node &&
                 (el.getKind() == ElementKind.METHOD || el.getKind() == ElementKind.CONSTRUCTOR)) {
                 int argIndex = args.indexOf(theExpression.getLeaf());
@@ -678,10 +685,13 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
     @Override
     public List<? extends TypeMirror> visitNewClass(NewClassTree node, Object p) {
         TypeMirror tm = info.getTrees().getTypeMirror(getCurrentPath());
-        if (tm.getKind() != TypeKind.DECLARED) {
+        if (tm == null || tm.getKind() != TypeKind.DECLARED) {
             return null;
         }
         Element el = info.getTrees().getElement(getCurrentPath());
+        if (el == null) {
+            return null;
+        }
         if (theExpression.getLeaf() != node.getEnclosingExpression()) {
             ExecutableType execType = (ExecutableType)info.getTypes().asMemberOf((DeclaredType)tm, el);
             return visitMethodOrNew(node, p, node.getArguments(), execType);
@@ -830,6 +840,9 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
             } else {
                 rhsType = expType;
             }
+            if (lhsType == null || rhsType == null) {
+                return null;
+            }
             if (lhsType.getKind() == TypeKind.DOUBLE) {
                 rettype = lhsType;
             } else if (rhsType.getKind() == TypeKind.DOUBLE) {
@@ -878,7 +891,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
                         TreePath expPath = getExpressionWithoutCasts();
                         TypeMirror expType = info.getTrees().getTypeMirror(expPath);
                         
-                        if (expType.getKind().isPrimitive() && expType.getKind() != followed.getKind()) {
+                        if (expType != null && expType.getKind().isPrimitive() && expType.getKind() != followed.getKind()) {
                             // if the cast is to more narrow type, permit it, as it looses precision, and potential produces a different value. Other
                             // hint / warning should take care of precision loss.
                             if (expType.getKind() != TypeKind.CHAR && followed.getKind().ordinal() < expType.getKind().ordinal()) {
@@ -940,7 +953,11 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
         if (theExpression == null) {
             initExpression(new TreePath(getCurrentPath(), node.getExpression()));
         }
-        return Collections.singletonList(info.getElements().getTypeElement("java.lang.Object").asType()); // NOI18N
+        TypeElement tel = info.getElements().getTypeElement("java.lang.Object");
+        if (tel == null) {
+            return null;
+        }
+        return Collections.singletonList(tel.asType()); // NOI18N
     }
     
     /**
@@ -969,7 +986,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
             // if the casted type is a primitive, the cast is NOT redundant as member select is applied to
             // the originally primitive value.
             TypeMirror castedType = info.getTrees().getTypeMirror(casted);
-            if (castedType.getKind().isPrimitive()) {
+            if (castedType != null && castedType.getKind().isPrimitive()) {
                 notRedundant = true;
             }
         }
@@ -980,7 +997,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
         List<TypeMirror> tt = new ArrayList<TypeMirror>();
         Element el = info.getTrees().getElement(getCurrentPath());
         
-        if (el.getKind() == ElementKind.METHOD) {
+        if (el != null && el.getKind() == ElementKind.METHOD) {
             // special hack: if the casted value is a lambda, we NEED to assign it a type prior to method invocation:
             TreePath exp = getExpressionWithoutCasts();
             if (exp != null && exp.getLeaf().getKind() == Tree.Kind.LAMBDA_EXPRESSION) {
@@ -1184,7 +1201,7 @@ public class ExpectedTypeResolver implements TreeVisitor<List<? extends TypeMirr
     @Override
     public List<? extends TypeMirror> visitEnhancedForLoop(EnhancedForLoopTree node, Object p) {
         TypeMirror varType = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), node.getVariable()));
-        if (varType.getKind() == TypeKind.ERROR) {
+        if (!Utilities.isValidType(varType)) {
             return null;
         } else {
             TypeMirror arrayType = info.getTypes().getArrayType(varType);
