@@ -48,11 +48,14 @@ import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
 import com.sun.source.tree.LambdaExpressionTree;
 import com.sun.source.tree.LambdaExpressionTree.BodyKind;
+
 import static com.sun.source.tree.LambdaExpressionTree.BodyKind.STATEMENT;
+
 import com.sun.source.tree.MemberReferenceTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
+import com.sun.source.tree.ModifiersTree;
 import com.sun.source.tree.NewClassTree;
 import com.sun.source.tree.ReturnTree;
 import com.sun.source.tree.Scope;
@@ -70,6 +73,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
+import javax.lang.model.SourceVersion;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
@@ -83,10 +87,11 @@ import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.ElementFilter;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.GeneratorUtilities;
+import org.netbeans.api.java.source.SourceUtils;
 import org.netbeans.api.java.source.TreeMaker;
 import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
-import org.netbeans.modules.editor.java.Utilities;
 import org.netbeans.spi.editor.hints.ErrorDescription;
 import org.netbeans.spi.java.hints.ErrorDescriptionFactory;
 import org.netbeans.spi.java.hints.Hint;
@@ -107,13 +112,15 @@ public class Lambda {
     @Messages({
         "DN_lambda2Class=Convert Lambda Expression to Anonymous Innerclass",
         "DESC_lambda2Class=Converts lambda expressions to anonymous inner classes",
-        "ERR_lambda2Class="
+        "ERR_lambda2Class=Anonymous class can be used"
     })
     @TriggerTreeKind(Kind.LAMBDA_EXPRESSION)
     public static ErrorDescription lambda2Class(HintContext ctx) {
         TypeMirror samType = ctx.getInfo().getTrees().getTypeMirror(ctx.getPath());
         
-        if (samType == null || samType.getKind() != TypeKind.DECLARED) return null;
+        if (samType == null || samType.getKind() != TypeKind.DECLARED) {
+            return null;
+        }
         
         return ErrorDescriptionFactory.forTree(ctx, ctx.getPath(), Bundle.ERR_lambda2Class(), new Lambda2Anonymous(ctx.getInfo(), ctx.getPath()).toEditorFix());
     }
@@ -122,7 +129,7 @@ public class Lambda {
     @Messages({
         "DN_lambda2MemberReference=Convert Lambda Expression to Member Reference",
         "DESC_lambda2MemberReference=Converts lambda expressions to member references",
-        "ERR_lambda2MemberReference=",
+        "ERR_lambda2MemberReference=Member reference can be used",
         "FIX_lambda2MemberReference=Use member reference"
     })
     @TriggerTreeKind(Kind.LAMBDA_EXPRESSION)
@@ -147,6 +154,9 @@ public class Lambda {
                 } else {
                     return null;
                 }
+                if (tree == null) {
+                    return null;
+                }
             } else {
                 return null;
             }
@@ -190,7 +200,9 @@ public class Lambda {
     })
     @TriggerPattern("($args$) -> $lambdaExpression")
     public static ErrorDescription expression2Return(HintContext ctx) {
-        if (((LambdaExpressionTree) ctx.getPath().getLeaf()).getBodyKind() != BodyKind.EXPRESSION) return null;
+        if (((LambdaExpressionTree) ctx.getPath().getLeaf()).getBodyKind() != BodyKind.EXPRESSION) {
+            return null;
+        }
         
         TypeMirror lambdaExpressionType = ctx.getInfo().getTrees().getTypeMirror(ctx.getVariables().get("$lambdaExpression"));
         String target =   lambdaExpressionType == null || lambdaExpressionType.getKind() != TypeKind.VOID
@@ -211,8 +223,9 @@ public class Lambda {
     public static ErrorDescription reference2Lambda(HintContext ctx) {
         Element refered = ctx.getInfo().getTrees().getElement(ctx.getPath());
         
-        if (refered == null || refered.getKind() != ElementKind.METHOD) return null;//XXX: constructors!
-        
+        if (refered == null || refered.getKind() != ElementKind.METHOD) {
+            return null;//XXX: constructors!
+        }        
         return ErrorDescriptionFactory.forTree(ctx, ctx.getPath(), Bundle.ERR_memberReference2Lambda(), new MemberReference2Lambda(ctx.getInfo(), ctx.getPath()).toEditorFix());
     }
     
@@ -232,26 +245,36 @@ public class Lambda {
             hasSyntheticParameterName |= var.getType() == null || ctx.getInfo().getTreeUtilities().isSynthetic(TreePath.getPath(ctx.getPath(), var.getType()));
         }
         
-        if (!hasSyntheticParameterName) return null;
+        if (!hasSyntheticParameterName) {
+            return null;
+        }
         
         return ErrorDescriptionFactory.forName(ctx, ctx.getPath(), Bundle.ERR_addExplicitLambdaParameters(), new AddExplicitLambdaParameterTypes(ctx.getInfo(), ctx.getPath()).toEditorFix());
     }
     
     private static ExecutableElement findAbstractMethod(CompilationInfo info, TypeMirror type) {
-        if (type.getKind() != TypeKind.DECLARED) return null;
+        if (type.getKind() != TypeKind.DECLARED) {
+            return null;
+        }
         
         TypeElement clazz = (TypeElement) ((DeclaredType) type).asElement();
         
-        if (!clazz.getKind().isInterface()) return null;
+        if (!clazz.getKind().isInterface()) {
+            return null;
+        }
         
         for (ExecutableElement ee : ElementFilter.methodsIn(clazz.getEnclosedElements())) {
-            if (ee.getModifiers().contains(Modifier.ABSTRACT)) return ee;
+            if (ee.getModifiers().contains(Modifier.ABSTRACT)) {
+                return ee;
+            }
         }
         
         for (TypeMirror tm : info.getTypes().directSupertypes(type)) {
             ExecutableElement ee = findAbstractMethod(info, tm);
             
-            if (ee != null) return ee;
+            if (ee != null) {
+                return ee;
+            }
         }
         
         return null;
@@ -268,6 +291,19 @@ public class Lambda {
         protected String getText() {
             return Bundle.FIX_lambda2Class();
         }
+        
+        private static TypeMirror avoidIntersectionType(CompilationInfo copy, TypeMirror org) {
+            if (org.getKind() == TypeKind.INTERSECTION) {
+                Element objEl = copy.getElements().getTypeElement("java.lang.Object"); // NOI18N
+                if (objEl == null) {
+                    // TODO: report
+                    return org;
+                }
+                return objEl.asType();
+            } else {
+                return org;
+            }
+        }
 
         @Override
         protected void performRewrite(TransformationContext ctx) throws Exception {
@@ -276,7 +312,7 @@ public class Lambda {
             TypeMirror samType = copy.getTrees().getTypeMirror(ctx.getPath());
             
             if (samType == null || samType.getKind() != TypeKind.DECLARED) {
-                //XXX
+                // FIXME: report
                 return ;
             }
             
@@ -294,7 +330,7 @@ public class Lambda {
                 
                 //XXX: should handle anonymous lambda parameters ('_')
                 if (p.getType() == null || copy.getTreeUtilities().isSynthetic(new TreePath(ctx.getPath(), p.getType()))) {
-                    methodParams.add(make.Variable(p.getModifiers(), p.getName(), make.Type(Utilities.resolveCapturedType(copy, resolvedType)), null));
+                    methodParams.add(make.Variable(p.getModifiers(), p.getName(), make.Type(SourceUtils.resolveCapturedType(copy, resolvedType)), null));
                 } else {
                     methodParams.add(p);
                 }
@@ -318,12 +354,32 @@ public class Lambda {
                     throw new IllegalStateException();
             }
             
-            MethodTree newMethod = make.Method(make.Modifiers(EnumSet.of(Modifier.PUBLIC)),
+            List<ExpressionTree> thrownTypes = new ArrayList<>(abstractMethod.getThrownTypes().size());
+            for (TypeMirror tm : abstractMethod.getThrownTypes()) {
+                // ErrorTypes are somehow handled, too, by make.Type
+                thrownTypes.add((ExpressionTree)make.Type(tm));
+            }
+            ModifiersTree mt = make.Modifiers(EnumSet.of(Modifier.PUBLIC));
+            // should I ever test for >= source 5, if there's a Lambda :) in the source already ?
+//            if (copy.getSourceVersion().compareTo(SourceVersion.RELEASE_5) >= 0) {
+                boolean generate = copy.getElements().getTypeElement("java.lang.Override") != null;
+
+                if (generate) {
+                   mt = make.addModifiersAnnotation(
+                           mt, make.Annotation(make.Identifier("Override"), Collections.<ExpressionTree>emptyList()));
+                }
+//            }
+    
+            TypeMirror retType = avoidIntersectionType(copy, descriptorType.getReturnType());
+            
+            MethodTree newMethod = make.Method(mt,
                                                abstractMethod.getSimpleName(),
-                                               make.Type(descriptorType.getReturnType()),
+                                               make.Type(retType),
                                                Collections.<TypeParameterTree>emptyList(), //XXX: type parameters
                                                methodParams,
-                                               Collections.<ExpressionTree>emptyList(), //XXX: throws types
+                                               // TODO: possibly filter out those exceptions, which are handled/never thrown 
+                                               // from the body
+                                               thrownTypes,
                                                newMethodBody,
                                                null);
             ClassTree innerClass = make.Class(make.Modifiers(EnumSet.noneOf(Modifier.class)),
@@ -339,7 +395,8 @@ public class Lambda {
             } else {
                 List<Tree> typeArguments = new ArrayList<>();
                 for (TypeMirror ta : ((DeclaredType) samType).getTypeArguments()) {
-                    typeArguments.add(make.Type(Utilities.resolveCapturedType(copy, ta)));
+                    typeArguments.add(make.Type(
+                            avoidIntersectionType(copy, SourceUtils.resolveCapturedType(copy, ta))));
                 }
                 targetTypeTree = (ExpressionTree) make.ParameterizedType(make.QualIdent(samTypeElement), typeArguments);
             }
@@ -385,7 +442,7 @@ public class Lambda {
             final WorkingCopy copy = ctx.getWorkingCopy();
             TypeMirror samType = copy.getTrees().getTypeMirror(ctx.getPath());
             if (samType == null || samType.getKind() != TypeKind.DECLARED) {
-                //XXX
+                // FIXME: report
                 return ;
             }
 
@@ -465,7 +522,7 @@ public class Lambda {
             List<VariableTree> formals = new ArrayList<>();
             List<IdentifierTree> actuals = new ArrayList<>();
             Scope scope = ctx.getWorkingCopy().getTrees().getScope(reference);
-            Set<String> usedNames = new HashSet<String>();
+            Set<String> usedNames = new HashSet<>();
             TreeMaker make = ctx.getWorkingCopy().getTreeMaker();
             
             if (on != null && (on.getKind().isClass() || on.getKind().isInterface()) && !refered.getModifiers().contains(Modifier.STATIC)) {
