@@ -62,8 +62,8 @@ import org.netbeans.spi.project.support.ant.PropertyUtils;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.URLMapper;
+import org.openide.util.BaseUtilities;
 import org.openide.util.Parameters;
-import org.openide.util.Utilities;
 
 /**
  * An API for project's classpaths modification.
@@ -195,7 +195,7 @@ public class ProjectClassPathModifier {
                 }
                 final FileObject fo;
                 if (urlToAdd.isAbsolute()) {
-                    fo = FileUtil.toFileObject(Utilities.toFile(urlToAdd));
+                    fo = FileUtil.toFileObject(BaseUtilities.toFile(urlToAdd));
                 } else {
                     File f = PropertyUtils.resolveFile(projectFolderFile, LibrariesSupport.convertURIToFilePath(urlToAdd));
                     fo = FileUtil.toFileObject(f);
