@@ -61,6 +61,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Properties;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.event.ChangeEvent;
@@ -105,6 +106,10 @@ import static org.netbeans.api.java.project.runner.JavaRunner.*;
 import org.netbeans.api.project.ProjectManager;
 import org.openide.loaders.DataObject;
 import org.openide.util.Lookup;
+import org.openide.util.RequestProcessor;
+import org.openide.util.Task;
+import org.openide.util.TaskListener;
+import org.openide.util.Union2;
 import org.openide.util.Utilities;
 import org.openide.util.lookup.AbstractLookup;
 import org.openide.util.lookup.InstanceContent;
@@ -117,31 +122,23 @@ import org.openide.util.lookup.InstanceContent;
 public class ProjectRunnerImpl implements JavaRunnerImplementation {
 
     private static final Logger LOG = Logger.getLogger(ProjectRunnerImpl.class.getName());
+    private static final Runnable NOP = new Runnable() {@Override public void run(){}};
+    private static final RequestProcessor RP = new RequestProcessor(ProjectRunnerImpl.class);
     
     public boolean isSupported(String command, Map<String, ?> properties) {
         return locateScript(command) != null;
     }
 
-    public ExecutorTask execute(String command, Map<String, ?> properties) throws IOException {
+    @Override
+    public ExecutorTask execute(final String command, final Map<String, ?> properties) throws IOException {
         if (QUICK_CLEAN.equals(command)) {
             return clean(properties);
         }
-        
-        String[] projectName = new String[1];
-        Map<String,String> antProps = computeProperties(command, properties, projectName);
-        
-        FileObject script = buildScript(command, false);
-        AntProjectCookie apc = new FakeAntProjectCookie(AntScriptUtils.antProjectCookieFor(script), command, projectName[0]);
-        AntTargetExecutor.Env execenv = new AntTargetExecutor.Env();
-        Properties props = execenv.getProperties();
-        props.putAll(antProps);
-        props.put("nb.wait.for.caches", "true");
-        if (properties.containsKey("maven.disableSources")) {
-            props.put("maven.disableSources", String.valueOf(properties.get("maven.disableSources")));
-        }
-        execenv.setProperties(props);
-
-        return AntTargetExecutor.createTargetExecutor(execenv).execute(apc, null);
+        final Work work = new Work(command, properties);
+        final ExecutorTask res = new WrapperTask(work);
+        work.setCallback(res);
+        RP.execute(work);
+        return res;
     }
 
     static Map<String,String> computeProperties(String command, Map<String, ?> properties, String[] projectNameOut) {
@@ -167,6 +164,10 @@ public class ProjectRunnerImpl implements JavaRunnerImplementation {
                     workDir = file.getAbsolutePath(); //NOI18N
                 }
             }
+        } else if (!new File(workDir).isDirectory()) {
+            IllegalArgumentException iae = new IllegalArgumentException("The work dir is not a folder.");
+            Exceptions.attachLocalizedMessage(iae, NbBundle.getMessage(ProjectRunnerImpl.class, "ERR_NoWorkDir"));
+            throw iae;
         }
         if (className == null) {
             Parameters.notNull(PROP_EXECUTE_FILE + " or " + PROP_CLASSNAME, toRun);
@@ -809,4 +810,119 @@ out:                for (FileObject root : exec.getRoots()) {
         }
 
     }
+
+    private final class Work implements Runnable {
+        private final String command;
+        private final Map<String,?> properties;
+        private final AtomicReference<Runnable> callBack;
+        //@GuardedBy("this")
+        private Union2<ExecutorTask,Throwable> result;
+        //@GuardedBy("this")
+        private boolean stopped;
+
+        Work(
+            final String command,
+            Map<String,?> properties) {
+            this.command = command;
+            this.properties = properties;
+            this.callBack = new AtomicReference<>(NOP);
+        }
+
+        void setCallback(final Runnable callBack) {
+            if (!this.callBack.compareAndSet(NOP, callBack)) {
+                throw new IllegalStateException("Already set"); //NOI18N
+            }
+        }
+
+        @Override
+        public void run() {
+            try {
+                String[] projectName = new String[1];
+                Map<String,String> antProps = computeProperties(command, properties, projectName);
+                FileObject script = buildScript(command, false);
+                AntProjectCookie apc = new FakeAntProjectCookie(AntScriptUtils.antProjectCookieFor(script), command, projectName[0]);
+                AntTargetExecutor.Env execenv = new AntTargetExecutor.Env();
+                Properties props = execenv.getProperties();
+                props.putAll(antProps);
+                props.put("nb.wait.for.caches", "true");
+                if (properties.containsKey("maven.disableSources")) {
+                    props.put("maven.disableSources", String.valueOf(properties.get("maven.disableSources")));
+                }
+                execenv.setProperties(props);
+                setResult(Union2.<ExecutorTask,Throwable>createFirst(AntTargetExecutor.createTargetExecutor(execenv).execute(apc, null)));
+            } catch (Throwable t) {
+                setResult(Union2.<ExecutorTask,Throwable>createSecond(t));
+                if (t instanceof ThreadDeath) {
+                    throw (ThreadDeath)t;
+                }
+            }
+        }
+
+        private synchronized void setResult(final Union2<ExecutorTask,Throwable> result) {
+            this.result = result;
+            if (result.hasFirst()) {
+                result.first().addTaskListener(new TaskListener() {
+                    @Override
+                    public void taskFinished(Task task) {
+                        callBack.get().run();
+                    }
+                });
+                if (stopped) {
+                    result.first().stop();
+                }
+            } else {
+                callBack.get().run();
+            }
+            this.notifyAll();
+        }
+
+        private synchronized Union2<ExecutorTask,Throwable> getResult() {
+            while (result == null) {
+                try {
+                    wait();
+                } catch (InterruptedException ie) {
+                    return null;
+                }
+            }
+            return result;
+        }
+
+        private synchronized void stop() {
+            if (result != null && result.hasFirst()) {
+                result.first().stop();
+            } else {
+                stopped = true;
+            }
+        }
+    }
+
+    private final class WrapperTask extends ExecutorTask {
+        private final Work work;
+
+        WrapperTask(final Work work) {
+            super(NOP);
+            this.work = work;
+        }
+
+        @Override
+        public void stop() {
+            work.stop();
+        }
+
+        @Override
+        public int result() {
+            final Union2<ExecutorTask, Throwable> result = work.getResult();
+            return result == null || result.hasSecond() ?
+                    -1 :
+                    result.first().result();
+        }
+
+        @Override
+        public InputOutput getInputOutput() {
+            final Union2<ExecutorTask, Throwable> result = work.getResult();
+            return result == null || result.hasSecond() ?
+                    InputOutput.NULL :
+                    result.first().getInputOutput();
+        }
+    }
 }
