@@ -51,6 +51,7 @@ import java.awt.Image;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.reflect.InvocationTargetException;
@@ -80,14 +81,10 @@ import org.netbeans.api.queries.FileBuiltQuery;
 import org.netbeans.api.queries.FileBuiltQuery.Status;
 import org.netbeans.modules.classfile.Access;
 import org.netbeans.modules.classfile.ClassFile;
+import org.netbeans.modules.classfile.InvalidClassFormatException;
 import org.netbeans.modules.java.source.usages.ExecutableFilesIndex;
 import org.netbeans.spi.java.loaders.RenameHandler;
-import org.openide.filesystems.FileChangeAdapter;
-import org.openide.filesystems.FileChangeListener;
-import org.openide.filesystems.FileEvent;
-import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileStateInvalidException;
-import org.openide.filesystems.FileUtil;
+import org.openide.filesystems.*;
 import org.openide.loaders.DataNode;
 import org.openide.loaders.DataObject;
 import org.openide.nodes.Children;
@@ -96,10 +93,14 @@ import org.openide.nodes.PropertySupport;
 import org.openide.nodes.Sheet;
 import org.openide.util.Exceptions;
 import org.openide.util.ImageUtilities;
+
 import static org.openide.util.ImageUtilities.assignToolTipToImage;
 import static org.openide.util.ImageUtilities.loadImage;
+
 import org.openide.util.Lookup;
+
 import static org.openide.util.NbBundle.getMessage;
+
 import org.openide.util.RequestProcessor;
 import org.openide.util.Utilities;
 import org.openide.util.WeakListeners;
@@ -146,28 +147,30 @@ public final class JavaNode extends DataNode implements ChangeListener {
         this.computedIconListener = new AtomicReference<>();
         this.setIconBaseWithExtension(isJavaSource ? JAVA_ICON_BASE : CLASS_ICON_BASE);
         Logger.getLogger("TIMER").log(Level.FINE, "JavaNode", new Object[] {jdo.getPrimaryFile(), this});
-        WORKER.post(IconTask.create(this));
-        if (isJavaSource) {
-            WORKER.post(new BuildStatusTask(this));
-            WORKER.post(new ExecutableTask(this));
-            jdo.addPropertyChangeListener(new PropertyChangeListener() {
-                public void propertyChange(PropertyChangeEvent evt) {
-                    if (DataObject.PROP_PRIMARY_FILE.equals(evt.getPropertyName())) {
-                        Logger.getLogger("TIMER").log(Level.FINE, "JavaNode", new Object[]{jdo.getPrimaryFile(), this});
-                        WORKER.post(new Runnable() {
-                            public void run() {
-                                computedIconListener.set(null);
-                                synchronized (JavaNode.this) {
-                                    status = null;
-                                    executableListener = null;
-                                    WORKER.post(new BuildStatusTask(JavaNode.this));
-                                    WORKER.post(new ExecutableTask(JavaNode.this));
+        if (!jdo.isTemplate()) {
+            WORKER.post(IconTask.create(this));
+            if (isJavaSource) {
+                WORKER.post(new BuildStatusTask(this));
+                WORKER.post(new ExecutableTask(this));
+                jdo.addPropertyChangeListener(new PropertyChangeListener() {
+                    public void propertyChange(PropertyChangeEvent evt) {
+                        if (DataObject.PROP_PRIMARY_FILE.equals(evt.getPropertyName())) {
+                            Logger.getLogger("TIMER").log(Level.FINE, "JavaNode", new Object[]{jdo.getPrimaryFile(), this});
+                            WORKER.post(new Runnable() {
+                                public void run() {
+                                    computedIconListener.set(null);
+                                    synchronized (JavaNode.this) {
+                                        status = null;
+                                        executableListener = null;
+                                        WORKER.post(new BuildStatusTask(JavaNode.this));
+                                        WORKER.post(new ExecutableTask(JavaNode.this));
+                                    }
                                 }
-                            }
-                        });
+                            });
+                        }
                     }
-                }
-            });
+                });
+            }
         }
     }
 
@@ -354,7 +357,7 @@ public final class JavaNode extends DataNode implements ChangeListener {
         }
         try {
             final FileObject fo = getDataObject().getPrimaryFile ();
-            computed = fo.getFileSystem ().getStatus ().annotateIcon (
+            computed = FileUIUtils.getImageDecorator(fo.getFileSystem ()).annotateIcon (
                 computed,
                 type,
                 Collections.singleton(fo));
@@ -414,7 +417,7 @@ public final class JavaNode extends DataNode implements ChangeListener {
         public final void run() {
             String res = null;
             final FileObject file = node.getDataObject().getPrimaryFile();
-            if (file != null) {
+            if (file != null && file.isValid()) {
                 if (node.computedIconListener.get() == null) {
                     final FileChangeListener l = new FCL(node);
                     if (node.computedIconListener.compareAndSet(null, l)) {
@@ -522,7 +525,7 @@ public final class JavaNode extends DataNode implements ChangeListener {
             @Override
             @CheckForNull
             String computeIcon(@NonNull final FileObject file) {
-                String res = null;
+                String res = CLASS_ICON_BASE;
                 try {
                     try (InputStream in = file.getInputStream()) {
                         final ClassFile cf = new ClassFile(in, false);
@@ -538,6 +541,14 @@ public final class JavaNode extends DataNode implements ChangeListener {
                                 CLASS_ICON_BASE;
                         }
                     }
+                } catch (FileNotFoundException e) {
+                    // may happen in the file is just being cleaned up; should not log.
+                } catch (InvalidClassFormatException e) {
+                    // broken class file just log
+                    LOG.log(
+                        Level.INFO,
+                        "Invalid classfile: {0}",   //NOI18N
+                        FileUtil.getFileDisplayName(file));
                 } catch (IOException e) {
                     Exceptions.printStackTrace(e);
                 }
