@@ -50,8 +50,7 @@ import java.awt.event.FocusListener;
 import javax.swing.JLabel;
 import org.netbeans.api.java.source.CodeStyle;
 import static org.netbeans.modules.java.ui.FmtOptions.*;
-import static org.netbeans.modules.java.ui.FmtOptions.CategorySupport.OPTION_ID;
-import org.netbeans.modules.java.ui.FmtOptions.CategorySupport;
+import static org.netbeans.modules.java.ui.CategorySupport.OPTION_ID;
 import org.netbeans.modules.options.editor.spi.PreferencesCustomizer;
 
 
