@@ -23,7 +23,7 @@
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
  * "Portions Copyrighted [year] [name of copyright owner]"
- * 
+ *
  * If you wish your version of this file to be governed by only the CDDL
  * or only the GPL Version 2, indicate your decision by adding
  * "[Contributor] elects to include this software in this distribution
@@ -34,9 +34,9 @@
  * However, if you add GPL Version 2 code and therefore, elected the GPL
  * Version 2 license, then the option applies only if the new code is
  * made subject to such option by the copyright holder.
- * 
+ *
  * Contributor(s):
- * 
+ *
  * Portions Copyrighted 2008 Sun Microsystems, Inc.
  */
 
@@ -57,8 +57,6 @@ import java.util.logging.Logger;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
-import javax.lang.model.element.Name;
-import javax.lang.model.element.QualifiedNameable;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.VariableElement;
 import javax.lang.model.type.ArrayType;
@@ -69,29 +67,23 @@ import javax.lang.model.type.TypeMirror;
 import javax.lang.model.type.TypeVariable;
 import javax.lang.model.type.WildcardType;
 import javax.lang.model.util.SimpleTypeVisitor6;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.source.ClassIndex;
-import org.netbeans.api.java.source.ClasspathInfo;
-import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementHandle;
-import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.SourceUtils;
-import org.netbeans.api.java.source.Task;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
-import org.netbeans.modules.java.source.indexing.TransactionContext;
-import org.netbeans.modules.java.source.parsing.FileManagerTransaction;
-import org.netbeans.modules.java.source.parsing.ProcessorGenerated;
 import org.netbeans.modules.java.source.usages.ClassIndexImpl;
 import org.netbeans.modules.java.source.usages.ClassIndexManager;
-import org.netbeans.modules.java.source.usages.ClasspathInfoAccessor;
 import org.netbeans.modules.java.source.usages.DocumentUtil;
 import org.netbeans.modules.parsing.lucene.support.IndexManager;
 import org.netbeans.modules.parsing.spi.indexing.support.QuerySupport;
 import org.netbeans.spi.jumpto.support.NameMatcher;
 import org.netbeans.spi.jumpto.support.NameMatcherFactory;
+import org.netbeans.spi.jumpto.symbol.SymbolDescriptor;
 import org.netbeans.spi.jumpto.symbol.SymbolProvider;
 import org.netbeans.spi.jumpto.type.SearchType;
 import org.openide.filesystems.FileObject;
@@ -108,32 +100,52 @@ import org.openide.util.Pair;
 public class JavaSymbolProvider implements SymbolProvider {
 
     private static final Logger LOGGER = Logger.getLogger(JavaSymbolProvider.class.getName());
-    
+
     private static final String CAPTURED_WILDCARD = "<captured wildcard>"; //NOI18N
     private static final String UNKNOWN = "<unknown>"; //NOI18N
-    private static final String INIT = "<init>"; //NOI18N
 
     private volatile boolean canceled;
 
+    @Override
     public String name() {
         return "java symbols";  //NOI18N
     }
 
+    @Override
     public String getDisplayName() {
         return NbBundle.getMessage(JavaTypeProvider.class, "MSG_JavaSymbols");
     }
-        
+
+    @Override
     public void computeSymbolNames(final Context context, final Result result) {
         try {
             final SearchType st = context.getSearchType();
             String textToSearch = context.getText();
+            final boolean scanInProgress = SourceUtils.isScanInProgress();
+            if (scanInProgress) {
+                // ui message
+                final String warningKind = NbBundle.getMessage(JavaSymbolProvider.class, "LBL_SymbolKind");
+                final String message = NbBundle.getMessage(JavaSymbolProvider.class, "LBL_ScanInProgress_warning", warningKind);
+                result.setMessage(message);
+                result.pendingResult();
+                final Cache cache = Cache.get(textToSearch, st);
+                if (cache != null) {
+                    cache.populateResult(result);
+                    return;
+                }
+            } else {
+                Cache.clear();
+            }
+            final Cache cache = scanInProgress ?
+                Cache.create(textToSearch, st) :
+                null;
             String prefix = null;
             final int dotIndex = textToSearch.lastIndexOf('.'); //NOI18N
             if (dotIndex > 0 && dotIndex != textToSearch.length()-1) {
                 prefix = textToSearch.substring(0, dotIndex);
                 textToSearch = textToSearch.substring(dotIndex+1);
             }
-            String[] _ident = new String[] {textToSearch};
+            final String textToHighLight = textToSearch;
             ClassIndex.NameKind _kind;
             boolean _caseSensitive;
             switch (st) {
@@ -143,15 +155,19 @@ public class JavaSymbolProvider implements SymbolProvider {
                     break;
                 case REGEXP:
                     _kind = ClassIndex.NameKind.REGEXP;
-                    _ident[0] = removeNonJavaChars(_ident[0]);
-                    _ident[0] = NameMatcherFactory.wildcardsToRegexp(_ident[0],true);
+                    textToSearch = NameMatcherFactory.wildcardsToRegexp(
+                            removeNonJavaChars(textToSearch),
+                            true);
                     _caseSensitive = true;
                     break;
                 case CAMEL_CASE:
-                    _ident = createCamelCase(_ident);
                     _kind = ClassIndex.NameKind.CAMEL_CASE;
                     _caseSensitive = true;
                     break;
+                case CASE_INSENSITIVE_CAMEL_CASE:
+                    _kind = ClassIndex.NameKind.CAMEL_CASE_INSENSITIVE;
+                    _caseSensitive = false;
+                    break;
                 case EXACT_NAME:
                     _kind = ClassIndex.NameKind.SIMPLE_NAME;
                     _caseSensitive = true;
@@ -166,20 +182,21 @@ public class JavaSymbolProvider implements SymbolProvider {
                     break;
                 case CASE_INSENSITIVE_REGEXP:
                     _kind = ClassIndex.NameKind.CASE_INSENSITIVE_REGEXP;
-                    _ident[0] = removeNonJavaChars(_ident[0]);            
-                    _ident[0] = NameMatcherFactory.wildcardsToRegexp(_ident[0],true);
+                    textToSearch = NameMatcherFactory.wildcardsToRegexp(
+                            removeNonJavaChars(textToSearch),
+                            true);
                     _caseSensitive = false;
                     break;
                 default:
                     throw new IllegalArgumentException();
             }
-            final String[] ident = _ident;
+            final String ident = textToSearch;
             final ClassIndex.NameKind kind = _kind;
             final boolean caseSensitive = _caseSensitive;
             final Pair<NameMatcher,Boolean> restriction;
             if (prefix != null) {
                 restriction = compileName(prefix,caseSensitive);
-                result.setHighlightText(textToSearch);
+                result.setHighlightText(textToHighLight);
             } else {
                 restriction = null;
             }
@@ -192,11 +209,11 @@ public class JavaSymbolProvider implements SymbolProvider {
                         Collections.<String>emptySet(),
                         Collections.<String>emptySet());
 
-                final Set<URL> rootUrls = new HashSet<URL>();
+                final Set<URL> rootUrls = new HashSet<>();
                 for(FileObject root : roots) {
                     if (canceled) {
                         return;
-                    }                    
+                    }
                     rootUrls.add(root.toURL());
                 }
 
@@ -223,73 +240,28 @@ public class JavaSymbolProvider implements SymbolProvider {
                             final Project project = FileOwnerQuery.getOwner(root);
                             final ClassIndexImpl impl = manager.getUsagesQuery(root.toURL(), true);
                             if (impl != null) {
-                                final Map<ElementHandle<TypeElement>,Set<String>> r = new HashMap<ElementHandle<TypeElement>,Set<String>>();
-                                for (String currentIdent : ident) {
-                                    impl.getDeclaredElements(currentIdent, kind, DocumentUtil.elementHandleConvertor(),r);
-                                }
+                                final Map<ElementHandle<TypeElement>,Set<String>> r = new HashMap<>();
+                                impl.getDeclaredElements(ident, kind, DocumentUtil.elementHandleConvertor(),r);
                                 if (!r.isEmpty()) {
-                                    //Needs FileManagerTransaction as it creates CPI with backgroundCompilation == true
-                                    TransactionContext.
-                                            beginTrans().
-                                            register(FileManagerTransaction.class, FileManagerTransaction.read()).
-                                            register(ProcessorGenerated.class, ProcessorGenerated.nullWrite());
-                                    try {
-                                        final ClasspathInfo cpInfo = ClasspathInfoAccessor.getINSTANCE().create(root,null,true,true,false,false);
-                                        final JavaSource js = JavaSource.create(cpInfo);
-                                        js.runUserActionTask(new Task<CompilationController>() {
-                                            @Override
-                                            public void run (final CompilationController controller) {
-                                                for (final Map.Entry<ElementHandle<TypeElement>,Set<String>> p : r.entrySet()) {
-                                                    final ElementHandle<TypeElement> owner = p.getKey();
-                                                    final TypeElement te = owner.resolve(controller);
-                                                    final Set<String> idents = p.getValue();
-                                                    if (te != null) {
-                                                        if (idents.contains(getSimpleName(te, null)) && matchesRestrictions(te, restriction)) {
-                                                            result.addResult(new JavaSymbolDescriptor(
-                                                                    te.getSimpleName().toString(),
-                                                                    te.getKind(),
-                                                                    te.getModifiers(),
-                                                                    owner,
-                                                                    ElementHandle.create(te),
-                                                                    project,
-                                                                    root,
-                                                                    impl));
-                                                        }
-                                                        for (Element ne : te.getEnclosedElements()) {
-                                                            if (idents.contains(getSimpleName(ne, te)) && matchesRestrictions(ne, restriction)) {
-                                                                result.addResult(new JavaSymbolDescriptor(
-                                                                    getDisplayName(ne, te),
-                                                                    ne.getKind(),
-                                                                    ne.getModifiers(),
-                                                                    owner,
-                                                                    ElementHandle.create(ne),
-                                                                    project,
-                                                                    root,
-                                                                    impl));
-                                                            }
-                                                        }
-                                                    }
+                                    for (final Map.Entry<ElementHandle<TypeElement>,Set<String>> p : r.entrySet()) {
+                                        final ElementHandle<TypeElement> owner = p.getKey();
+                                        for (String symbol : p.getValue()) {
+                                            if (matchesRestrictions(owner.getQualifiedName(), symbol, restriction, caseSensitive)) {
+                                                final AsyncJavaSymbolDescriptor d = new AsyncJavaSymbolDescriptor(
+                                                        project,
+                                                        root,
+                                                        impl,
+                                                        owner,
+                                                        symbol,
+                                                        caseSensitive);
+                                                result.addResult(d);
+                                                if (cache != null) {
+                                                    cache.offer(d);
                                                 }
                                             }
-
-                                            private String getSimpleName (
-                                                    @NonNull final Element element,
-                                                    @NullAllowed final Element enclosingElement) {
-                                                String result = element.getSimpleName().toString();
-                                                if (enclosingElement != null && INIT.equals(result)) {
-                                                    result = enclosingElement.getSimpleName().toString();
-                                                }
-                                                if (!caseSensitive) {
-                                                    result = result.toLowerCase();
-                                                }
-                                                return result;
-                                            }
-                                        },true);
-                                    } finally {
-                                        TransactionContext.get().commit();
+                                        }
                                     }
                                 }
-
                             }
                         }
                         return null;
@@ -302,27 +274,44 @@ public class JavaSymbolProvider implements SymbolProvider {
                 return;
             }
         } finally {
-            cleanup();
+            clearCancel();
         }
     }
 
-    private boolean matchesRestrictions(
-            @NonNull final Element e,
-            @NullAllowed Pair<NameMatcher,Boolean> restriction) {
+    private static boolean matchesRestrictions(
+            @NonNull final String fqn,
+            @NonNull final String ident,
+            @NullAllowed Pair<NameMatcher,Boolean> restriction,
+            final boolean caseSensitive) {
+        return matchesRestrictionsImpl(fqn, ident, restriction, caseSensitive, false);
+    }
+
+    private static boolean matchesRestrictionsImpl(
+            @NonNull final String fqn,
+            @NonNull final String ident,
+            @NullAllowed Pair<NameMatcher,Boolean> restriction,
+            final boolean caseSensitive,
+            final boolean enclosing) {
         if (restriction == null) {
             return true;
         }
-        final Element owner = e.getEnclosingElement();
-        if (owner == null) {
-            return false;
-        }                
-        final Name n;
-        if (restriction.second() && (owner instanceof QualifiedNameable)) {
-            n = ((QualifiedNameable)owner).getQualifiedName();
-        } else {
-            n = owner.getSimpleName();
-        }
-        return restriction.first().accept(n.toString());
+        final String simpleName = getSimpleName(fqn);
+        return restriction.first().accept(restriction.second() ? fqn : simpleName) ||
+               (!enclosing &&
+                (caseSensitive ? ident.equals(simpleName) : ident.equalsIgnoreCase(simpleName)) &&
+                matchesRestrictionsImpl(getOwner(fqn), ident, restriction, caseSensitive, true));
+    }
+
+    @NonNull
+    private static String getSimpleName(@NonNull final String fqn) {
+        final int index = fqn.lastIndexOf('.'); //NOI18N
+        return index < 0 ? fqn : fqn.substring(index+1);
+    }
+
+    @NonNull
+    private static String getOwner(@NonNull final String fqn) {
+        final int index = fqn.lastIndexOf('.'); //NOI18N
+        return index < 0 ? "" : fqn.substring(0, index);    //NOI18N
     }
 
     private static Pair<NameMatcher,Boolean> compileName(
@@ -345,67 +334,60 @@ public class JavaSymbolProvider implements SymbolProvider {
         }
         return false;
     }
-    
-    private static String getDisplayName (
+
+    @NonNull
+    static Pair<String,String> getDisplayName (
             @NonNull final Element e,
             @NonNull final Element enclosingElement) {
         assert e != null;
+        String name;
+        String suffix = null;
         if (e.getKind() == ElementKind.METHOD || e.getKind() == ElementKind.CONSTRUCTOR) {
-            StringBuilder sb = new StringBuilder();
-            if (e.getKind() == ElementKind.CONSTRUCTOR) {
-                sb.append(enclosingElement.getSimpleName());
-            } else {
-                sb.append(e.getSimpleName());
-            }
+            name = (e.getKind() == ElementKind.CONSTRUCTOR ?
+                    enclosingElement.getSimpleName():
+                    e.getSimpleName()).toString();
+            final StringBuilder sb = new StringBuilder();
             sb.append('('); //NOI18N
             ExecutableElement ee = (ExecutableElement) e;
             final List<? extends VariableElement> vl = ee.getParameters();
             for (Iterator<? extends VariableElement> it = vl.iterator(); it.hasNext();) {
                 final VariableElement v = it.next();
-                final TypeMirror tm = v.asType();                
+                final TypeMirror tm = v.asType();
                 sb.append(getTypeName(tm, false, true));
                 if (it.hasNext()) {
                     sb.append(", ");    //NOI18N
                 }
             }
             sb.append(')');
-            return sb.toString();
-        }
-        return e.getSimpleName().toString();
-    }
-    
-    private static String[] createCamelCase(final String[] text) {
-        if (text[0].length() == 0) {
-            return text;
+            suffix = sb.toString();
         } else {
-            return new String[] {
-                text[0],
-                Character.toLowerCase(text[0].charAt(0)) + text[0].substring(1)
-            };
+            name = e.getSimpleName().toString();
         }
+        return Pair.of(name,suffix);
     }
-    
+
     private static CharSequence getTypeName(TypeMirror type, boolean fqn, boolean varArg) {
-	if (type == null)
+	if (type == null) {
             return ""; //NOI18N
+        }
         return new TypeNameVisitor(varArg).visit(type, fqn);
     }
-    
+
     private static class TypeNameVisitor extends SimpleTypeVisitor6<StringBuilder,Boolean> {
-        
+
         private boolean varArg;
         private boolean insideCapturedWildcard = false;
-        
+
         private TypeNameVisitor(boolean varArg) {
             super(new StringBuilder());
             this.varArg = varArg;
         }
-        
+
         @Override
         public StringBuilder defaultAction(TypeMirror t, Boolean p) {
             return DEFAULT_VALUE.append(t);
         }
-        
+
         @Override
         public StringBuilder visitDeclared(DeclaredType t, Boolean p) {
             Element e = t.asElement();
@@ -417,17 +399,18 @@ public class JavaSymbolProvider implements SymbolProvider {
                     DEFAULT_VALUE.append("<"); //NOI18N
                     while(it.hasNext()) {
                         visit(it.next(), p);
-                        if (it.hasNext())
+                        if (it.hasNext()) {
                             DEFAULT_VALUE.append(", "); //NOI18N
+                        }
                     }
                     DEFAULT_VALUE.append(">"); //NOI18N
                 }
-                return DEFAULT_VALUE;                
+                return DEFAULT_VALUE;
             } else {
                 return DEFAULT_VALUE.append(UNKNOWN); //NOI18N
             }
         }
-                        
+
         @Override
         public StringBuilder visitArray(ArrayType t, Boolean p) {
             boolean isVarArg = varArg;
@@ -441,8 +424,9 @@ public class JavaSymbolProvider implements SymbolProvider {
             Element e = t.asElement();
             if (e != null) {
                 String name = e.getSimpleName().toString();
-                if (!CAPTURED_WILDCARD.equals(name))
+                if (!CAPTURED_WILDCARD.equals(name)) {
                     return DEFAULT_VALUE.append(name);
+                }
             }
             DEFAULT_VALUE.append("?"); //NOI18N
             if (!insideCapturedWildcard) {
@@ -455,8 +439,9 @@ public class JavaSymbolProvider implements SymbolProvider {
                     bound = t.getUpperBound();
                     if (bound != null && bound.getKind() != TypeKind.NULL) {
                         DEFAULT_VALUE.append(" extends "); //NOI18N
-                        if (bound.getKind() == TypeKind.TYPEVAR)
+                        if (bound.getKind() == TypeKind.TYPEVAR) {
                             bound = ((TypeVariable)bound).getLowerBound();
+                        }
                         visit(bound, p);
                     }
                 }
@@ -474,8 +459,9 @@ public class JavaSymbolProvider implements SymbolProvider {
                 bound = t.getExtendsBound();
                 if (bound != null) {
                     DEFAULT_VALUE.append(" extends "); //NOI18N
-                    if (bound.getKind() == TypeKind.WILDCARD)
+                    if (bound.getKind() == TypeKind.WILDCARD) {
                         bound = ((WildcardType)bound).getSuperBound();
+                    }
                     visit(bound, p);
                 } else if (len == 0) {
                     bound = SourceUtils.getBound(t);
@@ -501,7 +487,7 @@ public class JavaSymbolProvider implements SymbolProvider {
             return DEFAULT_VALUE;
         }
     }
-    
+
     private static String removeNonJavaChars(String text) {
        StringBuilder sb = new StringBuilder();
 
@@ -514,12 +500,69 @@ public class JavaSymbolProvider implements SymbolProvider {
        return sb.toString();
     }
 
+    @Override
     public void cancel() {
         canceled = true;
     }
 
-    public void cleanup() {        
+    @Override
+    public void cleanup() {
+        clearCancel();
+        Cache.clear();
+    }
+
+    private void clearCancel() {
         canceled = false;
     }
 
+    private static final class Cache {
+        private static Cache instance;
+
+        private final String text;
+        private final SearchType type;
+        private final Collection<SymbolDescriptor> descriptors;
+
+        private Cache(
+            @NonNull final String text,
+            @NonNull final SearchType type) {
+            this.text = text;
+            this.type = type;
+            this.descriptors = Collections.synchronizedSet(new HashSet<SymbolDescriptor>());
+        }
+
+        void populateResult(@NonNull final Result result) {
+            synchronized (descriptors) {
+                for (SymbolDescriptor d : descriptors) {
+                    result.addResult(d);
+                }
+            }
+        }
+
+        void offer(@NonNull final AsyncJavaSymbolDescriptor d) {
+            descriptors.add(d);
+        }
+
+        static void clear() {
+            instance = null;
+        }
+
+        @CheckForNull
+        static Cache get(
+            @NonNull final String text,
+            @NonNull final SearchType type) {
+            Cache res = instance;
+            if (res != null && (!res.text.equals(text) || res.type != type)) {
+                res = instance = null;
+            }
+            return res;
+        }
+
+        @NonNull
+        static Cache create(
+            @NonNull final String text,
+            @NonNull final SearchType type) {
+            return instance = new Cache(text, type);
+        }
+    }
+
 }
