@@ -129,7 +129,7 @@ import org.openide.util.NbBundle.Messages;
  * @see <a href="http://java.sun.com/javase/6/docs/technotes/tools/solaris/javadoc.html#javadoctags">Javadoc Tags</a>
  * @see <a href="http://java.sun.com/javase/6/docs/technotes/tools/solaris/javadoc.html#wheretags">Where Tags Can Be Used</a>
  * @see <a href="http://java.sun.com/javase/6/docs/technotes/guides/javadoc/deprecation/index.html">Deprecation of APIs</a>
- * 
+ *
  * @author Jan Pokorsky
  * @author Ralph Benjamin Ruijs
  */
@@ -142,12 +142,13 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
     private final TreePath currentPath;
     private final SourceVersion sourceVersion;
     private final Access access;
-    
+
     private Deque<StartElementTree> tagStack = new LinkedList<>();
     private Set<Element> foundParams = new HashSet<>();
     private Set<TypeMirror> foundThrows = new HashSet<>();
     private TypeMirror returnType = null;
     private boolean returnTypeFound = false;
+    private boolean foundInheritDoc = false;
     private Element currentElement;
     private final HintContext ctx;
 
@@ -169,7 +170,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                 !access.isAccessible(javac, currentPath, false)) {
             return errors;
         }
-        
+
         currentElement = javac.getTrees().getElement(currentPath);
         if (currentElement == null) {
             Logger.getLogger(Analyzer.class.getName()).log(
@@ -206,7 +207,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                                 inheritedTypeParams.add(paramTag.parameterName());
                             }
                         }
-                        
+
                     } while((overridden = elUtils.getOverriddenMethod(overridden)) != null);
                     if(ctx.isCanceled()) { break; }
                     TypeElement typeElement = elUtils.enclosingTypeElement(currentElement);
@@ -229,7 +230,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                             break;
                         default:
                             if (!returnTypeFound
-                                    //                                    && !foundInheritDoc
+                                    && !foundInheritDoc
                                     && !javac.getTypes().isSameType(ee.getReturnType(), javac.getElements().getTypeElement("java.lang.Void").asType())) {
                             Tree returnTree = methodTree.getReturnType();
                             DocTreePathHandle dtph = DocTreePathHandle.create(docTreePath, javac);
@@ -256,7 +257,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
         if(ctx.isCanceled()) { return Collections.<ErrorDescription>emptyList(); }
         return errors;
     }
-    
+
     @Override
     public Void visitAttribute(AttributeTree node, List<ErrorDescription> errors) {
         return super.visitAttribute(node, errors);
@@ -264,7 +265,10 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     @Override
     public Void visitAuthor(AuthorTree node, List<ErrorDescription> errors) {
-        return super.visitAuthor(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitAuthor(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
@@ -274,7 +278,10 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     @Override
     public Void visitDeprecated(DeprecatedTree node, List<ErrorDescription> errors) {
-        return super.visitDeprecated(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitDeprecated(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
@@ -282,7 +289,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
         DocTreePath currentDocPath = getCurrentPath();
         Void value = super.visitDocComment(node, errors);
         DocSourcePositions sp = (DocSourcePositions) javac.getTrees().getSourcePositions();
-        
+
         while (!tagStack.isEmpty()) {
             StartElementTree startTree = tagStack.pop();
             Name tagName = startTree.getName();
@@ -314,7 +321,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
         DocSourcePositions sp = (DocSourcePositions) javac.getTrees().getSourcePositions();
         int start = (int) sp.getStartPosition(javac.getCompilationUnit(), currentDocPath.getDocComment(), node);
         int end = (int) sp.getEndPosition(javac.getCompilationUnit(), currentDocPath.getDocComment(), node);
-        
+
         final Name treeName = node.getName();
         final HtmlTag t = HtmlTag.get(treeName);
         if (t == null) {
@@ -379,6 +386,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     @Override
     public Void visitInheritDoc(InheritDocTree node, List<ErrorDescription> errors) {
+        foundInheritDoc = true;
         return super.visitInheritDoc(node, errors);
     }
 
@@ -395,6 +403,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
     @Override
     @NbBundle.Messages({"# {0} - tag name", "# {1} - element type", "INVALID_TAG_DESC={0} tag cannot be used on {1}."})
     public Void visitParam(ParamTree tree, List<ErrorDescription> errors) {
+        boolean oldInheritDoc = foundInheritDoc;
         DocTreePath currentDocPath = getCurrentPath();
         DocTreePathHandle dtph = DocTreePathHandle.create(currentDocPath, javac);
         if(dtph == null) {
@@ -429,10 +438,11 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                 break;
         }
         warnIfEmpty(tree, tree.getDescription());
-        return super.visitParam(tree, errors);
+        super.visitParam(tree, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
-    private static final Logger LOG = Logger.getLogger(Analyzer.class.getName());
-    
+
     @NbBundle.Messages({"# {0} - @param name", "UNKNOWN_TYPEPARAM_DESC=Unknown @param: {0}",
                         "# {0} - @param name", "DUPLICATE_PARAM_DESC=Duplicate @param name: {0}"})
     private void checkParamDeclared(ParamTree tree, List<? extends Element> list,
@@ -454,7 +464,8 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
     }
 
     private void checkParamsDocumented(List<? extends Element> list, List<? extends Tree> trees, DocTreePath docTreePath, Set<String> inheritedParams, List<ErrorDescription> errors) {
-        for (int i = 0; i < list.size(); i++) {
+        if(foundInheritDoc) return;
+        for (int i = 0; i < list.size() && i < trees.size(); i++) {
             if(ctx.isCanceled()) { return; }
             Element e = list.get(i);
             Tree t = trees.get(i);
@@ -470,7 +481,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
             }
         }
     }
-    
+
     @NbBundle.Messages({"# {0} - [@throws|@exception]", "# {1} - @throws name",
                         "DUPLICATE_THROWS_DESC=Duplicate @{0} tag: {1}",
                         "# {0} - [@throws|@exception]", "# {1} - @throws name",
@@ -509,8 +520,9 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
             errors.add(ErrorDescriptionFactory.forSpan(ctx, start, end, UNKNOWN_THROWABLE_DESC(tree.getTagName(), fqn), new RemoveTagFix(dtph, "@" + tree.getTagName()).toEditorFix()));
         }
     }
-    
+
     private void checkThrowsDocumented(List<? extends TypeMirror> list, List<? extends ExpressionTree> trees, DocTreePath docTreePath, Set<String> inheritedThrows, List<ErrorDescription> errors) {
+        if(foundInheritDoc) return;
         for (int i = 0; i < list.size(); i++) {
             if(ctx.isCanceled()) { return; }
             TypeMirror e = list.get(i);
@@ -535,7 +547,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
             }
         }
     }
-    
+
     void warnIfEmpty(DocTree tree, List<? extends DocTree> list) {
 //        for (DocTree d: list) {
 //            switch (d.getKind()) {
@@ -560,6 +572,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                         "WRONG_CONSTRUCTOR_RETURN_DESC=Illegal @return tag.",
                         "DUPLICATE_RETURN_DESC=Duplicate @return tag."})
     public Void visitReturn(ReturnTree node, List<ErrorDescription> errors) {
+        boolean oldInheritDoc = foundInheritDoc;
         DocTreePath currentDocPath = getCurrentPath();
         DocTreePathHandle dtph = DocTreePathHandle.create(currentDocPath, javac);
         if(dtph == null) {
@@ -580,39 +593,57 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
         } else {
             returnTypeFound = true;
         }
-        return super.visitReturn(node, errors);
+        super.visitReturn(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     public Void visitSee(SeeTree node, List<ErrorDescription> errors) {
-        return super.visitSee(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitSee(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     public Void visitSerial(SerialTree node, List<ErrorDescription> errors) {
-        return super.visitSerial(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitSerial(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     public Void visitSerialData(SerialDataTree node, List<ErrorDescription> errors) {
-        return super.visitSerialData(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitSerialData(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     public Void visitSerialField(SerialFieldTree node, List<ErrorDescription> errors) {
-        return super.visitSerialField(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitSerialField(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     public Void visitSince(SinceTree node, List<ErrorDescription> errors) {
-        return super.visitSince(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitSince(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
     @Messages({"# {0} - Tag name",
                "TAG_UNKNOWN=Unknown HTML Tag: <{0}>",
-                "# {0} - Tag name",
-               "TAG_END_UNKNOWN=Unknown HTML End Tag: </{0}>"})
+               "# {0} - Tag name",
+               "TAG_END_UNKNOWN=Unknown HTML End Tag: </{0}>",
+               "TAG_SELF_CLOSING=Self-closing element not allowed"})
     public Void visitStartElement(StartElementTree node, List<ErrorDescription> errors) {
         DocTreePath currentDocPath = getCurrentPath();
         DocTreePathHandle dtph = DocTreePathHandle.create(currentDocPath, javac);
@@ -622,8 +653,8 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
         DocSourcePositions sp = (DocSourcePositions) javac.getTrees().getSourcePositions();
         int start = (int) sp.getStartPosition(javac.getCompilationUnit(), currentDocPath.getDocComment(), node);
         int end = (int) sp.getEndPosition(javac.getCompilationUnit(), currentDocPath.getDocComment(), node);
-        
-        
+
+
         final Name treeName = node.getName();
         final HtmlTag t = HtmlTag.get(treeName);
         if (t == null) {
@@ -633,6 +664,11 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
                 tagStack.push(node);
             }
         }
+        
+        if (node.isSelfClosing()) {
+            errors.add(ErrorDescriptionFactory.forSpan(ctx, start, end, TAG_SELF_CLOSING()));
+        }
+        
         return super.visitStartElement(node, errors);
     }
 
@@ -643,14 +679,22 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     @Override
     public Void visitThrows(ThrowsTree tree, List<ErrorDescription> errors) {
+        boolean oldInheritDoc = foundInheritDoc;
         ReferenceTree exName = tree.getExceptionName();
         DocTreePath refPath = new DocTreePath(getCurrentPath(), tree.getExceptionName());
         Element ex = javac.getDocTrees().getElement(refPath);
         Types types = javac.getTypes();
         Elements elements = javac.getElements();
-        TypeMirror throwable = elements.getTypeElement("java.lang.Throwable").asType();
-        TypeMirror error = elements.getTypeElement("java.lang.Error").asType();
-        TypeMirror runtime = elements.getTypeElement("java.lang.RuntimeException").asType();
+        final TypeElement throwableEl = elements.getTypeElement("java.lang.Throwable");
+        final TypeElement errorEl = elements.getTypeElement("java.lang.Error");
+        final TypeElement runtimeEl = elements.getTypeElement("java.lang.RuntimeException");
+        if(throwableEl == null || errorEl == null || runtimeEl == null) {
+            LOG.warning("Broken java-platform, cannot resolve " + throwableEl == null? "java.lang.Throwable" : errorEl == null? "java.lang.Error" : "java.lang.RuntimeException"); //NOI18N
+            return null;
+        }
+        TypeMirror throwable = throwableEl.asType();
+        TypeMirror error = errorEl.asType();
+        TypeMirror runtime = runtimeEl.asType();
         DocTreePath currentDocPath = getCurrentPath();
         DocTreePathHandle dtph = DocTreePathHandle.create(currentDocPath, javac);
         if(dtph == null) {
@@ -685,12 +729,18 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 //                env.messages.error(REFERENCE, tree, "dc.invalid.throws");
         }
         warnIfEmpty(tree, tree.getDescription());
-        return super.visitThrows(tree, errors);
+        super.visitThrows(tree, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
+    private static final Logger LOG = Logger.getLogger(Analyzer.class.getName());
 
     @Override
     public Void visitUnknownBlockTag(UnknownBlockTagTree node, List<ErrorDescription> errors) {
-        return super.visitUnknownBlockTag(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitUnknownBlockTag(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
@@ -705,7 +755,10 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     @Override
     public Void visitVersion(VersionTree node, List<ErrorDescription> errors) {
-        return super.visitVersion(node, errors);
+        boolean oldInheritDoc = foundInheritDoc;
+        super.visitVersion(node, errors);
+        foundInheritDoc = oldInheritDoc;
+        return null;
     }
 
     @Override
@@ -721,7 +774,7 @@ final class Analyzer extends DocTreePathScanner<Void, List<ErrorDescription>> {
 
     private void findInheritedParams(ExecutableElement method, TypeElement typeElement, Set<String> inheritedParams, Set<String> inheritedTypeParams, Set<String> inheritedThrows) {
         if(typeElement == null) return;
-        
+
         for (TypeMirror typeMirror : typeElement.getInterfaces()) {
             for (Element el : javac.getElementUtilities().getMembers(typeMirror, new ElementUtilities.ElementAcceptor() {
 
