@@ -46,6 +46,7 @@ package org.netbeans.modules.javaee.wildfly;
 import java.io.File;
 import java.io.FilenameFilter;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLClassLoader;
@@ -54,9 +55,11 @@ import java.security.CodeSource;
 import java.security.PermissionCollection;
 import java.security.Permissions;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
 import java.util.WeakHashMap;
 import java.util.logging.Level;
@@ -69,7 +72,18 @@ import javax.enterprise.deploy.spi.factories.DeploymentFactory;
 import org.netbeans.modules.j2ee.deployment.plugins.api.InstanceProperties;
 import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginProperties;
 import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginUtils;
+import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginUtils.Version;
+import org.objectweb.asm.ClassReader;
+import org.objectweb.asm.ClassWriter;
+import org.objectweb.asm.Opcodes;
+import org.objectweb.asm.tree.AbstractInsnNode;
+import org.objectweb.asm.tree.ClassNode;
+import org.objectweb.asm.tree.InsnList;
+import org.objectweb.asm.tree.InsnNode;
+import org.objectweb.asm.tree.MethodInsnNode;
+import org.objectweb.asm.tree.MethodNode;
 import org.openide.util.NbBundle;
+import org.openide.util.Utilities;
 
 /**
  *
@@ -116,8 +130,15 @@ public class WildflyDeploymentFactory implements DeploymentFactory {
 
     public static class WildFlyClassLoader extends URLClassLoader {
 
-        public WildFlyClassLoader(URL[] urls, ClassLoader parent) throws MalformedURLException, RuntimeException {
+        /**
+         * Patching the xnio code to avoid bug #249135
+         * @see https://netbeans.org/bugzilla/show_bug.cgi?id=249135
+         */
+        private final boolean patchXnio;
+
+        public WildFlyClassLoader(URL[] urls, ClassLoader parent, boolean patchXnio) throws MalformedURLException, RuntimeException {
             super(urls, parent);
+            this.patchXnio = patchXnio;
         }
 
         @Override
@@ -128,14 +149,74 @@ public class WildflyDeploymentFactory implements DeploymentFactory {
         }
 
         @Override
-       public Enumeration<URL> getResources(String name) throws IOException {
-           // get rid of annoying warnings
-           if (name.indexOf("jndi.properties") != -1) {// || name.indexOf("i18n_user.properties") != -1) { // NOI18N
-               return Collections.enumeration(Collections.<URL>emptyList());
-           }
+        public Enumeration<URL> getResources(String name) throws IOException {
+            // get rid of annoying warnings
+            if (name.contains("jndi.properties")) { // NOI18N
+                return Collections.enumeration(Collections.<URL>emptyList());
+            }
 
-           return super.getResources(name);
-       }
+            return super.getResources(name);
+        }
+
+        @Override
+        protected Class<?> findClass(String name) throws ClassNotFoundException {
+            // see issue #249135
+            if (patchXnio && "org.xnio.nio.WorkerThread".equals(name)) { // NOI18N
+                try {
+                    LOGGER.log(Level.INFO, "Patching the issue #249135");
+                    String path = name.replace('.', '/').concat(".class"); // NOI18N
+                    try (InputStream is = super.getResourceAsStream(path)) {
+                        ClassReader cr = new ClassReader(is);
+                        ClassWriter cw = new ClassWriter(cr, ClassWriter.COMPUTE_FRAMES) {
+
+                            @Override
+                            protected String getCommonSuperClass(String string, String string1) {
+                                if ("org/xnio/nio/NioHandle".equals(string) // NOI18N
+                                        || "org/xnio/nio/NioHandle".equals(string1)) { // NOI18N
+                                    return "java/lang/Object"; // NOI18N
+                                }
+                                return super.getCommonSuperClass(string, string1);
+                            }
+                        };
+                        ClassNode node = new ClassNode();
+                        cr.accept(node, 0);
+
+                        for (MethodNode m : (Collection<MethodNode>) node.methods) {
+                            if ("execute".equals(m.name) // NOI18N
+                                    && "(Ljava/lang/Runnable;)V".equals(m.desc)) { // NOI18N
+                                InsnList list = m.instructions;
+                                for (ListIterator it = list.iterator(); it.hasNext(); ) {
+                                    AbstractInsnNode n = (AbstractInsnNode) it.next();
+                                    if (n instanceof MethodInsnNode) {
+                                        MethodInsnNode mn = (MethodInsnNode) n;
+                                        if ("org/xnio/nio/Log".equals(mn.owner) // NOI18N
+                                                && "threadExiting".equals(mn.name) // NOI18N
+                                                && "()Ljava/util/concurrent/RejectedExecutionException;".equals(mn.desc)) { // NOI18N
+                                            if (it.hasNext()) {
+                                                AbstractInsnNode possibleThrow = (AbstractInsnNode) it.next();
+                                                if (possibleThrow.getOpcode() == Opcodes.ATHROW) {
+                                                    it.set(new InsnNode(Opcodes.POP));
+                                                    break;
+                                                }
+                                            }
+                                        }
+                                    }
+                                }
+                                break;
+                            }
+                        }
+
+                        node.accept(cw);
+                        byte[] newBytecode = cw.toByteArray();
+                        return super.defineClass(name, newBytecode, 0, newBytecode.length);
+                    }
+                } catch (Exception ex) {
+                    // just fallback to original behavior
+                    LOGGER.log(Level.INFO, null, ex);
+                }
+            }
+            return super.findClass(name);
+        }
     }
 
     public synchronized WildFlyClassLoader getWildFlyClassLoader(InstanceProperties ip) {
@@ -156,49 +237,55 @@ public class WildflyDeploymentFactory implements DeploymentFactory {
     public static WildFlyClassLoader createWildFlyClassLoader(String serverRoot) {
         try {
             String sep = File.separator;
-            File domFile = new File(serverRoot, WildflyPluginUtils.getModulesBase(serverRoot)
-                    + "org" + sep + "dom4j" + sep + "main" + sep + "dom4j-1.6.1.jar"); // NOI18N
-
-            if (!domFile.exists()) {
-                domFile = null;
+            List<URL> urlList = new ArrayList<>(20);
+            File org = new File(serverRoot, WildflyPluginUtils.getModulesBase(serverRoot) + "org");
+            addUrl(urlList, org, "dom4j" + sep + "main", Pattern.compile("dom4j-.*.jar"));
+            if (urlList.isEmpty()) {
                 LOGGER.log(Level.INFO, "No dom4j.jar availabale on classpath"); // NOI18N
             }
-
-            List<URL> urlList = new ArrayList<URL>();
-
-            if (domFile != null) {
-                urlList.add(domFile.toURI().toURL());
-            }
-
-            File org = new File(serverRoot, WildflyPluginUtils.getModulesBase(serverRoot) + "org");
-
             File jboss = new File(org, "jboss");
+            File wildfly = new File(org, "wildfly");
             File as = new File(jboss, "as");
 
-            if (domFile != null && domFile.exists()) {
-                urlList.add(domFile.toURI().toURL());
+            final File jbossModules = new File(serverRoot, "jboss-modules.jar");
+            if(jbossModules.exists()) {
+                urlList.add(Utilities.toURI(jbossModules).toURL());
+            }
+            final File jbossClient = new File(serverRoot, "bin" + sep + "client" + sep + "jboss-client.jar");
+            if(jbossClient.exists()) {
+                urlList.add(Utilities.toURI(jbossClient).toURL());
             }
-
-            urlList.add(new File(serverRoot, "jboss-modules.jar").toURI().toURL());
-            urlList.add(new File(serverRoot, "bin" + sep + "client" + sep + "jboss-client.jar").toURI().toURL());
-
             addUrl(urlList, jboss, "dmr" + sep + "main", Pattern.compile("jboss-dmr-.*.jar"));
             addUrl(urlList, jboss, "logging" + sep + "main", Pattern.compile("jboss-logging-.*.jar"));
             addUrl(urlList, jboss, "marshalling" + sep + "main", Pattern.compile("jboss-marshalling-.*.jar"));
             addUrl(urlList, jboss, "marshalling" + sep + "river" + sep + "main", Pattern.compile("jboss-marshalling-river-.*.jar"));
             addUrl(urlList, jboss, "remoting" + sep + "main", Pattern.compile("jboss-remoting-.*.jar"));
-            addUrl(urlList, jboss, "sals" + sep + "main", Pattern.compile("jboss-sasl-.*.jar"));
+            addUrl(urlList, jboss, "sasl" + sep + "main", Pattern.compile("jboss-sasl-.*.jar"));
             addUrl(urlList, jboss, "threads" + sep + "main", Pattern.compile("jboss-threads-.*.jar"));
+            addUrl(urlList, jboss, "xnio" + sep + "main", Pattern.compile("xnio-api-.*.jar"));
+            addUrl(urlList, jboss, "xnio" + sep + "nio" + sep + "main", Pattern.compile("xnio-nio-.*.jar"));
             addUrl(urlList, as, "controller" + sep + "main", Pattern.compile("wildfly-controller-.*.jar"));
             addUrl(urlList, as, "controller" + sep + "main", Pattern.compile("jboss-as-controller-.*.jar"));
             addUrl(urlList, as, "controller-client" + sep + "main", Pattern.compile("jboss-as-controller-client-.*.jar"));
             addUrl(urlList, as, "controller-client" + sep + "main", Pattern.compile("wildfly-controller-client-.*.jar"));
             addUrl(urlList, as, "protocol" + sep + "main", Pattern.compile("wildfly-protocol-.*.jar"));
             addUrl(urlList, as, "protocol" + sep + "main", Pattern.compile("jboss-as-protocol-.*.jar"));
-            addUrl(urlList, jboss, "xnio" + sep + "main", Pattern.compile("xnio-api-.*.jar"));
-            addUrl(urlList, jboss, "xnio" + sep + "nio" + sep + "main", Pattern.compile("xnio-nio-.*.jar"));
-
-            WildFlyClassLoader loader = new WildFlyClassLoader(urlList.toArray(new URL[] {}), WildflyDeploymentFactory.class.getClassLoader());
+            //CLI GUI
+//            addUrl(urlList, jboss, "aesh" + sep + "main", Pattern.compile("aesh-.*.jar"));
+//            addUrl(urlList, jboss, "staxmapper" + sep + "main", Pattern.compile("staxmapper-.*.jar"));
+//            addUrl(urlList, wildfly, "security" + sep + "manager" + sep + "main", Pattern.compile("wildfly-security-manager-.*.jar"));
+//            addUrl(urlList, jboss, "remoting-jmx" + sep + "main", Pattern.compile("remoting-jmx-.*.jar"));
+//            addUrl(urlList, jboss, "vfs" + sep + "main", Pattern.compile("jboss-vfs-.*.jar"));
+//            addUrl(urlList, org, "picketbox" + sep + "main", Pattern.compile("picketbox-.*.jar"));
+//            addUrl(urlList, as, "cli" + sep + "main", Pattern.compile("wildfly-cli-.*.jar"));
+            File serverPath = new File(serverRoot);
+            Version version = WildflyPluginUtils.getServerVersion(serverPath);
+            if (WildflyPluginUtils.WILDFLY_10_0_0.compareToIgnoreUpdate(version) >= 0) {
+                addUrl(urlList, wildfly, "common" + sep + "main", Pattern.compile("wildfly-common-.*.jar"));
+            }
+            boolean shouldPatchXnio = WildflyPluginUtils.WILDFLY_8_0_0.compareToIgnoreUpdate(version) <= 0 && WildflyPluginUtils.isWildFly(serverPath);
+            WildFlyClassLoader loader = new WildFlyClassLoader(urlList.toArray(new URL[] {}),
+                    WildflyDeploymentFactory.class.getClassLoader(), shouldPatchXnio);
             return loader;
         } catch (Exception e) {
             LOGGER.log(Level.WARNING, null, e);
@@ -208,19 +295,21 @@ public class WildflyDeploymentFactory implements DeploymentFactory {
 
     private static void addUrl(List<URL> result, File root, String path, final Pattern pattern) {
         File folder = new File(root, path);
-        File[] children = folder.listFiles(new FilenameFilter() {
-
-            @Override
-            public boolean accept(File dir, String name) {
-                return pattern.matcher(name).matches();
-            }
-        });
-        if (children != null) {
-            for (File child : children) {
-                try {
-                    result.add(child.toURI().toURL());
-                } catch (MalformedURLException ex) {
-                    LOGGER.log(Level.INFO, null, ex);
+        if(folder.exists() && folder.isDirectory()) {
+            File[] children = folder.listFiles(new FilenameFilter() {
+                @Override
+                public boolean accept(File dir, String name) {
+                    return pattern.matcher(name).matches();
+                }
+            });
+            if (children != null) {
+                for (File child : children) {
+                    try {
+                        result.add(child.toURI().toURL());
+                        LOGGER.log(Level.INFO, "Adding {0} to the classpath", child.getAbsolutePath());
+                    } catch (MalformedURLException ex) {
+                        LOGGER.log(Level.INFO, null, ex);
+                    }
                 }
             }
         }
