@@ -51,6 +51,8 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.WeakHashMap;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import javax.enterprise.deploy.model.DeployableObject;
 import javax.enterprise.deploy.shared.ActionType;
 import javax.enterprise.deploy.shared.CommandType;
@@ -87,6 +89,8 @@ import org.openide.util.Exceptions;
  */
 public class WildflyDeploymentManager implements DeploymentManager2 {
 
+    private static final Logger LOGGER = Logger.getLogger(WildflyDeploymentManager.class.getName());
+
     private static final int DEBUGGING_PORT = 8787;
     private static final int CONTROLLER_PORT = 9990;
 
@@ -120,17 +124,18 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
         this.df = df;
         this.realUri = realUri;
         this.instanceProperties = InstanceProperties.getInstanceProperties(realUri);
-        version = WildflyPluginUtils.getServerVersion(new File(this.instanceProperties.getProperty(WildflyPluginProperties.PROPERTY_ROOT_DIR)));
-        isWildfly = (version != null && WildflyPluginUtils.WILDFLY_8_0_0.compareTo(version) <= 0);
+        File serverPath = new File(this.instanceProperties.getProperty(WildflyPluginProperties.PROPERTY_ROOT_DIR));
+        version = WildflyPluginUtils.getServerVersion(serverPath);
+        isWildfly = WildflyPluginUtils.isWildFly(serverPath);
         int controllerPort = CONTROLLER_PORT;
         String adminPort = this.instanceProperties.getProperty(PROPERTY_ADMIN_PORT);
         if(adminPort != null) {
             controllerPort = Integer.parseInt(this.instanceProperties.getProperty(PROPERTY_ADMIN_PORT));
         }
         if (username != null && password != null) {
-            this.client = new WildflyClient(instanceProperties, getHost(), controllerPort, username, password);
+            this.client = new WildflyClient(instanceProperties, version, getHost(), controllerPort, username, password);
         } else {
-            this.client = new WildflyClient(instanceProperties, getHost(), controllerPort);
+            this.client = new WildflyClient(instanceProperties, version, getHost(), controllerPort);
         }
         ChangelogWildflyPlugin.showChangelog();
     }
@@ -167,7 +172,7 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                 progress.fireProgressEvent(null, new WildflyDeploymentStatus(ActionType.EXECUTE, CommandType.REDEPLOY, StateType.FAILED, ""));
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
             progress.fireProgressEvent(null, new WildflyDeploymentStatus(ActionType.EXECUTE, CommandType.REDEPLOY, StateType.FAILED, ex.getMessage()));
         }
         return progress;
@@ -195,7 +200,7 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                 progress.fireProgressEvent(tmids[0], new WildflyDeploymentStatus(ActionType.EXECUTE, CommandType.DISTRIBUTE, StateType.FAILED, ""));
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
             progress.fireProgressEvent(tmids[0], new WildflyDeploymentStatus(ActionType.EXECUTE, CommandType.DISTRIBUTE, StateType.FAILED, ex.getMessage()));
         }
         return progress;
@@ -243,7 +248,8 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                 }
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
+            return new TargetModuleID[]{};
         }
         return result.toArray(new TargetModuleID[result.size()]);
     }
@@ -283,7 +289,8 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                 }
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
+            return new TargetModuleID[]{};
         }
         return result.toArray(new TargetModuleID[result.size()]);
     }
@@ -310,9 +317,9 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                             ActionType.EXECUTE, CommandType.START, StateType.COMPLETED, null));
                 }
             } catch (IOException ex) {
-                Exceptions.printStackTrace(ex);
+                LOGGER.log(Level.INFO, null, ex);
                 progress.fireProgressEvent(wflyTmid, new WildflyDeploymentStatus(
-                        ActionType.EXECUTE, CommandType.START, StateType.FAILED, null));
+                        ActionType.EXECUTE, CommandType.START, StateType.FAILED, ex.getMessage()));
             }
         }
         return progress;
@@ -338,9 +345,9 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
                         ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.COMPLETED, null));
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
             progress.fireProgressEvent(null, new WildflyDeploymentStatus(
-                    ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.FAILED, null));
+                    ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.FAILED, ex.getMessage()));
         }
         return progress;
     }
@@ -403,6 +410,7 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
     public WildFlyProperties getProperties() {
         return new WildFlyProperties(this);
     }
+
     public boolean isWildfly() {
         return isWildfly;
     }
@@ -487,14 +495,14 @@ public class WildflyDeploymentManager implements DeploymentManager2 {
         progress.fireProgressEvent(null, new WildflyDeploymentStatus(
                 ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.RUNNING, null));
         try {
-            if (client.addMessageDestinations(destinations)) {
+            if (client.addMessageDestinations(destinations, getInstanceProperties())) {
                 progress.fireProgressEvent(null, new WildflyDeploymentStatus(
                         ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.COMPLETED, null));
             }
         } catch (IOException ex) {
-            Exceptions.printStackTrace(ex);
+            LOGGER.log(Level.INFO, null, ex);
             progress.fireProgressEvent(null, new WildflyDeploymentStatus(
-                    ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.FAILED, null));
+                    ActionType.EXECUTE, CommandType.UNDEPLOY, StateType.FAILED, ex.getMessage()));
         }
         return progress;
     }
