@@ -61,7 +61,7 @@ import org.netbeans.modules.javaee.wildfly.config.gen.EjbRef;
 import org.netbeans.modules.javaee.wildfly.config.gen.JbossClient;
 import org.netbeans.modules.javaee.wildfly.config.gen.ResourceRef;
 import org.netbeans.modules.javaee.wildfly.config.gen.ServiceRef;
-import org.netbeans.modules.javaee.wildfly.config.mdb.MessageDestinationSupport;
+import org.netbeans.modules.javaee.wildfly.config.mdb.MessageDestinationSupportImpl;
 import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginUtils;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -86,12 +86,12 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
     private JbossClient jbossClient;
 
     public CarDeploymentConfiguration(J2eeModule j2eeModule) {
-        this(j2eeModule, null);
+        this(j2eeModule, null, true);
     }
 
     /** Creates a new instance of CarDeploymentConfiguration */
-    public CarDeploymentConfiguration(J2eeModule j2eeModule, WildflyPluginUtils.Version version) {
-        super(j2eeModule, version);
+    public CarDeploymentConfiguration(J2eeModule j2eeModule, WildflyPluginUtils.Version version, boolean isWildFly) {
+        super(j2eeModule, version, isWildFly);
         jbossClientFile = j2eeModule.getDeploymentConfigurationFile("META-INF/jboss-client.xml"); // NOI18N
         getJbossClient();
         if (deploymentDescriptorDO == null) {
@@ -308,7 +308,7 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
                 //if it doesn't exist yet, create a new one
                 ResourceRef newRR = new ResourceRef();
                 newRR.setResRefName(name);
-                newRR.setJndiName(MessageDestinationSupport.CONN_FACTORY_JNDI_NAME_JB4);
+                newRR.setJndiName(MessageDestinationSupportImpl.CONN_FACTORY_JNDI_NAME_JB4);
                 modifiedJbossClient.addResourceRef(newRR);
             }
         });
