@@ -72,7 +72,7 @@ import org.netbeans.modules.javaee.wildfly.config.gen.Jboss;
 import org.netbeans.modules.javaee.wildfly.config.gen.MessageDriven;
 import org.netbeans.modules.javaee.wildfly.config.gen.ResourceRef;
 import org.netbeans.modules.javaee.wildfly.config.gen.Session;
-import org.netbeans.modules.javaee.wildfly.config.mdb.MessageDestinationSupport;
+import org.netbeans.modules.javaee.wildfly.config.mdb.MessageDestinationSupportImpl;
 import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginUtils;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -125,17 +125,17 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
     private String tempEjbName;
 
     public EjbDeploymentConfiguration(J2eeModule j2eeModule) {
-        this(j2eeModule, null);
+        this(j2eeModule, null, true);
     }
 
     /**
      * Creates a new instance of EjbDeploymentConfiguration
      */
-    public EjbDeploymentConfiguration(J2eeModule j2eeModule, WildflyPluginUtils.Version version) {
-        super(j2eeModule, version);
+    public EjbDeploymentConfiguration(J2eeModule j2eeModule, WildflyPluginUtils.Version version, boolean isWildFly) {
+        super(j2eeModule, version, isWildFly);
         this.jbossFile = j2eeModule.getDeploymentConfigurationFile("META-INF/jboss.xml"); // NOI18N;
         getJboss();
-        if (deploymentDescriptorDO == null) {
+        if (deploymentDescriptorDO == null && jbossFile != null) {
             try {
                 deploymentDescriptorDO = deploymentDescriptorDO.find(FileUtil.toFileObject(jbossFile));
                 deploymentDescriptorDO.addPropertyChangeListener(this);
@@ -161,7 +161,7 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
      *
      * @return jboss graph or null if the jboss.xml file is not parseable.
      */
-    public synchronized Jboss getJboss() {
+    private final synchronized Jboss getJboss() {
         if (jboss == null) {
             try {
                 if (jbossFile!= null && jbossFile.exists()) {
@@ -927,24 +927,6 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
         });
     }
 
-    /**
-     * Add a new mail service reference to the message-driven beans without it.
-     *
-     * @param resRefName mail service reference name
-     * @param beans the bean names (ejb-name) mapped to the message destinations (message-destination-link)
-     * which might need to add mail service reference specified by resRefName
-     */
-    private void addMsgDrvMailReference(final String resRefName, final Map beans)
-    throws ConfigurationException
-    {
-        modifyJboss(new JbossModifier() {
-           public void modify(Jboss modifiedJboss) {
-               String jndiName = MAIL_SERVICE_JNDI_NAME_JB4;
-               JBossDataSourceRefModifier.modifyMsgDrv(modifiedJboss, resRefName, beans, jndiName);
-           }
-        });
-    }
-
     public void bindMdbToMessageDestination(String mdbName, String name, MessageDestination.Type type) throws ConfigurationException {
 
         if (Double.parseDouble(j2eeModule.getModuleVersion()) > 2.1) {
@@ -1035,7 +1017,7 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
     {
         modifyJboss(new JbossModifier() {
            public void modify(Jboss modifiedJboss) {
-               String jndiName = MessageDestinationSupport.CONN_FACTORY_JNDI_NAME_JB4;
+               String jndiName = MessageDestinationSupportImpl.CONN_FACTORY_JNDI_NAME_JB4;
                JBossDataSourceRefModifier.modify(modifiedJboss, resRefName, beanNames, beanType, jndiName);
            }
         });
@@ -1052,7 +1034,7 @@ implements ModuleConfiguration, DatasourceConfiguration, DeploymentPlanConfigura
     {
         modifyJboss(new JbossModifier() {
            public void modify(Jboss modifiedJboss) {
-               String jndiName = MessageDestinationSupport.CONN_FACTORY_JNDI_NAME_JB4;
+               String jndiName = MessageDestinationSupportImpl.CONN_FACTORY_JNDI_NAME_JB4;
                JBossDataSourceRefModifier.modifyMsgDrv(modifiedJboss, connectionFactoryName, mdbName, jndiName);
            }
         });
