@@ -84,6 +84,8 @@ public class AddServerPropertiesVisualPanel extends JPanel {
     private javax.swing.JTextField hostField;
     private javax.swing.JLabel     portLabel;
     private javax.swing.JTextField portField;
+    private javax.swing.JLabel     managementPortLabel;
+    private javax.swing.JTextField managementPortField;
     private javax.swing.JLabel     userLabel;
     private javax.swing.JTextField userField;
     private javax.swing.JLabel     passwordLabel;
@@ -136,6 +138,10 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         return portField.getText().trim();
     }
 
+    public String getManagementPort(){
+        return managementPortField.getText().trim();
+    }
+
     public String getUser(){
         return userField.getText();
     }
@@ -157,6 +163,7 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         String path = model.getCurrentPath();
         domainPathField.setText(path);
         portField.setText(WildflyPluginUtils.getHTTPConnectorPort(path));
+        managementPortField.setText(WildflyPluginUtils.getManagementConnectorPort(path));
         fireChangeEvent();
     }
 
@@ -165,11 +172,19 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         String serverLocation = WildflyPluginProperties.getInstance().getInstallLocation();
         domainModel.setDomains(WildflyPluginUtils.getRegisteredDomains(serverLocation));
         String configLocation = WildflyPluginProperties.getInstance().getConfigLocation();
-        File domainDir = new File(configLocation).getParentFile().getParentFile();
-        if(domainModel.hasDomain(domainDir.getName())) {
-            domainModel.setSelectedItem(domainDir.getName());
+        File folder = new File(configLocation).getParentFile();
+        if (folder != null) {
+            folder = folder.getParentFile();
+        }
+        File domainDir = folder;
+        if (domainDir != null) {
+            if (domainModel.hasDomain(domainDir.getName())) {
+                domainModel.setSelectedItem(domainDir.getName());
+            } else {
+                domainModel.addDomain(domainDir.getName(), domainDir.getAbsolutePath());
+            }
         } else {
-            domainModel.addDomain(domainDir.getName(), domainDir.getAbsolutePath());
+            domainModel.setSelectedItem(null);
         }
         domainChanged();
     }
@@ -256,11 +271,21 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         portField.setColumns(20);
         portField.getAccessibleContext().setAccessibleDescription(NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_Port"));
         portField.getAccessibleContext().setAccessibleName(NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_Port"));
-        //portField.setEditable(false);
         portField.addKeyListener(new SomeChangesListener());
 
         portLabel.setLabelFor(portField);
 
+        managementPortLabel = new JLabel();
+        org.openide.awt.Mnemonics.setLocalizedText(managementPortLabel, NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_Management_Port")); // NOI18N
+
+        managementPortField = new JTextField();
+        managementPortField.setColumns(20);
+        managementPortField.getAccessibleContext().setAccessibleDescription(NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_Management_Port"));
+        managementPortField.getAccessibleContext().setAccessibleName(NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_Management_Port"));
+        managementPortField.addKeyListener(new SomeChangesListener());
+
+        managementPortLabel.setLabelFor(managementPortField);
+
         userLabel = new JLabel(NbBundle.getMessage(AddServerPropertiesVisualPanel.class, "LBL_User"));//NOI18N
         userField = new JTextField();
         userField.addKeyListener(new SomeChangesListener());
@@ -275,15 +300,12 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         setFocusable(false);
 
         setMinimumSize(new java.awt.Dimension(280, 217));
-       //   setNextFocusableComponent(domainPathField);
-
-
         //-------------- some label --------------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = 3;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(label1, gridBagConstraints);
 
 
@@ -291,7 +313,7 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridy = 0;
         gridBagConstraints.gridx = 2;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
 
         add(serverType, gridBagConstraints);
 
@@ -299,7 +321,7 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         //-------------- domain ---------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         gridBagConstraints.anchor = GridBagConstraints.WEST;
         add(domainLabel, gridBagConstraints);
 
@@ -308,7 +330,7 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         gridBagConstraints.gridy = 1;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(domainField, gridBagConstraints);
 
 
@@ -318,21 +340,22 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 2;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.anchor = GridBagConstraints.WEST;
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         add(domainPathLabel, gridBagConstraints);
 
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridy = 2;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(domainPathField, gridBagConstraints);
 
         //-------------- host ---------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 3;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         gridBagConstraints.anchor = GridBagConstraints.WEST;
         add(hostLabel, gridBagConstraints);
 
@@ -342,14 +365,14 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         gridBagConstraints.gridx = 1;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(hostField, gridBagConstraints);
 
 
         //-------------- port ---------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         gridBagConstraints.anchor = GridBagConstraints.WEST;
         add(portLabel, gridBagConstraints);
 
@@ -358,23 +381,38 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         gridBagConstraints.gridy = 4;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(portField, gridBagConstraints);
 
-
-        //-------------- User ---------------
+        //-------------- management port ---------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         gridBagConstraints.anchor = GridBagConstraints.WEST;
-        add(userLabel, gridBagConstraints);
+        add(managementPortLabel, gridBagConstraints);
 
 
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridy = 5;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
+        add(managementPortField, gridBagConstraints);
+
+
+        //-------------- User ---------------
+        gridBagConstraints = new java.awt.GridBagConstraints();
+        gridBagConstraints.gridx = 0;
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
+        gridBagConstraints.anchor = GridBagConstraints.WEST;
+        add(userLabel, gridBagConstraints);
+
+
+        gridBagConstraints = new java.awt.GridBagConstraints();
+        gridBagConstraints.gridy = 6;
+        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
+        gridBagConstraints.weightx = 1.0;
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(userField, gridBagConstraints);
 
 
@@ -382,16 +420,16 @@ public class AddServerPropertiesVisualPanel extends JPanel {
         //-------------- Password ---------------
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 6);
         gridBagConstraints.anchor = GridBagConstraints.WEST;
         add(passwordLabel, gridBagConstraints);
 
 
         gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.gridy = 6;
+        gridBagConstraints.gridy = 7;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 5);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 12, 0);
         add(passwordField, gridBagConstraints);
 
         //-------------  panell to fill out free space ------------------------
@@ -417,7 +455,6 @@ public class AddServerPropertiesVisualPanel extends JPanel {
 
         hostField.setText("localhost");//NOI18N
         portField.setText(WildflyPluginUtils.getHTTPConnectorPort(domainPathField.getText()));//NOI18N
-    //    serverTypeChanged();
         domainChanged();
 
     }
