@@ -43,23 +43,29 @@
  */
 package org.netbeans.modules.javaee.wildfly.ide.ui;
 
-import java.beans.PropertyVetoException;
 import java.io.File;
+
 import static java.io.File.separatorChar;
+
+import java.beans.PropertyVetoException;
+import java.io.FileInputStream;
+import java.io.FileReader;
 import java.io.FilenameFilter;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.ServerSocket;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.jar.Attributes;
+import java.util.jar.Manifest;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
-import org.netbeans.modules.javaee.wildfly.ide.ui.WildflyPluginUtils.Version;
 import org.openide.filesystems.JarFileSystem;
 
 /**
@@ -72,10 +78,18 @@ public class WildflyPluginUtils {
 
     public static final Version EAP_6_3_0 = new Version("7.4.0"); // NOI18N
 
+    public static final Version EAP_6_4_0 = new Version("7.5.0"); // NOI18N
+
     public static final Version WILDFLY_8_0_0 = new Version("8.0.0"); // NOI18N
 
     public static final Version WILDFLY_8_1_0 = new Version("8.1.0"); // NOI18N
 
+    public static final Version WILDFLY_8_2_0 = new Version("8.2.0"); // NOI18N
+
+    public static final Version WILDFLY_9_0_0 = new Version("9.0.0"); // NOI18N
+    
+    public static final Version WILDFLY_10_0_0 = new Version("10.0.0"); // NOI18N
+
     private static final Logger LOGGER = Logger.getLogger(WildflyPluginUtils.class.getName());
 
     public static final String LIB = "lib" + separatorChar;
@@ -216,11 +230,6 @@ public class WildflyPluginUtils {
         return true;
     }
 
-    //--------------------------------------------------------------------
-    /**
-     *
-     *
-     */
     public static String getDeployDir(String domainDir) {
         return domainDir + separatorChar + "deployments"; //NOI18N
     }
@@ -230,6 +239,11 @@ public class WildflyPluginUtils {
         return defaultPort;
     }
 
+     public static String getManagementConnectorPort(String configFile) {
+        String defaultPort = "9990"; // NOI18N
+        return defaultPort;
+    }
+
     /**
      * Return true if the specified port is free, false otherwise.
      */
@@ -262,14 +276,18 @@ public class WildflyPluginUtils {
     public static Version getServerVersion(File serverPath) {
         assert serverPath != null : "Can't determine version with null server path"; // NOI18N
 
-        Version version = null;
-        File serverDir = new File(serverPath, getModulesBase(serverPath.getAbsolutePath()) + "org/jboss/as/server/main");
-        File[] files = serverDir.listFiles(new JarFileFilter());
-        if (files != null) {
-            for (File jarFile : files) {
-                version = getVersion(jarFile);
-                if (version != null) {
-                    break;
+        Version version = getProductVersion(serverPath);
+        if (version == null) {
+            File serverDir = new File(serverPath, getModulesBase(serverPath.getAbsolutePath()) + "org/jboss/as/version/main");
+            File[] files = serverDir.listFiles(new VersionJarFileFilter());
+            if (files != null) {
+                for (File jarFile : files) {
+                    if (jarFile.getName().startsWith("jboss-as-version")) {
+                        version = getVersion(jarFile);
+                        if (version != null) {
+                            break;
+                        }
+                    }
                 }
             }
         }
@@ -279,11 +297,116 @@ public class WildflyPluginUtils {
         return version;
     }
 
-    static class JarFileFilter implements FilenameFilter {
+    /**
+     * Return the version of the server located at the given path. If the server
+     * version can't be determined returns <code>null</code>.
+     *
+     * @param serverPath path to the server directory
+     * @return specification version of the server using product.conf.
+     */
+    @CheckForNull
+    public static Version getProductVersion(File serverPath) {
+        assert serverPath != null : "Can't determine version with null server path"; // NOI18N
+        String productConf = getProductConf(serverPath);
+        if(productConf != null) {
+            try (FileReader reader = new FileReader(productConf)) {
+                Properties props = new Properties();
+                props.load(reader);
+                String slot = props.getProperty("slot");
+                if (slot != null) {
+                    File manifestFile = new File(serverPath, getModulesBase(serverPath.getAbsolutePath()) + "org.jboss.as.product".replace('.', separatorChar) + separatorChar + slot + separatorChar + "dir" + separatorChar + "META-INF" + separatorChar + "MANIFEST.MF");
+                    InputStream stream = new FileInputStream(manifestFile);
+                    Manifest manifest = new Manifest(stream);
+                    return new Version(manifest.getMainAttributes().getValue("JBoss-Product-Release-Version"));
+                }
+            } catch (Exception e) {
+                // Don't care
+            }
+        }
+        return null;
+    }
+
+    private static String getProductConf(File serverPath) {
+        final String defaultVal = serverPath.getAbsolutePath() + File.separatorChar + "bin" + File.separatorChar + "product.conf";
+        String env = System.getenv("JBOSS_PRODUCT_CONF");
+        if (env == null) {
+            env = defaultVal;
+        }
+        return env;
+    }
+
+    /**
+     * Check the product name of the server located at the given path. If the server
+     * version can't be determined returns <code>null</code>.
+     *
+     * @param serverPath path to the server directory
+     * @return specification version of the server using product.conf.
+     */
+    @CheckForNull
+    public static boolean isWildFly(File serverPath) {
+        assert serverPath != null : "Can't determine version with null server path"; // NOI18N
+        String productConf = getProductConf(serverPath);
+        if(productConf != null) {
+            try (FileReader reader = new FileReader(productConf)) {
+                Properties props = new Properties();
+                props.load(reader);
+                String slot = props.getProperty("slot");
+                if (slot != null) {
+                    File manifestFile = new File(serverPath, getModulesBase(serverPath.getAbsolutePath()) + "org.jboss.as.product".replace('.', separatorChar) + separatorChar + slot + separatorChar + "dir" + separatorChar + "META-INF" + separatorChar + "MANIFEST.MF");
+                    InputStream stream = new FileInputStream(manifestFile);
+                    Manifest manifest = new Manifest(stream);
+                    String productName = manifest.getMainAttributes().getValue("JBoss-Product-Release-Name");
+                    if(productName == null || productName.isEmpty()) {
+                        productName = manifest.getMainAttributes().getValue("JBoss-Project-Release-Name");
+                    }
+                    return productName == null || !productName.toLowerCase().contains("eap");
+                }
+            } catch (Exception e) {
+                // Don't care
+            }
+        }
+        return true;
+    }
+
+    /**
+     * Check the product name of the server located at the given path. If the server
+     * version can't be determined returns <code>null</code>.
+     *
+     * @param serverPath path to the server directory
+     * @return specification version of the server using product.conf.
+     */
+    @CheckForNull
+    public static boolean isWildFlyServlet(File serverPath) {
+        assert serverPath != null : "Can't determine version with null server path"; // NOI18N
+        String productConf = getProductConf(serverPath);
+        if(productConf != null) {
+            try (FileReader reader = new FileReader(productConf)) {
+                Properties props = new Properties();
+                props.load(reader);
+                String slot = props.getProperty("slot");
+                if (slot != null) {
+                    File manifestFile = new File(serverPath, getModulesBase(serverPath.getAbsolutePath()) + "org.jboss.as.product".replace('.', separatorChar) + separatorChar + slot + separatorChar + "dir" + separatorChar + "META-INF" + separatorChar + "MANIFEST.MF");
+                    InputStream stream = new FileInputStream(manifestFile);
+                    Manifest manifest = new Manifest(stream);
+                    String productName = manifest.getMainAttributes().getValue("JBoss-Product-Release-Name");
+                    if(productName == null || productName.isEmpty()) {
+                        productName = manifest.getMainAttributes().getValue("JBoss-Project-Release-Name");
+                    }
+                    return productName != null && (productName.contains("WildFly Web Lite") || productName.contains("WildFly Servlet"));
+                }
+            } catch (Exception e) {
+                e.printStackTrace();
+                // Don't care
+            }
+        }
+        return false;
+    }
+
+    private static class VersionJarFileFilter implements FilenameFilter {
 
         @Override
         public boolean accept(File dir, String name) {
-            return name.endsWith(".jar");
+            return name.endsWith(".jar") && (name.startsWith("jboss-as-version") || name.startsWith("wildfly-version"));
         }
     }
 
@@ -301,10 +424,7 @@ public class WildflyPluginUtils {
                 return new Version(version);
             }
             return null;
-        } catch (IOException ex) {
-            LOGGER.log(Level.INFO, null, ex);
-            return null;
-        } catch (PropertyVetoException ex) {
+        } catch (IOException | PropertyVetoException ex) {
             LOGGER.log(Level.INFO, null, ex);
             return null;
         }
@@ -395,6 +515,7 @@ public class WildflyPluginUtils {
          */
         @Override
         public boolean equals(Object obj) {
+            // XXX thiw want match compareTo contract in case there will be numbers like "1" and "01".
             if (obj == null) {
                 return false;
             }
@@ -458,18 +579,31 @@ public class WildflyPluginUtils {
          * @param o version to compare with
          */
         public int compareToIgnoreUpdate(Version o) {
-            if(o == null) {
+            if (o == null) {
                 return 1;
             }
-            int comparison = majorNumber.compareTo(o.majorNumber);
+            int comparison = compare(majorNumber, o.majorNumber);
             if (comparison != 0) {
                 return comparison;
             }
-            comparison = minorNumber.compareTo(o.minorNumber);
+            comparison = compare(minorNumber, o.minorNumber);
             if (comparison != 0) {
                 return comparison;
             }
-            return microNumber.compareTo(o.microNumber);
+            return compare(microNumber, o.microNumber);
+        }
+
+        private int compare(String number1, String number2) {
+            if (number1.length() != number2.length()) {
+                try {
+                    Integer i1 = Integer.parseInt(number1);
+                    Integer i2 = Integer.parseInt(number2);
+                    return i1.compareTo(i2);
+                } catch (NumberFormatException ex) {
+                    // compare as strings below
+                }
+            }
+            return number1.compareTo(number2);
         }
 
     }
