@@ -430,6 +430,7 @@ public final class JFXProjectUtils {
 
     /**
      * Checks if the project uses Maven build system
+     *
      * @param prj the project to check
      * @return true if is Maven project
      */
@@ -439,12 +440,24 @@ public final class JFXProjectUtils {
             return false;
         }
         fo = fo.getFileObject("pom.xml"); //NOI18N
-        if (fo != null) {
-            return true;
-        }
-        return false;
+        return fo != null;
     }
-    
+
+    /**
+     * Checks if the project uses Gradle build system
+     *
+     * @param prj the project to check
+     * @return true if is Gradle project
+     */
+    public static boolean isGradleProject(@NonNull final Project prj) {
+        FileObject fo = prj.getProjectDirectory();
+        if (fo == null || !fo.isValid()) {
+            return false;
+        }
+        fo = fo.getFileObject("build.gradle"); //NOI18N
+        return fo != null;
+    }
+
     public static boolean isMavenFXProject(@NonNull final Project prj) {
         if (isMavenProject(prj)) {
             try {
@@ -454,13 +467,15 @@ public final class JFXProjectUtils {
                 Document doc = builder.parse(FileUtil.toFile(pomXml));
                 XPathFactory xPathfactory = XPathFactory.newInstance();
                 XPath xpath = xPathfactory.newXPath();
-                XPathExpression exprJfxrt = xpath.compile("//bootclasspath[contains(text(),'jfxrt')]");
-                XPathExpression exprPackager = xpath.compile("//executable[contains(text(),'javafxpackager')]");
+                XPathExpression exprJfxrt = xpath.compile("//bootclasspath[contains(text(),'jfxrt')]"); //NOI18N
+                XPathExpression exprFxPackager = xpath.compile("//executable[contains(text(),'javafxpackager')]"); //NOI18N
+                XPathExpression exprPackager = xpath.compile("//executable[contains(text(),'javapackager')]"); //NOI18N
                 boolean jfxrt = (Boolean) exprJfxrt.evaluate(doc, XPathConstants.BOOLEAN);
                 boolean packager = (Boolean) exprPackager.evaluate(doc, XPathConstants.BOOLEAN);
-                return jfxrt && packager;
+                boolean fxPackager = (Boolean) exprFxPackager.evaluate(doc, XPathConstants.BOOLEAN);
+                return jfxrt && (packager || fxPackager);
             } catch (XPathExpressionException | ParserConfigurationException | SAXException | IOException ex) {
-                Exceptions.printStackTrace(ex);
+                LOGGER.log(Level.INFO, "Error while parsing pom.xml.", ex);  //NOI18N
                 return false;
             }
         }
