@@ -98,7 +98,7 @@ public class FXMLTemplateWizardIterator implements WizardDescriptor.Instantiatin
     private SourceGroupSupport supportFXML;
     private SourceGroupSupport supportController;
     private SourceGroupSupport supportCSS;
-    private boolean isMaven = false;
+    private boolean isMavenOrGradle = false;
     private transient int index;
     private transient WizardDescriptor.Panel[] panels;
 
@@ -132,17 +132,17 @@ public class FXMLTemplateWizardIterator implements WizardDescriptor.Instantiatin
                     NbBundle.getMessage(FXMLTemplateWizardIterator.class,
                     "MSG_ConfigureFXMLPanel_Project_Null_Error")); // NOI18N
         }
-        isMaven = JFXProjectUtils.isMavenProject(project);
-        
+        isMavenOrGradle = JFXProjectUtils.isMavenProject(project) || JFXProjectUtils.isGradleProject(project);
+
         Sources sources = ProjectUtils.getSources(project);
         SourceGroup[] sourceGroupsJava = sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
         SourceGroup[] sourceGroupsResources = sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_RESOURCES);
-        if (sourceGroupsJava == null) {
+        if (sourceGroupsJava == null || sourceGroupsJava.length == 0) {
             throw new IllegalStateException(
                     NbBundle.getMessage(FXMLTemplateWizardIterator.class,
                     "MSG_ConfigureFXMLPanel_SGs_Error")); // NOI18N
         }
-        if(isMaven) {
+        if(isMavenOrGradle) {
             supportFXML = new SourceGroupSupport(JavaProjectConstants.SOURCES_TYPE_RESOURCES);
             supportCSS = new SourceGroupSupport(JavaProjectConstants.SOURCES_TYPE_RESOURCES);
             if(sourceGroupsResources != null && sourceGroupsResources.length > 0) {
@@ -153,6 +153,14 @@ public class FXMLTemplateWizardIterator implements WizardDescriptor.Instantiatin
                         new String[]{defaultMavenFXMLPackage, defaultMavenImagesPackage, defaultMavenCSSPackage});
                 supportCSS.addSourceGroupProxy(project, NbBundle.getMessage(FXMLTemplateWizardIterator.class,"LAB_ProjectResources"), // NOI18N
                         new String[]{defaultMavenFXMLPackage, defaultMavenImagesPackage, defaultMavenCSSPackage});
+                FileObject dirFXML = supportFXML.getCurrentPackageFolder(true);
+                if (dirFXML == null) {
+                    // default Maven resources are overriden in the project's pom.xml (#250097)
+                    supportFXML = new SourceGroupSupport(JavaProjectConstants.SOURCES_TYPE_JAVA);
+                    supportFXML.addSourceGroups(sourceGroupsJava); //must exist
+                    supportCSS = new SourceGroupSupport(JavaProjectConstants.SOURCES_TYPE_JAVA);
+                    supportCSS.addSourceGroups(sourceGroupsJava); //must exist
+                }
             }
         } else {
             supportFXML = new SourceGroupSupport(JavaProjectConstants.SOURCES_TYPE_JAVA);
@@ -188,9 +196,9 @@ public class FXMLTemplateWizardIterator implements WizardDescriptor.Instantiatin
 
     private WizardDescriptor.Panel[] createPanels(Project project, SourceGroupSupport supportFXML, SourceGroupSupport supportController, SourceGroupSupport supportCSS) {
         return new WizardDescriptor.Panel[]{
-                    new ConfigureFXMLPanelVisual.Panel(project, supportFXML, isMaven),
-                    new ConfigureFXMLControllerPanelVisual.Panel(supportController, isMaven),
-                    new ConfigureFXMLCSSPanelVisual.Panel(supportCSS, isMaven)
+                    new ConfigureFXMLPanelVisual.Panel(project, supportFXML, isMavenOrGradle),
+                    new ConfigureFXMLControllerPanelVisual.Panel(supportController, isMavenOrGradle),
+                    new ConfigureFXMLCSSPanelVisual.Panel(supportCSS, isMavenOrGradle)
                 };
     }
 
