@@ -41,6 +41,8 @@
  */
 package org.netbeans.modules.javascript.jstestdriver;
 
+import org.netbeans.modules.javascript.jstestdriver.ui.nodes.JSTestDriverTestRunnerNodeFactory;
+import org.netbeans.modules.javascript.jstestdriver.ui.nodes.JumpToCallStackAction;
 import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
@@ -56,6 +58,8 @@ import java.util.concurrent.Semaphore;
 import java.util.logging.Level;
 import java.util.logging.LogRecord;
 import java.util.logging.Logger;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.extexecution.print.ConvertedLine;
@@ -65,7 +69,7 @@ import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.libs.jstestdriver.api.JsTestDriver;
 import org.netbeans.libs.jstestdriver.api.ServerListener;
 import org.netbeans.libs.jstestdriver.api.TestListener;
-import org.netbeans.modules.gsf.testrunner.api.Manager;
+import org.netbeans.modules.gsf.testrunner.ui.api.Manager;
 import org.netbeans.modules.gsf.testrunner.api.Report;
 import org.netbeans.modules.gsf.testrunner.api.RerunHandler;
 import org.netbeans.modules.gsf.testrunner.api.RerunType;
@@ -83,6 +87,7 @@ import org.netbeans.modules.web.common.api.WebUtils;
 import org.openide.LifecycleManager;
 import org.openide.cookies.LineCookie;
 import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.MIMEResolver;
 import org.openide.loaders.DataObject;
 import org.openide.loaders.DataObjectNotFoundException;
@@ -90,6 +95,7 @@ import org.openide.text.Line;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.NbBundle.Messages;
+import org.openide.util.Pair;
 import org.openide.util.Parameters;
 import org.openide.util.RequestProcessor;
 import org.openide.util.lookup.AbstractLookup;
@@ -179,6 +185,12 @@ public class JSTestDriverSupport {
         assert testDriver != null;
         testDriver.stopServer();
         TestDriverServiceNode.getInstance().refresh();
+        try { // try waiting a bit after stopping server
+            Thread.sleep(1000);
+        } catch (InterruptedException ex) {
+            LOGGER.log(Level.INFO, null, ex);
+            Thread.currentThread().interrupt();
+        }
         if (integratedBrowserPanes != null) {
             for (WebBrowserPane wbp : integratedBrowserPanes) {
                 wbp.close(true);
@@ -368,7 +380,7 @@ public class JSTestDriverSupport {
         }
 
         // XXX: exact this algorithm is also in 
-        // web.javascript.debugger/src/org/netbeans/modules/web/javascript/debugger/console/BrowserConsoleLogger.java
+        // org.netbeans.modules.web.webkit.tooling.console.BrowserConsoleLogger.java
         // keep them in sync
         @Override
         public List<ConvertedLine> convert(String line) {
@@ -432,6 +444,12 @@ public class JSTestDriverSupport {
                 return null;
             }
             int ue = line.indexOf(' ', u1);
+            int uee = line.indexOf('\n', u1);
+            if (uee != -1
+                    && uee < ue) {
+                // #236037
+                ue = uee;
+            }
             if (ue < 0) {
                 ue = line.length();
             }
@@ -550,6 +568,7 @@ public class JSTestDriverSupport {
         })
         public Listener(Project project, Rerun rerun) {
             manager = Manager.getInstance();
+            manager.setNodeFactory(new JSTestDriverTestRunnerNodeFactory(new CallStackCallback(project)));
             testSession = new TestSession(
                     Bundle.JsTestDriverSupport_runner_title(ProjectUtils.getInformation(project).getDisplayName()),
                     project, TestSession.SessionType.TEST);
@@ -690,4 +709,40 @@ public class JSTestDriverSupport {
         USG_LOGGER.log(logRecord);
     }
 
+    //~ Inner classes
+
+    private static final class CallStackCallback implements JumpToCallStackAction.Callback {
+
+        private static final Pattern FILE_LINE_PATTERN = Pattern.compile(" [(](?<FILE>[^:]+):(?<LINE>\\d+):(?<COLUMN>\\d+)[)]"); // NOI18N
+
+        private final File projectDir;
+
+
+        public CallStackCallback(Project project) {
+            assert project != null;
+            projectDir = FileUtil.toFile(project.getProjectDirectory());
+        }
+
+        @Override
+        public Pair<File, int[]> parseLocation(String callStack) {
+            Matcher matcher = FILE_LINE_PATTERN.matcher(callStack);
+            if (matcher.find()) {
+                File path = new File(matcher.group("FILE").replace('/', File.separatorChar)); // NOI18N
+                File file;
+                if (path.isAbsolute()) {
+                    file = path;
+                } else {
+                    file = new File(projectDir, path.getPath());
+                    if (!file.isFile()) {
+                        return null;
+                    }
+                }
+                int[] lineColumn = {Integer.parseInt(matcher.group("LINE")), Integer.parseInt(matcher.group("COLUMN"))};
+                return Pair.of(file, lineColumn); // NOI18N
+            }
+            return null;
+        }
+
+    }
+
 }
