@@ -69,8 +69,8 @@ import org.netbeans.modules.javascript.karma.preferences.KarmaPreferences;
 import org.netbeans.modules.javascript.karma.preferences.KarmaPreferencesValidator;
 import org.netbeans.modules.javascript.karma.util.FileUtils;
 import org.netbeans.modules.javascript.karma.util.KarmaUtils;
-import org.netbeans.modules.javascript.karma.util.ValidationResult;
 import org.netbeans.modules.web.clientproject.api.jstesting.JsTestingProviders;
+import org.netbeans.modules.web.common.api.ValidationResult;
 import org.netbeans.spi.project.ui.CustomizerProvider2;
 import org.netbeans.spi.project.ui.support.NodeList;
 import org.openide.DialogDisplayer;
@@ -99,7 +99,6 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private final Project project;
     private final ChangeSupport changeSupport = new ChangeSupport(this);
-    private final PreferenceChangeListener preferenceChangeListener = WeakListeners.create(PreferenceChangeListener.class, this, KarmaPreferences.class);
 
 
     public KarmaChildrenList(Project project) {
@@ -132,12 +131,12 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     @Override
     public void addNotify() {
-        KarmaPreferences.addPreferenceChangeListener(project, preferenceChangeListener);
+        KarmaPreferences.addPreferenceChangeListener(project, WeakListeners.create(PreferenceChangeListener.class, this, KarmaPreferences.class));
     }
 
     @Override
     public void removeNotify() {
-        KarmaPreferences.removePreferenceChangeListener(project, preferenceChangeListener);
+        // noop
     }
 
     @Override
@@ -250,6 +249,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class StartKarmaServerAction extends BaseNodeAction {
 
+        public StartKarmaServerAction() {
+        }
+
         @Override
         protected void performAction(Project project) {
             KarmaServers.getInstance().startServer(project);
@@ -270,6 +272,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class StopKarmaServerAction extends BaseNodeAction {
 
+        public StopKarmaServerAction() {
+        }
+
         @Override
         protected void performAction(Project project) {
             KarmaServers.getInstance().stopServer(project, false);
@@ -290,6 +295,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class RestartKarmaServerAction extends BaseNodeAction {
 
+        public RestartKarmaServerAction() {
+        }
+
         @Override
         protected void performAction(Project project) {
             KarmaServers.getInstance().restartServer(project);
@@ -310,6 +318,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class DebugKarmaServerAction extends CallableSystemAction implements ContextAwareAction {
 
+        public DebugKarmaServerAction() {
+        }
+
         @NbBundle.Messages("DebugKarmaServerAction.name=Debug")
         @Override
         public String getName() {
@@ -368,6 +379,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class ActiveKarmaConfigAction extends CallableSystemAction implements ContextAwareAction {
 
+        public ActiveKarmaConfigAction() {
+        }
+
         @NbBundle.Messages("ActiveKarmaConfigAction.name=Set Configuration")
         @Override
         public String getName() {
@@ -462,6 +476,9 @@ public class KarmaChildrenList implements NodeList<Node>, PreferenceChangeListen
 
     private static final class CustomizeKarmaAction extends BaseNodeAction {
 
+        public CustomizeKarmaAction() {
+        }
+
         @Override
         protected void performAction(Project project) {
             project.getLookup().lookup(CustomizerProvider2.class).showCustomizer(JsTestingProviders.CUSTOMIZER_IDENT, null);
