@@ -41,6 +41,7 @@
  */
 package org.netbeans.modules.javascript2.editor;
 
+import java.io.IOException;
 import java.util.*;
 import java.util.concurrent.Callable;
 import java.util.logging.Level;
@@ -51,10 +52,20 @@ import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenId;
 import org.netbeans.api.lexer.TokenSequence;
+import org.netbeans.api.project.FileOwnerQuery;
+import org.netbeans.api.project.Project;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.modules.csl.api.*;
 import org.netbeans.modules.csl.spi.DefaultCompletionResult;
 import org.netbeans.modules.csl.spi.ParserResult;
+import org.netbeans.modules.csl.spi.support.CancelSupport;
+import org.netbeans.modules.css.indexing.api.CssIndex;
+import org.netbeans.modules.html.editor.lib.api.HtmlVersion;
+import org.netbeans.modules.html.editor.lib.api.model.HtmlModel;
+import org.netbeans.modules.html.editor.lib.api.model.HtmlModelFactory;
+import org.netbeans.modules.html.editor.lib.api.model.HtmlTag;
+import org.netbeans.modules.html.editor.lib.api.model.HtmlTagAttribute;
+import org.netbeans.modules.html.editor.lib.api.model.HtmlTagType;
 import org.netbeans.modules.javascript2.editor.spi.CompletionContext;
 import org.netbeans.modules.javascript2.editor.JsCompletionItem.CompletionRequest;
 import org.netbeans.modules.javascript2.editor.doc.JsDocumentationCodeCompletion;
@@ -81,6 +92,7 @@ import org.netbeans.modules.parsing.spi.Parser.Result;
 import org.netbeans.modules.parsing.spi.indexing.support.IndexResult;
 import org.netbeans.modules.parsing.spi.indexing.support.QuerySupport;
 import org.openide.filesystems.FileObject;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 
 /**
@@ -99,6 +111,10 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
 
     @Override
     public CodeCompletionResult complete(CodeCompletionContext ccContext) {
+        final CancelSupport cancelSupport = CancelSupport.getDefault();
+        if (cancelSupport.isCancelled()) {
+            return CodeCompletionResult.NONE;
+        }
         long start = System.currentTimeMillis();
         
         
@@ -128,10 +144,16 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
             request.result = jsParserResult;
             request.info = info;
             request.prefix = pref;
+            request.completionContext = context;
+            request.addHtmlTagAttributes = false;
+            request.cancelSupport = cancelSupport;
         
         jsParserResult.getModel().resolve();
         final List<CompletionProposal> resultList = new ArrayList<CompletionProposal>();
         HashMap<String, List<JsElement>> added = new HashMap<String, List<JsElement>>();
+        if (cancelSupport.isCancelled()) {
+            return CodeCompletionResult.NONE;
+        }
         if (ccContext.getQueryType() == QueryType.ALL_COMPLETION) {
             switch (context) {
                 case GLOBAL:
@@ -150,7 +172,7 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
                 default:
                     break;
             }
-            if (context == CompletionContext.EXPRESSION || context == CompletionContext.OBJECT_MEMBERS || context == CompletionContext.OBJECT_PROPERTY) {
+            if ((context == CompletionContext.EXPRESSION || context == CompletionContext.OBJECT_MEMBERS || context == CompletionContext.OBJECT_PROPERTY) && !request.prefix.isEmpty()) {
                 Collection<? extends IndexResult> indexResults = JsIndex.get(fileObject).query(JsIndex.FIELD_BASE_NAME, request.prefix, QuerySupport.Kind.PREFIX, JsIndex.TERMS_BASIC_INFO);
                 for (IndexResult indexResult : indexResults) {
                     IndexedElement indexElement = IndexedElement.create(indexResult);
@@ -172,10 +194,16 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
                     // create code completion results
                     JsCompletionItem.Factory.create(toAdd, request, resultList);
                     break;
+                case STRING_ELEMENTS_BY_ID:
+                    completeTagIds(request, resultList);
+                    break;
+                case STRING_ELEMENTS_BY_CLASS_NAME:
+                    completeCSSClassNames(request, resultList);
+                    break;
                 case GLOBAL:
                     HashMap<String, List<JsElement>> addedProperties = new HashMap<String, List<JsElement>>();
                     addedProperties.putAll(getDomCompletionResults(request));
-                    for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects()) {
+                    for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects(fileObject)) {
                         for (JsObject object : libGlobal.getProperties().values()) {
                             addPropertyToMap(request, addedProperties, object);
                         }
@@ -190,11 +218,14 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
                     completeInWith(request, addedProperties);
                     JsCompletionItem.Factory.create(addedProperties, request, resultList);
                     break;
+                case CALL_ARGUMENT:
+                    completeCallArguments(request, resultList);
                 case EXPRESSION:
                     completeKeywords(request, resultList);
                     completeExpression(request, added);
                     completeObjectProperty(request, added);
                     completeInWith(request, added);
+                    added.remove(ModelUtils.PROTOTYPE);
                     break;
                 case OBJECT_PROPERTY:
                     completeObjectProperty(request, added);
@@ -205,12 +236,16 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
                 case DOCUMENTATION:
                     JsDocumentationCodeCompletion.complete(request, resultList);
                     break;
+                case OBJECT_PROPERTY_NAME:
+                    completeObjectPropertyName(request, added);
                 default:
                     break;
             }
         }
         JsCompletionItem.Factory.create(added, request, resultList);
-        
+        if (request.addHtmlTagAttributes) {
+            completeTagAttributes(request, resultList);
+        }
         long end = System.currentTimeMillis();
         LOGGER.log(Level.FINE, "Counting JS CC took {0}ms ",  (end - start));
         for (CompletionProvider interceptor : EditorExtender.getDefault().getCompletionProviders()) {
@@ -311,6 +346,10 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
             return documentation != null ? Documentation.create(documentation) : null;
         }
         
+        if (element instanceof JsCompletionItem.SimpleDocElement) {
+            String documentation = ((JsCompletionItem.SimpleDocElement) element).getDocumentation();
+            return documentation != null ? Documentation.create(documentation) : null;
+        }
         if (OffsetRange.NONE.equals(element.getOffsetRange(info))) {
             return Documentation.create(NbBundle.getMessage(JsCodeCompletion.class, "MSG_ItemFromUsageDoc"));
         }
@@ -373,7 +412,9 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
             if (id == JsTokenId.IDENTIFIER || id.isKeyword()) {
                 prefix = token.text().toString();
                 if (upToOffset) {
-                    prefix = prefix.substring(0, offset - ts.offset());
+                    if (offset - ts.offset() >= 0) {
+                        prefix = prefix.substring(0, offset - ts.offset());
+                    }
                 }
             }
             if (id == JsTokenId.DOC_COMMENT) {
@@ -484,7 +525,7 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         }
         
         // from libraries
-        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects()) {
+        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects(fo)) {
             for (JsObject object : libGlobal.getProperties().values()) {
                 addPropertyToMap(request, addedItems, object);
             }
@@ -507,7 +548,9 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         List<String> expChain = ModelUtils.resolveExpressionChain(request.result.getSnapshot(), request.anchor, false);
         if (!expChain.isEmpty()) {
             Map<String, List<JsElement>> toAdd = getCompletionFromExpressionChain(request, expChain);
-            
+            if (request.cancelSupport.isCancelled()) {
+                return;
+            }
             FileObject fo = request.result.getSnapshot().getSource().getFileObject();
             if (fo != null) {
                 long start = System.currentTimeMillis();
@@ -528,9 +571,12 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         FileObject fo = request.info.getSnapshot().getSource().getFileObject();
         JsIndex jsIndex = JsIndex.get(fo);
         Collection<TypeUsage> resolveTypeFromExpression = new ArrayList<TypeUsage>();
-        resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(request.result.getModel(), jsIndex, expChain, request.anchor));
-
-        resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, request.result, true);
+        HashMap<String, List<JsElement>> addedProperties = new HashMap<String, List<JsElement>>();
+        resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(request.result.getModel(), jsIndex, expChain, request.anchor, true));
+        if (request.cancelSupport.isCancelled()) {
+            return addedProperties;
+        }
+        resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, request.result, true, true);
         
         // try to map window property
         Collection<String> windowProp = new ArrayList<String>();
@@ -552,10 +598,9 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         for (String string : prototypeChain) {
             resolveTypeFromExpression.add(new TypeUsageImpl(string));
         }
-        
-        
-
-        HashMap<String, List<JsElement>> addedProperties = new HashMap<String, List<JsElement>>();
+        if (request.cancelSupport.isCancelled()) {
+            return addedProperties;
+        }
         boolean isFunction = false; // addding Function to the prototype chain?
         List<JsObject> lastResolvedObjects = new ArrayList<JsObject>();
         for (TypeUsage typeUsage : resolveTypeFromExpression) {
@@ -587,8 +632,11 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
             addObjectPropertiesFromIndex("Function", jsIndex, request, addedProperties); //NOI18N
         }
 
+        if (request.cancelSupport.isCancelled()) {
+            return addedProperties;
+        }
         addObjectPropertiesFromIndex("Object", jsIndex, request, addedProperties); //NOI18N
-
+        
         if (isPublic) {
             // now look to the index again for declared item outside
             StringBuilder fqn = new StringBuilder();
@@ -609,6 +657,197 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         return addedProperties;
     }
     
+    private Identifier findNameOfFunctionCall (CompletionRequest request) {
+        // is an argument of a function call?
+        TokenHierarchy<?> th = request.result.getSnapshot().getTokenHierarchy();
+        if (th == null) {
+            return null;
+        }
+        TokenSequence<JsTokenId> ts = th.tokenSequence(JsTokenId.javascriptLanguage());
+        if (ts == null) {
+            return null;
+        }
+        
+        ts.move(request.anchor);
+        
+        if (!ts.moveNext() && !ts.movePrevious()){
+            return null;
+        }
+            
+        int curlyDeep = 0;
+        Token<? extends JsTokenId> token = ts.token();
+        JsTokenId tokenId = token.id();
+        while (ts.movePrevious() && tokenId != JsTokenId.BRACKET_LEFT_PAREN
+                && tokenId != JsTokenId.OPERATOR_SEMICOLON) {
+            if (tokenId == JsTokenId.BRACKET_LEFT_CURLY) {
+                curlyDeep++;
+            }
+            token = ts.token();
+            tokenId = token.id();
+        }
+        
+        
+        if (tokenId == JsTokenId.BRACKET_LEFT_PAREN) {
+            token = LexUtilities.findPreviousNonWsNonComment(ts);
+            if (token != null && token.id() == JsTokenId.IDENTIFIER) {
+                String functionName = token.text().toString();
+                return new IdentifierImpl(functionName, new OffsetRange(ts.offset(), ts.offset() + functionName.length()));
+            }
+        }
+        return null;
+    }
+    
+    private List<IndexedElement.FunctionIndexedElement> findFunctionInIndex(Identifier functionName, CompletionRequest request) {
+        List<IndexedElement.FunctionIndexedElement> result = new ArrayList<IndexedElement.FunctionIndexedElement>();
+        List<String> expChain = ModelUtils.resolveExpressionChain(request.result.getSnapshot(), functionName.getOffsetRange().getStart() - 1, false);
+        FileObject fo = request.info.getSnapshot().getSource().getFileObject();
+        if (fo != null) {
+            JsIndex jsIndex = JsIndex.get(fo);
+            if (expChain.isEmpty()) {
+                // global space
+                Collection<IndexedElement> globalVars = jsIndex.getGlobalVar(functionName.getName());
+                for (IndexedElement globalVar : globalVars) {
+                    if (globalVar.getName().equals(functionName) && globalVar.getJSKind().isFunction()) {
+                        result.add((IndexedElement.FunctionIndexedElement)globalVar);
+                    }
+                }
+            } else {
+                // the expression needs to be resolved
+                Collection<TypeUsage> types = ModelUtils.resolveTypeFromExpression(request.result.getModel(), jsIndex, expChain, request.anchor, false);
+                for (TypeUsage type : types) {
+                    Collection<IndexedElement> properties = jsIndex.getPropertiesWithPrefix(type.getType(), functionName.getName());
+                    properties.addAll(jsIndex.getPropertiesWithPrefix(type.getType() + "." + ModelUtils.PROTOTYPE, functionName.getName()));
+                    for (IndexedElement property : properties) {
+                        if (property.getName().equals(functionName.getName()) && property.getJSKind().isFunction()) {
+                            IndexedElement.FunctionIndexedElement function = (IndexedElement.FunctionIndexedElement)property;
+                            result.add(function);
+                        }
+                    }
+                }
+            }
+        }
+        return result;
+    }
+    
+    private List<TypeUsage> findPossibleCallArgTypes(CompletionRequest request) {
+        Identifier functionName = findNameOfFunctionCall(request);
+        if (functionName == null) {
+            // probably not in a call
+            return null;
+        }
+        List<TypeUsage> result = new ArrayList<TypeUsage>();
+        List<IndexedElement.FunctionIndexedElement> functions = findFunctionInIndex(functionName, request);
+        for (IndexedElement.FunctionIndexedElement function : functions) {
+            LinkedHashMap<String, Collection<String>> parameters = function.getParameters();
+            for (Collection<String> assignments: parameters.values()) {
+                if (!assignments.isEmpty()) {
+                    for (String assignment : assignments) {
+                        result.add(new TypeUsageImpl(assignment));
+                    }
+                }
+            }
+        }
+        return result;
+    }
+    
+    private void completeObjectPropertyName(CompletionRequest request, Map<String, List<JsElement>> addedItems) {
+        // is an argument of the function call?
+        TokenHierarchy<?> th = request.result.getSnapshot().getTokenHierarchy();
+        if (th == null) {
+            return;
+        }
+        TokenSequence<JsTokenId> ts = th.tokenSequence(JsTokenId.javascriptLanguage());
+        if (ts == null) {
+            return;
+        }
+        
+        ts.move(request.anchor);
+        
+        if (!ts.moveNext() && !ts.movePrevious()){
+            return;
+        }
+            
+        int curlyDeep = 0;
+        Token<? extends JsTokenId> token = ts.token();
+        JsTokenId tokenId = token.id();
+        while (ts.movePrevious() && tokenId != JsTokenId.BRACKET_LEFT_PAREN
+                && tokenId != JsTokenId.OPERATOR_SEMICOLON) {
+            if (tokenId == JsTokenId.BRACKET_LEFT_CURLY) {
+                curlyDeep++;
+            }
+            token = ts.token();
+            tokenId = token.id();
+        }
+        
+        // what is the function?
+        if (curlyDeep == 1 && tokenId == JsTokenId.BRACKET_LEFT_PAREN) {
+            token = LexUtilities.findPreviousNonWsNonComment(ts);
+            if (token != null && token.id() == JsTokenId.IDENTIFIER) {
+                String functionName = token.text().toString();
+                List<String> expChain = ModelUtils.resolveExpressionChain(request.result.getSnapshot(), ts.offset() - 1, false);
+                List<TypeUsage> possibleTypes = new ArrayList<TypeUsage>();
+                FileObject fo = request.info.getSnapshot().getSource().getFileObject();
+                JsIndex jsIndex = JsIndex.get(fo);
+                if (expChain.isEmpty()) {
+                    // global space
+                    Collection<? extends JsObject> variables = ModelUtils.getVariables(request.result.getModel(), request.anchor);
+                    for (JsObject variable : variables) {
+                        if (variable.getName().equals(functionName) && variable.getJSKind().isFunction()) {
+                            // do we now the tape of the argument?
+                            JsFunction function = (JsFunction)variable;
+                            Collection<? extends JsObject> parameters = function.getParameters();
+                            for (JsObject parameter: parameters) {
+                                if (!parameter.getAssignments().isEmpty()) {
+                                    possibleTypes.addAll(parameter.getAssignments());
+                                }
+                            }
+                            break;
+                        }
+                    }
+                    Collection<IndexedElement> globalVars = jsIndex.getGlobalVar(functionName);
+                    for (IndexedElement globalVar : globalVars) {
+                        if (globalVar.getName().equals(functionName) && globalVar.getJSKind().isFunction()) {
+                            IndexedElement.FunctionIndexedElement function = (IndexedElement.FunctionIndexedElement)globalVar;
+                            LinkedHashMap<String, Collection<String>> parameters = function.getParameters();
+                            for (Collection<String> assignments: parameters.values()) {
+                                if (!assignments.isEmpty()) {
+                                    for (String type : assignments) {
+                                        possibleTypes.add(new TypeUsageImpl(type));
+                                    }
+                                }
+                            }
+                        }
+                    }
+                } else {
+                    Collection<TypeUsage> types = ModelUtils.resolveTypeFromExpression(request.result.getModel(), jsIndex, expChain, request.anchor, false);
+                    for (TypeUsage type : types) {
+                        Collection<IndexedElement> properties = jsIndex.getPropertiesWithPrefix(type.getType(), functionName);
+                        properties.addAll(jsIndex.getPropertiesWithPrefix(type.getType() + "." + ModelUtils.PROTOTYPE, functionName));
+                        for (IndexedElement property : properties) {
+                            if (property.getName().equals(functionName) && property.getJSKind().isFunction()) {
+                                IndexedElement.FunctionIndexedElement function = (IndexedElement.FunctionIndexedElement)property;
+                                LinkedHashMap<String, Collection<String>> parameters = function.getParameters();
+                                for (Collection<String> assignments: parameters.values()) {
+                                    if (!assignments.isEmpty()) {
+                                        for (String assignment : assignments) {
+                                            possibleTypes.add(new TypeUsageImpl(assignment));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+                }
+                if (!possibleTypes.isEmpty()) {
+                    for (TypeUsage type : possibleTypes) {
+                        addObjectPropertiesFromIndex(type.getType(), jsIndex, request, addedItems);
+                    }
+                }
+            }
+        }
+        
+    }
+    
     private List<String> resolveExpressionChainFromString(CompletionRequest request) {
         TokenHierarchy<?> th = request.info.getSnapshot().getTokenHierarchy();
         TokenSequence<? extends JsTokenId> ts = LexUtilities.getJsTokenSequence(th, request.anchor);
@@ -826,7 +1065,7 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         if (jsObject.getJSKind() == JsElement.Kind.OBJECT || jsObject.getJSKind() == JsElement.Kind.CONSTRUCTOR
                 || jsObject.getJSKind() == JsElement.Kind.OBJECT_LITERAL) {
             for (JsObject property : jsObject.getProperties().values()) {
-                if(!property.getModifiers().contains(Modifier.PRIVATE) && !property.isAnonymous()) {
+                if(!(request.completionContext == OBJECT_MEMBERS && property.getModifiers().contains(Modifier.PRIVATE) && property.getModifiers().size() == 1) && !property.isAnonymous()) {
                     addPropertyToMap(request, properties, property);
                 }
             }
@@ -847,7 +1086,7 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         if (!typesFromWith.isEmpty()) {
             FileObject fo = request.info.getSnapshot().getSource().getFileObject();
             JsIndex jsIndex = JsIndex.get(fo);
-            Collection<TypeUsage> resolveTypes = ModelUtils.resolveTypes(typesFromWith, request.result, true);
+            Collection<TypeUsage> resolveTypes = ModelUtils.resolveTypes(typesFromWith, request.result, true, true);
             for (TypeUsage type : resolveTypes) {
                 JsObject localObject = ModelUtils.findJsObjectByName(request.result.getModel(), type.getType());
                 if (localObject != null) {
@@ -859,6 +1098,24 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         }
     }
     
+    private void completeCallArguments(CompletionRequest request, List<CompletionProposal> resultList) {
+        // find (if exist) the function which is called.
+        List<TypeUsage> types = findPossibleCallArgTypes(request);
+        FileObject fo = request.result.getSnapshot().getSource().getFileObject();
+        if (types != null && fo != null && !types.isEmpty()) {
+            JsIndex jsIndex = JsIndex.get(fo);
+            for (TypeUsage type: types) {
+                Collection<? extends IndexResult> fromIndex = jsIndex.findByFqn(type.getType(), JsIndex.TERMS_BASIC_INFO);
+                for (IndexResult indexResult: fromIndex) {
+                    IndexedElement indexElement = IndexedElement.create(indexResult);
+                    if (indexElement.getJSKind() == JsElement.Kind.CALLBACK) {
+                        resultList.add(new JsCompletionItem.JsCallbackCompletionItem((IndexedElement.FunctionIndexedElement)indexElement, request));
+                    }
+                }
+            }
+        }
+    }
+    
     private void completeKeywords(CompletionRequest request, List<CompletionProposal> resultList) {
         for (String keyword : JsKeyWords.KEYWORDS.keySet()) {
             if (startsWith(keyword, request.prefix)) {
@@ -867,6 +1124,71 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         }
     }
     
+    private void completeTagAttributes(CompletionRequest request,  List<CompletionProposal> resultList) {
+        
+        for(HtmlTagAttribute attribute: getAllAttributes())  {
+            if (attribute.getName().startsWith(request.prefix)) {
+                resultList.add(new JsCompletionItem.JsHtmlAttributeItem(attribute, request));
+            }
+        }
+    }
+    
+    private void completeTagIds(CompletionRequest request, List<CompletionProposal> resultList) {
+        FileObject fo = request.result.getSnapshot().getSource().getFileObject();
+        if (fo == null) {
+            return;
+        }
+        Project project = FileOwnerQuery.getOwner(fo);
+        HashSet<String> unique = new HashSet<String>();
+        try {
+            CssIndex cssIndex = CssIndex.create(project);
+            Map<FileObject, Collection<String>> findIdsByPrefix = cssIndex.findIdsByPrefix(request.prefix);
+
+            for (Collection<String> ids : findIdsByPrefix.values()) {
+                for (String id : ids) {
+                    if (!id.isEmpty()) {
+                        unique.add(id);
+                    }
+                }
+            }
+        } catch (IOException ex) {
+            Exceptions.printStackTrace(ex);
+        }
+        if (!unique.isEmpty()) {
+            for (Iterator<String> iterator = unique.iterator(); iterator.hasNext();) {
+                resultList.add(new JsCompletionItem.CssCompletionItem(iterator.next(), request));
+            }
+        }
+    }
+    
+    private void completeCSSClassNames(CompletionRequest request, List<CompletionProposal> resultList) {
+        FileObject fo = request.result.getSnapshot().getSource().getFileObject();
+        if(fo == null) {
+            return;
+        }
+        Project project = FileOwnerQuery.getOwner(fo);
+        HashSet<String> unique = new HashSet<String>();
+        try {
+            CssIndex cssIndex = CssIndex.create(project);
+            Map<FileObject, Collection<String>> findIdsByPrefix = cssIndex.findClassesByPrefix(request.prefix);
+
+            for (Collection<String> ids : findIdsByPrefix.values()) {
+                for (String id : ids) {
+                    if (!id.isEmpty()) {
+                        unique.add(id);
+                    }
+                }
+            }
+        } catch (IOException ex) {
+            Exceptions.printStackTrace(ex);
+        }
+        if (!unique.isEmpty()) {
+            for (Iterator<String> iterator = unique.iterator(); iterator.hasNext();) {
+                resultList.add(new JsCompletionItem.CssCompletionItem(iterator.next(), request));
+            }
+        }
+    }
+    
     private boolean startsWith(String theString, String prefix) {
         if (prefix == null || prefix.length() == 0) {
             return true;
@@ -887,7 +1209,7 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
             lastResolvedObjects.add(jsObject);
         }
 
-        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects()) {
+        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects(request.result.getSnapshot().getSource().getFileObject())) {
             JsObject found = ModelUtils.findJsObjectByName(libGlobal, type.getType());
             if (found != null && found != libGlobal) {
                 jsObject = found;
@@ -938,57 +1260,65 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
     
     private void addObjectPropertiesFromIndex(String fqn, JsIndex jsIndex, CompletionRequest request, Map<String, List<JsElement>> addedProperties) {
         Collection<IndexedElement> properties = jsIndex.getProperties(fqn);
-        String prototypeFQN = null;
         for (IndexedElement indexedElement : properties) {
             addPropertyToMap(request, addedProperties, indexedElement);
             if (ModelUtils.PROTOTYPE.equals(indexedElement.getName())) {
-                prototypeFQN = indexedElement.getFQN();
+                Collection<IndexedElement> protoProperties = jsIndex.getProperties(indexedElement.getFQN());
+                for (IndexedElement protoProperty : protoProperties) {
+                    addPropertyToMap(request, addedProperties, protoProperty);
+                }
             }
         }
-        if (prototypeFQN != null) {
-            properties = jsIndex.getProperties(prototypeFQN);
-            for (IndexedElement indexedElement : properties) {
-                addPropertyToMap(request, addedProperties, indexedElement);
-            }
+        if (fqn.equals("Element")) {
+            request.addHtmlTagAttributes = true;
         }
     }
     
     private void addPropertyToMap(CompletionRequest request, Map<String, List<JsElement>> addedProperties, JsElement property) {    
         String name = property.getName();
-        if (startsWith(name, request.prefix) && !(ModelUtils.getDisplayName(property.getName()).isEmpty())) {
+        if (startsWith(name, request.prefix) && !(ModelUtils.getDisplayName(property.getName()).isEmpty())
+                && property.getJSKind() != JsElement.Kind.CALLBACK) {
             if (!(name.equals(request.prefix) && !property.isDeclared() && request.anchor == property.getOffset())) { // don't include just the prefix
                 List<JsElement> elements = addedProperties.get(name);
-                if (elements == null || elements.isEmpty()) {
-                    List<JsElement> properties = new ArrayList<JsElement>(1);
-                    properties.add(property);
-                    addedProperties.put(name, properties);
-                } else {
-                    if (!ModelUtils.PROTOTYPE.equals(name) && property.isDeclared()) {
-                        boolean addAsNew = true;
-                        if (!elements.isEmpty()) {
-                            for (int i = 0; i < elements.size(); i++) {
-                                JsElement element = elements.get(i);
-                                FileObject fo = element.getFileObject();
-                                if (!element.isDeclared() || (fo != null && fo.equals(property.getFileObject()))) {
-                                    if (!element.isDeclared() || (element.getOffsetRange() == OffsetRange.NONE && property.getOffsetRange() != OffsetRange.NONE)) {
-                                        elements.remove(i);
-                                        elements.add(property);
-                                        addAsNew = false;
-                                        break;
-                                    } else if (fo != null && fo.equals(property.getFileObject())) {
+                if (!ModelUtils.PROTOTYPE.equals(name)) {
+                    if (elements == null || elements.isEmpty()) {
+                        List<JsElement> properties = new ArrayList<JsElement>(1);
+                        properties.add(property);
+                        addedProperties.put(name, properties);
+                    } else {
+                        if (property.isDeclared()) {
+                            boolean addAsNew = true;
+                            if (!elements.isEmpty()) {
+                                for (int i = 0; i < elements.size(); i++) {
+                                    JsElement element = elements.get(i);
+                                    FileObject fo = element.getFileObject();
+                                    if (!element.isDeclared() || (fo != null && fo.equals(property.getFileObject()))) {
+                                        if (!element.isDeclared() || (element.getOffsetRange() == OffsetRange.NONE && property.getOffsetRange() != OffsetRange.NONE)) {
+                                            elements.remove(i);
+                                            elements.add(property);
+                                            addAsNew = false;
+                                            break;
+                                        } else if (fo != null && fo.equals(property.getFileObject())) {
+                                            addAsNew = false;
+                                            break;
+                                        }
+                                    } else if (element.isPlatform() && property.isPlatform()) {
                                         addAsNew = false;
                                         break;
                                     }
-                                } else if (element.isPlatform() && property.isPlatform()) {
-                                    addAsNew = false;
-                                    break;
                                 }
                             }
+                            if (addAsNew) {
+                                // expect that all items are declaration -> so just add the next declaraiton
+                                elements.add(property);
+                            }
                         }
-                        if (addAsNew) {
-                            // expect that all items are declaration -> so just add the next declaraiton
-                            elements.add(property);
-                        }
+                    }
+                } else {
+                    if (elements == null && property.isPlatform()) {
+                        List<JsElement> properties = new ArrayList<JsElement>(1);
+                        properties.add(property);
+                        addedProperties.put(name, properties);
                     }
                 }
             }
@@ -1016,5 +1346,21 @@ class JsCodeCompletion implements CodeCompletionHandler2 {
         int slashIndex = prefix.lastIndexOf('/') + 1; //NOI18N
         return (Math.max(0, Math.max(hashIndex, Math.max(dotIndex, Math.max(parenIndex,Math.max(columnIndex, Math.max(bracketIndex, Math.max(spaceIndex, slashIndex))))))));
     }
+    
+    
+    private Collection<HtmlTagAttribute> getAllAttributes() {
+        HtmlModel htmlModel = HtmlModelFactory.getModel(HtmlVersion.HTML5);
+        Map<String, HtmlTagAttribute> result = new HashMap<String, HtmlTagAttribute>();
+        for (HtmlTag htmlTag : htmlModel.getAllTags()) {
+            for (HtmlTagAttribute htmlTagAttribute : htmlTag.getAttributes()) {
+                // attributes can probably differ per tag so we can just offer some of them,
+                // at least for the CC purposes it should be complete list of attributes for unknown tag
+                if (!result.containsKey(htmlTagAttribute.getName())) {
+                    result.put(htmlTagAttribute.getName(), htmlTagAttribute);
+                }
+            }
+        }
+        return result.values();
+    }
 
 }
