@@ -41,7 +41,9 @@
  */
 package org.netbeans.modules.javascript2.editor;
 
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -54,10 +56,11 @@ import org.netbeans.modules.csl.api.ColoringAttributes;
 import org.netbeans.modules.csl.api.Modifier;
 import org.netbeans.modules.csl.api.OffsetRange;
 import org.netbeans.modules.csl.api.SemanticAnalyzer;
-import org.netbeans.modules.csl.spi.ParserResult;
 import org.netbeans.modules.javascript2.editor.doc.spi.JsComment;
 import org.netbeans.modules.javascript2.editor.api.lexer.JsTokenId;
 import org.netbeans.modules.javascript2.editor.api.lexer.LexUtilities;
+import org.netbeans.modules.javascript2.editor.hints.JSHintSupport;
+import org.netbeans.modules.javascript2.editor.model.Identifier;
 import org.netbeans.modules.javascript2.editor.model.JsFunction;
 import org.netbeans.modules.javascript2.editor.model.JsObject;
 import org.netbeans.modules.javascript2.editor.model.Model;
@@ -78,11 +81,15 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
     //public static final EnumSet<ColoringAttributes> UNUSED_VARIABLE_SET = EnumSet.of(ColoringAttributes.UNUSED, ColoringAttributes.VA);
     public static final EnumSet<ColoringAttributes> UNUSED_OBJECT_SET = EnumSet.of( ColoringAttributes.UNUSED,  ColoringAttributes.CLASS);
     public static final EnumSet<ColoringAttributes> UNUSED_METHOD_SET = EnumSet.of( ColoringAttributes.UNUSED,  ColoringAttributes.METHOD);
+    public static final EnumSet<ColoringAttributes> LOCAL_VARIABLE_DECLARATION = EnumSet.of(ColoringAttributes.LOCAL_VARIABLE_DECLARATION);
+    public static final EnumSet<ColoringAttributes> LOCAL_VARIABLE_DECLARATION_UNUSED = EnumSet.of(ColoringAttributes.LOCAL_VARIABLE_DECLARATION, ColoringAttributes.UNUSED);
+    public static final EnumSet<ColoringAttributes> LOCAL_VARIABLE_USE = EnumSet.of(ColoringAttributes.LOCAL_VARIABLE);
     
     private boolean cancelled;
     private Map<OffsetRange, Set<ColoringAttributes>> semanticHighlights;
-    private static final List<String> GLOBAL_TYPES = Arrays.asList(Type.ARRAY, Type.STRING, Type.BOOLEAN, Type.NUMBER, Type.UNDEFINED);
-
+    private static final List<String> GLOBAL_TYPES = Arrays.asList(Type.ARRAY, Type.STRING, Type.BOOLEAN, Type.NUMBER);
+    private Collection<OffsetRange> globalJsHintInlines = new ArrayList<OffsetRange>();
+    
     public JsSemanticAnalyzer() {
         this.cancelled = false;
         this.semanticHighlights = null;
@@ -105,8 +112,11 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                 new HashMap<OffsetRange, Set<ColoringAttributes>>(100);
         Model model = result.getModel();
         JsObject global = model.getGlobalObject();
-
-        highlights = count(result, global, highlights);
+        Collection<Identifier> definedGlobal = JSHintSupport.getDefinedGlobal(result.getSnapshot(), -1);
+        for (Identifier iden: definedGlobal) {
+            globalJsHintInlines.add(iden.getOffsetRange());
+        }
+        highlights = count(result, global, highlights, new ArrayList<String>());
 
         if (highlights != null && highlights.size() > 0) {
             semanticHighlights = highlights;
@@ -115,8 +125,10 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
         }
     }
 
-    private Map<OffsetRange, Set<ColoringAttributes>> count (JsParserResult result, JsObject parent, Map<OffsetRange, Set<ColoringAttributes>> highlights) {
-
+    private Map<OffsetRange, Set<ColoringAttributes>> count (JsParserResult result, JsObject parent, Map<OffsetRange, Set<ColoringAttributes>> highlights, List<String> processedObjects) {
+        if (ModelUtils.wasProcessed(parent, processedObjects)) {
+            return highlights;
+        }
         for (Iterator<? extends JsObject> it = parent.getProperties().values().iterator(); it.hasNext();) {
             JsObject object = it.next();
             if (object.getDeclarationName() != null) {
@@ -141,7 +153,7 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                         }
                         for(JsObject param: ((JsFunction)object).getParameters()) {
                             if (!(object instanceof JsObjectReference && !((JsObjectReference)object).getOriginal().isAnonymous())) {
-                                count(result, param, highlights);
+                                count(result, param, highlights, processedObjects);
                             }
                             if (!hasSourceOccurences(result, param)) {
                                 OffsetRange range = LexUtilities.getLexerOffsets(result, param.getDeclarationName().getOffsetRange());
@@ -170,12 +182,10 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                     case OBJECT:
                     case OBJECT_LITERAL:
                         if(!"UNKNOWN".equals(object.getName())) {
-                            if (parent.getParent() == null && !GLOBAL_TYPES.contains(object.getName())) {
-                                addColoring(result, highlights, object.getDeclarationName().getOffsetRange(), ColoringAttributes.GLOBAL_SET);
+                             if (parent.getParent() == null && !GLOBAL_TYPES.contains(object.getName())) {
+                                addColoring(result, highlights, object.getDeclarationName().getOffsetRange(), ColoringAttributes.GLOBAL_SET); 
                                 for (Occurrence occurence : object.getOccurrences()) {
-                                    if (!isCommentOccurence(result, occurence)) {
-                                        addColoring(result, highlights, occurence.getOffsetRange(), ColoringAttributes.GLOBAL_SET);
-                                    }
+                                    addColoring(result, highlights, occurence.getOffsetRange(), ColoringAttributes.GLOBAL_SET);
                                 }
                             } else if (object.isDeclared() && !ModelUtils.PROTOTYPE.equals(object.getName()) && !object.isAnonymous()) {
                                 if((object.getOccurrences().isEmpty()
@@ -196,30 +206,19 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                         }
                         break;
                     case PROPERTY:
-                        if(object.isDeclared()) {
-                            highlights.put(LexUtilities.getLexerOffsets(result, object.getDeclarationName().getOffsetRange()), ColoringAttributes.FIELD_SET);
-                            for(Occurrence occurence: object.getOccurrences()) {
-                                if (!isCommentOccurence(result, occurence)) {
-                                    highlights.put(LexUtilities.getLexerOffsets(result, occurence.getOffsetRange()), ColoringAttributes.FIELD_SET);
-                                }
-                            }
-                        }
-                        break;
                     case FIELD:
-                        highlights.put(object.getDeclarationName().getOffsetRange(), ColoringAttributes.FIELD_SET);
-                        for (Occurrence occurence : object.getOccurrences()) {
-                            if (!isCommentOccurence(result, occurence)) {
-                                highlights.put(LexUtilities.getLexerOffsets(result, occurence.getOffsetRange()), ColoringAttributes.FIELD_SET);
+                        if(object.isDeclared()) {
+                            addColoring(result, highlights, object.getDeclarationName().getOffsetRange(), ColoringAttributes.FIELD_SET);
+                            for(Occurrence occurence: object.getOccurrences()) {
+                                addColoring(result, highlights, occurence.getOffsetRange(), ColoringAttributes.FIELD_SET);
                             }
                         }
                         break;
                     case VARIABLE:
                         if (parent.getParent() == null && !GLOBAL_TYPES.contains(object.getName())) {
-                            highlights.put(LexUtilities.getLexerOffsets(result, object.getDeclarationName().getOffsetRange()), ColoringAttributes.GLOBAL_SET);
+                            addColoring(result, highlights, object.getDeclarationName().getOffsetRange(), ColoringAttributes.GLOBAL_SET);
                             for(Occurrence occurence: object.getOccurrences()) {
-                                if (!isCommentOccurence(result, occurence)) {
-                                    highlights.put(LexUtilities.getLexerOffsets(result, occurence.getOffsetRange()), ColoringAttributes.GLOBAL_SET);
-                                }
+                                addColoring(result, highlights, occurence.getOffsetRange(), ColoringAttributes.GLOBAL_SET);
                             }
                         } else {
                             if ((object.getOccurrences().isEmpty()
@@ -228,7 +227,11 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                                 OffsetRange range = object.getDeclarationName().getOffsetRange();
                                 if (range.getStart() < range.getEnd()) {
                                     // some virtual variables (like arguments) doesn't have to be declared, but are in the model
-                                    highlights.put(LexUtilities.getLexerOffsets(result, object.getDeclarationName().getOffsetRange()), ColoringAttributes.UNUSED_SET);
+                                    if (object.getModifiers().contains(Modifier.PRIVATE) || object.getModifiers().contains(Modifier.PROTECTED)) { 
+                                        highlights.put(LexUtilities.getLexerOffsets(result, object.getDeclarationName().getOffsetRange()), LOCAL_VARIABLE_DECLARATION_UNUSED);
+                                    } else {
+                                        highlights.put(LexUtilities.getLexerOffsets(result, object.getDeclarationName().getOffsetRange()), ColoringAttributes.UNUSED_SET);
+                                    }
                                 }
                             } else if (object instanceof JsObjectImpl && !ModelUtils.ARGUMENTS.equals(object.getName())) {   // NOI18N
                                 if (object.getOccurrences().size() <= ((JsObjectImpl)object).getCountOfAssignments()) {
@@ -241,6 +244,14 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                                             highlights.put(LexUtilities.getLexerOffsets(result, occurence.getOffsetRange()), ColoringAttributes.UNUSED_SET);
                                         }
                                     }
+                                } else if (object.getModifiers().contains(Modifier.PRIVATE) || object.getModifiers().contains(Modifier.PROTECTED)) {
+                                    OffsetRange decOffset = object.getDeclarationName().getOffsetRange();
+                                    addColoring(result, highlights, decOffset, LOCAL_VARIABLE_DECLARATION);
+                                    for(Occurrence occurence: object.getOccurrences()) {
+                                        if (occurence.getOffsetRange().getLength() > 0 && !occurence.getOffsetRange().equals(decOffset)) {
+                                            addColoring(result, highlights, occurence.getOffsetRange(), LOCAL_VARIABLE_USE);
+                                        }
+                                    }
                                 }
                             }
                         }
@@ -251,17 +262,17 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
                 break;
             }
             if (!(object instanceof JsObjectReference && ModelUtils.isDescendant(object, ((JsObjectReference)object).getOriginal()))) {
-                highlights = count(result, object, highlights);
+                highlights = count(result, object, highlights, processedObjects);
             }
         }
 
         return highlights;
     }
 
-    private void addColoring(ParserResult result, Map<OffsetRange, Set<ColoringAttributes>> highlights, OffsetRange astRange, Set<ColoringAttributes> coloring) {
+    private void addColoring(JsParserResult result, Map<OffsetRange, Set<ColoringAttributes>> highlights, OffsetRange astRange, Set<ColoringAttributes> coloring) {
         int start = result.getSnapshot().getOriginalOffset(astRange.getStart());
         int end = result.getSnapshot().getOriginalOffset(astRange.getEnd());
-        if (start > -1 && end > -1 && start < end) {
+        if (start > -1 && end > -1 && start < end && !isInComment(result, astRange)) {
             OffsetRange range = start == astRange.getStart() ? astRange : new OffsetRange(start, end);
             highlights.put(range, coloring);
         }
@@ -300,7 +311,7 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
 
         int sourceOccurenceCount = 0;
         for (Occurrence occurrence : param.getOccurrences()) {
-            if (!isCommentOccurence(result, occurrence)) {
+            if (!isInComment(result, occurrence.getOffsetRange())) {
                  sourceOccurenceCount++;
             }
             if (sourceOccurenceCount > 1) {
@@ -310,13 +321,15 @@ public class JsSemanticAnalyzer extends SemanticAnalyzer<JsParserResult> {
         return false;
     }
 
-    private static boolean isCommentOccurence(JsParserResult result, Occurrence occurence) {
-        // Comment blocks are cached by holders so this is faster than calls to token sequences.
+    private boolean isInComment(JsParserResult result, OffsetRange range) {
         for (JsComment comment : result.getDocumentationHolder().getCommentBlocks().values()) {
-            if (comment.getOffsetRange().containsInclusive(occurence.getOffsetRange().getStart())) {
+            if (comment.getOffsetRange().containsInclusive(range.getStart())) {
                 return true;
             }
         }
+        if (globalJsHintInlines.contains(range)) {
+            return true;
+        }
         return false;
     }
 
