@@ -124,6 +124,7 @@ public class IndexedElement implements JsElement {
     protected static IndexDocument createDocument(JsObject object, String fqn, IndexingSupport support, Indexable indexable) {
         IndexDocument elementDocument = support.createDocument(indexable);
         elementDocument.addPair(JsIndex.FIELD_BASE_NAME, object.getName(), true, true);
+        elementDocument.addPair(JsIndex.FIELD_BASE_NAME_INSENSITIVE, object.getName().toLowerCase(), true, false);
         elementDocument.addPair(JsIndex.FIELD_FQ_NAME,  fqn + (object.isAnonymous() ? ANONYMOUS_POSFIX 
                 : object.getJSKind() == Kind.PARAMETER ? PARAMETER_POSTFIX : OBJECT_POSFIX), true, true);
 //        boolean isGlobal = object.getParent() != null ? ModelUtils.isGlobal(object.getParent()) : ModelUtils.isGlobal(object);
@@ -182,6 +183,7 @@ public class IndexedElement implements JsElement {
     protected static IndexDocument createDocumentForReference(JsObjectReference object, String fqn, IndexingSupport support, Indexable indexable) {
         IndexDocument elementDocument = support.createDocument(indexable);
         elementDocument.addPair(JsIndex.FIELD_BASE_NAME, object.getName(), true, true);
+        elementDocument.addPair(JsIndex.FIELD_BASE_NAME_INSENSITIVE, object.getName(), true, false);
         elementDocument.addPair(JsIndex.FIELD_FQ_NAME,  fqn + (object.isAnonymous() ? ANONYMOUS_POSFIX 
                 : object.getJSKind() == Kind.PARAMETER ? PARAMETER_POSTFIX : OBJECT_POSFIX), true, true);
         elementDocument.addPair(JsIndex.FIELD_OFFSET, Integer.toString(object.getOffset()), true, true);            
@@ -500,6 +502,7 @@ public class IndexedElement implements JsElement {
         private static final int PARAMETER = 1 << 17;
         private static final int PROPERTY_GETTER = 1 << 18;
         private static final int PROPERTY_SETTER = 1 << 19;
+        private static final int CALLBACK = 1 << 22;
 
         private static final int PLATFORM = 1 << 20;
 
@@ -534,6 +537,7 @@ public class IndexedElement implements JsElement {
             if (kind == JsElement.Kind.PROPERTY_SETTER) value = value | PROPERTY_SETTER;
             if (kind == JsElement.Kind.VARIABLE) value = value | VARIABLE;
             if (kind == JsElement.Kind.OBJECT_LITERAL) value = value | OBJECT_LITERAL;
+            if (kind == JsElement.Kind.CALLBACK) value = value | CALLBACK;
 
             if (object.isPlatform()) value = value | PLATFORM;
 
@@ -581,6 +585,7 @@ public class IndexedElement implements JsElement {
             else if ((flag & PROPERTY_SETTER) != 0) result = JsElement.Kind.PROPERTY_SETTER;
             else if ((flag & VARIABLE) != 0) result = JsElement.Kind.VARIABLE;
             else if ((flag & OBJECT_LITERAL) != 0) result = JsElement.Kind.OBJECT_LITERAL;
+            else if ((flag & CALLBACK) != 0) result = JsElement.Kind.CALLBACK;
             return result;
         }
     }
