@@ -55,7 +55,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.WeakHashMap;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import java.util.logging.Level;
@@ -76,6 +75,10 @@ import org.openide.filesystems.FileObject;
 public class JsIndex {
 
     public static final String FIELD_BASE_NAME = "bn"; //NOI18N
+    /**
+     * The same as FIELD_BASE_NAME, but case insensitive. 
+     */
+    public static final String FIELD_BASE_NAME_INSENSITIVE = "bni"; // NOI18N
     /**
      * In this field is in the lucene also coded, whether the object is anonymous (last char is 'A')
      * or normal object (last char is 'O'). If someone needs to access this field
@@ -134,8 +137,6 @@ public class JsIndex {
         }
     };
 
-    private static final AtomicBoolean INDEX_CHANGED = new AtomicBoolean(true);
-
     private static final Map<StatsKey, StatsValue> QUERY_STATS = new HashMap<StatsKey, StatsValue>();
 
     /* GuardedBy(QUERY_STATS) */
@@ -160,7 +161,15 @@ public class JsIndex {
     }
 
     public static void changeInIndex() {
-        INDEX_CHANGED.set(true);
+        WRITE_LOCK.lock();
+        try {
+            CACHE_INDEX_RESULT_SMALL.clear();
+            CACHE_INDEX_RESULT_LARGE.clear();
+            INDEX_CACHE.clear();
+            LOG.log(Level.FINEST, "Cache cleared");
+        } finally {
+            WRITE_LOCK.unlock();
+        }
     }
 
     public static JsIndex get(FileObject fo) {
@@ -181,18 +190,7 @@ public class JsIndex {
         }
 
         try {
-            if (INDEX_CHANGED.get()) {
-                WRITE_LOCK.lock();
-                try {
-                    CACHE_INDEX_RESULT_SMALL.clear();
-                    CACHE_INDEX_RESULT_LARGE.clear();
-                    LOG.log(Level.FINEST, "Cache cleared");
-                } finally {
-                    WRITE_LOCK.unlock();
-                }
-                INDEX_CHANGED.set(false);
-            }
-
+            
             CacheKey key = new CacheKey(this, fieldName, fieldValue, kind);
             CacheValue value = getCachedValue(key, fieldsToLoad);
 
