@@ -54,6 +54,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.EnumSet;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -71,6 +72,7 @@ import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.modules.csl.api.Documentation;
 import org.netbeans.modules.csl.api.Modifier;
 import org.netbeans.modules.csl.api.OffsetRange;
+import org.netbeans.modules.csl.spi.ParserResult;
 import org.netbeans.modules.javascript2.editor.api.lexer.JsTokenId;
 import org.netbeans.modules.javascript2.editor.api.lexer.LexUtilities;
 import org.netbeans.modules.javascript2.editor.doc.spi.JsDocumentationHolder;
@@ -82,6 +84,7 @@ import org.netbeans.modules.javascript2.editor.model.impl.JsFunctionImpl;
 import org.netbeans.modules.javascript2.editor.model.impl.JsFunctionReference;
 import org.netbeans.modules.javascript2.editor.model.impl.JsObjectImpl;
 import org.netbeans.modules.javascript2.editor.model.impl.JsWithObjectImpl;
+import org.netbeans.modules.javascript2.editor.model.impl.ModelExtender;
 import org.netbeans.modules.javascript2.editor.model.impl.ModelUtils;
 import org.netbeans.modules.javascript2.editor.model.impl.ModelVisitor;
 import org.netbeans.modules.javascript2.editor.model.impl.OccurrenceBuilder;
@@ -89,6 +92,7 @@ import org.netbeans.modules.javascript2.editor.model.impl.ParameterObject;
 import org.netbeans.modules.javascript2.editor.model.impl.TypeUsageImpl;
 import org.netbeans.modules.javascript2.editor.spi.model.ModelElementFactory;
 import org.netbeans.modules.javascript2.editor.parser.JsParserResult;
+import org.netbeans.modules.javascript2.editor.spi.model.ObjectInterceptor;
 import org.openide.util.NbBundle;
 
 /**
@@ -138,6 +142,8 @@ public final class Model {
     
     private ModelVisitor visitor;
     
+    private Map<String, Map<Integer, List<TypeUsage>>> returnTypesFromFrameworks;
+    
     /**
      * contains with expression?
      */
@@ -148,8 +154,21 @@ public final class Model {
         this.occurrencesSupport = new OccurrencesSupport(this);
         this.occurrenceBuilder = new OccurrenceBuilder(parserResult);
         this.resolveWithObjects = false;
+        this.returnTypesFromFrameworks = new HashMap<String, Map<Integer, List<TypeUsage>>>();
     }
 
+    /**
+     * 
+     * @param parserResult
+     * @return the model, if the parser result is created on top of a js source
+     */
+    public static Model getModel(final ParserResult parserResult) {
+        if (parserResult instanceof JsParserResult) {
+            return ((JsParserResult)parserResult).getModel();
+        }
+        return null;
+    }
+    
     private synchronized ModelVisitor getModelVisitor() {
         boolean resolveWindowProperties = false;
         if (visitor == null) {
@@ -173,12 +192,34 @@ public final class Model {
                     Collection<ModelVisitor.FunctionCall> fncCalls = entry.getValue();
                     if (fncCalls != null && !fncCalls.isEmpty()) {
                         for (ModelVisitor.FunctionCall call : fncCalls) {
-                            entry.getKey().intercept(call.getName(),
+                            Collection<TypeUsage> returnTypes = entry.getKey().intercept(parserResult.getSnapshot(), call.getName(),
                                     visitor.getGlobalObject(), call.getScope(), elementFactory, call.getArguments());
+                            if (returnTypes != null) {
+                                Map<Integer, List<TypeUsage>> functionCalls = returnTypesFromFrameworks.get(call.getName());
+                                if (functionCalls == null) {
+                                    functionCalls = new HashMap<Integer, List<TypeUsage>>();
+                                    returnTypesFromFrameworks.put(call.getName(), functionCalls);
+                                }
+                                List<TypeUsage> types = functionCalls.get(call.getCallOffset());
+                                if (types == null) {
+                                    types = new ArrayList();
+                                    functionCalls.put(new Integer(call.getCallOffset()), types);
+                                }
+                                for (TypeUsage type: returnTypes) {
+                                    if (!types.contains(type)) {
+                                        types.add(type);
+                                    }
+                                }
+                            }
                         }
                     }
                 }
             }
+            
+            for (ObjectInterceptor objectInterceptor : ModelExtender.getDefault().getObjectInterceptors()) {
+                objectInterceptor.interceptGlobal(visitor.getGlobalObject(), elementFactory);
+            }
+            
             resolveWindowProperties = !resolveWithObjects;
             long end = System.currentTimeMillis();
             if(LOGGER.isLoggable(Level.FINE)) {
@@ -223,14 +264,14 @@ public final class Model {
         JsObject fromType = null;
         if (outerExpression == null) {
             outerExpression = ech;
-            resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, ech, offset));
-            resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true);
+            resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, ech, offset, true));
+            resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true, true);
             withTypes.addAll(resolveTypeFromExpression);
         } else {
             ech.addAll(outerExpression);
             boolean resolved = false;
-            resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, ech, offset));
-            resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true);
+            resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, ech, offset, true));
+            resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true, true);
             for(TypeUsage type : resolveTypeFromExpression) {
                 fromType = ModelUtils.findJsObjectByName(visitor.getGlobalObject(), type.getType());
                 if (fromType != null) {
@@ -242,8 +283,8 @@ public final class Model {
             }
             if (!resolved) {
                 resolveTypeFromExpression.clear();
-                resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, originalExp, offset));
-                resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true);
+                resolveTypeFromExpression.addAll(ModelUtils.resolveTypeFromExpression(this, jsIndex, originalExp, offset, true));
+                resolveTypeFromExpression = ModelUtils.resolveTypes(resolveTypeFromExpression, parserResult, true, true);
                 for (TypeUsage type : resolveTypeFromExpression) {
                     fromType = ModelUtils.findJsObjectByName(visitor.getGlobalObject(), type.getType());
                     if (fromType != null) {
@@ -265,7 +306,7 @@ public final class Model {
             fromType = ModelUtils.findJsObjectByName(visitor.getGlobalObject(), type.getType());
             if (fromType != null) {
                 processWithExpressionOccurrences(fromType, ((JsWithObjectImpl)with).getExpressionRange(), originalExp);
-                Collection<TypeUsage> assignments = ModelUtils.resolveTypes(fromType.getAssignments(), parserResult, true);
+                Collection<TypeUsage> assignments = ModelUtils.resolveTypes(fromType.getAssignments(), parserResult, true, true);
                 for (TypeUsage assignment : assignments) {
                     Collection<IndexedElement> properties = jsIndex.getProperties(assignment.getType());
                     for (IndexedElement indexedElement : properties) {
@@ -462,6 +503,19 @@ public final class Model {
         return getModelVisitor().getGlobalObject();
     }
     
+    /**
+     * This returns types of a function call that starts on the offsetCall. 
+     * These return types can be influenced by the call arguments and are obtained
+     * from the function interceptors defined in the frameworks. 
+     * @param name the name of the function
+     * @param offsetCall offset where the call starts (the first letter of the method name)
+     * @return 
+     */
+    public Collection<TypeUsage> getReturnTypesFromFrameworks(String name, int offsetCall) {
+        Map<Integer, List<TypeUsage>> returnTypes = returnTypesFromFrameworks.get(name);
+        return  (returnTypes != null) ? returnTypes.get(offsetCall) : null;
+    }
+    
     public synchronized void resolve() {
         if (visitor == null) {
             getModelVisitor();
@@ -491,7 +545,26 @@ public final class Model {
         }
         return result;
     }
-
+    
+    /**
+     * 
+     * @param name can not be null. Single name of the variable
+     * @param offset the variable is defined in the context (or higher) of this offset
+     * @return 
+     */
+    public JsObject findVariable(final String name, final int offset) {
+        if (name == null || name.isEmpty()) {
+            return null;
+        }
+        Collection<? extends JsObject> variables = getVariables(offset);
+        for (JsObject jsObject: variables) {
+            if (name.equals(jsObject.getName())) {
+                return jsObject;
+            }
+        }
+        return null;
+    }
+   
     private void resolveLocalTypes(JsObject object, JsDocumentationHolder docHolder) {
         Set<String> alreadyResolved = new HashSet<String>();
         resolveLocalTypes(object, docHolder, alreadyResolved);
@@ -765,7 +838,7 @@ public final class Model {
 
                 Collection<? extends TypeUsage> ret = function.getReturnTypes();
                 if (parseResult != null) {
-                    ret = ModelUtils.resolveTypes(ret, parseResult, true);
+                    ret = ModelUtils.resolveTypes(ret, parseResult, true, true);
                 }
                 List<TypeUsage> returnTypes = new ArrayList<TypeUsage>(ret);
                 Collections.sort(returnTypes, RETURN_TYPES_COMPARATOR);
