@@ -60,9 +60,13 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
     private JsObject parent;
     final private List<Occurrence> occurrences = new ArrayList<Occurrence>();
     final private NavigableMap<Integer, Collection<TypeUsage>> assignments = new TreeMap<Integer, Collection<TypeUsage>>();
+    final private Map<String, Integer>assignmentsReverse = new HashMap();
+    private int countOfAssignments = 0;
     final private boolean hasName;
     private Documentation documentation;
     protected JsElement.Kind kind;
+    private boolean isVirtual;
+    private boolean isAnonymous;
 
     public JsObjectImpl(JsObject parent, Identifier name, OffsetRange offsetRange,
             String mimeType, String sourceLabel) {
@@ -72,6 +76,8 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
         this.parent = parent;
         this.hasName = name.getOffsetRange().getStart() != name.getOffsetRange().getEnd();
         this.kind = null;
+        this.isVirtual = false;
+        this.isAnonymous = false;
     }
 
     public JsObjectImpl(JsObject parent, Identifier name, OffsetRange offsetRange,
@@ -80,8 +86,9 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
                 isDeclared, offsetRange, modifiers, mimeType, sourceLabel);
         this.declarationName = name;
         this.parent = parent;
-        this.hasName = name.getOffsetRange().getStart() != name.getOffsetRange().getEnd();
+        this.hasName = !OffsetRange.NONE.equals(name.getOffsetRange()) && (name.getOffsetRange().getStart() != name.getOffsetRange().getEnd());
         this.kind = null;
+        this.isVirtual = false;
     }
 
     public JsObjectImpl(JsObject parent, Identifier name, OffsetRange offsetRange,
@@ -188,6 +195,15 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
         this.parent = newParent;
     }
 
+    @Override
+    public boolean isVirtual() {
+        return isVirtual;
+    }
+
+    public void setVirtual(boolean isVirtual) {
+        this.isVirtual = isVirtual;
+    }
+
     @Override
     public int getOffset() {
         return declarationName == null ? -1 : declarationName.getOffsetRange().getStart();
@@ -217,32 +233,62 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
     }
 
     public void addAssignment(Collection<TypeUsage> typeNames, int offset) {
-        Collection<TypeUsage> types = assignments.get(offset);
-        if (types == null) {
-            types = new ArrayList<TypeUsage>();
-            assignments.put(offset, types);
+        for(TypeUsage type: typeNames) {
+            addAssignment(type, offset);
         }
-        types.addAll(typeNames);
+    }
+
+    @Override
+    public void clearAssignments() {
+        assignments.clear();
     }
 
     @Override
     public void addAssignment(TypeUsage typeName, int offset) {
+        if (Type.UNDEFINED.equals(typeName.getType()) && assignments.size() > 0) {
+            // don't add undefined type, if there are already some types
+            return;
+        }
         Collection<TypeUsage> types = assignments.get(offset);
         if (types == null) {
+            // create always empty list, need to be counted for number of assignments.
             types = new ArrayList<TypeUsage>();
             assignments.put(offset, types);
         }
+        
+        Integer alreadyDefinedOffset = assignmentsReverse.get(typeName.getType());
+        if (alreadyDefinedOffset != null) {
+            // there is already assignment of this type. It's enough to store the
+            // assignment with the min offset
+            if(alreadyDefinedOffset <= offset) {
+                // do nothing, just remember the previous one
+                return;
+            } else {
+                // we need to replace the assignment with bigger offset
+                Collection<TypeUsage> typesToRemove = assignments.get(alreadyDefinedOffset);
+                for (TypeUsage type : typesToRemove) {
+                    if (type.getType().equals(typeName.getType())) {
+                        typesToRemove.remove(type);
+                        break;
+                    }
+                }
+            }
+        }
+        assignmentsReverse.put(typeName.getType(), offset);
         types.add(typeName);
     }
 
     @Override
     public Collection<? extends TypeUsage> getAssignmentForOffset(int offset) {
-        Collection<? extends TypeUsage> result = Collections.EMPTY_LIST;
+        List<? extends TypeUsage> result = new ArrayList();
         Map.Entry<Integer, Collection<TypeUsage>> found = assignments.floorEntry(offset);
-        if (found != null) {
-            result = new ArrayList(found.getValue());
+        int tmpOffset = offset;
+        while (found != null) {
+            result.addAll((Collection)found.getValue());
+            tmpOffset = found.getKey() - 1;
+            found = assignments.floorEntry(tmpOffset);
         }
-        if (result.isEmpty()) {
+//        if (result.isEmpty()) {
 //            Collection<TypeUsage> resolved = new HashSet();
 //            for(TypeUsage item : result) {
 //                TypeUsageImpl type = (TypeUsageImpl)item;
@@ -259,10 +305,10 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
 //                // keep somthink in the assignments. 
 //                resolved.add(new TypeUsageImpl("Object", offset, true));
 //            }
-            Collection<TypeUsage> resolved = new HashSet();
-            //resolved.add(new TypeUsageImpl("Object", offset, true));
-            result = resolved;
-        }
+//            Collection<TypeUsage> resolved = new HashSet();
+//            //resolved.add(new TypeUsageImpl("Object", offset, true));
+//            result = resolved;
+//        }
 
         return result;
     }
@@ -299,7 +345,12 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
 
     @Override
     public boolean isAnonymous() {
-        return false;
+        return isAnonymous;
+    }
+
+    @Override
+    public void setAnonymous(boolean value) {
+        this.isAnonymous = value;
     }
 
     @Override
@@ -330,8 +381,7 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
         this.kind = kind;
     }
 
-    protected Collection<TypeUsage> resolveAssignments(JsObject jsObject, int offset) {
-        Collection<String> visited = new HashSet();  // for preventing infinited loops
+    protected Collection<TypeUsage> resolveAssignments(JsObject jsObject, int offset) {        Collection<String> visited = new HashSet();  // for preventing infinited loops
         return resolveAssignments(jsObject, offset, visited);
     }
 
@@ -470,6 +520,15 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
             unresolved.addAll(resolved);
         }
 
+        if (!isAnonymous()) {
+            List<OffsetRange> docOccurrences = jsDocHolder.getOccurencesMap().get(getFullyQualifiedName());
+            if (docOccurrences != null) {
+                for (OffsetRange offsetRange : docOccurrences) {
+                    addOccurrence(offsetRange);
+                }
+            }
+        }
+        
         if (!isAnonymous() && assignments.isEmpty()) {
             // try to recount occurrences
             JsObject global = ModelUtils.getGlobalObject(parent);
@@ -489,9 +548,8 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
                 }
             }
 
-            if (occurrences.size() != correctedOccurrences.size()) {
-                occurrences.clear();
-                occurrences.addAll(correctedOccurrences);
+            for(Occurrence occurrence : correctedOccurrences){
+                addOccurrence(occurrence.getOffsetRange());
             }
         }
 
@@ -657,6 +715,7 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
         return documentation;
     }
 
+    @Override
     public void setDocumentation(Documentation doc) {
         this.documentation = doc;
     }
@@ -673,9 +732,99 @@ public class JsObjectImpl extends JsElementImpl implements JsObject {
             getModifiers().remove(Modifier.DEPRECATED);
         }
     }
+    
+    
 
 //    @Override
 //    public String toString() {
 //        return "JsObjectImpl{" + "declarationName=" + declarationName + ", parent=" + parent + ", kind=" + kind + '}';
 //    }
+
+    @Override
+    public boolean moveProperty(String name, JsObject newParent) {
+        JsObject property = getProperty(name);
+        if (property == null) {
+            return false;
+        }
+        if (property instanceof JsObjectImpl) {
+            String oldFQN = property.getFullyQualifiedName();
+            ((JsObjectImpl)property).setParent(newParent);
+            newParent.addProperty(name, property);
+            String newFQN = property.getFullyQualifiedName();
+            JsObject global = ModelUtils.getGlobalObject(this);
+            if (global instanceof JsObjectImpl) {
+                ((JsObjectImpl)global).correctAssignmentsInModel(oldFQN, newFQN, new HashSet<String>());
+            }
+            return properties.remove(name) != null;
+        }
+        return false;
+    }
+    
+    private void correctAssignmentsInModel (String fromType, String toType, Set<String> done) {
+        if (!done.contains(getFullyQualifiedName())) {
+            done.add(getFullyQualifiedName());
+            correctTypes(fromType, toType);
+            for (JsObject property: getProperties().values()) {
+                if (property instanceof JsObjectImpl) {
+                    ((JsObjectImpl)property).correctAssignmentsInModel(fromType, toType, done);
+                }
+            }
+        }
+    }
+    
+    protected void correctTypes(String fromType, String toType) {
+        for (Integer offset: assignments.keySet()) {
+            Collection<TypeUsage> types = assignments.get(offset);
+            List<TypeUsage> copy = new ArrayList(types);
+            String typeR = null;
+            for (TypeUsage type : copy) {
+                typeR = replaceTypeInFQN(type.getType(), fromType, toType);
+                if (typeR != null) {
+                    types.remove(type);
+                    types.add(new TypeUsageImpl(typeR, type.getOffset(), type.isResolved()));
+                }
+            }
+        }
+    }
+    
+    /**
+     * 
+     * @param typeFQN type that where should be changed
+     * @param fromType  the old type or part of a type
+     * @param toType    the new type or part of a type
+     * @return null, if it's not possible to replace or the result FQN
+     */
+    protected String replaceTypeInFQN(String typeFQN, String fromType, String toType) {
+        String typeR = null;
+        if (typeFQN.isEmpty()) {
+            return null;
+        }
+        if (typeFQN.equals(fromType)) {
+            typeR = toType;
+        } else {
+            int index = typeFQN.indexOf(fromType);
+            if (typeFQN.startsWith(SemiTypeResolverVisitor.ST_START_DELIMITER)) {
+                // it's semitype. we need to mask the semitypes
+                int delEndIndex = typeFQN.indexOf(';');
+                if (delEndIndex > 0 && index < delEndIndex) {
+                    index = typeFQN.indexOf(fromType, delEndIndex);
+                } 
+                 
+            }
+            if (index > -1 && !typeFQN.contains(toType)
+                    && (index == 0 || typeFQN.charAt(index - 1) == '.' || typeFQN.charAt(index - 1) == ';')
+                    && ((index + fromType.length()) == typeFQN.length() || typeFQN.charAt(index + fromType.length()) == '.')) {
+                boolean replace = (index == 0 || typeFQN.startsWith(SemiTypeResolverVisitor.ST_START_DELIMITER));
+                if (!replace && index > 0) {
+                    String typePrefix = typeFQN.substring(0, index - 1);
+                    JsObject global = ModelUtils.getGlobalObject(this);
+                    replace = ModelUtils.findJsObjectByName(global, typePrefix) != null;
+                }
+                if (replace) {
+                    typeR = typeFQN.substring(0, index) + toType + typeFQN.substring(index + fromType.length());
+                }
+            }
+        }
+        return typeR;
+    }
 }
