@@ -48,6 +48,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -72,6 +73,7 @@ import org.netbeans.modules.javascript2.editor.model.JsArray;
 import org.netbeans.modules.javascript2.editor.model.JsElement;
 import org.netbeans.modules.javascript2.editor.model.JsFunction;
 import org.netbeans.modules.javascript2.editor.model.JsObject;
+import org.netbeans.modules.javascript2.editor.model.JsReference;
 import org.netbeans.modules.javascript2.editor.model.JsWith;
 import org.netbeans.modules.javascript2.editor.model.Model;
 import org.netbeans.modules.javascript2.editor.model.Occurrence;
@@ -98,6 +100,8 @@ public class ModelUtils {
     
     private static final List<String> KNOWN_TYPES = Arrays.asList(Type.ARRAY, Type.STRING, Type.BOOLEAN, Type.NUMBER, Type.UNDEFINED);
     
+    private static final int MAX_RECURSION_DEEP_RESOLVING_ASSIGNMENTS = 10;
+    
     public static JsObjectImpl getJsObject (ModelBuilder builder, List<Identifier> fqName, boolean isLHS) {
         JsObject result = builder.getCurrentObject();
         JsObject tmpObject = null;
@@ -124,6 +128,9 @@ public class ModelUtils {
                 DeclarationScope scope = builder.getCurrentDeclarationFunction();
                 while (scope != null && tmpObject == null && scope.getParentScope() != null) {
                     tmpObject = ((JsFunction)scope).getParameter(firstName);
+                    if (tmpObject == null) {
+                        tmpObject = ((JsObject)scope).getProperty(firstName);
+                    }
                     scope = scope.getParentScope();
                 }
                 if (tmpObject == null) {
@@ -194,6 +201,17 @@ public class ModelUtils {
                     break;
                 }
             }
+            if ( object.getJSKind() == JsElement.Kind.WITH_OBJECT) {
+                for (JsWith innerWith :((JsWith)object).getInnerWiths()){
+                    if (!visited.contains(innerWith.getFullyQualifiedName())) {
+                        tmpObject = findJsObject(innerWith, offset, visited);
+                    }
+                    if (tmpObject != null) {
+                        result = tmpObject;
+                        break;
+                    }
+                }
+            }
             if (object instanceof JsArray) {
                 JsArray array = (JsArray)object;
                 for (TypeUsage type : array.getTypesInArray()) {
@@ -289,7 +307,8 @@ public class ModelUtils {
                 while (deep) {
                     deep = false;
                     for (DeclarationScope innerScope : result.getChildrenScopes()) {
-                        if (((DeclarationScopeImpl)innerScope).getOffsetRange().containsInclusive(offset)) {
+                        if ((innerScope instanceof DeclarationScopeImpl)
+                                && ((DeclarationScopeImpl)innerScope).getOffsetRange().containsInclusive(offset)) {
                             result = innerScope;
                             deep = true;
                             break;
@@ -369,8 +388,10 @@ public class ModelUtils {
     private static Collection<TypeUsage> tryResolveWindowProperty(Model model, JsIndex jsIndex, String name) {
         // since issue #215863
         String fqn = null;
+        int offset = -1;
         for (IndexedElement indexedElement : jsIndex.getProperties("window")) { //NOI18N
             if (indexedElement.getName().equals(name)) {
+                offset = indexedElement.getOffset();
                 fqn = "window." + name;
                 break;
             }
@@ -378,6 +399,7 @@ public class ModelUtils {
         if (fqn == null) {
             for (IndexedElement indexedElement : jsIndex.getProperties("Window.prototype")) { //NOI18N
                 if (indexedElement.getName().equals(name)) {
+                    offset = indexedElement.getOffset();
                     fqn = "Window.prototype." + name; //NOI18N
                     break;
                 }
@@ -385,7 +407,7 @@ public class ModelUtils {
         }
         if (fqn != null) {
             List<TypeUsage> fromAssignment = new ArrayList<TypeUsage>();
-            resolveAssignments(model, jsIndex, fqn, fromAssignment);
+            resolveAssignments(model, jsIndex, fqn, offset, fromAssignment);
             if (fromAssignment.isEmpty()) {
                 fromAssignment.add(new TypeUsageImpl(fqn));
             } 
@@ -741,7 +763,7 @@ public class ModelUtils {
         return result;
     }
     
-    public static Collection<TypeUsage> resolveTypeFromExpression (Model model, @NullAllowed JsIndex jsIndex, List<String> exp, int offset) {
+    public static Collection<TypeUsage> resolveTypeFromExpression (Model model, @NullAllowed JsIndex jsIndex, List<String> exp, int offset, boolean includeAllPossible) {
         List<JsObject> localObjects = new ArrayList<JsObject>();
         List<JsObject> lastResolvedObjects = new ArrayList<JsObject>();
         List<TypeUsage> lastResolvedTypes = new ArrayList<TypeUsage>();
@@ -759,7 +781,7 @@ public class ModelUtils {
                 if ("this".equals(name)) {
                     JsObject thisObject = ModelUtils.findJsObject(model, offset);
                     JsObject first = thisObject;
-                    while (thisObject != null && thisObject.getParent() != null
+                    while (thisObject != null && thisObject.getParent() != null && thisObject.getParent().getJSKind() != JsElement.Kind.FILE
                             && thisObject.getJSKind() != JsElement.Kind.CONSTRUCTOR
                             && thisObject.getJSKind() != JsElement.Kind.ANONYMOUS_OBJECT
                             && thisObject.getJSKind() != JsElement.Kind.OBJECT_LITERAL) {
@@ -782,6 +804,7 @@ public class ModelUtils {
                     Collection<? extends TypeUsage> typeFromWith = getTypeFromWith(model, offset);
                     if (!typeFromWith.isEmpty()) {
                         String firstNamePart = index == -1 ? name : name.substring(0, index);
+                        String changedName = name;
                         for (TypeUsage type : typeFromWith) {
                             //Collection<TypeUsage> resolveTypeFromSemiType = ModelUtils.resolveTypeFromSemiType(model.getGlobalObject(), type);
                             String sType = type.getType();
@@ -791,10 +814,12 @@ public class ModelUtils {
 //                            }
                             localObject = ModelUtils.findJsObjectByName(model, sType);
                             if (localObject != null && localObject.getProperty(firstNamePart) != null) {
-                                name = localObject.getFullyQualifiedName() + "." + name;
-                                break;
+                                changedName = localObject.getFullyQualifiedName() + "." + name;
+                            } else {
+                                lastResolvedTypes.add(new TypeUsageImpl(sType + "." + name, -1, true));
                             }
                         }
+                        name = changedName;
                     }
                     
                     if (index > -1) { // the first part is a fqn
@@ -803,6 +828,7 @@ public class ModelUtils {
                             localObjects.add(localObject);
                         }
                     } else {
+                        boolean canBeWindowsProp = true;
                         for (JsObject object : model.getVariables(offset)) {
                             if (object.getName().equals(name)) {
                                 localObjects.add(object);
@@ -810,8 +836,15 @@ public class ModelUtils {
                                 break;
                             }
                         }
+                        if (localObject != null && localObject.getJSKind().isFunction() && i - 2 > -1) {
+                            JsFunction localFunc = (JsFunction)localObject;
+                            String paramName = exp.get(i - 2);
+                            if (localFunc.getParameter(paramName) != null) {
+                                canBeWindowsProp = false;
+                            }
+                        }
 
-                        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects()) {
+                        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects(model.getGlobalObject().getFileObject())) {
                             assert libGlobal != null;
                             for (JsObject object : libGlobal.getProperties().values()) {
                                 if (object.getName().equals(name)) {
@@ -821,7 +854,7 @@ public class ModelUtils {
                                 }
                             }
                         }
-                        if (jsIndex != null) {
+                        if (jsIndex != null && canBeWindowsProp) {
                             Collection<TypeUsage> windowProperty = tryResolveWindowProperty(model, jsIndex, name);
                             if (windowProperty != null && !windowProperty.isEmpty()) {
                                 lastResolvedTypes.addAll(windowProperty);
@@ -850,7 +883,7 @@ public class ModelUtils {
 //                            }
 //                        } else {
                         if ("@pro".equals(kind) && jsIndex != null) { //NOI18N
-                            resolveAssignments(model, jsIndex, name, fromAssignments);
+                            resolveAssignments(model, jsIndex, name, -1,  fromAssignments);
                         } 
 //                        }
                         lastResolvedTypes.addAll(fromAssignments);
@@ -863,7 +896,7 @@ public class ModelUtils {
                                     sType = sType.substring(5);
                                     sType = sType.replace("@pro;", ".");
                                 }   
-                                ModelUtils.resolveAssignments(model, jsIndex, sType, fromAssignments);
+                                ModelUtils.resolveAssignments(model, jsIndex, sType, typeUsage.getOffset(), fromAssignments);
                                 for (TypeUsage typeUsage1 : fromAssignments) {
                                     String localFqn = localObject != null ? localObject.getFullyQualifiedName() : null;
                                     if (localFqn != null  && name.startsWith(localFqn) && name.length() > localFqn.length() ) {
@@ -902,6 +935,29 @@ public class ModelUtils {
                                     // if it's a method call, add all retuturn types
                                     lastResolvedTypes.addAll(((JsFunction) lObject).getReturnTypes());
                                 }
+                                int lastCallOffset = -1;
+                                for (Occurrence occurrence : lObject.getOccurrences()) {
+                                    if (lastCallOffset < occurrence.getOffsetRange().getStart() && occurrence.getOffsetRange().getStart() <= offset) {
+                                        lastCallOffset = occurrence.getOffsetRange().getStart();
+                                    }
+                                }
+                                Collection<TypeUsage> returnTypesFromFrameworks = model.getReturnTypesFromFrameworks(lObject.getName(), lastCallOffset);
+                                if (returnTypesFromFrameworks != null && !returnTypesFromFrameworks.isEmpty()) {
+                                    lastResolvedTypes.addAll(returnTypesFromFrameworks);
+                                }
+                                if (jsIndex != null) {
+                                    Collection<? extends IndexResult> findByFqn = jsIndex.findByFqn(name, JsIndex.TERMS_BASIC_INFO);
+                                    for (Iterator<? extends IndexResult> iterator = findByFqn.iterator(); iterator.hasNext();) {
+                                        IndexedElement indexElement = IndexedElement.create(iterator.next());
+                                        if(indexElement instanceof IndexedElement.FunctionIndexedElement) {
+                                            IndexedElement.FunctionIndexedElement iFunction = (IndexedElement.FunctionIndexedElement)indexElement;
+                                            for (String type : iFunction.getReturnTypes()) {
+                                                lastResolvedTypes.add(new TypeUsageImpl(type, -1, false));
+                                            }
+                                        }
+
+                                    }
+                                }
                             } else if ("@arr".equals(kind) && lObject instanceof JsArray) {
                                 lastResolvedTypes.addAll(((JsArray) lObject).getTypesInArray());
                             } else {
@@ -1009,7 +1065,7 @@ public class ModelUtils {
                             if (checkProperty) {
                                 String propertyFQN = propertyToCheck != null ? propertyToCheck : typeName + "." + name;
                                 List<TypeUsage> fromAssignment = new ArrayList<TypeUsage>();
-                                resolveAssignments(model, jsIndex, propertyFQN, fromAssignment);
+                                resolveAssignments(model, jsIndex, propertyFQN, -1, fromAssignment);
                                 if (fromAssignment.isEmpty()) {
                                     ModelUtils.addUniqueType(newResolvedTypes, new TypeUsageImpl(propertyFQN));
                                 } else {
@@ -1018,7 +1074,7 @@ public class ModelUtils {
                             }
                         }
                         // from libraries look for top level types
-                        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects()) {
+                        for (JsObject libGlobal : ModelExtender.getDefault().getExtendingGlobalObjects(model.getGlobalObject().getFileObject())) {
                             for (JsObject object : libGlobal.getProperties().values()) {
                                 if (object.getName().equals(typeUsage.getType())) {
                                     JsObject property = object.getProperty(name);
@@ -1051,20 +1107,39 @@ public class ModelUtils {
                 if (jsObject.isDeclared()) {
                     String fqn = jsObject.getFullyQualifiedName();
                     if (!resultTypes.containsKey(fqn)) {
-                        resultTypes.put(fqn, new TypeUsageImpl(fqn, offset));
+                        if (includeAllPossible || hasDeclaredProperty(jsObject)) {
+                            resultTypes.put(fqn, new TypeUsageImpl(fqn, offset));
+                        }
                     }
                 }
             }
             return resultTypes.values();
     }
 
+    public static boolean hasDeclaredProperty(JsObject jsObject) {
+        boolean result =  false;
+        
+        Iterator<? extends JsObject> it = jsObject.getProperties().values().iterator();
+        while (!result && it.hasNext()) {
+            JsObject property = it.next();
+            result = property.isDeclared();
+            if (!result) {
+                result = hasDeclaredProperty(property);
+            } 
+        }
+
+        return result;
+    }
+    
     public static List<String> expressionFromType(TypeUsage type) {
         String sexp = type.getType();
-        if ((sexp.startsWith("@exp;") || sexp.startsWith("@new;") || sexp.startsWith("@arr;") || sexp.startsWith("@pro;")
+        if ((sexp.startsWith("@exp;") || sexp.startsWith("@new;") || sexp.startsWith("@arr;") || sexp.contains("@pro;")
                 || sexp.startsWith("@call;") || sexp.startsWith(SemiTypeResolverVisitor.ST_WITH)) && (sexp.length() > 5)) {
             
-            int start = sexp.startsWith("@call;") || sexp.startsWith("@arr;") || sexp.startsWith(SemiTypeResolverVisitor.ST_WITH) ? 1 : sexp.charAt(5) == '@' ? 6 : 5;
-            sexp = sexp.substring(start);
+            if (sexp.charAt(0) == '@') {
+                int start = sexp.startsWith("@call;") || sexp.startsWith("@arr;") || sexp.startsWith(SemiTypeResolverVisitor.ST_WITH) ? 1 : sexp.charAt(5) == '@' ? 6 : 5;
+                sexp = sexp.substring(start);
+            }
             List<String> nExp = new ArrayList<String>();
             String[] split = sexp.split("@");
             for (int i = split.length - 1; i > -1; i--) {
@@ -1085,7 +1160,7 @@ public class ModelUtils {
         }
     }
     
-    public static Collection<TypeUsage> resolveTypes(Collection<? extends TypeUsage> unresolved, JsParserResult parserResult, boolean useIndex) {
+    public static Collection<TypeUsage> resolveTypes(Collection<? extends TypeUsage> unresolved, JsParserResult parserResult, boolean useIndex, boolean includeAllPossible) {
         //assert !SwingUtilities.isEventDispatchThread() : "Type resolution may block AWT due to index search";
         Collection<TypeUsage> types = new ArrayList<TypeUsage>(unresolved);
         if (types.size() == 1 && types.iterator().next().isResolved()) {
@@ -1114,7 +1189,7 @@ public class ModelUtils {
                     if (nExp.size() > 1) {
                         // passing original prevents the unresolved return types
                         // when recursion in place
-                        ModelUtils.addUniqueType(resolved, original, ModelUtils.resolveTypeFromExpression(model, jsIndex, nExp, typeUsage.getOffset()));
+                        ModelUtils.addUniqueType(resolved, original, ModelUtils.resolveTypeFromExpression(model, jsIndex, nExp, typeUsage.getOffset(), includeAllPossible));
                     } else {
                         ModelUtils.addUniqueType(resolved, new TypeUsageImpl(typeUsage.getType(), typeUsage.getOffset(), true));
                     }
@@ -1167,20 +1242,28 @@ public class ModelUtils {
         }
     }
     
-    private static void resolveAssignments(Model model, JsIndex jsIndex, String fqn, List<TypeUsage> resolved) {
+    private static int deepRA = 0;
+    private static void resolveAssignments(Model model, JsIndex jsIndex, String fqn, int offset, List<TypeUsage> resolved) {
         Set<String> alreadyProcessed = new HashSet<String>();
+        deepRA = 0;
         for(TypeUsage type : resolved) {
             alreadyProcessed.add(type.getType());
         }
-        resolveAssignments(model, jsIndex, fqn, resolved, alreadyProcessed);
+        resolveAssignments(model, jsIndex, fqn, offset, resolved, alreadyProcessed);
     }
     
-    private static void resolveAssignments(Model model, JsIndex jsIndex, String fqn, List<TypeUsage> resolved, Set<String> alreadyProcessed) {
+    private static void resolveAssignments(Model model, JsIndex jsIndex, String fqn, int offset,  List<TypeUsage> resolved, Set<String> alreadyProcessed) {
         if (!alreadyProcessed.contains(fqn)) {
             alreadyProcessed.add(fqn);
-            if (!fqn.startsWith("@")) {
+            deepRA++;
+            String fqnCorrected = fqn;
+            if (fqnCorrected.startsWith(SemiTypeResolverVisitor.ST_EXP) && !fqnCorrected.contains(SemiTypeResolverVisitor.ST_CALL)) {
+                fqnCorrected = fqnCorrected.substring(fqnCorrected.indexOf(SemiTypeResolverVisitor.ST_EXP) + SemiTypeResolverVisitor.ST_EXP.length());
+                fqnCorrected = fqnCorrected.replace(SemiTypeResolverVisitor.ST_PRO, ".");   //NOI18N
+            }
+            if (!fqnCorrected.startsWith("@")) {
                 if (jsIndex != null) {
-                    Collection<? extends IndexResult> indexResults = jsIndex.findByFqn(fqn, JsIndex.FIELD_ASSIGNMENTS);
+                    Collection<? extends IndexResult> indexResults = jsIndex.findByFqn(fqnCorrected, JsIndex.FIELD_ASSIGNMENTS);
                     boolean hasAssignments = false;
                     boolean isType = false;
                     for (IndexResult indexResult: indexResults) {
@@ -1192,14 +1275,14 @@ public class ModelUtils {
                                     resolved.clear();
                                     break;
                                 }
-                                if (!alreadyProcessed.contains(type.getType())) {
-                                    resolveAssignments(model, jsIndex, type.getType(), resolved, alreadyProcessed);
+                                if (!alreadyProcessed.contains(type.getType()) && deepRA < MAX_RECURSION_DEEP_RESOLVING_ASSIGNMENTS) {
+                                    resolveAssignments(model, jsIndex, type.getType(), type.getOffset(), resolved, alreadyProcessed);
                                 }
                             }
                         }
                     }
                     if (indexResults.isEmpty()) {
-                        JsObject found = ModelUtils.findJsObjectByName(model.getGlobalObject(), fqn);
+                        JsObject found = ModelUtils.findJsObjectByName(model.getGlobalObject(), fqnCorrected);
                         if (found != null) {
                             Collection<? extends TypeUsage> assignments = found.getAssignments();
                             if (!assignments.isEmpty()) {
@@ -1215,17 +1298,17 @@ public class ModelUtils {
                                     }
                                 }
                                 for (TypeUsage type : toProcess) {
-                                    if (!alreadyProcessed.contains(type.getType())) {
-                                        resolveAssignments(model, jsIndex, type.getType(), resolved, alreadyProcessed);
+                                    if (!alreadyProcessed.contains(type.getType()) && deepRA < MAX_RECURSION_DEEP_RESOLVING_ASSIGNMENTS) {
+                                        resolveAssignments(model, jsIndex, type.getType(), type.getOffset(), resolved, alreadyProcessed);
                                     }
                                 }
                             }
                         }
                     }
 
-                    Collection<IndexedElement> properties = jsIndex.getProperties(fqn);
+                    Collection<IndexedElement> properties = jsIndex.getProperties(fqnCorrected);
                     for (IndexedElement property : properties) {
-                        if (property.getFQN().startsWith(fqn) && (property.isDeclared() || ModelUtils.PROTOTYPE.equals(property.getName()))) {
+                        if (property.getFQN().startsWith(fqnCorrected) && (property.isDeclared() || ModelUtils.PROTOTYPE.equals(property.getName()))) {
                             isType = true;
                             break;
                         }
@@ -1233,11 +1316,11 @@ public class ModelUtils {
 
 
                     if(!hasAssignments || isType) {
-                        ModelUtils.addUniqueType(resolved, new TypeUsageImpl(fqn, -1, true));
+                        ModelUtils.addUniqueType(resolved, new TypeUsageImpl(fqnCorrected, offset, true));
                     }
                 }
             } else {
-                ModelUtils.addUniqueType(resolved, new TypeUsageImpl(fqn, -1, false));
+                ModelUtils.addUniqueType(resolved, new TypeUsageImpl(fqn, offset, false));
             }
         }
     }
@@ -1288,8 +1371,14 @@ public class ModelUtils {
      */
     public static Collection <? extends TypeUsage> getTypeFromWith(Model model, int offset) {
         JsObject jsObject = ModelUtils.findJsObject(model, offset);
+        JsObject previous = jsObject;
         while (jsObject != null && jsObject.isAnonymous() && jsObject.getJSKind() != JsElement.Kind.WITH_OBJECT) {
             jsObject = ModelUtils.findJsObject(model, jsObject.getOffset() - 1);
+            if (jsObject.getFullyQualifiedName().endsWith(previous.getFullyQualifiedName())) {
+                break;
+            } else {
+                previous = jsObject;
+            }
         }
         while(jsObject != null && jsObject.getJSKind() != JsElement.Kind.WITH_OBJECT) {
             jsObject = jsObject.getParent();
@@ -1339,8 +1428,8 @@ public class ModelUtils {
     
     
     public static void addDocTypesOccurence(JsObject jsObject, JsDocumentationHolder docHolder) {
-        if (docHolder.getOccurencesMap().containsKey(jsObject.getName())) {
-            for (OffsetRange offsetRange : docHolder.getOccurencesMap().get(jsObject.getName())) {
+        if (docHolder.getOccurencesMap().containsKey(jsObject.getFullyQualifiedName())) {
+            for (OffsetRange offsetRange : docHolder.getOccurencesMap().get(jsObject.getFullyQualifiedName())) {
                 ((JsObjectImpl)jsObject).addOccurrence(offsetRange);
             }
         }
@@ -1594,4 +1683,72 @@ public class ModelUtils {
             }
         }
     }
+    
+    public static void changeDeclarationScope(JsObject where, DeclarationScope newScope) {
+        changeDeclarationScope(where, newScope, new HashSet<String>());
+    }
+    
+    private static void changeDeclarationScope(JsObject where, DeclarationScope newScope, Set<String> done) {
+        if (!done.contains(where.getFullyQualifiedName())) {
+            done.add(where.getFullyQualifiedName());
+            if (where instanceof DeclarationScope) {
+                if (where.isDeclared()) {
+                    DeclarationScope scope = (DeclarationScope)where;
+                    DeclarationScope oldScope = scope.getParentScope();
+                    if (oldScope != null) {
+                        oldScope.getChildrenScopes().remove(scope);
+                        if (scope instanceof DeclarationScopeImpl) {
+                            ((DeclarationScopeImpl)scope).setParentScope(newScope);
+                        }  
+                    }
+                    newScope.addDeclaredScope(scope);
+                }
+            } else {
+                for (JsObject property : where.getProperties().values()) {
+                    changeDeclarationScope(property, newScope, done);
+                }
+            }
+        }
+    }
+    
+    /**
+     * This method is useful, when you need to go through the model and be sure that
+     * the algorithm will not run into endless cycle. In the model there can be references
+     * to an object that can caused endless cycle. This method check whether the object has an reference or
+     * the original of the reference object was already processed. Also adds the fully qualified names of the object
+     * and the references to the list of processed objects. 
+     * @param object object that should be processed
+     * @param processedObjects list of already processed object
+     * @return true if the object full qualified name or his reference full qualified name is in the processedObjects list.
+     */
+    public static boolean wasProcessed (JsObject object, List<String> processedObjects) {
+        if (processedObjects.contains(object.getFullyQualifiedName())) {
+            return true;
+        } else if (object instanceof JsReference) {
+            JsObject original = ((JsReference) object).getOriginal();
+            boolean isOrginalReachable = !original.isAnonymous() && !original.getName().equals(object.getName());
+            JsObject origParent = original.getParent();
+            while (origParent != null && isOrginalReachable) {
+                if (origParent.isAnonymous() && !(origParent.getParent() != null && origParent.getParent().getParent() == null)) {
+                    isOrginalReachable = false;
+                }
+                origParent = origParent.getParent();
+            }
+            if (isOrginalReachable) {
+                processedObjects.add(object.getFullyQualifiedName());
+                return true;
+            }
+            if (processedObjects.contains(original.getFullyQualifiedName())) {
+                return true;
+            } else {
+                processedObjects.add(object.getFullyQualifiedName());
+                processedObjects.add(original.getFullyQualifiedName());
+            }
+        } else {
+            if (object.getJSKind() != JsElement.Kind.FILE) {
+                processedObjects.add(object.getFullyQualifiedName());
+            }
+        }
+        return false;
+    }
 }
