@@ -53,6 +53,7 @@ import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.modules.csl.api.DeclarationFinder;
 import org.netbeans.modules.csl.api.ElementHandle;
 import org.netbeans.modules.csl.api.HtmlFormatter;
+import org.netbeans.modules.csl.api.Modifier;
 import org.netbeans.modules.csl.api.OffsetRange;
 import org.netbeans.modules.csl.spi.ParserResult;
 import org.netbeans.modules.javascript2.editor.EditorExtender;
@@ -60,6 +61,9 @@ import org.netbeans.modules.javascript2.editor.index.IndexedElement;
 import org.netbeans.modules.javascript2.editor.index.JsIndex;
 import org.netbeans.modules.javascript2.editor.api.lexer.JsTokenId;
 import org.netbeans.modules.javascript2.editor.api.lexer.LexUtilities;
+import org.netbeans.modules.javascript2.editor.lexer.JsDocumentationTokenId;
+import org.netbeans.modules.javascript2.editor.model.JsElement;
+import org.netbeans.modules.javascript2.editor.model.JsFunction;
 import org.netbeans.modules.javascript2.editor.model.JsObject;
 import org.netbeans.modules.javascript2.editor.model.Model;
 import org.netbeans.modules.javascript2.editor.model.Occurrence;
@@ -70,6 +74,8 @@ import org.netbeans.modules.javascript2.editor.model.impl.SemiTypeResolverVisito
 import org.netbeans.modules.javascript2.editor.parser.JsParserResult;
 import org.netbeans.modules.parsing.api.Snapshot;
 import org.netbeans.modules.parsing.spi.indexing.support.IndexResult;
+import org.netbeans.modules.parsing.spi.indexing.support.QuerySupport;
+import org.netbeans.modules.web.common.api.LexerUtils;
 import org.openide.filesystems.FileObject;
 import org.openide.util.Exceptions;
 
@@ -121,14 +127,14 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                                         int docTsOffset = LexUtilities.getLexerOffset(jsResult, ts.offset());
                                         if (!(docTsOffset <= docOffset && docOffset <= (docTsOffset + ts.token().length()))) {
                                             // return the declaration only if it's not the same identifier
-                                            return new DeclarationLocation(fo, docOffset);
+                                            return new DeclarationLocation(fo, docOffset, object);
                                         }
                                     }
                                 }
                             }
                         } else {
                             // TODO we need to solve to translating model offsets to the doc offset for other files?
-                            return new DeclarationLocation(fo, getDeclarationOffset(object));
+                            return new DeclarationLocation(fo, getDeclarationOffset(object), object);
                         }
                         
                     }
@@ -140,6 +146,63 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                     if (location != null) {
                         return location;
                     }
+                    // get FQN of the object that we need resolved
+                    String fqn = object.getFullyQualifiedName();
+                    // we need all parts of FQN
+                    String[] fqnParts = fqn.split("\\.");
+                    // parent should contain the top object
+                    parent = object;
+                    while (parent != null  && !fqnParts[0].equals(parent.getFullyQualifiedName())) {
+                        parent  = parent.getParent();
+                    }
+                    if (parent == null) {
+                        return DeclarationLocation.NONE;
+                    }
+                    int partIndex = 1;
+                    // find the last object that is defined in the file / model. The rest will be done through the index. 
+                    while (partIndex < fqnParts.length) {
+                        JsObject property = parent.getProperty(fqnParts[partIndex]);
+                        if (property != null && property.isDeclared()) {
+                            partIndex++;
+                            parent = property;
+                        } else {
+                            break;
+                        }
+                    }
+                    // build the FQN of the last defined property in the file / model
+                    String lastDefinedFQN = parent.getFullyQualifiedName();
+                    List<IndexResult> rItems = new ArrayList();
+                    if (partIndex < fqnParts.length) {
+                        // find the next property from FQN in the index for the defined property in the file / model
+                        rItems.addAll(findPropertyOfType(jsIndex, lastDefinedFQN.toString(), fqnParts[partIndex]));
+                        parent = findPropertyOrParameterInModel(parent, fqnParts[partIndex]);
+                        partIndex++;
+                        for (int i = partIndex; (!rItems.isEmpty()) && i < fqnParts.length; i++ ) {
+                            List<IndexResult> copy = new ArrayList(rItems);
+                            rItems.clear();
+                            // and for the found property find next property from the FQN
+                            for (IndexResult indexResult : copy) {
+                                rItems.addAll(findPropertyOfType(jsIndex, IndexedElement.getFQN(indexResult), fqnParts[i]));
+                            }
+                            if (rItems.isEmpty() && parent != null) {
+                                // require js places parameter assignment only in the model. The assignments are not available in the indes
+                                Collection<? extends TypeUsage> assigns = parent.getAssignments();
+                                if (!assigns.isEmpty()) {
+                                    for (Type type : assigns) {
+                                        String afqn = getFQNFromType(type);
+                                        rItems.addAll(findPropertyOfType(jsIndex, afqn, fqnParts[i]));
+                                    }
+                                }
+                            }
+                            if (parent != null) {
+                                parent = findPropertyOrParameterInModel(parent, fqnParts[i]);
+                            }
+                        }
+                    }
+                    location = processIndexResult(rItems);
+                    if (location != null) {
+                        return location;
+                    }
                 } 
             } else {
                 FileObject fo = object.getFileObject();
@@ -148,11 +211,11 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                         if (fo.equals(snapshot.getSource().getFileObject())) {
                             int docOffset = LexUtilities.getLexerOffset(jsResult, getDeclarationOffset(object));
                             if (docOffset > -1) {
-                                return new DeclarationLocation(fo, docOffset);
+                                return new DeclarationLocation(fo, docOffset, object);
                             }
                         } else {
                             // TODO we need to solve to translating model offsets to the doc offset for other files?
-                            return new DeclarationLocation(fo, getDeclarationOffset(object));
+                            return new DeclarationLocation(fo, getDeclarationOffset(object), object);
                         }
                         
                     }
@@ -192,6 +255,26 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                 return loc;
             }
         }
+        // try to find the symbol in index and offer the declarations. 
+        if (occurrence != null) {
+            JsObject object = occurrence.getDeclarations().iterator().next();
+            FileObject fo = object.getFileObject();
+            if (fo != null && object.getName() != null) {
+                Collection<? extends IndexResult> items = JsIndex.get(fo).query(JsIndex.FIELD_BASE_NAME, object.getName(), QuerySupport.Kind.EXACT, JsIndex.TERMS_BASIC_INFO);
+                List<IndexResult> indexResults = new ArrayList<IndexResult>();
+                for (IndexResult item : items) {
+                    IndexedElement element = IndexedElement.create(item);
+                    if (!element.getModifiers().contains(Modifier.PRIVATE) && element.getJSKind() != JsElement.Kind.PARAMETER) {
+                        indexResults.add(item);
+                    }
+                }
+                DeclarationLocation location = processIndexResult(indexResults);
+                if (location != null) {
+                    return location;
+                }
+            }
+        }
+        
         return DeclarationLocation.NONE;
     }
 
@@ -201,11 +284,36 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                 : object.getOffset();
     }
     
+    private JsObject findPropertyOrParameterInModel(JsObject parent, String name) {
+        JsObject object = parent.getProperty(name);
+        if (object == null && parent instanceof JsFunction) {
+            object = ((JsFunction)parent).getParameter(name);
+        } 
+        return object;
+    }
+    
     private Collection<? extends IndexResult> findPropertyOfType(JsIndex jsIndex, String fqn, String propertyName) {
-        Collection<? extends IndexResult> items = jsIndex.findByFqn(
-                fqn + "." + propertyName, JsIndex.TERMS_BASIC_INFO); // NOI18N
+        return findPropertyOfType(jsIndex, fqn, propertyName, 0);
+    }
+    
+    private Collection<? extends IndexResult> findPropertyOfType(JsIndex jsIndex, String fqn, String propertyName, int count) {
+        List<IndexResult> items = new ArrayList();
+        if (count > 5) {
+            return items;
+        }
+        items.addAll(jsIndex.findByFqn(
+                fqn + "." + propertyName, JsIndex.TERMS_BASIC_INFO)); // NOI18N
         if (items.isEmpty()) {
-            items = jsIndex.findByFqn(fqn + ".prototype." + propertyName, JsIndex.TERMS_BASIC_INFO); // NOI18N
+            items.addAll(jsIndex.findByFqn(fqn + ".prototype." + propertyName, JsIndex.TERMS_BASIC_INFO)); // NOI18N
+        }
+        if (items.isEmpty()) {
+            Collection<? extends IndexResult> findByFqn = jsIndex.findByFqn(fqn, JsIndex.TERMS_BASIC_INFO);
+            for (IndexResult indexResult : findByFqn) {
+            Collection<TypeUsage> assignments = IndexedElement.getAssignments(indexResult);
+                for (Type tmpType : assignments) {
+                    items.addAll(findPropertyOfType(jsIndex, getFQNFromType(tmpType), propertyName, count++));
+                }
+            }
         }
         return items;
     }
@@ -259,6 +367,18 @@ public class DeclarationFinderImpl implements DeclarationFinder {
                     ts.move(caretOffset);
                     if (ts.moveNext() && ts.token().id() == JsTokenId.IDENTIFIER) {
                         value[0] = new OffsetRange(ts.offset(), ts.offset() + ts.token().length());
+                    } else if (ts.token() != null && ts.token().id() == JsTokenId.DOC_COMMENT) {
+                        TokenSequence<? extends JsDocumentationTokenId> tsDoc = LexerUtils.getTokenSequence(doc, caretOffset, JsDocumentationTokenId.language(), true);
+                        if (tsDoc != null) {
+                            if (tsDoc.token() != null && tsDoc.token().id() == JsDocumentationTokenId.OTHER) {
+                                if (tsDoc.moveNext() && tsDoc.token().id() == JsDocumentationTokenId.BRACKET_RIGHT_CURLY
+                                        && tsDoc.movePrevious() && tsDoc.movePrevious() && tsDoc.token().id() == JsDocumentationTokenId.BRACKET_LEFT_CURLY) {
+                                    tsDoc.moveNext();
+                                    value[0] = new OffsetRange(tsDoc.offset(), tsDoc.offset() + tsDoc.token().length());
+                                }
+                            }
+                        }
+                        
                     }
                 }
             }
