@@ -64,9 +64,14 @@ public abstract class SanitizingParser extends Parser {
 
     private static final Logger LOGGER = Logger.getLogger(SanitizingParser.class.getName());
     
-    private static final boolean PARSE_BIG_FILES = Boolean.getBoolean("nb.js.parse.big.files"); //NOI18N
-    private static final long MAX_FILE_SIZE_TO_PARSE = Integer.getInteger("nb.js.big.file.size", 1024 * 1024); //NOI18N
-    private static final long MAX_MINIMIZE_FILE_SIZE_TO_PARSE = Integer.getInteger("nb.js.big.minimize.file.size", (1024 * 1024) / 3); //NOI18N
+    public static final boolean PARSE_BIG_FILES = Boolean.getBoolean("nb.js.parse.big.files"); //NOI18N
+    public static final long MAX_FILE_SIZE_TO_PARSE = Integer.getInteger("nb.js.big.file.size", 1024 * 1024); //NOI18N
+    private static final long MAX_MINIMIZE_FILE_SIZE_TO_PARSE = Integer.getInteger("nb.js.big.minimize.file.size", 0); //NOI18N
+    /**
+     * This is count of closing curly brackets that follows at the end of a json file. 
+     * If the file has sequence of MAX_RICHT_CURLY_BRACKETS, then it's not parse due stack overflow.
+     */
+    private static final int MAX_RIGHT_CURLY_BRACKETS = 30;
 
     private final Language<JsTokenId> language;
 
@@ -94,7 +99,7 @@ public abstract class SanitizingParser extends Parser {
 
     protected abstract String getDefaultScriptName();
 
-    protected abstract FunctionNode parseSource(Snapshot snapshot, String name, String text, JsErrorManager errorManager) throws Exception;
+    protected abstract FunctionNode parseSource(Snapshot snapshot, String name, String text, int caretOffset,  JsErrorManager errorManager) throws Exception;
 
     protected abstract String getMimeType();
     
@@ -146,7 +151,7 @@ public abstract class SanitizingParser extends Parser {
                 return false;
             }
 
-            if (size > MAX_MINIMIZE_FILE_SIZE_TO_PARSE) {
+            if (size > MAX_MINIMIZE_FILE_SIZE_TO_PARSE && !snapshot.getMimeType().equals(JsTokenId.JSON_MIME_TYPE)) {
                 // try to find only for the file that has size bigger then 1/3 of the max size
                 boolean isMinified = false;
                 TokenSequence<? extends JsTokenId> ts = LexUtilities.getTokenSequence(snapshot, 0, language);
@@ -155,7 +160,7 @@ public abstract class SanitizingParser extends Parser {
                     int countedLines = 0;
                     int countChars = 0;
                     while (!isMinified && ts.moveNext() && countedLines < 5) {
-                        LexUtilities.findNext(ts, Arrays.asList(JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT, JsTokenId.EOL));
+                        LexUtilities.findNext(ts, Arrays.asList(JsTokenId.DOC_COMMENT, JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT, JsTokenId.EOL, JsTokenId.WHITESPACE));
                         offset = ts.offset();
                         LexUtilities.findNextToken(ts, Arrays.asList(JsTokenId.EOL));
                         countChars += (ts.offset() - offset);
@@ -168,6 +173,23 @@ public abstract class SanitizingParser extends Parser {
                         return false;
                     }
                 }
+            } else if (snapshot.getMimeType().equals(JsTokenId.JSON_MIME_TYPE)) {
+                int index = text.length() - 1;
+                char ch = text.charAt(index);
+                while (index > 0 && ch != '}') {
+                    index--;
+                    ch = text.charAt(index);
+                }
+                int count = 0;
+                while (index > 0 && ch == '}' && count <= MAX_RIGHT_CURLY_BRACKETS) {
+                    index--;
+                    count++;
+                    ch = text.charAt(index);
+                    
+                }
+                if (count >= MAX_RIGHT_CURLY_BRACKETS) {   // See issue 247274
+                    return false;
+                }
             }
         }
         return true;
@@ -196,7 +218,7 @@ public abstract class SanitizingParser extends Parser {
         
         JsErrorManager current = new JsErrorManager(context.getSnapshot(), language);
         FunctionNode node = parseSource(context.getSnapshot(), context.getName(),
-                context.getSource(), current);
+                context.getSource(), context.getCaretOffset(), current);
 
         if (copyErrors) {
             errorManager.fillErrors(current);
@@ -264,6 +286,12 @@ public abstract class SanitizingParser extends Parser {
                         int start = ts.offset();
                         if (start >= 0 && ts.moveNext()) {
                             int end = ts.offset();
+                            ts.movePrevious();
+                            while(ts.movePrevious() && ts.token().id() == JsTokenId.WHITESPACE) {
+                            }
+                            if (ts.token().id() == JsTokenId.OPERATOR_DOT) {
+                                start = ts.offset();
+                            }
                             StringBuilder builder = new StringBuilder(context.getOriginalSource());
                             erase(builder, start, end);
                             context.setSanitizedSource(builder.toString());
