@@ -70,6 +70,10 @@ public class JsCodeCompletionGeneralTest extends JsCodeCompletionBase {
     public void testIssue217029_01() throws Exception {
         checkCompletion("testfiles/completion/issue217029.js", "element.ch^arAt(10);", false);
     }
+    
+    public void testIssue217029_02() throws Exception {
+        checkCompletion("testfiles/completion/issue217029.js", "element.ch^        //here", false);
+    }
 
     public void testIssue215861_01() throws Exception {
         checkCompletion("testfiles/completion/issue215861.js", "console.log(\"Browser \"+navigator.^);", false);
@@ -367,6 +371,50 @@ public class JsCodeCompletionGeneralTest extends JsCodeCompletionBase {
         checkCompletion("testfiles/completion/general/findObjectByOffset.js", "return this._age.to^Fixed(1);", false);
     }
     
+    public void testIssue248132_01() throws Exception {
+        checkCompletion("testfiles/completion/general/issue248132.js", "var issue248132 = Date.U^TC();", false);
+    }
+    
+    public void testIssue248132_02() throws Exception {
+        checkCompletion("testfiles/completion/general/issue248132.js", "var issue248132 = Da^te.UTC();", false);
+    }
+    
+    public void testIssue248132_03() throws Exception {
+        checkCompletion("testfiles/completion/general/issue248132.js", "var w1 = new window.Wo^rker();", false);
+    }
+    
+    public void testIssue248132_04() throws Exception {
+        checkCompletion("testfiles/completion/general/issue248132.js", "var w2 = window.Wo^rker;", false);
+    }
+    
+    public void testIssue251821_01() throws Exception {
+        checkCompletion("testfiles/completion/general/issue251821.js", "var res = a1.aproper^ty.toLocaleString(); ", false);
+    }
+    
+    public void testIssue251968_01() throws Exception {
+        checkCompletion("testfiles/completion/general/issue251821.js", "var res = a1.aproperty.to^LocaleString(); ", false);
+    }
+    
+    public void testIssue205127_01() throws Exception {
+        checkCompletion("testfiles/completion/general/issue205127.js", "document.getElementById(\"in1\").va^;", false);
+    }
+    
+    public void testIssue205127_02() throws Exception {
+        checkCompletion("testfiles/completion/general/issue205127.js", "elem.st^yle.color = \"FFFFF\";", false);
+    }
+    
+    public void testIssue237421_01() throws Exception {
+        checkCompletion("testfiles/completion/general/issue237421.js", "var foo = this.g^ ;", false);
+    }
+    
+    public void testIssue237421_02() throws Exception {
+        checkCompletion("testfiles/completion/general/issue237421.js", "var foo2 = this.getTest().m^;", false);
+    }
+    
+    public void testIssue237421_03() throws Exception {
+        checkCompletion("testfiles/completion/general/issue237421.js", "var foo3 = this.getTest().property1.a^;", false);
+    }
+    
     @Override
     protected Map<String, ClassPath> createClassPathsForTest() {
         List<FileObject> cpRoots = new LinkedList<FileObject>(ClasspathProviderImplAccessor.getJsStubs());
