@@ -524,7 +524,127 @@ public class JsStructureScannerTest extends JsTestBase {
         checkStructure("testfiles/structure/issue241963.js");
     }
     
+    public void testIssue243140_01() throws Exception {
+        checkStructure("testfiles/structure/issue243140_01.js");
+    }
+    
+    public void testIssue243140_02() throws Exception {
+        checkStructure("testfiles/structure/issue243140_02.js");
+    }
+    
     public void testIssue246896() throws Exception {
         checkStructure("testfiles/structure/issue246896.js");
     }
+    
+    public void testIssue247365() throws Exception {
+        checkStructure("testfiles/structure/issue247365.js");
+    }
+    
+    public void testIssue247564() throws Exception {
+        checkStructure("testfiles/structure/issue247564.js");
+    }
+    
+    public void testIssue237878() throws Exception {
+        checkStructure("testfiles/completion/issue237878.js");
+    }
+    
+    public void testIssue190645() throws Exception {
+        checkStructure("testfiles/markoccurences/issue190645.js"); 
+    }
+    
+    public void testIssue249006() throws Exception {
+        checkStructure("testfiles/coloring/issue249006.js");
+    }
+    
+    public void testIssue249119() throws Exception {
+        checkStructure("testfiles/coloring/issue249119.js");
+    }
+    
+    public void testIssue250112() throws Exception {
+        checkStructure("testfiles/markoccurences/issue250112.js"); 
+    }
+    
+    public void testIssue250110() throws Exception {
+        checkStructure("testfiles/markoccurences/issue250110.js"); 
+    }
+    
+    public void testCallBackDeclaration1() throws Exception {
+        checkStructure("testfiles/markoccurences/callbackDeclaration1.js"); 
+    }
+    
+    public void testCallBackDeclaration2() throws Exception {
+        checkStructure("testfiles/markoccurences/callbackDeclaration2.js"); 
+    }
+    
+    public void testIssue250392() throws Exception {
+        checkStructure("testfiles/structure/issue250392.js");
+    }
+    
+    public void testIssue251758() throws Exception {
+        checkStructure("testfiles/structure/issue251758.js");
+    }
+    
+    public void testIssue245528() throws Exception {
+        checkStructure("testfiles/structure/issue245528.js");
+    }
+    
+    public void testIssue238685_01() throws Exception {
+        checkStructure("testfiles/model/issue238685_01.js");
+    }
+    
+    public void testIssue252022() throws Exception {
+        checkStructure("testfiles/hints/issue252022.js");
+    }
+    
+    public void testIssue249487() throws Exception {
+        checkStructure("testfiles/markoccurences/issue249487.js");
+    }
+    
+    public void testIssue252375() throws Exception {
+        checkStructure("testfiles/markoccurences/issue252375.js");
+    }
+    
+    public void testIssue252028() throws Exception {
+        checkStructure("testfiles/structure/issue252028.js");
+    }
+    
+    public void testIssue234480() throws Exception {
+        checkStructure("testfiles/structure/issue234480.js");
+    }
+    
+    public void testIssue224796() throws Exception {
+        checkStructure("testfiles/structure/issue224796.js");
+    }
+    
+    public void testIssue243566() throws Exception {
+        checkStructure("testfiles/coloring/issue243566.js");
+    }
+    
+    public void testIssue246451() throws Exception {
+        checkStructure("testfiles/coloring/issue246451.js");
+    }
+    
+    public void testIssue245916() throws Exception {
+        checkStructure("testfiles/structure/issue245916.js");
+    }
+    
+    public void testIssue253128() throws Exception {
+        checkStructure("testfiles/structure/issue253128.js");
+    }
+    
+    public void testIssue253147() throws Exception {
+        checkStructure("testfiles/structure/issue253147.js");
+    }
+    
+    public void testIssue253129() throws Exception {
+        checkStructure("testfiles/coloring/issue253129.js");
+    }
+    
+    public void testIssue224463() throws Exception {
+        checkStructure("testfiles/structure/issue224463.js");
+    }
+    
+    public void testIssue233155() throws Exception {
+        checkStructure("testfiles/structure/issue233155.js");
+    }
 }
