@@ -51,6 +51,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.regex.Pattern;
 import org.netbeans.api.lexer.Token;
+import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
@@ -70,7 +71,7 @@ import org.netbeans.modules.javascript2.requirejs.editor.EditorUtils;
 import org.netbeans.modules.javascript2.requirejs.editor.FSCompletionUtils;
 import org.netbeans.modules.javascript2.requirejs.editor.index.RequireJsIndex;
 import org.netbeans.modules.javascript2.requirejs.editor.index.RequireJsIndexer;
-import org.netbeans.modules.parsing.api.Source;
+import org.netbeans.modules.parsing.api.Snapshot;
 import org.openide.filesystems.FileObject;
 import org.openide.util.Exceptions;
 
@@ -90,7 +91,8 @@ public class DefineInterceptor implements FunctionInterceptor {
     }
 
     @Override
-    public void intercept(String name, JsObject globalObject, DeclarationScope scope, ModelElementFactory factory, Collection<FunctionArgument> args) {
+    public Collection<TypeUsage> intercept(Snapshot snapshot, String name, JsObject globalObject,
+            DeclarationScope scope, ModelElementFactory factory, Collection<FunctionArgument> args) {
         FunctionArgument fArg = null;
         FunctionArgument modules = null;
 
@@ -116,7 +118,7 @@ public class DefineInterceptor implements FunctionInterceptor {
         FileObject fo = globalObject.getFileObject();
         if (fo == null) {
             // no action
-            return;
+            return Collections.emptyList();
         }
 
         if (fArg != null) {
@@ -132,13 +134,12 @@ public class DefineInterceptor implements FunctionInterceptor {
 
                 if (posibleFunc != null && posibleFunc instanceof JsFunction) {
                     JsFunction defFunc = (JsFunction) posibleFunc;
-                    Source source = Source.create(fo);
-                    List<String> paths = new ArrayList<String>();
-                    if (modules != null) {
-                        TokenSequence<? extends JsTokenId> ts = LexUtilities.getJsTokenSequence(source.createSnapshot().getTokenHierarchy(), modules.getOffset());
+                    List<String> paths = new ArrayList<>();
+                    if (modules != null && snapshot != null) {
+                        TokenSequence<? extends JsTokenId> ts = LexUtilities.getJsTokenSequence(snapshot.getTokenHierarchy(), snapshot.getOriginalOffset(modules.getOffset()));
                         if (ts == null) {
-                            return;
-                        }
+                            return Collections.emptyList();
+                        } 
                         ts.move(modules.getOffset());
                         if (ts.moveNext()) {
                             Token<? extends JsTokenId> token = ts.token();
@@ -180,7 +181,7 @@ public class DefineInterceptor implements FunctionInterceptor {
                     } else if (modules != null && modules.getValue() instanceof JsArray) {
                         Project project = FileOwnerQuery.getOwner(fo);
                         if (project == null || !RequireJsPreferences.getBoolean(project, RequireJsPreferences.ENABLED)) {
-                            return;
+                            return Collections.emptyList();
                         }
                         // add assignments for the parameters
                         if (!paths.isEmpty()) {
@@ -212,32 +213,37 @@ public class DefineInterceptor implements FunctionInterceptor {
                 }
             }
         } else if (modules != null && modules.getValue() instanceof String) {
-            Source source = Source.create(fo);
             Project project = FileOwnerQuery.getOwner(fo);
             if (project == null || !RequireJsPreferences.getBoolean(project, RequireJsPreferences.ENABLED)) {
-                return;
+                return Collections.emptyList();
+            }
+            TokenHierarchy<?> th = snapshot.getTokenHierarchy();
+            TokenSequence<? extends JsTokenId> ts = null;
+            if (th != null) {
+                ts = LexUtilities.getJsTokenSequence(th, modules.getOffset());
             }
-            TokenSequence<? extends JsTokenId> ts = LexUtilities.getJsTokenSequence(source.createSnapshot().getTokenHierarchy(), modules.getOffset());
             if (ts == null) {
-                return;
+                return Collections.emptyList();
             }
             ts.move(modules.getOffset());
             if (ts.movePrevious()) {
                 Token<? extends JsTokenId> token = ts.token();
                 token = LexUtilities.findPrevious(ts, Arrays.asList(JsTokenId.WHITESPACE, JsTokenId.EOL, JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT,
                         JsTokenId.STRING_BEGIN, JsTokenId.BRACKET_LEFT_PAREN));
-                if (token.id() == JsTokenId.IDENTIFIER && EditorUtils.REQUIRE.equals(token.text().toString()) && ts.movePrevious()) {
+                if (token.id() == JsTokenId.IDENTIFIER
+                        && (EditorUtils.REQUIRE.equals(token.text().toString()) || EditorUtils.REQUIREJS.equals(token.text().toString()))
+                        && ts.movePrevious()) {
+                    RequireJsIndex rIndex = null;
+                    try {
+                        rIndex = RequireJsIndex.get(project);
+                    } catch (IOException ex) {
+                        Exceptions.printStackTrace(ex);
+                    }
                     token = LexUtilities.findPrevious(ts, Arrays.asList(JsTokenId.WHITESPACE, JsTokenId.EOL, JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT));
                     if (token.id() == JsTokenId.OPERATOR_ASSIGNMENT && ts.movePrevious()) {
                         token = LexUtilities.findPrevious(ts, Arrays.asList(JsTokenId.WHITESPACE, JsTokenId.EOL, JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT));
                         if (token.id() == JsTokenId.IDENTIFIER) {
-                            // now we have the name of the object, that contains the expoert from module
-                            RequireJsIndex rIndex = null;
-                            try {
-                                rIndex = RequireJsIndex.get(project);
-                            } catch (IOException ex) {
-                                Exceptions.printStackTrace(ex);
-                            }
+                            // now we have the name of the object, that contains the export from module
                             if (rIndex != null) {
                                 FileObject fileObject = FSCompletionUtils.findMappedFileObject(modules.getValue().toString(), fo);
                                 if (fileObject != null) {
@@ -264,11 +270,44 @@ public class DefineInterceptor implements FunctionInterceptor {
                                 }
                             }
                         }
+                    } else {
+                        // there is no assignment, we should add return type for require/requirejs function to enable CC
+                        // even for case: require('app/myModule').| 
+                        ts.moveNext();
+                        token = LexUtilities.findNext(ts, Arrays.asList(JsTokenId.WHITESPACE, JsTokenId.EOL, JsTokenId.BLOCK_COMMENT, JsTokenId.LINE_COMMENT));
+                        String requireFunctionName = null;
+                        if (token.id() == JsTokenId.IDENTIFIER
+                                && (EditorUtils.REQUIRE.equals(token.text().toString()) || EditorUtils.REQUIREJS.equals(token.text().toString()))) {
+                            // find out whether require or requirejs has been used
+                            requireFunctionName = token.text().toString();
+                        }
+                        if (rIndex != null && requireFunctionName != null) {
+                            FileObject fileObject = FSCompletionUtils.findMappedFileObject(modules.getValue().toString(), fo);
+                            if (fileObject != null) {
+                                Collection<? extends TypeUsage> exposedTypes = rIndex.getExposedTypes(fileObject.getName(), factory);
+                                JsObject requireObj = globalObject.getProperty(requireFunctionName);
+                                if (requireObj != null) {
+                                    if (!(requireObj instanceof JsFunction)) {
+                                        JsObject parent = requireObj.getParent();
+                                        requireObj = factory.newFunction(scope, requireObj.getParent(), requireObj.getName(), new ArrayList<String>());
+                                        parent.addProperty(requireObj.getName(), requireObj);
+                                    }
+                                    if (requireObj instanceof JsFunction) {
+                                        JsFunction requireFun = (JsFunction) globalObject.getProperty(requireFunctionName);
+                                        // now add all typeUsages found in index as return types
+                                        for (TypeUsage typeUsage : exposedTypes) {
+                                            requireFun.addReturnType(typeUsage);
+                                        }
+                                    }
+                                }
+                            }
+                        }
                     }
                 }
             }
 
         }
+        return Collections.emptyList();
     }
 
     private boolean saveToIndex() {
