@@ -398,7 +398,7 @@ final class RequireJsPanel extends JPanel implements HelpCtx.Provider {
             int row = table.rowAtPoint(p);
             int col = table.columnAtPoint(p);
             Object value = table.getValueAt(row, col);
-            if (value instanceof LocalPathCell) {
+            if (isSupportEnabled && value instanceof LocalPathCell) {
                 Rectangle cellRect = table.getCellRect(row, col, false);
                 LocalPathCell localPathCell = (LocalPathCell) value;
                 JButton button = localPathCell.getButton();
@@ -447,6 +447,6 @@ final class RequireJsPanel extends JPanel implements HelpCtx.Provider {
 
     @Override
     public HelpCtx getHelpCtx() {
-        return null;
+        return new HelpCtx("org.netbeans.modules.javascript2.requirejs.ui.RequireJsPanel");
     }
 }
