@@ -122,7 +122,7 @@ public class RequireFileCodeCompletionTest extends JsCodeCompletionBase {
     }
     
     public void testFSCompletion04() throws Exception {
-        checkAppliedCompletion("TestProject1/js/fileCC/main3.js", "requirejs(['^']);", "requirejs(['folder1/^']);", "folder1", false);
+        checkAppliedCompletion("TestProject1/js/fileCC/main3.js", "requirejs(['^']);", "requirejs(['./folder1/^']);", "folder1", false);
         
     }
     
@@ -158,6 +158,54 @@ public class RequireFileCodeCompletionTest extends JsCodeCompletionBase {
         checkCompletion("TestProject1/js/folder2/fs.js", "'lib/api/v0.1/OM^',", false);        
     }
     
+    public void testIssue248197_01() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest01.js", "var a = require('^');", "var a = require('./aaa^');", "aaa", false);        
+    }
+    
+    public void testIssue248197_02() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest02.js", "var a2 = require('./^');", "var a2 = require('./aaa^');", "aaa", false);        
+    }
+    
+    public void testIssue248197_03() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest03.js", "var a3 = require('./a^');", "var a3 = require('./aaa^');", "aaa", false);        
+    }
+    
+    public void testIssue248197_04() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest04.js", "var l1 = require('^');", "var l1 = require('./lib/^');", "lib", false);        
+    }
+
+    public void testIssue248197_05() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest05.js", "var l2 = require('./l^');", "var l2 = require('./lib/^');", "lib", false);        
+    }
+
+    public void testIssue248197_06() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest06.js", "var l3 = require('./lib/^');", "var l3 = require('./lib/bbb^');", "bbb", false);        
+    }
+    
+    public void testIssue248197_07() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue248197/mainTest07.js", "var l4 = require('./lib/b^');", "var l4 = require('./lib/bbb^');", "bbb", false);        
+    }
+    
+    public void testIssue248198_01() throws Exception {
+        checkCompletion("TestProject1/js/fileCC/folder1/module2.js", "var a2 = require('./^');", false);        
+    }
+    
+    public void testIssue247759_01() throws Exception {
+        checkCompletion("TestProject1/js/folder1/api/v0.1/issue247759.js", "define(['^'], function () {});", false);        
+    }
+    
+    public void testIssue247729_01() throws Exception {
+        checkAppliedCompletion("TestProject1/js/main3.js", "'text!fileCC/folder2/template/^',", "'text!fileCC/folder2/template/body.html^',", "body", false);        
+    }
+    
+    public void testIssue249026_01() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue249026/base.dt/js/issue249026_1.js", "'^'", "'base.dt/^'", "base.dt", false);        
+    }
+    
+    public void testIssue249026_02() throws Exception {
+        checkAppliedCompletion("TestProject1/js/fileCC/issue249026/base.dt/js/issue249026_2.js", "'b^'", "'base.dt/^'", "base.dt", false);        
+    }
+    
     public void checkAppliedCompletion(final String file, final String caretLine, final String expectedLine, final String itemToComplete, final boolean includeModifiers) throws Exception {
         final CodeCompletionHandler.QueryType type = CodeCompletionHandler.QueryType.COMPLETION;
         final boolean caseSensitive = true;
@@ -354,7 +402,7 @@ public class RequireFileCodeCompletionTest extends JsCodeCompletionBase {
                 });
 
                 assertDescriptionMatches(file, bd.getText(0, bd.getLength()), true, ".expected.js");
-                final String fileName = file.substring(0, file.indexOf(".")) + ".js." + getName() + ".expected.js";
+                final String fileName = file.substring(0, file.lastIndexOf(".")) + ".js." + getName() + ".expected.js";
                 assertTrue("File not found: " + getTestFile(fileName).getPath(), getTestFile(fileName).isValid());
                 Source expectedSource = getTestSource(getTestFile(fileName));
                 final StringBuilder expectedContent = new StringBuilder(expectedSource.getDocument(false).getText(0, expectedSource.getDocument(false).getLength()));
