@@ -51,6 +51,7 @@ package org.netbeans.modules.jumpto.file;
 import java.awt.Color;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
+import java.awt.event.KeyEvent;
 import java.util.Arrays;
 import java.util.List;
 import java.util.logging.Level;
@@ -61,6 +62,8 @@ import javax.swing.Action;
 import javax.swing.BorderFactory;
 import javax.swing.ButtonModel;
 import javax.swing.Icon;
+import javax.swing.InputMap;
+import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.KeyStroke;
@@ -75,9 +78,11 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
+import org.netbeans.api.annotations.common.StaticResource;
 import org.netbeans.api.project.Project;
-import org.netbeans.api.project.ProjectInformation;
+import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.modules.jumpto.SearchHistory;
 import org.netbeans.modules.jumpto.common.UiUtils;
 import org.netbeans.spi.jumpto.file.FileDescriptor;
@@ -85,13 +90,19 @@ import org.openide.util.ImageUtilities;
 import org.openide.util.Mutex;
 import org.openide.util.NbBundle;
 import org.openide.util.NbCollections;
+import org.openide.util.Pair;
 
 /**
  *
- * @author  Petr Hrebejk, Andrei Badea, Tomas Zezula
+ * @author  Petr Hrebejk
+ * @author  Andrei Badea
+ * @author  Tomas Zezula
  */
 public class FileSearchPanel extends javax.swing.JPanel implements ActionListener {
 
+    @StaticResource
+    private static final String WAIT_ICON_RES = "org/netbeans/modules/jumpto/resources/wait.gif";    // NOI18N
+    private static Icon WAIT_ICON = ImageUtilities.loadImageIcon(WAIT_ICON_RES, false);
     public static final String SEARCH_IN_PROGRES = NbBundle.getMessage(FileSearchPanel.class, "TXT_SearchingOtherProjects"); // NOI18N
     private static Icon WARN_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/jumpto/resources/warning.png", false); // NOI18N
     private static final Logger LOG = Logger.getLogger(FileSearchPanel.class.getName());
@@ -100,7 +111,6 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
     private final Project currentProject;
     private boolean containsScrollPane;
     private JLabel messageLabel;
-    private String oldText;
     private List<?> selectedItems;
     /* package */ long time;
 
@@ -140,10 +150,11 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
         if ( currentProject == null ) {
             mainProjectCheckBox.setEnabled(false);
             mainProjectCheckBox.setSelected(false);
-        }
-        else {
-            ProjectInformation pi = currentProject.getLookup().lookup(ProjectInformation.class);
-            mainProjectCheckBox.setText(NbBundle.getMessage(FileSearchPanel.class, "FMT_CurrentProjectLabel", pi.getDisplayName())); // NOI18N
+        } else {
+            mainProjectCheckBox.setText(NbBundle.getMessage(
+                FileSearchPanel.class,
+                "FMT_CurrentProjectLabel",
+                ProjectUtils.getInformation(currentProject).getDisplayName()));
         }
         
         mainProjectCheckBox.addActionListener(this);
@@ -154,7 +165,8 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
         resultList.setCellRenderer( contentProvider.getListCellRenderer(
                 resultList,
                 fileNameTextField.getDocument(),
-                caseSensitiveCheckBox.getModel()));
+                caseSensitiveCheckBox.getModel(),
+                mainProjectCheckBox.getModel()));
         resultList.addListSelectionListener(new ListSelectionListener() {
             @Override
             public void valueChanged(ListSelectionEvent e) {
@@ -208,7 +220,6 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
                     "Reset selected items");    //NOI18N
                 selectedItems = null;
                 resultList.setModel(model);
-                ((FileSearchAction.Renderer) resultList.getCellRenderer()).setColorPrefered(isPreferedProject());
                 if (done) {
                     setListPanelContent(null,false);
                 }
@@ -226,13 +237,13 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
                         setWarning(NbBundle.getMessage(
                             FileSearchPanel.class,
                             "TXT_PartialResults"));
-                        final int index = resultList.getSelectedIndex();
-                        if (index == -1) {
-                            LOG.log(
-                                Level.FINE,
-                                "Select first item.");  //NOI18N
-                            resultList.setSelectedIndex(0);
-                        }
+                    }
+                    final int index = resultList.getSelectedIndex();
+                    if (index == -1) {
+                        LOG.log(
+                            Level.FINE,
+                            "Select first item.");  //NOI18N
+                        resultList.setSelectedIndex(0);
                     } else if (selectedItems != null && !selectedItems.isEmpty()) {
                         LOG.log(
                             Level.FINE,
@@ -258,25 +269,32 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
         });
     }
 
-    void searchCompleted() {
-        Mutex.EVENT.readAccess(new Runnable() {
-            @Override
-            public void run() {
-                if (resultList.getModel().getSize() > 0) {
-                    setWarning(null);
-                } else {
-                    try {
-                       Pattern.compile(getText().replace(".", "\\.").replace( "*", ".*" ).replace( '?', '.' ), Pattern.CASE_INSENSITIVE); // NOI18N
-                       setListPanelContent( NbBundle.getMessage(FileSearchPanel.class, "TXT_NoTypesFound") ,false ); // NOI18N
-                   } catch (PatternSyntaxException pse) {
-                       setListPanelContent( NbBundle.getMessage(FileSearchPanel.class, "TXT_SyntaxError", pse.getDescription(),pse.getIndex()) ,false ); // NOI18N
-                   }
-                }
+    boolean searchCompleted(final boolean success) {
+        assert SwingUtilities.isEventDispatchThread();
+        setWarning(null);
+        boolean res;
+        if (success) {
+            res = true;
+            String msg = null;
+            if (resultList.getModel().getSize() == 0) {
+                try {
+                   Pattern.compile(getText().replace(".", "\\.").replace( "*", ".*" ).replace( '?', '.' ), Pattern.CASE_INSENSITIVE); // NOI18N
+                   msg = NbBundle.getMessage(FileSearchPanel.class, "TXT_NoTypesFound");
+               } catch (PatternSyntaxException pse) {
+                   msg = NbBundle.getMessage(FileSearchPanel.class, "TXT_SyntaxError", pse.getDescription(),pse.getIndex());
+               }
+               res = false;
+            } else if (resultList.getSelectedIndex() == -1) {
+                resultList.setSelectedIndex(0);
             }
-        });
+            setListPanelContent(msg, false);
+        } else {
+            res = false;
+        }
+        return res;
     }
 
-    void setListPanelContent( String message, boolean waitIcon ) {
+    private void setListPanelContent( String message, boolean waitIcon ) {
         if ( message == null && !containsScrollPane ) {
            listPanel.remove( messageLabel );
            listPanel.add( resultScrollPane );
@@ -287,7 +305,7 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
         else if ( message != null ) { 
            jTextFieldLocation.setText(""); 
            messageLabel.setText(message);
-           messageLabel.setIcon( waitIcon ? FileSearchAction.Renderer.WAIT_ICON : null);
+           messageLabel.setIcon( waitIcon ? WAIT_ICON : null);
            if ( containsScrollPane ) {
                listPanel.remove( resultScrollPane );
                listPanel.add( messageLabel );
@@ -312,12 +330,10 @@ public class FileSearchPanel extends javax.swing.JPanel implements ActionListene
     
     private void update() {
         time = System.currentTimeMillis();
-        final String text = getText();        
-        if ( oldText == null || oldText.trim().length() == 0 || !text.startsWith(oldText) ) {
+        final String text = getText();
+        if (contentProvider.setListModel(this, text)) {
             setListPanelContent(NbBundle.getMessage(FileSearchPanel.class, "TXT_Searching"),true);
         }
-        oldText = text;
-        contentProvider.setListModel(this, text);
     }
 
     private void setWarning(String warningMessage) {
@@ -492,31 +508,47 @@ private void resultListValueChanged(javax.swing.event.ListSelectionEvent evt) {/
         }
 }//GEN-LAST:event_resultListValueChanged
 
+    @CheckForNull
+    private Pair<String,JComponent> listActionFor(KeyEvent ev) {
+        InputMap map = resultList.getInputMap();
+        Object o = map.get(KeyStroke.getKeyStrokeForEvent(ev));
+        if (o instanceof String) {
+            return Pair.<String,JComponent>of((String)o, resultList);
+        }
+        map = resultScrollPane.getInputMap(WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
+        o = map.get(KeyStroke.getKeyStrokeForEvent(ev));
+        if (o instanceof String) {
+            return Pair.<String,JComponent>of((String)o, resultScrollPane);
+        }
+        return null;
+    }
+
     private void fileNameTextFieldKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_fileNameTextFieldKeyPressed
-        Object actionKey = resultList.getInputMap().get(KeyStroke.getKeyStrokeForEvent(evt));
-        
+        final Pair<String,JComponent> p = listActionFor(evt);
+        final String actionKey = p == null ? null : p.first();
+        final JComponent actionTarget = p == null ? null : p.second();
+
         // see JavaFastOpen.boundScrollingKey()
-        boolean isListScrollAction = 
+        boolean isListScrollAction =
             "selectPreviousRow".equals(actionKey) || // NOI18N
-            "selectPreviousRowExtendSelection".equals(actionKey) || // NOI18N            
+            "selectPreviousRowExtendSelection".equals(actionKey) || // NOI18N
             "selectNextRow".equals(actionKey) || // NOI18N
             "selectNextRowExtendSelection".equals(actionKey) || // NOI18N
             // "selectFirstRow".equals(action) || // NOI18N
             // "selectLastRow".equals(action) || // NOI18N
-            "scrollUp".equals(actionKey) || // NOI18N            
-            "scrollUpExtendSelection".equals(actionKey) || // NOI18N            
+            "scrollUp".equals(actionKey) || // NOI18N
+            "scrollUpExtendSelection".equals(actionKey) || // NOI18N
             "scrollDown".equals(actionKey) || // NOI18N
             "scrollDownExtendSelection".equals(actionKey); // NOI18N
-        
-        
+
         int selectedIndex = resultList.getSelectedIndex();
         ListModel model = resultList.getModel();
         int modelSize = model.getSize();
-        
+
         // Wrap around
-        if ( "selectNextRow".equals(actionKey) && 
+        if ( "selectNextRow".equals(actionKey) &&
               ( selectedIndex == modelSize - 1 ||
-                ( selectedIndex == modelSize - 2 && 
+                ( selectedIndex == modelSize - 2 &&
                   model.getElementAt(modelSize - 1) == SEARCH_IN_PROGRES )
              ) ) {
             resultList.setSelectedIndex(0);
@@ -526,19 +558,18 @@ private void resultListValueChanged(javax.swing.event.ListSelectionEvent evt) {/
         else if ( "selectPreviousRow".equals(actionKey) &&
                    selectedIndex == 0 ) {
             int last = modelSize - 1;
-            
             if ( model.getElementAt(last) == SEARCH_IN_PROGRES ) {
                 last--;
-            } 
-            
+            }
             resultList.setSelectedIndex(last);
             resultList.ensureIndexIsVisible(last);
             return;
         }
-        
+
         if (isListScrollAction) {
-            Action a = resultList.getActionMap().get(actionKey);
-            a.actionPerformed(new ActionEvent(resultList, 0, (String)actionKey));
+            assert actionTarget != null;
+            final Action a = actionTarget.getActionMap().get(actionKey);
+            a.actionPerformed(new ActionEvent(actionTarget, 0, (String)actionKey));
             evt.consume();
         } else {
             //handling http://netbeans.org/bugzilla/show_bug.cgi?id=203119
@@ -589,7 +620,6 @@ private void resultListValueChanged(javax.swing.event.ListSelectionEvent evt) {/
     
     /** Sets the initial text to find in case the user did not start typing yet. */
     public void setInitialText( final String text ) {
-        oldText = text;
         SwingUtilities.invokeLater( new Runnable() {
             public void run() {
                 String textInField = fileNameTextField.getText();
@@ -647,9 +677,10 @@ private void resultListValueChanged(javax.swing.event.ListSelectionEvent evt) {/
         public ListCellRenderer getListCellRenderer(
                 @NonNull JList list,
                 @NonNull Document nameDocument,
-                @NonNull ButtonModel caseSensitive);
+                @NonNull ButtonModel caseSensitive,
+                @NonNull ButtonModel colorPrefered);
 
-        public void setListModel( FileSearchPanel panel, String text );
+        public boolean setListModel( FileSearchPanel panel, String text );
 
         public void closeDialog();
 
