@@ -62,6 +62,8 @@ import javax.swing.BorderFactory;
 import javax.swing.ButtonModel;
 import javax.swing.Icon;
 import javax.swing.InputMap;
+import javax.swing.JComponent;
+import static javax.swing.JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT;
 import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.KeyStroke;
@@ -76,6 +78,7 @@ import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.BadLocationException;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.modules.jumpto.SearchHistory;
@@ -83,6 +86,7 @@ import org.netbeans.modules.jumpto.common.UiUtils;
 import org.netbeans.spi.jumpto.type.TypeDescriptor;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
+import org.openide.util.Pair;
 
 /**
  *
@@ -98,8 +102,6 @@ public class GoToPanel extends javax.swing.JPanel {
     private boolean containsScrollPane;
     JLabel messageLabel;
     private Iterable<? extends TypeDescriptor> selectedTypes = Collections.emptyList();
-    private volatile int textId = 0;
-    private String oldText;
     private String oldMessage;
     
     // Time when the serach stared (for debugging purposes)
@@ -161,35 +163,29 @@ public class GoToPanel extends javax.swing.JPanel {
 
     /** Sets the model from different therad
      */
-    public void setModel( final ListModel model, final int id ) { 
-        // XXX measure time here
-        final int fid;
-        // -1 only from EDT
-        fid = id == -1 ? textId : id;
-        SwingUtilities.invokeLater(new Runnable() {
-           public void run() {
-               if (fid != textId) {
-                   return;
-               }
-               if (model.getSize() > 0 || getText() == null || getText().trim().length() == 0 ) {
-                   matchesList.setModel(model);
-                   matchesList.setSelectedIndex(0);
-                   setListPanelContent(null,false);
-                   if ( time != -1 ) {
-                       GoToTypeAction.LOGGER.fine("Real search time " + (System.currentTimeMillis() - time) + " ms.");
-                       time = -1;
-                   }
-               }
-               else {
-                   setListPanelContent( NbBundle.getMessage(GoToPanel.class, "TXT_NoTypesFound") ,false ); // NOI18N
-               }
+    boolean setModel( final ListModel model) {
+        assert SwingUtilities.isEventDispatchThread();
+       if (model.getSize() > 0 || getText() == null || getText().trim().length() == 0 ) {
+           matchesList.setModel(model);
+           matchesList.setSelectedIndex(0);
+           setListPanelContent(null,false);
+           if ( time != -1 ) {
+               GoToTypeAction.LOGGER.fine("Real search time " + (System.currentTimeMillis() - time) + " ms.");
+               time = -1;
            }
-       });
+           return true;
+       } else {
+           setListPanelContent( NbBundle.getMessage(GoToPanel.class, "TXT_NoTypesFound") ,false ); // NOI18N
+           return false;
+       }
     }
-    
+
+    boolean revalidateModel () {
+        return setModel(matchesList.getModel());
+    }
+
     /** Sets the initial text to find in case the user did not start typing yet. */
     public void setInitialText( final String text ) {
-        oldText = text;
         SwingUtilities.invokeLater( new Runnable() {
             public void run() {
                 String textInField = nameField.getText();
@@ -417,11 +413,7 @@ public class GoToPanel extends javax.swing.JPanel {
     private javax.swing.JScrollPane matchesScrollPane1;
     javax.swing.JTextField nameField;
     // End of variables declaration//GEN-END:variables
-        
-    public int getTextId() {
-        return textId;
-    }
-    
+
     private String getText() {
         try {
             String text = nameField.getDocument().getText(0, nameField.getDocument().getLength());
@@ -441,13 +433,11 @@ public class GoToPanel extends javax.swing.JPanel {
     }
 
     void updateMessage(@NullAllowed final String message) {
-        final String text = getText();
-        if (oldText == null || oldText.trim().length() == 0 || !text.startsWith(oldText) ||
-        (message == null ? oldMessage != null : !message.equals(oldMessage))) {
+        if (message == null ? oldMessage != null : !message.equals(oldMessage)) {
             setListPanelContent(message,true); // NOI18N
         }
     }
-    
+
     void setListPanelContent( String message ,boolean waitIcon ) {
         assert SwingUtilities.isEventDispatchThread();
         oldMessage = message;
@@ -476,18 +466,27 @@ public class GoToPanel extends javax.swing.JPanel {
        }                
     }
     
-    private String listActionFor(KeyEvent ev) {
+    @CheckForNull
+    private Pair<String,JComponent> listActionFor(KeyEvent ev) {
         InputMap map = matchesList.getInputMap();
         Object o = map.get(KeyStroke.getKeyStrokeForEvent(ev));
         if (o instanceof String) {
-            return (String)o;
-        } else {
-            return null;
+            return Pair.<String,JComponent>of((String)o, matchesList);
         }
+        map = matchesScrollPane1.getInputMap(WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
+        o = map.get(KeyStroke.getKeyStrokeForEvent(ev));
+        if (o instanceof String) {
+            return Pair.<String,JComponent>of((String)o, matchesScrollPane1);
+        }
+        return null;
     }
 
     private boolean boundScrollingKey(KeyEvent ev) {
-        String action = listActionFor(ev);
+        final Pair<String,JComponent> p = listActionFor(ev);
+        if (p == null) {
+            return false;
+        }
+        String action = p.first();
         // See BasicListUI, MetalLookAndFeel:
         return "selectPreviousRow".equals(action) || // NOI18N
         "selectNextRow".equals(action) || // NOI18N
@@ -498,8 +497,12 @@ public class GoToPanel extends javax.swing.JPanel {
     }
 
     private void delegateScrollingKey(KeyEvent ev) {
-        String action = listActionFor(ev);
-        
+        final Pair<String,JComponent> p = listActionFor(ev);
+        if (p == null) {
+            return;
+        }
+        final String action = p.first();
+        final JComponent target = p.second();
         // Wrap around
         if ( "selectNextRow".equals(action) && 
             matchesList.getSelectedIndex() == matchesList.getModel().getSize() -1 ) {
@@ -515,9 +518,9 @@ public class GoToPanel extends javax.swing.JPanel {
             return;
         }        
         // Plain delegation        
-        Action a = matchesList.getActionMap().get(action);
+        Action a = target.getActionMap().get(action);
         if (a != null) {
-            a.actionPerformed(new ActionEvent(matchesList, 0, action));
+            a.actionPerformed(new ActionEvent(target, 0, action));
         }
     }
     
@@ -544,7 +547,6 @@ public class GoToPanel extends javax.swing.JPanel {
             // handling http://netbeans.org/bugzilla/show_bug.cgi?id=203512
             if (dialog.pastedFromClipboard) {
                 dialog.pastedFromClipboard = false;
-                dialog.textId++;
             } else {
                 update();
             }
@@ -575,32 +577,29 @@ public class GoToPanel extends javax.swing.JPanel {
                 dialog.jTextFieldLocation.setText("");      //NOI18N
             }
         }
-        
+
         private void update() {
             dialog.time = System.currentTimeMillis();
-            dialog.updateMessage(NbBundle.getMessage(GoToPanel.class, "TXT_Searching"));
-            String text = dialog.getText();            
-            dialog.oldText = text;
-            dialog.textId++;
-            dialog.contentProvider.setListModel(dialog,text);            
+            final String text = dialog.getText();
+            if (dialog.contentProvider.setListModel(dialog, text)) {
+                dialog.updateMessage(NbBundle.getMessage(GoToPanel.class, "TXT_Searching"));
+            }
         }
-                                         
     }
-             
-        
+
+
     public static interface ContentProvider {
 
         @NonNull
         public ListCellRenderer getListCellRenderer(
                 @NonNull JList list,
                 @NonNull ButtonModel caseSensitive);
-        
-        public void setListModel( GoToPanel panel, String text );
-        
+
+        public boolean setListModel( GoToPanel panel, String text );
+
         public void closeDialog();
-        
+
         public boolean hasValidContent ();
-                
     }
 
 }
