@@ -50,14 +50,8 @@ import org.netbeans.modules.jumpto.common.Models;
 import org.netbeans.spi.jumpto.type.SearchType;
 import org.netbeans.spi.jumpto.type.TypeProvider;
 import org.netbeans.spi.jumpto.type.TypeDescriptor;
-import java.awt.Component;
-import java.awt.Color;
-import java.awt.Container;
 import java.awt.Dialog;
 import java.awt.Dimension;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
-import java.awt.Insets;
 import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -74,62 +68,57 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import java.util.regex.Pattern;
 import javax.swing.AbstractAction;
 import javax.swing.ButtonModel;
 import javax.swing.DefaultListModel;
+import javax.swing.Icon;
 import javax.swing.JButton;
 import javax.swing.ListCellRenderer;
 import javax.swing.JEditorPane;
-import javax.swing.JLabel;
 import javax.swing.JList;
-import javax.swing.JPanel;
-import javax.swing.JViewport;
 import javax.swing.ListModel;
 import javax.swing.SwingUtilities;
-import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.jumpto.type.TypeBrowser;
-import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ui.OpenProjects;
 import org.netbeans.editor.JumpList;
-import org.netbeans.modules.jumpto.EntitiesListCellRenderer;
-import org.netbeans.modules.jumpto.common.HighlightingNameFormatter;
+import org.netbeans.modules.jumpto.common.AbstractModelFilter;
+import org.netbeans.modules.jumpto.common.CurrentSearch;
+import org.netbeans.modules.jumpto.common.ItemRenderer;
 import org.netbeans.modules.jumpto.common.Utils;
-import org.netbeans.modules.jumpto.file.LazyListModel;
 import org.netbeans.modules.sampler.Sampler;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.ErrorManager;
-import org.openide.awt.HtmlRenderer;
 import org.openide.cookies.EditorCookie;
 import org.openide.nodes.Node;
 import org.openide.text.NbDocument;
 import org.openide.util.Exceptions;
 import org.openide.util.HelpCtx;
-import org.openide.util.ImageUtilities;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.Pair;
 import org.openide.util.Parameters;
 import org.openide.util.RequestProcessor;
 import org.openide.util.Utilities;
 import org.openide.windows.TopComponent;
 
-/** 
+/**
  * XXX split into action and support class, left this just to minimize diff
- * XXX Icons
  * XXX Don't look for all projects (do it lazy in filter or renderer)
  * @author Petr Hrebejk
  */
-public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentProvider, LazyListModel.Filter {
-    
+public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentProvider {
+
     static final Logger LOGGER = Logger.getLogger(GoToTypeAction.class.getName()); // Used from the panel as well
-    
-    private Collection<? extends SearchType> nameKinds;
+
+    private SearchType nameKind;
     private static ListModel EMPTY_LIST_MODEL = new DefaultListModel();
     private static final RequestProcessor rp = new RequestProcessor ("GoToTypeAction-RequestProcessor",1);      //NOI18N
     private static final RequestProcessor PROFILE_RP = new RequestProcessor("GoToTypeAction-Profile",1);        //NOI18N
@@ -143,6 +132,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
     private final TypeBrowser.Filter typeFilter;
     private final String title;
     private final boolean multiSelection;
+    private final CurrentSearch<TypeDescriptor> currentSearch;
 
     /** Creates a new instance of OpenTypeAction */
     public GoToTypeAction() {
@@ -152,7 +142,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             true
         );
     }
-    
+
     public GoToTypeAction(String title, TypeBrowser.Filter typeFilter, boolean multiSelection, TypeProvider... typeProviders) {
         super( NbBundle.getMessage( GoToTypeAction.class,"TXT_GoToType") );
         putValue("PopupMenuText", NbBundle.getBundle(GoToTypeAction.class).getString("editor-popup-TXT_GoToType")); // NOI18N
@@ -160,8 +150,28 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         this.typeFilter = typeFilter;
         this.implicitTypeProviders = typeProviders.length == 0 ? null : Collections.unmodifiableCollection(Arrays.asList(typeProviders));
         this.multiSelection = multiSelection;
+        this.currentSearch = new CurrentSearch(new Callable<AbstractModelFilter<TypeDescriptor>>() {
+            @Override
+            public AbstractModelFilter<TypeDescriptor> call() throws Exception {
+                return new AbstractModelFilter<TypeDescriptor>() {
+                    @Override
+                    @NonNull
+                    protected String getItemValue(@NonNull final TypeDescriptor item) {
+                        return item.getSimpleName();
+                    }
+                    @Override
+                    protected void update(@NonNull final TypeDescriptor item) {
+                        String searchText = getSearchText();
+                        if (searchText == null) {
+                            searchText = "";    //NOI18N
+                        }
+                        TypeProviderAccessor.DEFAULT.setHighlightText(item, searchText);
+                    }
+                };
+            }
+        });
     }
-    
+
     @Override
     public void actionPerformed( ActionEvent e ) {
         final Iterable<? extends TypeDescriptor> selectedTypes = getSelectedTypes();
@@ -172,11 +182,11 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             }
         }
     }
-            
+
     public Iterable<? extends TypeDescriptor> getSelectedTypes() {
         return getSelectedTypes(true);
     }
-    
+
     public Iterable<? extends TypeDescriptor> getSelectedTypes(final boolean visible) {
         return getSelectedTypes(visible, null);
     }
@@ -206,7 +216,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                     }
                 }
             }
-            
+
             dialog.setVisible(visible);
             result = panel.getSelectedTypes();
 
@@ -215,41 +225,32 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         }
         return result;
     }
-    
+
     @Override
     public boolean isEnabled () {
         return OpenProjects.getDefault().getOpenProjects().length>0;
     }
-    
-    @Override
-    public boolean accept(Object obj) {
-        return typeFilter == null ? true : typeFilter.accept((TypeDescriptor) obj);
-    }
-    
-    @Override
-    public void scheduleUpdate(Runnable run) {
-        SwingUtilities.invokeLater(run);
-    }
-    
+
     // Implementation of content provider --------------------------------------
-    
-    
+
+
     @Override
     public ListCellRenderer getListCellRenderer(
             @NonNull final JList list,
             @NonNull final ButtonModel caseSensitive) {
         Parameters.notNull("list", list);   //NOI18N
         Parameters.notNull("caseSensitive", caseSensitive); //NOI18N
-        return new Renderer(list, caseSensitive);
+        return ItemRenderer.Builder.create(
+                list,
+                caseSensitive,
+                new TypeDescriptorConvertor()).build();
     }
-    
-    
+
+
     @Override
-    public void setListModel( GoToPanel panel, String text ) {
+    public boolean setListModel( GoToPanel panel, String text ) {
         assert SwingUtilities.isEventDispatchThread();
-        if (okButton != null) {
-            okButton.setEnabled (false);
-        } 
+        enableOK(false);
         //handling http://netbeans.org/bugzilla/show_bug.cgi?id=178555
         //add a MouseListener to the messageLabel JLabel so that the search can be cancelled without exiting the dialog
         final GoToPanel goToPanel = panel;
@@ -271,56 +272,52 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             task.cancel();
             running = null;
         }
-        
+
         if ( text == null ) {
-            panel.setModel(EMPTY_LIST_MODEL, -1);
-            return;
+            currentSearch.resetFilter();
+            panel.setModel(EMPTY_LIST_MODEL);
+            return false;
         }
-        
-        boolean exact = text.endsWith(" "); // NOI18N
-        
+
+        final boolean exact = text.endsWith(" "); // NOI18N
         text = text.trim();
-        
+
         if ( text.length() == 0 || !Utils.isValidInput(text)) {
-            panel.setModel(EMPTY_LIST_MODEL, -1);
-            return;
+            currentSearch.resetFilter();
+            panel.setModel(EMPTY_LIST_MODEL);
+            return false;
         }
-        
-        int wildcard = Utils.containsWildCard(text);
-                
-        if (exact) {
-            nameKinds = Collections.singleton(
-                panel.isCaseSensitive() ?
-                    SearchType.EXACT_NAME :
-                    SearchType.CASE_INSENSITIVE_EXACT_NAME);
-        } else if ((Utils.isAllUpper(text) && text.length() > 1) || Utils.isCamelCase(text)) {
-            nameKinds = Arrays.asList(
-                new SearchType[] {
-                    SearchType.CAMEL_CASE,
-                    panel.isCaseSensitive() ?
-                        SearchType.PREFIX :
-                        SearchType.CASE_INSENSITIVE_PREFIX});
-        } else if (wildcard != -1) {
-            nameKinds = Collections.singleton(
-                panel.isCaseSensitive() ?
-                    SearchType.REGEXP :
-                    SearchType.CASE_INSENSITIVE_REGEXP);
+
+        nameKind = Utils.getSearchType(text, exact, panel.isCaseSensitive(), null, null);
+        if (nameKind == SearchType.REGEXP || nameKind == SearchType.CASE_INSENSITIVE_REGEXP) {
             text = Utils.removeNonNeededWildCards(text);
-        } else {
-            nameKinds = Collections.singleton(
-                panel.isCaseSensitive() ?
-                    SearchType.PREFIX :
-                    SearchType.CASE_INSENSITIVE_PREFIX);
         }
-        
-        // Compute in other thread        
-        running = new Worker( text , panel.isCaseSensitive(), panel.getTextId());
-        task = rp.post( running, 220);
-        if ( panel.time != -1 ) {
-            LOGGER.log( Level.FINE, "Worker posted after {0} ms.", System.currentTimeMillis() - panel.time ); //NOI18N
+
+        final Pair<String,String> nameAndScope = Utils.splitNameAndScope(text.trim());
+        final String name = nameAndScope.first();
+        final String scope = nameAndScope.second();
+        if (name.isEmpty() && scope == null) {
+            //Empty name, wait for next char
+            currentSearch.resetFilter();
+            panel.setModel(EMPTY_LIST_MODEL);
+            return false;
+        }
+
+        // Compute in other thread
+        if (currentSearch.isNarrowing(nameKind, name, scope, true)) {
+            currentSearch.filter(nameKind, name, null);
+            enableOK(panel.revalidateModel());
+            return false;
+        } else {
+            running = new Worker(text, panel.isCaseSensitive());
+            task = rp.post( running, 220);
+            if ( panel.time != -1 ) {
+                LOGGER.log( Level.FINE, "Worker posted after {0} ms.", System.currentTimeMillis() - panel.time ); //NOI18N
+            }
+            return true;
         }
     }
-    
+
     @Override
     public void closeDialog() {
         // Closing event can be sent several times.
@@ -330,24 +327,24 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         dialog.setVisible( false );
         cleanup();
     }
-    
+
     @Override
     public boolean hasValidContent () {
         return this.okButton != null && this.okButton.isEnabled();
     }
-    
-    // Private methods ---------------------------------------------------------        
-    
+
+    // Private methods ---------------------------------------------------------
+
     /** Creates the dialog to show
      */
    private Dialog createDialog( final GoToPanel panel) {
-       
+
         okButton = new JButton (NbBundle.getMessage(GoToTypeAction.class, "CTL_OK"));
         okButton.getAccessibleContext().setAccessibleDescription(okButton.getText());
         okButton.setEnabled (false);
         panel.getAccessibleContext().setAccessibleName( NbBundle.getMessage( GoToTypeAction.class, "AN_GoToType") ); //NOI18N
         panel.getAccessibleContext().setAccessibleDescription( NbBundle.getMessage( GoToTypeAction.class, "AD_GoToType") ); //NOI18N
-                        
+
         DialogDescriptor dialogDescriptor = new DialogDescriptor(
             panel,                             // innerPane
             title, // displayName
@@ -357,23 +354,23 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             DialogDescriptor.DEFAULT_ALIGN,
             HelpCtx.DEFAULT_HELP,
             new DialogButtonListener( panel ) );                                 // Action listener
-        
+
          dialogDescriptor.setClosingOptions(new Object[] {okButton, DialogDescriptor.CANCEL_OPTION});
-            
+
         // panel.addPropertyChangeListener( new HelpCtxChangeListener( dialogDescriptor, helpCtx ) );
 //        if ( panel instanceof HelpCtx.Provider ) {
 //            dialogDescriptor.setHelpCtx( ((HelpCtx.Provider)panel).getHelpCtx() );
 //        }
-        
+
         Dialog d = DialogDisplayer.getDefault().createDialog( dialogDescriptor );
-        
+
         // Set size when needed
         final int width = UiOptions.GoToTypeDialog.getWidth();
         final int height = UiOptions.GoToTypeDialog.getHeight();
         if (width != -1 && height != -1) {
             d.setPreferredSize(new Dimension(width,height));
         }
-        
+
         // Center the dialog after the size changed.
         Rectangle r = Utilities.getUsableScreenBounds();
         int maxW = (r.width * 9) / 10;
@@ -388,17 +385,17 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                 cleanup();
             }
         });
-        
+
         return d;
 
-    } 
-   
+    }
+
     private Dimension initialDimension;
-    
-    private void cleanup() {    
+
+    private void cleanup() {
         assert SwingUtilities.isEventDispatchThread();
         if ( GoToTypeAction.this.dialog != null ) { // Closing event for some reson sent twice
-        
+
             // Save dialog size only when changed
             final int currentWidth = dialog.getWidth();
             final int currentHeight = dialog.getHeight();
@@ -409,7 +406,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             initialDimension = null;
             // Clean caches
             GoToTypeAction.this.dialog.dispose();
-            GoToTypeAction.this.dialog = null;                                    
+            GoToTypeAction.this.dialog = null;
             //1st) Cancel current task
             if ( running != null ) {
                 running.cancel();
@@ -428,30 +425,73 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                         typeProviders = null;
                     }
                 }
-            });            
+            });
         }
     }
-    
+
+    private void enableOK(final boolean enable) {
+        if (okButton != null) {
+            okButton.setEnabled (enable);
+        }
+    }
+
     // Private classes ---------------------------------------------------------
-       
-    
-    
+
+
+    private static final class TypeDescriptorConvertor implements ItemRenderer.Convertor<TypeDescriptor> {
+        @Override
+        public String getName(@NonNull final TypeDescriptor item) {
+            return item.getTypeName();
+        }
+
+        @Override
+        public String getHighlightText(@NonNull final TypeDescriptor item) {
+            return TypeProviderAccessor.DEFAULT.getHighlightText(item);
+        }
+
+        @Override
+        public String getOwnerName(@NonNull final TypeDescriptor item) {
+            return item.getContextName();
+        }
+
+        @Override
+        public String getProjectName(@NonNull final TypeDescriptor item) {
+            return item.getProjectName();
+        }
+
+        @Override
+        public String getFilePath(@NonNull final TypeDescriptor item) {
+            return item.getFileDisplayPath();
+        }
+
+        @Override
+        public Icon getItemIcon(@NonNull final TypeDescriptor item) {
+            return item.getIcon();
+        }
+
+        @Override
+        public Icon getProjectIcon(@NonNull final TypeDescriptor item) {
+            return item.getProjectIcon();
+        }
+
+        @Override
+        public boolean isFromCurrentProject(@NonNull final TypeDescriptor item) {
+            return false;
+        }
+    }
+
     private class Worker implements Runnable {
-        
+
         private volatile boolean isCanceled = false;
         private volatile TypeProvider current;
         private final String text;
-        private final boolean caseSensitive;        
+        private final boolean caseSensitive;
         private final long createTime;
 
-        private int lastSize = -1;
-        private final int textId;
-        
-        public Worker( String text, final boolean caseSensitive, int textId) {
+        public Worker( String text, final boolean caseSensitive) {
             this.text = text;
             this.caseSensitive = caseSensitive;
             this.createTime = System.currentTimeMillis();
-            this.textId = textId;
             LOGGER.log( Level.FINE, "Worker for {0} - created after {1} ms.",   //NOI18N
                     new Object[]{
                         text,
@@ -460,7 +500,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         }
 
         @Override
-        public void run() {            
+        public void run() {
             final Future<?> f = OpenProjects.getDefault().openProjects();
             if (!f.isDone()) {
                 try {
@@ -471,9 +511,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                         }
                     });
                     f.get();
-                } catch (InterruptedException ex) {
-                    LOGGER.fine(ex.getMessage());
-                } catch (ExecutionException ex) {
+                } catch (InterruptedException | ExecutionException ex) {
                     LOGGER.fine(ex.getMessage());
                 } finally {
                     SwingUtilities.invokeLater(new Runnable() {
@@ -484,6 +522,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                     });
                 }
             }
+            int lastSize = -1;
             for (;;) {
                 final int[] retry = new int[1];
 
@@ -505,40 +544,37 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                         return;
                     }
                     final int newSize = types.size();
+                    final boolean done = retry[0] <= 0;
+                    final boolean resultChanged = lastSize != newSize;
                     //Optimistic the types just added, but safer is compare the collections.
                     //Unfortunatelly no TypeDescriptor impl provides equals.
-                    if (lastSize != newSize) {
+                    if (resultChanged || done) {
                         lastSize = newSize;
-                        ListModel model = Models.fromList(types);
-                        if (typeFilter != null) {
-                            model = LazyListModel.create(model, GoToTypeAction.this, 0.1, "Not computed yet");
+                        final ListModel fmodel;
+                        if (resultChanged) {
+                            ListModel model = Models.fromList(types, currentSearch.resetFilter(), null);
+                            if (typeFilter != null) {
+                                model = FilteredListModel.create(model, new FilterAdaptor(typeFilter), NbBundle.getMessage(GoToTypeAction.class, "LBL_Computing"));
+                            }
+                            fmodel = model;
+                        } else {
+                            fmodel = null;
                         }
-                        final ListModel fmodel = model;
-                        if ( isCanceled ) {
-                            LOGGER.log( Level.FINE, "Worker for {0} exited after cancel {1} ms.",   //NOI18N
-                                    new Object[]{
-                                        text,
-                                        System.currentTimeMillis() - createTime
-                                    });
+                        if (isCanceled) {
                             return;
                         }
-
-                        if ( !isCanceled && fmodel != null ) {
-                            LOGGER.log( Level.FINE, "Worker for text {0} finished after {1} ms.",   //NOI18N
-                                    new Object[]{
-                                        text,
-                                        System.currentTimeMillis() - createTime
-                                    });
-                            SwingUtilities.invokeLater(new Runnable() {
-                                @Override
-                                public void run() {
-                                    panel.setModel(fmodel, textId);
-                                    if (okButton != null && !types.isEmpty()) {
-                                        okButton.setEnabled (true);
-                                    }
+                        SwingUtilities.invokeLater(new Runnable() {
+                            @Override
+                            public void run() {
+                                if (done) {
+                                    final Pair<String, String> nameAndScope = Utils.splitNameAndScope(text);
+                                    currentSearch.searchCompleted(nameKind, nameAndScope.first(), nameAndScope.second());
                                 }
-                            });
-                        }
+                                if (fmodel != null && !isCanceled) {
+                                    enableOK(panel.setModel(fmodel));
+                                }
+                            }
+                        });
                     }
                 } finally {
                     if (profile != null) {
@@ -561,7 +597,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                 }
             } // for
         }
-        
+
         public void cancel() {
             if ( panel.time != -1 ) {
                 LOGGER.log( Level.FINE, "Worker for text {0} canceled after {1} ms.",   //NOI18N
@@ -583,13 +619,9 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         @SuppressWarnings("unchecked")
         private List<? extends TypeDescriptor> getTypeNames(String text, int[] retry) {
             // TODO: Search twice, first for current project, then for all projects
-            final Set<TypeDescriptor> items = new HashSet<TypeDescriptor>();
+            final Set<TypeDescriptor> items = new HashSet<>();
             final String[] message = new String[1];
-            final Collection<TypeProvider.Context> contexts = new HashSet<TypeProvider.Context>(2);
-            for (SearchType nameKind : nameKinds) {
-                contexts.add(TypeProviderAccessor.DEFAULT.createContext(null, text, nameKind));
-            }
-            assert !contexts.isEmpty();
+            final TypeProvider.Context context = TypeProviderAccessor.DEFAULT.createContext(null, text, nameKind);
             assert rp.isRequestProcessorThread();
             if (typeProviders == null) {
                 typeProviders = implicitTypeProviders != null ? implicitTypeProviders : Lookup.getDefault().lookupAll(TypeProvider.class);
@@ -598,15 +630,13 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                 if (isCanceled) {
                     return null;
                 }
-                current = provider;                
+                current = provider;
                 long start = System.currentTimeMillis();
                 try {
                     LOGGER.log(Level.FINE, "Calling TypeProvider: {0}", provider);  //NOI18N
-                    for (TypeProvider.Context context : contexts) {
-                        final TypeProvider.Result result = TypeProviderAccessor.DEFAULT.createResult(items, message, context);
-                        provider.computeTypeNames(context, result);
-                        retry[0] = mergeRetryTimeOut(retry[0], TypeProviderAccessor.DEFAULT.getRetry(result));
-                    }
+                    final TypeProvider.Result result = TypeProviderAccessor.DEFAULT.createResult(items, message, context);
+                    provider.computeTypeNames(context, result);
+                    retry[0] = mergeRetryTimeOut(retry[0], TypeProviderAccessor.DEFAULT.getRetry(result));
                 } finally {
                     current = null;
                 }
@@ -615,17 +645,17 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                         new Object[]{
                             provider.getDisplayName(),
                             delta
-                        });                
+                        });
             }
             if ( !isCanceled ) {
                 final ArrayList<TypeDescriptor> result = new ArrayList<TypeDescriptor>(items);
                 Collections.sort(result, new TypeComparator(caseSensitive));
-                panel.setWarning(message[0]);                
+                panel.setWarning(message[0]);
                 return result;
             }
             else {
                 return null;
-            }            
+            }
         }
 
         private int mergeRetryTimeOut(
@@ -641,237 +671,26 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
         }
     }
 
-    private static class MyPanel extends JPanel {
-	
-	private TypeDescriptor td;
-	
-	void setDescriptor(TypeDescriptor td) {
-	    this.td = td;
-	    // since the same component is reused for dirrerent list itens, 
-	    // null the tool tip
-	    putClientProperty(TOOL_TIP_TEXT_KEY, null);
-	}
-
-	@Override
-	public String getToolTipText() {
-	    // the tool tip is gotten from the descriptor 
-	    // and cached in the standard TOOL_TIP_TEXT_KEY property
-	    String text = (String) getClientProperty(TOOL_TIP_TEXT_KEY);
-	    if( text == null ) {
-                if( td != null ) {
-                    text = td.getFileDisplayPath();
-                }
-                putClientProperty(TOOL_TIP_TEXT_KEY, text);
-	    }
-	    return text;
-	}
-    }
-
     final void waitSearchFinished() {
         assert SwingUtilities.isEventDispatchThread();
         task.waitFinished();
     }
 
-    private static final class Renderer extends EntitiesListCellRenderer implements ActionListener {
-         
-        private MyPanel rendererComponent;
-        private JLabel jlName = HtmlRenderer.createLabel();
-        private JLabel jlPkg = new JLabel();
-        private JLabel jlPrj = new JLabel();
-        private int DARKER_COLOR_COMPONENT = 15;
-        private int LIGHTER_COLOR_COMPONENT = 80;        
-        private Color fgColor;
-        private Color fgColorLighter;
-        private Color bgColor;
-        private Color bgColorDarker;
-        private Color bgSelectionColor;
-        private Color fgSelectionColor;
-        
-        private JList jList;
-        private boolean caseSensitive;
-        private final HighlightingNameFormatter typeNameFormatter;
-
-        @SuppressWarnings("LeakingThisInConstructor")
-        public Renderer(
-                @NonNull final JList list,
-                @NonNull final ButtonModel caseSensitive) {
-            
-            jList = list;
-            this.caseSensitive = caseSensitive.isSelected();
-            resetName();
-            Container container = list.getParent();
-            if ( container instanceof JViewport ) {
-                ((JViewport)container).addChangeListener(this);
-                stateChanged(new ChangeEvent(container));
-            }
-            
-            rendererComponent = new MyPanel();
-            rendererComponent.setLayout(new GridBagLayout());
-            GridBagConstraints c = new GridBagConstraints();
-            c.gridx = 0;
-            c.gridy = 0;
-            c.gridwidth = 1;
-            c.gridheight = 1;
-            c.fill = GridBagConstraints.NONE;
-            c.weightx = 0;
-            c.anchor = GridBagConstraints.WEST;
-            c.insets = new Insets (0,0,0,7);
-            rendererComponent.add( jlName, c);
-            
-            c = new GridBagConstraints();
-            c.gridx = 1;
-            c.gridy = 0;
-            c.gridwidth = 1;
-            c.gridheight = 1;
-            c.fill = GridBagConstraints.HORIZONTAL;
-            c.weightx = 0.1;
-            c.anchor = GridBagConstraints.WEST;
-            c.insets = new Insets (0,0,0,7);
-            rendererComponent.add( jlPkg, c);
-            
-            c = new GridBagConstraints();
-            c.gridx = 2;
-            c.gridy = 0;
-            c.gridwidth = 1;
-            c.gridheight = 1;
-            c.fill = GridBagConstraints.NONE;
-            c.weightx = 0;
-            c.anchor = GridBagConstraints.EAST;
-            rendererComponent.add( jlPrj, c);
-            
-            
-            jlPkg.setOpaque(false);
-            jlPrj.setOpaque(false);                        
-
-            jlPkg.setFont(list.getFont());
-            jlPrj.setFont(list.getFont());
-
-
-            jlPrj.setHorizontalAlignment(RIGHT);
-            jlPrj.setHorizontalTextPosition(LEFT);
-            
-            // setFont( list.getFont() );            
-            fgColor = list.getForeground();
-            fgColorLighter = new Color( 
-                                   Math.min( 255, fgColor.getRed() + LIGHTER_COLOR_COMPONENT),
-                                   Math.min( 255, fgColor.getGreen() + LIGHTER_COLOR_COMPONENT),
-                                   Math.min( 255, fgColor.getBlue() + LIGHTER_COLOR_COMPONENT)
-                                  );
-                            
-            bgColor = new Color( list.getBackground().getRGB() );
-            bgColorDarker = new Color(
-                                    Math.abs(bgColor.getRed() - DARKER_COLOR_COMPONENT),
-                                    Math.abs(bgColor.getGreen() - DARKER_COLOR_COMPONENT),
-                                    Math.abs(bgColor.getBlue() - DARKER_COLOR_COMPONENT)
-                            );
-            bgSelectionColor = list.getSelectionBackground();
-            fgSelectionColor = list.getSelectionForeground();
-            this.typeNameFormatter = HighlightingNameFormatter.createBoldFormatter();
-            caseSensitive.addActionListener(this);
-            jlName.setOpaque( true );
-        }
-        
-        public @Override Component getListCellRendererComponent( JList list,
-                                                       Object value,
-                                                       int index,
-                                                       boolean isSelected,
-                                                       boolean hasFocus) {
-            
-            // System.out.println("Renderer for index " + index );
-            
-            int height = list.getFixedCellHeight();
-            int width = list.getFixedCellWidth() - 1;
-            
-            width = width < 200 ? 200 : width;
-            
-            // System.out.println("w, h " + width + ", " + height );
-            
-            Dimension size = new Dimension( width, height );
-            rendererComponent.setMaximumSize(size);
-            rendererComponent.setPreferredSize(size);            
-            resetName();
-            if ( isSelected ) {
-                jlName.setForeground(fgSelectionColor);
-                jlName.setBackground( bgSelectionColor );
-                jlPkg.setForeground(fgSelectionColor);
-                jlPrj.setForeground(fgSelectionColor);                
-                rendererComponent.setBackground(bgSelectionColor);
-            }
-            else {
-                jlName.setForeground(fgColor);
-                jlPkg.setForeground(fgColorLighter);
-                jlPrj.setForeground(fgColor);
-                final Color bgc = index % 2 == 0 ? bgColor : bgColorDarker;
-                jlName.setBackground(bgc);    //Html does not support transparent bg
-                rendererComponent.setBackground(bgc);
-            }
-            if ( value instanceof TypeDescriptor ) {
-                long time = System.currentTimeMillis();
-                TypeDescriptor td = (TypeDescriptor)value;                
-                jlName.setIcon(td.getIcon());
-                //highlight matching search text patterns in type
-                final String formattedTypeName = typeNameFormatter.formatName(
-                        td.getTypeName(),
-                        TypeProviderAccessor.DEFAULT.getHighlightText(td),
-                        caseSensitive,
-                        isSelected? fgSelectionColor : fgColor);
-                jlName.setText(formattedTypeName);
-                jlPkg.setText(td.getContextName());
-                setProjectName(jlPrj, td.getProjectName());
-                jlPrj.setIcon(td.getProjectIcon());
-		rendererComponent.setDescriptor(td);                
-                LOGGER.log(Level.FINE, "  Time in paint {0} ms.", System.currentTimeMillis() - time);   //NOI18N
-            }
-            else {
-                jlName.setText( value.toString() );
-            }
-            
-            return rendererComponent;
-        }
-        
-        @Override
-        public void stateChanged(ChangeEvent event) {
-            
-            JViewport jv = (JViewport)event.getSource();
-            
-            jlName.setText( "Sample" ); // NOI18N
-            //jlName.setIcon(UiUtils.getElementIcon(ElementKind.CLASS, null));
-            jlName.setIcon(ImageUtilities.loadImageIcon("org/netbeans/modules/jumpto/type/sample.png", false)); //NOI18N
-            
-            jList.setFixedCellHeight(jlName.getPreferredSize().height);
-            jList.setFixedCellWidth(jv.getExtentSize().width);
-        }
-        
-        @Override
-        public void actionPerformed(@NonNull final ActionEvent e) {
-            caseSensitive = ((ButtonModel)e.getSource()).isSelected();
-        }
-
-        private void resetName() {
-            ((HtmlRenderer.Renderer)jlName).reset();
-            jlName.setFont(jList.getFont());
-            jlName.setOpaque(true);
-            ((HtmlRenderer.Renderer)jlName).setHtml(true);
-            ((HtmlRenderer.Renderer)jlName).setRenderStyle(HtmlRenderer.STYLE_TRUNCATE);
-        }
-
-     } // Renderer
-    
     private class DialogButtonListener implements ActionListener {
-        
+
         private GoToPanel panel;
-        
+
         public DialogButtonListener( GoToPanel panel ) {
             this.panel = panel;
         }
-        
+
         @Override
-        public void actionPerformed(ActionEvent e) {            
+        public void actionPerformed(ActionEvent e) {
             if ( e.getSource() == okButton) {
                 panel.setSelectedTypes();
             }
         }
-        
+
     }
 
 
@@ -898,7 +717,7 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
             time = System.currentTimeMillis();
             this.profiler = profiler;
         }
-        
+
         Profile start() {
             PROFILE_RP.post(this, 3000); // 3s
             return this;
@@ -935,7 +754,27 @@ public class GoToTypeAction extends AbstractAction implements GoToPanel.ContentP
                 Exceptions.printStackTrace(ex);
             }
         }
-
     }
 
+    private static final class FilterAdaptor implements Models.Filter<TypeDescriptor> {
+        private final TypeBrowser.Filter filter;
+
+        FilterAdaptor(@NonNull final TypeBrowser.Filter filter) {
+            Parameters.notNull("filter", filter);   //NOI18N
+            this.filter = filter;
+        }
+
+        @Override
+        public boolean accept(TypeDescriptor item) {
+            return filter.accept(item);
+        }
+
+        @Override
+        public void addChangeListener(ChangeListener listener) {
+        }
+
+        @Override
+        public void remmoveChangeListener(ChangeListener listener) {
+        }
+    }
 }
