@@ -44,12 +44,15 @@
 
 package org.netbeans.modules.junit;
 
-import java.util.logging.Level;
+import org.netbeans.modules.junit.api.JUnitSettings;
+import org.netbeans.modules.junit.api.JUnitTestUtil;
 import java.awt.BorderLayout;
 import java.awt.GridLayout;
 import java.awt.event.ActionListener;
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
 import java.net.URI;
 import java.net.URL;
 import java.util.ArrayList;
@@ -60,8 +63,8 @@ import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.Set;
-import java.util.concurrent.Callable;
 import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -95,38 +98,36 @@ import org.netbeans.modules.junit.plugin.JUnitPlugin;
 import org.netbeans.modules.gsf.testrunner.api.SelfResizingPanel;
 import org.netbeans.modules.gsf.testrunner.plugin.CommonPlugin.CreateTestParam;
 import org.netbeans.modules.gsf.testrunner.plugin.CommonPlugin.Location;
-import org.netbeans.modules.junit.wizards.Utils;
 import org.netbeans.spi.java.classpath.ClassPathProvider;
 import org.netbeans.spi.java.classpath.support.ClassPathSupport;
-import org.netbeans.spi.java.project.support.ui.BrokenReferencesSupport.LibraryDefiner;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.ErrorManager;
 import org.openide.NotifyDescriptor;
 import org.openide.awt.Mnemonics;
-import org.openide.cookies.SaveCookie;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
-import org.openide.loaders.DataFolder;
-import org.openide.loaders.DataObject;
-import org.openide.loaders.DataObjectNotFoundException;
 import org.openide.util.HelpCtx;
-import org.openide.util.Lookup;
 import org.openide.util.Mutex;
 import org.openide.util.NbBundle;
-import org.openide.util.NbBundle.Messages;
-import static org.netbeans.modules.junit.Bundle.*;
 import static java.util.logging.Level.FINER;
 import static java.util.logging.Level.FINEST;
+import org.netbeans.api.actions.Savable;
 import static org.netbeans.api.java.classpath.ClassPath.SOURCE;
 import static org.netbeans.api.java.classpath.ClassPath.COMPILE;
 import static org.netbeans.api.java.project.JavaProjectConstants.SOURCES_TYPE_JAVA;
 import org.netbeans.modules.gsf.testrunner.api.UnitTestsUsage;
 import org.netbeans.modules.java.testrunner.GuiUtils;
+import static org.netbeans.modules.java.testrunner.JavaUtils.PROP_JUNIT_SELECTED_VERSION;
+import org.netbeans.modules.junit.api.JUnitUtils;
 import static org.openide.ErrorManager.ERROR;
 import static org.openide.ErrorManager.WARNING;
 import static org.openide.NotifyDescriptor.CANCEL_OPTION;
 import static org.openide.NotifyDescriptor.WARNING_MESSAGE;
+import org.openide.loaders.DataFolder;
+import org.openide.loaders.DataObject;
+import org.openide.loaders.DataObjectNotFoundException;
+import org.openide.util.Exceptions;
 import org.openide.util.Utilities;
 
 /**
@@ -179,6 +180,8 @@ public final class DefaultPlugin extends JUnitPlugin {
     
     private static boolean generatingIntegrationTest = false;
     
+    private static final String PROJECT_PROPERTIES_PATH = "nbproject/project.properties";
+    
     public static void logJUnitUsage(URI projectURI) {
         String version = "";
         if (junitVer == null) {
@@ -852,7 +855,7 @@ public final class DefaultPlugin extends JUnitPlugin {
         progress.show();
 
         String msg = NbBundle.getMessage(
-                    JUnitTestCreatorProvider.class,
+                    DefaultPlugin.class,
                     "MSG_StatusBar_CreateTest_Begin");                  //NOI18N
         progress.displayStatusText(msg);
         generatingIntegrationTest = Boolean.TRUE.equals(params.get(CreateTestParam.INC_GENERATE_INTEGRATION_TEST));
@@ -1015,7 +1018,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                 Mutex.EVENT.writeAccess(new Runnable() {
 
                     public void run() {
-                        TestUtil.notifyUser(finalMessage, NotifyDescriptor.INFORMATION_MESSAGE);
+                        JUnitTestUtil.notifyUser(finalMessage, NotifyDescriptor.INFORMATION_MESSAGE);
                     }
                 });
             }
@@ -1117,7 +1120,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                 case JUNIT3:
                     return true;
                 case JUNIT4:
-                    String sourceLevel = TestUtil.getSourceLevel(selectedFiles[0]);
+                    String sourceLevel = JUnitTestUtil.getSourceLevel(selectedFiles[0]);
                     if (sourceLevel == null) {    //could not get source level
                         return true;
                     }
@@ -1147,7 +1150,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                     }
                     return true;
                 case JUNIT4:
-                    String sourceLevel = TestUtil.getSourceLevel(selectedFiles[0]);
+                    String sourceLevel = JUnitTestUtil.getSourceLevel(selectedFiles[0]);
                     if ((sourceLevel != null)
                             && (sourceLevel.compareTo("1.5")) >= 0) {   //NOI18N
                         if (storeSettings) {
@@ -1157,7 +1160,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                     } else if (sourceLevel == null) {
                         String msgKey
                             = "MSG_select_junit_version_srclvl_unknown";//NOI18N
-                        junitVer = askUserWhichJUnitToUse(msgKey, true, true);
+                        loadJUnitToUseFromPropertiesFile(project);
                         if ((junitVer != null) && storeSettings) {
                             return storeProjectSettingsJUnitVer(project);
                         }
@@ -1179,7 +1182,7 @@ public final class DefaultPlugin extends JUnitPlugin {
         String msgKey;
         boolean offerJUnit4;
         boolean showSourceLevelReqs;
-        String sourceLevel = TestUtil.getSourceLevel(selectedFiles[0]);
+        String sourceLevel = JUnitTestUtil.getSourceLevel(selectedFiles[0]);
         if (sourceLevel == null) {
             msgKey = "MSG_select_junit_version_srclvl_unknown";         //NOI18N
             offerJUnit4 = true;
@@ -1189,9 +1192,12 @@ public final class DefaultPlugin extends JUnitPlugin {
             offerJUnit4 = (sourceLevel.compareTo("1.5") >= 0);          //NOI18N
             showSourceLevelReqs = !offerJUnit4;
         }
-        junitVer = askUserWhichJUnitToUse(msgKey,
-                                          offerJUnit4,
-                                          showSourceLevelReqs);
+        loadJUnitToUseFromPropertiesFile(project);
+        if(junitVer == null) {
+            // probably new project after 8.1, since determining junitVer failed
+            // sofar, so as last resort default to 4.x
+            junitVer = JUnitVersion.JUNIT4;
+        }
         if ((junitVer != null) && storeSettings) {
             return storeProjectSettingsJUnitVer(project);
         }
@@ -1261,6 +1267,31 @@ public final class DefaultPlugin extends JUnitPlugin {
 //        return NbBundle.getMessage(getClass(), bundleKey);
 //    }
     
+    private Properties getProjectProperties(FileObject projectDir) throws IOException {
+            FileObject projectProperties = FileUtil.createData(projectDir, PROJECT_PROPERTIES_PATH);
+            InputStream propertiesIS = projectProperties.getInputStream();
+            Properties props = new Properties();
+            props.load(propertiesIS);
+            propertiesIS.close();
+            return props;
+        }
+    
+    private void loadJUnitToUseFromPropertiesFile(Project project) {
+        final FileObject projectDir = project.getProjectDirectory();
+        ProjectManager.mutex().postReadRequest(new Runnable() {
+            @Override
+            public void run() {
+                try {
+                    Properties props = getProjectProperties(projectDir);
+                    String property = props.getProperty(PROP_JUNIT_SELECTED_VERSION);
+                    junitVer = property == null ? null : (property.equals("3") ? JUnitVersion.JUNIT3 : JUnitVersion.JUNIT4);
+                } catch (IOException ex) {
+                    Exceptions.printStackTrace(ex);
+                }
+            }
+        });
+    }
+    
     /**
      */
     private JUnitVersion askUserWhichJUnitToUse(String msgKey,
@@ -1395,22 +1426,30 @@ public final class DefaultPlugin extends JUnitPlugin {
         final boolean hasJUnit3;
         final boolean hasJUnit4;
         final ClassPath classPath = getTestClassPath(project); //may throw ISE
-        if (classPath != null) {
-            hasJUnit3 = (classPath.findResource(JUNIT3_SPECIFIC) != null);
-            hasJUnit4 = (classPath.findResource(JUNIT4_SPECIFIC) != null);
-        } else {
-            hasJUnit3 = false;
-            hasJUnit4 = false;
-        }
+        
+        loadJUnitToUseFromPropertiesFile(project);
+        if (junitVer == null) {
+            if (classPath != null) {
+                hasJUnit3 = (classPath.findResource(JUNIT3_SPECIFIC) != null);
+                hasJUnit4 = (classPath.findResource(JUNIT4_SPECIFIC) != null);
+            } else {
+                hasJUnit3 = false;
+                hasJUnit4 = false;
+            }
 
-        if (hasJUnit3 != hasJUnit4) {
-            junitVer = hasJUnit3 ? JUnitVersion.JUNIT3
-                                 : JUnitVersion.JUNIT4;
+            if (hasJUnit3 != hasJUnit4) {
+                junitVer = hasJUnit3 ? JUnitVersion.JUNIT3
+                        : JUnitVersion.JUNIT4;
+                if (LOG_JUNIT_VER.isLoggable(FINEST)) {
+                    LOG_JUNIT_VER.finest(" - detected version " + junitVer);//NOI18N
+                }
+            } else {
+                LOG_JUNIT_VER.finest(" - no version detected");             //NOI18N
+            }
+        } else {
             if (LOG_JUNIT_VER.isLoggable(FINEST)) {
                 LOG_JUNIT_VER.finest(" - detected version " + junitVer);//NOI18N
             }
-        } else {
-            LOG_JUNIT_VER.finest(" - no version detected");             //NOI18N
         }
         return (classPath != null);
     }
@@ -1432,7 +1471,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                                 + ')');
         }
 
-        final Collection<FileObject> testFolders = Utils.getTestFolders(project);
+        final Collection<FileObject> testFolders = JUnitUtils.getTestFolders(project);
         if (testFolders.isEmpty()) {
             LOG_JUNIT_VER.finest(" - no unit test folders found");           //NOI18N
         }
@@ -1466,35 +1505,7 @@ public final class DefaultPlugin extends JUnitPlugin {
      * @param  project  project whose configuration file is to be checked
      * @see  #junitVer
      */
-    @Messages({
-        "junitlib_confirm_title=Create Tests",
-        "junitlib_confirm_text=<html><p>To create JUnit tests, the IDE needs to download and install the JUnit library.</p><p>Do you want to proceed?<p>",
-        "junitlib_confirm_accept=Download and Install JUnit"
-    })
     private boolean storeProjectSettingsJUnitVer(final Project project) {
-        if (LibraryManager.getDefault().getLibrary("junit_4") == null) {
-            for (LibraryDefiner definer : Lookup.getDefault().lookupAll(LibraryDefiner.class)) {
-                Callable<Library> download = definer.missingLibrary("junit_4");
-                if (download != null) {
-                    NotifyDescriptor nd = new NotifyDescriptor.Confirmation(junitlib_confirm_text(), junitlib_confirm_title());
-                    JButton accept = new JButton(junitlib_confirm_accept());
-                    accept.setDefaultCapable(true);
-                    nd.setOptions(new Object[] {accept, NotifyDescriptor.CANCEL_OPTION});
-                    if (DialogDisplayer.getDefault().notify(nd) == accept) {
-                        try {
-                            download.call();
-                        } catch (Exception x) {
-                            LOG_JUNIT_VER.log(Level.INFO, null, x);
-                            return false;
-                        }
-                    } else {
-                        return false;
-                    }
-                    break;
-                }
-            }
-        }
-
         assert junitVer != null;
 
         if (LOG_JUNIT_VER.isLoggable(FINER)) {
@@ -1521,6 +1532,7 @@ public final class DefaultPlugin extends JUnitPlugin {
 
         Library libraryToAdd = null;
         Collection<Library> librariesToRemove = null;
+        Library libraryHamcrest = null;
 
         LOG_JUNIT_VER.finest(" - checking libraries:");                 //NOI18N
         Library[] libraries = LibraryManager.getDefault().getLibraries();
@@ -1529,6 +1541,10 @@ public final class DefaultPlugin extends JUnitPlugin {
             if (LOG_JUNIT_VER.isLoggable(FINEST)) {
                 LOG_JUNIT_VER.finest("    " + name);
             }
+            if (name.equals("hamcrest")) {                            //NOI18N
+                libraryHamcrest = library;
+                continue;
+            }
             if (!name.startsWith("junit")) {                            //NOI18N
                 LOG_JUNIT_VER.finest("     - not a JUnit library");     //NOI18N
                 continue;
@@ -1545,8 +1561,10 @@ public final class DefaultPlugin extends JUnitPlugin {
             } else {
                 verNumToAdd = null;
             }
-            String verNumToRemove = (junitVer == JUnitVersion.JUNIT3)
-                                    ? "4" : "3";                        //NOI18N
+            // junit-3.8.2 binaries were removed from standard build. User can 
+            // open legacy project with or create new testcases using junit 3.x
+            // style. This means only junit-3.x can be removed no matter what.
+            String verNumToRemove = "3";                        //NOI18N
             if (name.equals("junit")) {                                 //NOI18N
                 add    = (verNumToAdd    == "3");                       //NOI18N
                 remove = (verNumToRemove == "3");                       //NOI18N
@@ -1598,7 +1616,11 @@ public final class DefaultPlugin extends JUnitPlugin {
 
         final Library[] libsToAdd, libsToRemove;
         if (libraryToAdd != null) {
-            libsToAdd = new Library[] {libraryToAdd};
+            // junit-3.8.2 binaries were removed from standard build. User can 
+            // open legacy project with or create new testcases using junit 3.x
+            // style. junit-4.x and hamcrest binaries are added as test 
+            // dependencies for the project in those cases as well.
+            libsToAdd = new Library[] {libraryToAdd, libraryHamcrest};
         } else{
             libsToAdd = null;
         }
@@ -1683,7 +1705,7 @@ public final class DefaultPlugin extends JUnitPlugin {
             Collections.<FileObject>emptyList();
         }
 
-        final Collection<FileObject> testFolders = Utils.getTestFolders(project);
+        final Collection<FileObject> testFolders = JUnitUtils.getTestFolders(project);
         if (testFolders.isEmpty()) {
             Collections.<FileObject>emptyList();
         }
@@ -1815,15 +1837,15 @@ public final class DefaultPlugin extends JUnitPlugin {
                     String srcClassNameFull = clsToTest.getQualifiedName();
                     if ((requestedTestClassName != null)
                             && !mainClassProcessed
-                            && TestUtil.getSimpleName(srcClassNameFull)
+                            && JUnitTestUtil.getSimpleName(srcClassNameFull)
                                    .equals(sourceFile.getName())) {
                         testClassName = requestedTestClassName;
                         mainClassProcessed = true;
                     } else {
                         if(generatingIntegrationTest) {
-                            testClassName = TestUtil.getIntegrationTestClassName(srcClassNameFull);
+                            testClassName = JUnitTestUtil.getIntegrationTestClassName(srcClassNameFull);
                         } else {
-                            testClassName = TestUtil.getTestClassName(srcClassNameFull);
+                            testClassName = JUnitTestUtil.getTestClassName(srcClassNameFull);
                         }
                     }
                     String testResourceName = testClassName.replace('.', '/');
@@ -1918,7 +1940,7 @@ public final class DefaultPlugin extends JUnitPlugin {
                                 parentSuite,
                                 progress);
             }
-        } else if (srcFileObj.isData() && TestUtil.isJavaFile(srcFileObj)) {
+        } else if (srcFileObj.isData() && JUnitTestUtil.isJavaFile(srcFileObj)) {
             results = createSingleTest(srcFileObj,
                                        (String) null, //use the default clsName
                                        testCreator,
@@ -1968,7 +1990,7 @@ public final class DefaultPlugin extends JUnitPlugin {
         String dotPkg = pkg.replace('/', '.');
         String fullSuiteName = rootFolderName.concat((suiteName != null)
                                ? pkg + '/' + suiteName
-                               : (generatingIntegrationTest ? TestUtil.convertPackage2ITSuiteName(pkg) : TestUtil.convertPackage2SuiteName(pkg)));
+                               : (generatingIntegrationTest ? JUnitTestUtil.convertPackage2ITSuiteName(pkg) : JUnitTestUtil.convertPackage2SuiteName(pkg)));
 
         String classNames = makeListOfClasses(classesToInclude, null);
         String classes = makeListOfClasses(classesToInclude, ".class"); //NOI18N
@@ -2072,7 +2094,7 @@ public final class DefaultPlugin extends JUnitPlugin {
         setAnnotationsSupport(targetFolder, junitVer, templateParams);
         TestCreator testCreator = new TestCreator(params, junitVer);
         final ClasspathInfo cpInfo = ClasspathInfo.create(targetRootFolder);
-        List<String> testClassNames = TestUtil.getJavaFileNames(targetFolder,
+        List<String> testClassNames = JUnitTestUtil.getJavaFileNames(targetFolder,
                                                                 cpInfo);
         
         final String templateId;
@@ -2177,7 +2199,7 @@ public final class DefaultPlugin extends JUnitPlugin {
         final boolean supported;
         switch (junitVer) {
             case JUNIT3:
-                supported = TestUtil.areAnnotationsSupported(testFolder);
+                supported = JUnitTestUtil.areAnnotationsSupported(testFolder);
                 break;
             case JUNIT4:
                 supported = true;
@@ -2196,7 +2218,7 @@ public final class DefaultPlugin extends JUnitPlugin {
      *
      */
     private static void save(DataObject dataObj) throws IOException {
-        SaveCookie sc = dataObj.getCookie(SaveCookie.class);
+        Savable sc = dataObj.getLookup().lookup(Savable.class);
         if (null != sc) {
             sc.save();
         }
@@ -2233,7 +2255,7 @@ public final class DefaultPlugin extends JUnitPlugin {
      */
     private static void noTemplateMessage(String temp) {
         String msg = NbBundle.getMessage(
-                JUnitTestCreatorProvider.class,
+                DefaultPlugin.class,
                 "MSG_template_not_found",                           //NOI18N
                 temp);
         NotifyDescriptor descr = new NotifyDescriptor.Message(
@@ -2260,8 +2282,8 @@ public final class DefaultPlugin extends JUnitPlugin {
      *         andKey.
      */
     private static String strReason(TestabilityResult reason, String commaKey, String andKey) {
-        String strComma = NbBundle.getMessage(JUnitTestCreatorProvider.class,commaKey);
-        String strAnd = NbBundle.getMessage(JUnitTestCreatorProvider.class,andKey);
+        String strComma = NbBundle.getMessage(DefaultPlugin.class,commaKey);
+        String strAnd = NbBundle.getMessage(DefaultPlugin.class,andKey);
         String strReason = reason.getReason( // string representation of the reasons
                         strComma.substring(1, strComma.length()-1),
                         strAnd.substring(1, strAnd.length()-1));
