@@ -177,7 +177,7 @@ public class TargetAppRunner implements CommonConstants {
                             AsyncMessageCommand msg = (AsyncMessageCommand) cmd;
 
                             if (msg.isPositive()) {
-                                appStatusHandler.displayNotification(msg.getMessage());
+//                                appStatusHandler.displayNotification(msg.getMessage());
                             } else {
                                 appStatusHandler.displayError(msg.getMessage());
 
@@ -827,7 +827,10 @@ public class TargetAppRunner implements CommonConstants {
         }
 
         try {
-            runningAppProcess = Runtime.getRuntime().exec(cmdArray, null, dir);
+            ProcessBuilder builder = new ProcessBuilder(cmdArray).directory(dir);
+            builder.redirectError(ProcessBuilder.Redirect.INHERIT);
+            builder.redirectOutput(ProcessBuilder.Redirect.INHERIT);
+            runningAppProcess = builder.start();
         } catch (IOException ex) {
             StringBuilder sb = new StringBuilder();
 
