@@ -50,6 +50,7 @@ import java.nio.ByteBuffer;
 import java.nio.file.Files;
 import java.nio.file.InvalidPathException;
 import java.nio.file.Path;
+import java.text.MessageFormat;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
@@ -138,7 +139,7 @@ public class CheckoutRevisionCommand extends GitCommand {
 
             cache = repository.lockDirCache();
             DirCacheCheckout dco = null;
-            RevCommit commit;
+            RevCommit commit = null;
             try {
                 commit = Utils.findCommit(repository, revision);
                 dco = headTree == null ? new DirCacheCheckout(repository, cache, commit.getTree()) : new DirCacheCheckout(repository, headTree, cache, commit.getTree());
@@ -170,6 +171,10 @@ public class CheckoutRevisionCommand extends GitCommand {
                     mergeConflicts(dco.getConflicts(), cache);
                 }
                 // End of JGit WA
+            } catch (org.eclipse.jgit.dircache.InvalidPathException ex) {
+                throw new GitException("Commit " + commit.name() + " cannot be checked out because an invalid file name in one of the files.\n"
+                        + "Please remove the file from repository with an external tool and try again.\n\n"
+                        + ex.getMessage());
             } catch (CheckoutConflictException ex) {
                 List<String> conflicts = dco.getConflicts();
                 throw new GitException.CheckoutConflictException(conflicts.toArray(new String[conflicts.size()]), ex);
@@ -225,6 +230,24 @@ public class CheckoutRevisionCommand extends GitCommand {
             throw new GitException(ex);
         }
     }
+    
+    @Override
+    protected boolean prepareCommand () throws GitException {
+        boolean canExecute = super.prepareCommand();
+        if (canExecute) {
+            Repository repository = getRepository();
+            try {
+                if (!failOnConflict && repository.readDirCache().hasUnmergedPaths()) {
+                    String message = MessageFormat.format(Utils.getBundle(GitCommand.class).getString("MSG_Error_CannotCheckoutHasConflicts"), repository.getWorkTree()); //NOI18N
+                    monitor.preparationsFailed(message);
+                    throw new GitException(message);
+                }
+            } catch (IOException ex) {
+                throw new GitException(ex);
+            }
+        }
+        return canExecute;
+    }
 
     @Override
     protected String getCommandDescription () {
