@@ -62,6 +62,9 @@ import java.io.*;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
+import java.security.AccessController;
+import java.security.PrivilegedActionException;
+import java.security.PrivilegedExceptionAction;
 import java.util.ArrayDeque;
 import java.util.Arrays;
 import java.util.Date;
@@ -80,7 +83,7 @@ import org.netbeans.modules.masterfs.providers.ProvidedExtensions;
 import org.netbeans.modules.masterfs.watcher.Watcher;
 import org.openide.util.Enumerations;
 import org.openide.util.Exceptions;
-import org.openide.util.Utilities;
+import org.openide.util.BaseUtilities;
 
 
 /**
@@ -194,7 +197,7 @@ public abstract class BaseFileObj extends FileObject {
             fileNaming = fileNaming.getParent();
         }
         String rootName = stack.removeFirst();
-        if (Utilities.isWindows()) {
+        if (BaseUtilities.isWindows()) {
             rootName = rootName.replace(File.separatorChar, '/');
             if(rootName.startsWith("//")) {  //NOI18N
                 // UNC root like //computer/sharedFolder
@@ -603,7 +606,7 @@ public abstract class BaseFileObj extends FileObject {
         FileObject retVal = null;
         if (!isRoot()) {
             final FileNaming parent = getFileName().getParent();
-            if (Utilities.isWindows()) {
+            if (BaseUtilities.isWindows()) {
                 if (parent == null) {
                     retVal = FileBasedFileSystem.getInstance().getRoot();
                 } else {
@@ -866,6 +869,9 @@ public abstract class BaseFileObj extends FileObject {
                     refreshExistingParent(expected, fire);
                 }
             }
+        } catch (Error e) { // #249301
+            LOG.log(Level.INFO, "Cannot refresh file {0}", getPath());  //NOI18N
+            throw e;
         } finally {
             stopWatch.stop();
         }
@@ -1063,7 +1069,7 @@ public abstract class BaseFileObj extends FileObject {
     }
 
     final ProvidedExtensions getProvidedExtensions() {
-        FileBasedFileSystem.StatusImpl status = (FileBasedFileSystem.StatusImpl) FileBasedFileSystem.getInstance().getStatus();
+        FileBasedFileSystem.StatusImpl status = (FileBasedFileSystem.StatusImpl) FileBasedFileSystem.getInstance().getDecorator();
         ProvidedExtensions extensions = status.getExtensions();
         return extensions;
     }
@@ -1084,6 +1090,86 @@ public abstract class BaseFileObj extends FileObject {
     FolderObj getExistingParent() {         
         return getExistingParentFor(getFileName().getFile(), getFactory());
     }
+
+    /**
+     * Get {@link Path} object for this BaseFileObj.
+     */
+    private Path getNativePath() throws IOException {
+        File file = getFileName().getFile();
+        final Path path;
+        try {
+            path = file.toPath();
+        } catch (RuntimeException e) {
+            throw new IOException("Cannot get Path for " + this, e);    //NOI18N
+        }
+        return path;
+    }
+
+    @Override
+    public boolean isSymbolicLink() throws IOException {
+        Path p = getNativePath();
+        return Files.isSymbolicLink(p);
+    }
+
+    @Override
+    public FileObject readSymbolicLink() throws IOException {
+        final Path path = getNativePath();
+        try {
+            return AccessController.doPrivileged(
+                    new PrivilegedExceptionAction<FileObject>() {
+
+                        @Override
+                        public FileObject run() throws Exception {
+                            Path target = Files.readSymbolicLink(path);
+                            Path absoluteTarget = target.isAbsolute()
+                                ? target
+                                : path.getParent().resolve(target);
+                            File file = absoluteTarget.toFile();
+                            File normFile = FileUtil.normalizeFile(file);
+                            return FileBasedFileSystem.getFileObject(normFile);
+                        }
+                    });
+        } catch (PrivilegedActionException ex) {
+            throw new IOException(ex);
+        }
+    }
+
+    @Override
+    public String readSymbolicLinkPath() throws IOException {
+        final Path path = getNativePath();
+        try {
+            return AccessController.doPrivileged(
+                    new PrivilegedExceptionAction<String>() {
+
+                        @Override
+                        public String run() throws Exception {
+                            Path target = Files.readSymbolicLink(path);
+                            return target.toString();
+                        }
+                    });
+        } catch (PrivilegedActionException ex) {
+            throw new IOException(ex);
+        }
+    }
+
+    @Override
+    public FileObject getCanonicalFileObject() throws IOException {
+        final Path path = getNativePath();
+        try {
+            return AccessController.doPrivileged(
+                    new PrivilegedExceptionAction<FileObject>() {
+
+                        @Override
+                        public FileObject run() throws Exception {
+                            Path realPath = path.toRealPath();
+                            File realFile = realPath.toFile();
+                            return FileBasedFileSystem.getFileObject(realFile);
+                        }
+                    });
+        } catch (PrivilegedActionException ex) {
+            throw new IOException(ex);
+        }
+    }
     
     private static class FileEventImpl extends FileEvent implements Enumeration<FileEvent> {
         static {
