@@ -74,7 +74,7 @@ import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
 import org.openide.util.Mutex;
-import org.openide.util.Utilities;
+import org.openide.util.BaseUtilities;
 import org.openide.util.WeakSet;
 
 /**
@@ -111,6 +111,11 @@ public final class FileObjectFactory {
     
     private FileObjectFactory(FileInfo fInfo, Object msg) {
         final BaseFileObj realRoot = create(fInfo);
+        if (realRoot == null) { // #252580
+            Logger.getLogger(FileObjectFactory.class.getName()).log(
+                    Level.SEVERE, "No fo for " + fInfo + " queried for " + msg,
+                    new NullPointerException());
+        }
         assert realRoot != null : "No fo for " + fInfo + " queried for " + msg;
         root = realRoot;
     }
@@ -774,7 +779,7 @@ public final class FileObjectFactory {
     }
 
     public boolean isWarningEnabled() {
-        return WARNINGS && !Utilities.isMac();
+        return WARNINGS && !BaseUtilities.isMac();
     }
 
     //only for tests purposes
