@@ -54,15 +54,11 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Enumeration;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
-import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
-import java.util.TreeSet;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 import java.util.logging.Level;
@@ -193,13 +189,13 @@ public class MavenProjectGrammar extends AbstractSchemaBasedGrammar {
                 NodeList lst = el.getChildNodes();
                 if (lst.getLength() > 0) {
                     if ("artifactId".equals(el.getNodeName())) { //NOI18N
-                        holder.setArtifactId(lst.item(0).getNodeValue());
+                        holder.setArtifactId(getNodeValue(lst.item(0).getNodeValue(), owner.getLookup().lookup(NbMavenProject.class)));
                     }
                     if ("groupId".equals(el.getNodeName())) { //NOI18N
-                        holder.setGroupId(lst.item(0).getNodeValue());
+                        holder.setGroupId(getNodeValue(lst.item(0).getNodeValue(), owner.getLookup().lookup(NbMavenProject.class)));
                     }
                     if ("version".equals(el.getNodeName())) { //NOI18N
-                        holder.setVersion(lst.item(0).getNodeValue());
+                        holder.setVersion(getNodeValue(lst.item(0).getNodeValue(), owner.getLookup().lookup(NbMavenProject.class)));
                     }
                 }
             }
@@ -208,6 +204,45 @@ public class MavenProjectGrammar extends AbstractSchemaBasedGrammar {
         return holder;
     }
     
+    static String getNodeValue(String value, NbMavenProject prj) {
+        StringBuilder sb = new StringBuilder();
+        Properties props = prj.getMavenProject().getProperties();
+            
+        int idxLeft = value.indexOf("${"); // NOI18N
+        if(idxLeft < 0) {
+            return value;
+        } else if(idxLeft > 0) {
+            sb.append(value.substring(0, idxLeft));
+        } 
+        int idxRight = 0;
+        while(idxLeft > -1) {
+            idxRight = value.indexOf("}", idxLeft + 2); // NOI18N
+            if(idxRight > -1) {
+                String propName = value.substring(idxLeft + 2, idxRight);
+                String prop = props.getProperty(propName);
+                if(prop != null) {
+                    sb.append(prop);
+                } else {
+                    // something is wrong; return the original value and hope for the best
+                    return value;
+                }
+            } else {
+                // something is wrong; return the original value and hope for the best
+                return value;
+            }
+            idxLeft = value.indexOf("${", idxRight); // NOI18N
+            if(idxRight < value.length()) {
+                if(idxLeft > idxRight) {                    
+                    sb.append(value.substring(idxRight + 1, idxLeft));
+                } else {
+                    sb.append(value.substring(idxRight + 1, value.length()));
+                }
+            }             
+            idxRight++;
+        }        
+        return sb.toString();
+    }
+    
     private ArtifactInfoHolder findPluginInfo(Node previous, MavenEmbedder embedder, boolean checkLocalRepo) {
         ArtifactInfoHolder holder = findArtifactInfo(previous);
         if (holder.getGroupId() == null) {
@@ -340,7 +375,17 @@ public class MavenProjectGrammar extends AbstractSchemaBasedGrammar {
         if (virtualTextCtx.getCurrentPrefix().length() > 0) {
             String prefix = virtualTextCtx.getCurrentPrefix();
             if (prefix.lastIndexOf("${") > prefix.lastIndexOf("}")) {
-                String propPrefix = prefix.substring(prefix.lastIndexOf("${") + 2);
+                int propStart = prefix.lastIndexOf("${") + 2;
+                int delLen = -1;
+                String propPrefix = prefix.substring(propStart);
+                String val = virtualTextCtx.getNodeValue();
+                int e = val.indexOf('}', propStart);
+                if (e != -1) {
+                    int s = val.indexOf("${", propStart);
+                    if (s == -1 || e < s) {
+                        delLen = e - (propStart + propPrefix.length()) + 1; // with the closing curly brace, caret will be placed after it
+                    }
+                }
                 FileObject fo = getEnvironment().getFileObject();
                 if (fo != null) {
                     List<String> set = new ArrayList<String>();
@@ -368,9 +413,19 @@ public class MavenProjectGrammar extends AbstractSchemaBasedGrammar {
                     Collection<GrammarResult> elems = new ArrayList<GrammarResult>();
                     Collections.sort(set);
                     String suffix = virtualTextCtx.getNodeValue().substring(prefix.length());
+                    int pplen = propPrefix.length();
                     for (String pr : set) {
                         if (pr.startsWith(propPrefix)) {
-                            elems.add(new ExpressionValueTextElement(pr, propPrefix, suffix));
+                            int l = delLen;
+                            if (l == -1) {
+                                // delete all following characters which match the property name
+                                for (l = 0; (l < suffix.length()) && (l + pplen < pr.length()); l++) {
+                                    if (suffix.charAt(l) != pr.charAt(pplen +l)) {
+                                        break;
+                                    }
+                                }
+                            }
+                            elems.add(new ExpressionValueTextElement(pr, propPrefix, l));
                         }
                     }
                     return Collections.enumeration(elems);
