@@ -572,20 +572,36 @@ public abstract class AbstractSchemaBasedGrammar implements GrammarQuery {
     }
      
     protected static class ExpressionValueTextElement extends AbstractSchemaBasedGrammar.MyTextElement {
-        private String suffix;
+        private final int delLen;
+        private final String suffix;
+        
         public ExpressionValueTextElement(String pr, String propPrefix, String suffix) {
-              super(pr, propPrefix);
-              this.suffix = suffix;
+            super(pr, propPrefix);
+            this.suffix = suffix;
+            this.delLen = -1;
         }
-          
+
+        public ExpressionValueTextElement(String pr, String propPrefix, int delL) {
+            super(pr, propPrefix);
+            this.suffix = null;
+            this.delLen = delL;
+        }
+        
           @Override
         public String getNodeValue() {
             String end = name.substring(prefix.length()) + "}";
+            if (suffix == null) {
+                return end;
+            }
             String suff = suffix;
             if (suff.indexOf("}") < suff.indexOf("{")) {
                 suff = suff.substring(suff.indexOf("}") + 1);
             }
-            return end + suff;
+            return suff;
+         }
+        
+        public int getLength() {
+            return delLen == -1 ? super.getLength() : delLen;
         }
     }
      
