@@ -42,9 +42,15 @@
 
 package org.netbeans.modules.maven.indexer;
 
+import org.netbeans.modules.maven.indexer.api.RepositoryQueries;
 import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.URI;
+import java.nio.file.FileStore;
+import java.nio.file.Files;
 import java.util.*;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.logging.Level;
@@ -61,6 +67,7 @@ import org.apache.lucene.store.SimpleFSDirectory;
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.index.*;
+import org.apache.maven.index.Scanner;
 import org.apache.maven.index.artifact.ArtifactPackagingMapper;
 import org.apache.maven.index.context.DefaultIndexingContext;
 import org.apache.maven.index.context.IndexCreator;
@@ -68,7 +75,6 @@ import org.apache.maven.index.context.IndexUtils;
 import org.apache.maven.index.context.IndexingContext;
 import org.apache.maven.index.creator.OsgiArtifactIndexCreator;
 import org.apache.maven.index.expr.StringSearchExpression;
-import org.apache.maven.index.search.grouping.GGrouping;
 import org.apache.maven.index.updater.IndexUpdateRequest;
 import org.apache.maven.index.updater.IndexUpdater;
 import org.apache.maven.index.updater.ResourceFetcher;
@@ -80,6 +86,7 @@ import org.apache.maven.settings.crypto.SettingsDecrypter;
 import org.apache.maven.settings.crypto.SettingsDecryptionResult;
 import org.apache.maven.wagon.Wagon;
 import org.apache.maven.wagon.authentication.AuthenticationInfo;
+import org.apache.maven.wagon.events.TransferListener;
 import org.apache.maven.wagon.providers.http.HttpWagon;
 import org.apache.maven.wagon.proxy.ProxyInfo;
 import org.codehaus.plexus.ContainerConfiguration;
@@ -97,13 +104,34 @@ import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.annotations.common.SuppressWarnings;
 import org.netbeans.modules.maven.embedder.EmbedderFactory;
 import org.netbeans.modules.maven.embedder.MavenEmbedder;
-import org.netbeans.modules.maven.indexer.api.*;
+import org.netbeans.modules.maven.indexer.api.NBArtifactInfo;
+import org.netbeans.modules.maven.indexer.api.NBGroupInfo;
+import org.netbeans.modules.maven.indexer.api.NBVersionInfo;
+import org.netbeans.modules.maven.indexer.api.QueryField;
+import org.netbeans.modules.maven.indexer.api.RepositoryInfo;
+import org.netbeans.modules.maven.indexer.api.RepositoryPreferences;
 import org.netbeans.modules.maven.indexer.api.RepositoryQueries.Result;
-import org.netbeans.modules.maven.indexer.spi.*;
+import org.netbeans.modules.maven.indexer.spi.ArchetypeQueries;
+import org.netbeans.modules.maven.indexer.spi.BaseQueries;
+import org.netbeans.modules.maven.indexer.spi.ChecksumQueries;
+import org.netbeans.modules.maven.indexer.spi.ClassUsageQuery;
+import org.netbeans.modules.maven.indexer.spi.ClassesQuery;
+import org.netbeans.modules.maven.indexer.spi.ContextLoadedQuery;
+import org.netbeans.modules.maven.indexer.spi.DependencyInfoQueries;
+import org.netbeans.modules.maven.indexer.spi.GenericFindQuery;
+import org.netbeans.modules.maven.indexer.spi.Redo;
+import org.netbeans.modules.maven.indexer.spi.RepositoryIndexerImplementation;
+import org.netbeans.modules.maven.indexer.spi.impl.IndexingNotificationProvider;
 import org.openide.modules.Places;
-import org.openide.util.*;
+import org.openide.util.BaseUtilities;
+import org.openide.util.Exceptions;
+import org.openide.util.Lookup;
+import org.openide.util.Mutex;
+import org.openide.util.MutexException;
+import org.openide.util.RequestProcessor;
 import org.openide.util.lookup.ServiceProvider;
 import org.openide.util.lookup.ServiceProviders;
+import org.openide.util.NbBundle.Messages;
 
 @ServiceProviders({
     @ServiceProvider(service=RepositoryIndexerImplementation.class),
@@ -289,10 +317,10 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
                 File contextfile = context.getRepository();
                 File repofile = info.getRepositoryPath() != null ? new File(info.getRepositoryPath()) : null;
                 //try to figure if context reload is necessary
-                if (!Utilities.compareObjects(contexturl, indexUpdateUrl)) {
+                if (!BaseUtilities.compareObjects(contexturl, indexUpdateUrl)) {
                     LOGGER.log(Level.FINE, "Remote context changed: {0}, unload/load", info.getId());
                     unloadIndexingContext(info.getId());
-                } else if (!Utilities.compareObjects(contextfile, repofile)) {
+                } else if (!BaseUtilities.compareObjects(contextfile, repofile)) {
                     LOGGER.log(Level.FINE, "Local context changed: {0}, unload/load", info.getId());
                     unloadIndexingContext(info.getId());
                 } else {
@@ -434,13 +462,20 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
             removeIndexingContext(ic, false);
         }
     }
-
+    
+    @Messages({"# {0} - folder path",
+               "MSG_NoSpace=There is not enough space in your temp folder to download and unpack the index for ''{0}''.",
+               "# {0} - folder path",
+               "MSG_SeemsNoSpace=It seems that there is not enough space in your temp folder to download and unpack the index for ''{0}''."})
     private void indexLoadedRepo(final RepositoryInfo repo, boolean updateLocal) throws IOException {
         Mutex mutex = getRepoMutex(repo);
         assert mutex.isWriteAccess();
         synchronized (indexingMutexes) {
             indexingMutexes.add(mutex);
         }
+        boolean fetchFailed = false;
+        long t = System.currentTimeMillis();
+        RemoteIndexTransferListener listener = null;
         try {
             IndexingContext indexingContext = getIndexingContexts().get(repo.getId());
             if (indexingContext == null) {
@@ -449,7 +484,7 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
             }
             if (repo.isRemoteDownloadable()) {
                 LOGGER.log(Level.FINE, "Indexing Remote Repository: {0}", repo.getId());
-                final RemoteIndexTransferListener listener = new RemoteIndexTransferListener(repo);
+                listener = new RemoteIndexTransferListener(repo);
                 try {
                     String protocol = URI.create(indexingContext.getIndexUpdateUrl()).getScheme();
                     SettingsDecryptionResult settings = embedder.lookup(SettingsDecrypter.class).decrypt(new DefaultSettingsDecryptionRequest(EmbedderFactory.getOnlineEmbedder().getSettings()));
@@ -487,7 +522,7 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
                         httpwagon.setHttpHeaders(p);
                     }
                             
-                    ResourceFetcher fetcher = new WagonHelper.WagonFetcher(wagon, listener, wagonAuth, wagonProxy);
+                    ResourceFetcher fetcher = createFetcher(wagon, listener, wagonAuth, wagonProxy);
                     listener.setFetcher(fetcher);
                     IndexUpdateRequest iur = new IndexUpdateRequest(indexingContext, fetcher);
                     
@@ -503,6 +538,9 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
                     }
                     try {
                         remoteIndexUpdater.fetchAndUpdateIndex(iur);
+                    } catch (IOException ex) {
+                        fetchFailed = true;
+                        throw ex;
                     } finally {
                         if (nic != null) {
                             nic.end();
@@ -517,28 +555,71 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
                     //#210743
                     LOGGER.log(Level.FINE, "Local repository at {0} doesn't exist, no scan.", indexingContext.getRepository());
                 } else {
-                    RepositoryIndexerListener listener = new RepositoryIndexerListener(indexingContext);
+                    RepositoryIndexerListener repoListener = new RepositoryIndexerListener(indexingContext);
                     try {
-                        scan(indexingContext, null, listener, updateLocal);
+                        scan(indexingContext, null, repoListener, updateLocal);
                     } finally {
-                        listener.close();
+                        repoListener.close();
                     }
                 }
             }
+        } catch (IOException e) {
+            // see also issue #250365
+            String noSpaceLeftMsg = null;
+            if(e.getMessage().contains("No space left on device")) {
+                noSpaceLeftMsg = Bundle.MSG_NoSpace(repo.getName());
+            }
+            
+            long downloaded = listener != null ? listener.getUnits() * 1024 : -1;
+            long usableSpace = -1;
+            File tmpFolder = new File(System.getProperty("java.io.tmpdir"));
+            try {
+                FileStore store = Files.getFileStore(tmpFolder.toPath());
+                usableSpace = store.getUsableSpace();                    
+            } catch (IOException ex) {
+                Exceptions.printStackTrace(ex);
+            }
+            LOGGER.log(Level.INFO, "Downloaded maven index file has size {0} (zipped). The usable space in {1} (java.io.tmpdir) is {2}.", new Object[]{downloaded, tmpFolder, usableSpace});
+
+            // still might be a problem with a too small tmp,
+            // let's try to figure out ...
+            if(noSpaceLeftMsg == null && downloaded > -1 && downloaded * 15 > usableSpace) {
+                noSpaceLeftMsg = Bundle.MSG_SeemsNoSpace(repo.getName());
+            }
+
+            if(noSpaceLeftMsg != null) {
+                LOGGER.log(Level.INFO, null, e);
+                IndexingNotificationProvider np = Lookup.getDefault().lookup(IndexingNotificationProvider.class);
+                if(np != null) {
+                    np.notifyError(noSpaceLeftMsg);
+                } else {
+                    throw e;
+                }
+            } else {
+                throw e;
+            }
         } catch (Cancellation x) {
             throw new IOException("canceled indexing");
         } catch (ComponentLookupException x) {
             throw new IOException("could not find protocol handler for " + repo.getRepositoryUrl(), x);
         } finally {
+            if(isDiag()) {
+                LOGGER.log(Level.INFO, "Indexing of {0} took {1} millis.", new Object[]{repo.getId(), System.currentTimeMillis() - t});
+            }
             synchronized (indexingMutexes) {
                 indexingMutexes.remove(mutex);
             }
-            RepositoryPreferences.setLastIndexUpdate(repo.getId(), new Date());
-            fireChangeIndex(repo);
-            
+            if(!fetchFailed) {
+                RepositoryPreferences.setLastIndexUpdate(repo.getId(), new Date());
+                fireChangeIndex(repo);
+            }
         }
     }
 
+    private static boolean isDiag() {
+        return Boolean.getBoolean("maven.indexing.diag");
+    }
+
     //spawn the indexing into a separate thread..
     private void spawnIndexLoadedRepo(final RepositoryInfo repo) {
         RP.post(new Runnable() {
@@ -1701,7 +1782,7 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
 
         private SkippedAction(Result<?> result) {
             this.result = result;
-}
+        }
         
         @Override
         public void run(RepositoryInfo repo, IndexingContext context) throws IOException {
@@ -1717,10 +1798,31 @@ public class NexusRepositoryIndexerImpl implements RepositoryIndexerImplementati
         public boolean accepts(IndexingContext ctx, ArtifactInfo ai) {
             if ("javadoc".equals(ai.classifier) || "sources".equals(ai.classifier)) {
                 return false;
-}
+            }
             return true;
         }
         
     }
-
+    
+    private WagonHelper.WagonFetcher createFetcher(final Wagon wagon, TransferListener listener, AuthenticationInfo authenticationInfo, ProxyInfo proxyInfo) {
+        if(isDiag()) {
+            return new WagonHelper.WagonFetcher(wagon, listener, authenticationInfo, proxyInfo) {
+                @Override
+                public InputStream retrieve(String name) throws IOException, FileNotFoundException {
+                    String id = wagon.getRepository().getId();
+                    if(name.contains("properties") && System.getProperty("maven.diag.index.properties." + id) != null) { // NOI18N
+                        LOGGER.log(Level.INFO, "maven indexer will use local properties file: {0}", System.getProperty("maven.diag.index.properties." + id)); // NOI18N
+                        return new FileInputStream(new File(System.getProperty("maven.diag.index.properties." + id))); // NOI18N
+                    } else if(name.contains(".gz") && System.getProperty("maven.diag.index.gz." + id) != null) { // NOI18N
+                        LOGGER.log(Level.INFO, "maven indexer will use gz file: {0}", System.getProperty("maven.diag.index.gz." + id)); // NOI18N
+                        return new FileInputStream(new File(System.getProperty("maven.diag.index.gz." + id))); // NOI18N
+                    }
+                    return super.retrieve(name);
+                }
+            };
+        } else {
+            return new WagonHelper.WagonFetcher(wagon, listener, authenticationInfo, proxyInfo);
+        }
+    }
+    
 }
