@@ -72,7 +72,6 @@ import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
-import org.netbeans.modules.gsf.testrunner.api.Manager;
 import org.netbeans.modules.gsf.testrunner.api.RerunHandler;
 import org.netbeans.modules.gsf.testrunner.api.RerunType;
 import org.netbeans.modules.gsf.testrunner.api.Status;
@@ -81,6 +80,10 @@ import org.netbeans.modules.gsf.testrunner.api.TestSuite;
 import org.netbeans.modules.gsf.testrunner.api.Testcase;
 import org.netbeans.modules.gsf.testrunner.api.Trouble;
 import org.netbeans.modules.gsf.testrunner.api.UnitTestsUsage;
+import org.netbeans.modules.gsf.testrunner.api.CommonUtils;
+import org.netbeans.modules.gsf.testrunner.api.CoreManager;
+import org.netbeans.modules.junit.api.JUnitTestSuite;
+import org.netbeans.modules.junit.api.JUnitTestcase;
 import org.netbeans.modules.maven.api.Constants;
 import org.netbeans.modules.maven.api.NbMavenProject;
 import org.netbeans.modules.maven.api.PluginPropertyUtils;
@@ -88,9 +91,9 @@ import org.netbeans.modules.maven.api.execute.RunConfig;
 import org.netbeans.modules.maven.api.execute.RunUtils;
 import org.netbeans.modules.maven.api.output.OutputProcessor;
 import org.netbeans.modules.maven.api.output.OutputVisitor;
-import org.netbeans.modules.maven.junit.nodes.JUnitTestRunnerNodeFactory;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
+import org.openide.util.Lookup;
 import org.openide.util.Utilities;
 
 /**
@@ -275,6 +278,16 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
         return name;
     } 
     
+    private CoreManager getManagerProvider() {
+        Collection<? extends Lookup.Item<CoreManager>> providers = Lookup.getDefault().lookupResult(CoreManager.class).allItems();
+        for (Lookup.Item<CoreManager> provider : providers) {
+            if(provider.getDisplayName().equals(CommonUtils.MAVEN_PROJECT_TYPE.concat("_").concat(CommonUtils.JUNIT_TF))) {
+                return provider.getInstance();
+            }
+        }
+        return null;
+    }
+    
     private void createSession(File nonNormalizedFile) {
         if (session == null) {
             File fil = FileUtil.normalizeFile(nonNormalizedFile);
@@ -294,8 +307,11 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
 			}
 		    }
 		    final TestSession.SessionType fType = type;
-		    session = new TestSession(createSessionName(mvnprj.getMavenProject().getId()), prj, TestSession.SessionType.TEST,
-			    new JUnitTestRunnerNodeFactory(session, prj));
+                    CoreManager junitManager = getManagerProvider();
+                    if (junitManager != null) {
+                        junitManager.registerNodeFactory();
+                    }
+                    session = new TestSession(createSessionName(mvnprj.getMavenProject().getId()), prj, TestSession.SessionType.TEST);
 		    session.setRerunHandler(new RerunHandler() {
 			public @Override
 			void rerun() {
@@ -381,7 +397,9 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
 			void removeChangeListener(ChangeListener listener) {
 			}
 		    });
-		    Manager.getInstance().testStarted(session);
+		    if (junitManager != null) {
+                        junitManager.testStarted(session);
+                    }
 		}
 	    }
 	}
@@ -441,7 +459,10 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
         if (runningTestClass != null && outputDir != null) {
             generateTest();
         }
-        Manager.getInstance().sessionFinished(session);
+        CoreManager junitManager = getManagerProvider();
+        if (junitManager != null) {
+            junitManager.sessionFinished(session);
+        }
         runningTestClass = null;
         outputDir = null;
         session = null;
@@ -484,6 +505,10 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
     public @Override void sequenceFail(String sequenceId, OutputVisitor visitor) {
         // try to get the failed test class. How can this be solved if it is not the first one in the list?
         if(surefireRunningInParallel) {
+            if(runningTestClassesInParallel.isEmpty()) {
+                // no test case is currently running, so do nothing (is this a more serious failure?)
+                return;
+            }
             runningTestClass = runningTestClassesInParallel.get(0);
         }
         sequenceEnd(sequenceId, visitor);
@@ -536,9 +561,13 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
             }
             Element testSuite = document.getRootElement();
             assert "testsuite".equals(testSuite.getName()) : "Root name " + testSuite.getName(); //NOI18N
-            TestSuite suite = new TestSuite(testSuite.getAttributeValue("name"));
+            TestSuite suite = new JUnitTestSuite(testSuite.getAttributeValue("name"), session);
             session.addSuite(suite);
-            Manager.getInstance().displaySuiteRunning(session, suite.getName());
+            CoreManager junitManager = getManagerProvider();
+            if (junitManager != null) {
+                junitManager.displaySuiteRunning(session, suite.getName());
+            }
+            File output = new File(outputDir, runningTestClass + suffix + "-output.txt");
             
             @SuppressWarnings("unchecked")
             List<Element> testcases = testSuite.getChildren("testcase"); //NOI18N
@@ -549,9 +578,11 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
                 if (name.endsWith(nameSuffix)) {
                     name = name.substring(0, name.length() - nameSuffix.length());
                 }
-                Testcase test = new Testcase(name, null, session);
+                Testcase test = new JUnitTestcase(name, null, session);
                 Element stdout = testcase.getChild("system-out"); //NOI18N
-                if (stdout != null) {
+                // If *-output.txt file exists do not log standard output here to avoid logging it twice.
+                // By default surefire only reports standard output for failing testcases.
+                if (!output.isFile() && stdout != null) {
                     logText(stdout.getText(), test, false);
                 }
                 Element failure = testcase.getChild("failure"); //NOI18N
@@ -594,11 +625,16 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
             String time = testSuite.getAttributeValue("time");
             // the surefire plugin does not print out localised numbers, so use the english format
             float fl = NumberFormat.getNumberInstance(Locale.ENGLISH).parse(time).floatValue();
-            long timeinmilis = (long)(fl * 1000);
-            Manager.getInstance().displayReport(session, session.getReport(timeinmilis));
-            File output = new File(outputDir, runningTestClass + suffix + "-output.txt");
+            long timeinmilis = (long) (fl * 1000);
+            if (junitManager != null) {
+                junitManager.displayReport(session, session.getReport(timeinmilis));
+            } else { // update report status as a minimum
+                session.getReport(timeinmilis).setCompleted(true);
+            }
             if (output.isFile()) {
-                Manager.getInstance().displayOutput(session, FileUtils.fileRead(output), false);
+                if (junitManager != null) {
+                    junitManager.displayOutput(session, FileUtils.fileRead(output), false);
+                }
             }
         } catch (IOException x) {
             LOG.log(Level.WARNING, "parsing " + report, x);
@@ -613,7 +649,10 @@ public class JUnitOutputListenerProvider implements OutputProcessor {
         while (tokens.hasMoreTokens()) {
             lines.add(tokens.nextToken());
         }
-        Manager.getInstance().displayOutput(session, text, failure);
+        CoreManager junitManager = getManagerProvider();
+        if (junitManager != null) {
+            junitManager.displayOutput(session, text, failure);
+        }
         test.addOutputLines(lines);
     }
 
