@@ -57,7 +57,9 @@ import java.nio.file.attribute.BasicFileAttributes;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -108,7 +110,6 @@ import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileRenameEvent;
 import org.openide.filesystems.FileUtil;
-import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle.Messages;
 import org.openide.util.NbCollections;
@@ -695,7 +696,10 @@ public final class NbMavenProjectImpl implements Project {
                 Files.walkFileTree(sourceRoot, visitor);
                 toRet.addAll(visitor.getOtherRoots());
             } catch (IOException ex) {
-                Exceptions.printStackTrace(ex);
+                // log as info to keep trace about possible problems, 
+                // but lets not be too agressive with level and notification                
+                // see also issue #251071
+                LOG.log(Level.INFO, null, ex);
             }
         }
         URI[] res = getResources(test);
@@ -859,6 +863,7 @@ public final class NbMavenProjectImpl implements Project {
                     UILookupMergerSupport.createRecommendedTemplatesMerger(),
                     UILookupMergerSupport.createProjectProblemsProviderMerger(),
                     LookupProviderSupport.createSourcesMerger(),
+                    LookupProviderSupport.createSharabilityQueryMerger(),
                     ProjectClassPathModifier.extenderForModifier(this),
                     LookupMergerSupport.createClassPathModifierMerger());
     }
@@ -877,7 +882,12 @@ public final class NbMavenProjectImpl implements Project {
     @Override
     public boolean equals(Object obj) {
         if (obj instanceof Project) {
-            NbMavenProjectImpl impl = ((Project) obj).getLookup().lookup(NbMavenProjectImpl.class);
+            NbMavenProjectImpl impl;
+            if (obj instanceof NbMavenProjectImpl) {
+                impl = ((NbMavenProjectImpl) obj);
+            } else {
+                impl = ((Project) obj).getLookup().lookup(NbMavenProjectImpl.class);
+            }
             if (impl != null) {
                 return getPOMFile().equals(impl.getPOMFile());
             }
@@ -899,12 +909,14 @@ public final class NbMavenProjectImpl implements Project {
 
         
         private final FileProvider fileProvider;
-        private File[] filesToWatch;
+        private List<File> filesToWatch;
         private long lastTime = 0;
-
+        
+        private Map<File, Long> lastMods;
+        
         /** Relative file paths to watch. */
         Updater(FileProvider toWatch) {
-            fileProvider = toWatch;
+            fileProvider = toWatch;            
         }
 
         @Override
@@ -939,18 +951,18 @@ public final class NbMavenProjectImpl implements Project {
         public void fileFolderCreated(FileEvent fileEvent) {
             //TODO possibly remove this fire.. watch for actual path..
 //            NbMavenProject.fireMavenProjectReload(NbMavenProjectImpl.this);
-        }
+        }    
 
         @Override
         public void fileRenamed(FileRenameEvent fileRenameEvent) {
         }
 
         synchronized void attachAll() {
-            File[] toWatch = fileProvider.getFiles();
-            Arrays.sort(toWatch);
-            this.filesToWatch = toWatch;
+            this.filesToWatch = new ArrayList(Arrays.asList(fileProvider.getFiles()));
             
-            for (File file : toWatch) {
+            filesToWatch.addAll(getParents()); 
+            Collections.sort(filesToWatch);
+            for (File file : filesToWatch) {
                 try {
                     FileUtil.addFileChangeListener(this, file);
                 } catch (IllegalArgumentException ex) {
@@ -965,11 +977,53 @@ public final class NbMavenProjectImpl implements Project {
                     assert false : "project opened twice in a row, issue #236211 for " + projectFile.getAbsolutePath();
                 }
             }
+            
+            if(lastMods == null) {
+                // attached for the first time, 
+                // preserve lastModified of interestig files 
+                lastMods = new HashMap<>(filesToWatch.size());
+                for (File file : filesToWatch) {
+                    lastMods.put(file, file.lastModified());
+                }
+            } else {
+                for (Map.Entry<File, Long> e : lastMods.entrySet()) {
+                    File file = e.getKey();
+                    long ts = file.lastModified();
+                    if( e.getValue() < ts ) {
+                        // attached after being previously dettached and 
+                        // lastModified of an interesting file changed in the meantime 
+                        // -> force pom refresh
+                        lastMods.put(file, ts);
+                        NbMavenProject.fireMavenProjectReload(NbMavenProjectImpl.this);
+                    }
+                }
+                
+            }            
+        }
+
+        protected List<File> getParents() {
+            LinkedList<File> ret = new LinkedList<>();
+            MavenProject project = getOriginalMavenProject();
+            while(true) {
+                try {
+                    MavenProject parent = loadParentOf(getEmbedder(), project);
+                    File parentFile = parent != null ? parent.getFile() : null;
+                    if(parentFile != null) {
+                        ret.add(parentFile);
+                        project = parent;
+                    } else {
+                        break;
+                    }
+                } catch (ProjectBuildingException ex) {
+                    break;
+                }
+            } 
+            return ret;
         }
 
         synchronized void detachAll() {
             if (filesToWatch != null) {
-                File[] toWatch = filesToWatch;
+                List<File> toWatch = filesToWatch;
                 filesToWatch = null;
                 for (File file : toWatch) {
                     try {
