@@ -52,6 +52,7 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
+import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.DefaultListCellRenderer;
@@ -60,6 +61,7 @@ import javax.swing.JFileChooser;
 import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.JTextField;
+import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
@@ -68,11 +70,13 @@ import org.netbeans.api.java.project.JavaProjectConstants;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
+import org.netbeans.modules.java.api.common.project.ui.ProjectUISupport;
 import org.netbeans.modules.maven.NbMavenProjectImpl;
 import org.netbeans.modules.maven.api.customizer.ModelHandle2;
 import org.netbeans.modules.maven.classpath.MavenSourcesImpl;
 import org.netbeans.modules.maven.execute.model.ActionToGoalMapping;
 import org.netbeans.modules.maven.execute.model.NetbeansActionMapping;
+import org.netbeans.modules.maven.options.MavenSettings;
 import org.netbeans.spi.project.ActionProvider;
 import org.netbeans.spi.project.ui.support.ProjectCustomizer;
 import org.openide.DialogDescriptor;
@@ -115,6 +119,10 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
     
     public RunJarPanel(ModelHandle2 handle, NbMavenProjectImpl project, ProjectCustomizer.Category category) {
         initComponents();
+        boolean isVMOptionsWrap = MavenSettings.getDefault().isVMOptionsWrap();
+        wrapCheckBox.setSelected(isVMOptionsWrap);
+        txtVMOptions.setLineWrap(isVMOptionsWrap);
+        
         this.category = category;
         this.handle = handle;
         this.project = project;
@@ -240,7 +248,7 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
             }
             if (params != null) {
                 oldAllParams = params;
-                oldVMParams = splitJVMParams(params);
+                oldVMParams = splitJVMParams(params, true);
                 if (oldVMParams != null && oldVMParams.contains("-classpath %classpath")) {
                     oldVMParams = oldVMParams.replace("-classpath %classpath", "");
                 }
@@ -319,10 +327,13 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
         txtWorkDir = new javax.swing.JTextField();
         btnWorkDir = new javax.swing.JButton();
         lblVMOptions = new javax.swing.JLabel();
-        txtVMOptions = new javax.swing.JTextField();
         lblHint = new javax.swing.JLabel();
         lblConfiguration = new javax.swing.JLabel();
         comConfiguration = new javax.swing.JComboBox();
+        jScrollPane1 = new javax.swing.JScrollPane();
+        txtVMOptions = new javax.swing.JTextArea();
+        customizeOptionsButton = new javax.swing.JButton();
+        wrapCheckBox = new javax.swing.JCheckBox();
 
         lblMainClass.setLabelFor(txtMainClass);
         org.openide.awt.Mnemonics.setLocalizedText(lblMainClass, org.openide.util.NbBundle.getMessage(RunJarPanel.class, "LBL_MainClass")); // NOI18N
@@ -352,11 +363,32 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
 
         comConfiguration.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
 
+        txtVMOptions.setColumns(20);
+        txtVMOptions.setLineWrap(true);
+        txtVMOptions.setRows(5);
+        jScrollPane1.setViewportView(txtVMOptions);
+        txtVMOptions.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(RunJarPanel.class, "RunJarPanel.txtVMOptions.AccessibleContext.accessibleDescription")); // NOI18N
+
+        org.openide.awt.Mnemonics.setLocalizedText(customizeOptionsButton, org.openide.util.NbBundle.getMessage(RunJarPanel.class, "RunJarPanel.customizeOptionsButton.text")); // NOI18N
+        customizeOptionsButton.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                customizeOptionsButtonActionPerformed(evt);
+            }
+        });
+
+        wrapCheckBox.setSelected(true);
+        org.openide.awt.Mnemonics.setLocalizedText(wrapCheckBox, org.openide.util.NbBundle.getMessage(RunJarPanel.class, "RunJarPanel.wrapCheckBox.text")); // NOI18N
+        wrapCheckBox.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                wrapCheckBoxActionPerformed(evt);
+            }
+        });
+
         javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
             layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
+            .addGroup(layout.createSequentialGroup()
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                     .addComponent(lblWorkDir)
                     .addComponent(lblVMOptions)
@@ -365,19 +397,23 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
                     .addComponent(lblMainClass))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                    .addComponent(txtVMOptions, javax.swing.GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
-                    .addComponent(txtWorkDir, javax.swing.GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
-                    .addComponent(txtArguments, javax.swing.GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
-                    .addComponent(txtMainClass, javax.swing.GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
-                    .addComponent(comConfiguration, 0, 225, Short.MAX_VALUE))
+                    .addGroup(layout.createSequentialGroup()
+                        .addComponent(lblHint)
+                        .addGap(0, 0, Short.MAX_VALUE))
+                    .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 261, Short.MAX_VALUE)
+                    .addComponent(txtWorkDir)
+                    .addComponent(txtArguments)
+                    .addComponent(txtMainClass)
+                    .addComponent(comConfiguration, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                    .addComponent(btnWorkDir)
-                    .addComponent(btnMainClass)))
-            .addGroup(layout.createSequentialGroup()
-                .addGap(128, 128, 128)
-                .addComponent(lblHint)
-                .addContainerGap(246, Short.MAX_VALUE))
+                    .addGroup(layout.createSequentialGroup()
+                        .addGap(6, 6, 6)
+                        .addComponent(wrapCheckBox))
+                    .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
+                        .addComponent(btnWorkDir, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                        .addComponent(btnMainClass, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                        .addComponent(customizeOptionsButton, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))))
         );
         layout.setVerticalGroup(
             layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
@@ -400,12 +436,19 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
                     .addComponent(txtWorkDir, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                     .addComponent(btnWorkDir))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
-                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
-                    .addComponent(lblVMOptions)
-                    .addComponent(txtVMOptions, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
-                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
-                .addComponent(lblHint)
-                .addContainerGap(139, Short.MAX_VALUE))
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                    .addGroup(layout.createSequentialGroup()
+                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                            .addComponent(lblVMOptions)
+                            .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 55, Short.MAX_VALUE))
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(lblHint)
+                        .addGap(40, 40, 40))
+                    .addGroup(layout.createSequentialGroup()
+                        .addComponent(customizeOptionsButton)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(wrapCheckBox)
+                        .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))))
         );
 
         txtMainClass.getAccessibleContext().setAccessibleDescription("Main class");
@@ -413,7 +456,6 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
         txtArguments.getAccessibleContext().setAccessibleDescription("Arguments");
         txtWorkDir.getAccessibleContext().setAccessibleDescription("Working directory");
         btnWorkDir.getAccessibleContext().setAccessibleDescription("Browse working directory");
-        txtVMOptions.getAccessibleContext().setAccessibleDescription("VM options");
         comConfiguration.getAccessibleContext().setAccessibleDescription("Configuration");
     }// </editor-fold>//GEN-END:initComponents
 
@@ -435,10 +477,28 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
         }
     }//GEN-LAST:event_btnWorkDirActionPerformed
 
+    private void customizeOptionsButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_customizeOptionsButtonActionPerformed
+        String origin = txtVMOptions.getText();
+        try {
+            String result = ProjectUISupport.showVMOptionCustomizer(SwingUtilities.getWindowAncestor(this), origin);
+            result = splitJVMParams(result, true);
+            txtVMOptions.setText(result);
+        } catch (Exception e) {
+            Logger.getLogger(RunJarPanel.class.getName()).log(Level.WARNING, "Cannot parse vm options.", e); // NOI18N
+        }
+    }//GEN-LAST:event_customizeOptionsButtonActionPerformed
+
+    private void wrapCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_wrapCheckBoxActionPerformed
+        boolean selected = wrapCheckBox.isSelected();
+        MavenSettings.getDefault().setVMOptionsWrap(selected);
+        txtVMOptions.setLineWrap(selected);
+    }//GEN-LAST:event_wrapCheckBoxActionPerformed
+
     void applyChanges() {
         String newMainClass = txtMainClass.getText().trim();
         String newParams = txtArguments.getText().trim();
         String newVMParams = txtVMOptions.getText().trim();
+        newVMParams = newVMParams.replace('\n', ' ');
         String newWorkDir = txtWorkDir.getText().trim();
         ActionToGoalMapping a2gm = handle.getActionMappings((ModelHandle2.Configuration) comConfiguration.getSelectedItem());
         if (isCurrentRun || isCurrentDebug || isCurrentProfile) {
@@ -541,13 +601,21 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
     }
     
     static String splitJVMParams(String line) {
+        return splitJVMParams(line, false);
+    }
+    
+    private static String splitJVMParams(String line, boolean newLines) {
         PropertySplitter ps = new PropertySplitter(line);
         ps.setSeparator(' '); //NOI18N
         String s = ps.nextPair();
         String jvms = ""; //NOI18N
         while (s != null) {
             if (s.startsWith("-") || /* #199411 */s.startsWith("\"-") || s.contains("%classpath")) { //NOI18N
-                jvms = jvms + " " + s;
+                if(s.contains("%classpath")) {
+                    jvms =  jvms + " " + s;
+                } else {
+                    jvms =  jvms + (jvms.isEmpty() ? "" : (newLines ? "\n" : " ")) + s;
+                }
             } else if (s.equals("${packageClassName}") || s.matches("[\\w]+[\\.]{0,1}[\\w\\.]*")) { //NOI18N
                 break;
             }
@@ -587,6 +655,8 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
     private javax.swing.JButton btnMainClass;
     private javax.swing.JButton btnWorkDir;
     private javax.swing.JComboBox comConfiguration;
+    private javax.swing.JButton customizeOptionsButton;
+    private javax.swing.JScrollPane jScrollPane1;
     private javax.swing.JLabel lblArguments;
     private javax.swing.JLabel lblConfiguration;
     private javax.swing.JLabel lblHint;
@@ -595,8 +665,9 @@ public class RunJarPanel extends javax.swing.JPanel implements HelpCtx.Provider
     private javax.swing.JLabel lblWorkDir;
     private javax.swing.JTextField txtArguments;
     private javax.swing.JTextField txtMainClass;
-    private javax.swing.JTextField txtVMOptions;
+    private javax.swing.JTextArea txtVMOptions;
     private javax.swing.JTextField txtWorkDir;
+    private javax.swing.JCheckBox wrapCheckBox;
     // End of variables declaration//GEN-END:variables
 
     private void setupConfigurations() {
