@@ -98,6 +98,7 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
     private static final RequestProcessor PROCESSOR = new RequestProcessor("Maven ComandLine Output Redirection", Integer.getInteger("maven.concurrent.builds", 16) * 2); //NOI18N
     private static final Logger LOG = Logger.getLogger(CommandLineOutputHandler.class.getName());
     private InputOutput inputOutput;
+    /*test*/ static final Pattern DOWNLOAD = Pattern.compile("^(\\d+(/\\d*)? ?(M|K|b|KB|B|\\?)\\s*)+$"); //NOI18N
     private static final Pattern linePattern = Pattern.compile("\\[(DEBUG|INFO|WARNING|ERROR|FATAL)\\] (.*)"); // NOI18N
     public static final Pattern startPatternM2 = Pattern.compile("\\[INFO\\] \\[([\\w]*):([\\w]*)[ ]?.*\\]"); // NOI18N
     public static final Pattern startPatternM3 = Pattern.compile("\\[INFO\\] --- (\\S+):\\S+:(\\S+)(?: [(]\\S+[)])? @ \\S+ ---"); // ExecutionEventLogger.mojoStarted NOI18N
@@ -128,11 +129,8 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
     private boolean addProjectFold = false;
     private URL[] mavencoreurls;
 
-    
-    
-
-    CommandLineOutputHandler(ProgressHandle hand, boolean createVisitorContext) {
-        super(hand, createVisitorContext ? new OutputVisitor(new ContextImpl()) : new OutputVisitor());
+    public CommandLineOutputHandler(InputOutput io, Project proj, ProgressHandle hand, RunConfig config, boolean createVisitorContext) {
+        super(proj, hand, config, createVisitorContext ? new OutputVisitor(new ContextImpl()) : new OutputVisitor());
         if (createVisitorContext) {
             contextImpl = (ContextImpl) visitor.getContext();
             assert contextImpl != null;
@@ -140,10 +138,6 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
         }
         this.parser = new JSONParser();
         handle = hand;
-    }
-
-    public CommandLineOutputHandler(InputOutput io, Project proj, ProgressHandle hand, RunConfig config, boolean createVisitorContext) {
-        this(hand, createVisitorContext);
         inputOutput = io;
         stdOut = inputOutput.getOut();
 //        logger = new Logger();
@@ -259,6 +253,7 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
                 }
                 if (char1[0] == '\r') { //NOI18N
                     skipLF = true;
+                    buf.append(char1[0]);
                     return buf.toString();
                 }
                 buf.append(char1[0]);
@@ -297,12 +292,19 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
                         line = readLine();
                         continue;
                     }
-                    if (line.startsWith(INFO_NETBEANS_EXEC_EVENT)) {
+                    int execEventIdx = line.indexOf(INFO_NETBEANS_EXEC_EVENT);
+                    if (execEventIdx == 0) {
                         processExecEvent(parseExecEvent(line));
 //                        stdOut.println(line); //XXX temporary
                         line = readLine();
                         continue;
-                    }                    
+                    }
+                    
+                    String nextLine = null;
+                    if(execEventIdx > 0) {
+                        nextLine = line.substring(execEventIdx);
+                        line = line.substring(0, execEventIdx);
+                    }                   
                     if (line.startsWith("[INFO] Final Memory:")) { //NOI18N
                         // previous value [INFO] --------------- is too early, the compilation errors don't get processed in this case.
                         //heuristics..
@@ -331,23 +333,35 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
                         CommandLineOutputHandler.this.processStart(getEventId(SEC_MOJO_EXEC, tag), stdOut);
                         checkSleepiness();
                     }
-                    Matcher match = linePattern.matcher(line);
-                    if (match.matches()) {
-                        String levelS = match.group(1);
-                        Level level = Level.valueOf(levelS);
-                        String text = match.group(2);
-                        updateFoldForException(text);
-                        processLine(text, stdOut, level);
-                        if (level == Level.INFO && contextImpl == null) { //only perform for maven 2.x now
-                            checkProgress(text);
+                    
+                    boolean isDownloadProgress = false;
+                    if(line.length() > 0 && line.charAt(line.length() - 1) == '\r') {
+                        // issue #252514
+                        if (DOWNLOAD.matcher(line).matches()) {
+                            isDownloadProgress = true;
+                        } else {
+                            line = line.substring(0, line.length() - 1);
+                        }
+                    }
+                    if(!isDownloadProgress) {
+                        Matcher match = linePattern.matcher(line);
+                        if (match.matches()) {
+                            String levelS = match.group(1);
+                            Level level = Level.valueOf(levelS);
+                            String text = match.group(2);
+                            updateFoldForException(text);
+                            processLine(MavenSettings.getDefault().isShowLoggingLevel() ? line : text, stdOut, level);
+                            if (level == Level.INFO && contextImpl == null) { //only perform for maven 2.x now
+                                checkProgress(text);
+                            }
+                        } else {
+                            // oh well..
+                            updateFoldForException(line);
+                            processLine(line, stdOut, Level.INFO);
                         }
-                    } else {
-                        // oh well..
-                        updateFoldForException(line);
-                        processLine(line, stdOut, Level.INFO);
                     }
                     if (contextImpl == null && firstFailure == null) {
-                        match = reactorFailure.matcher(line);
+                        Matcher match = reactorFailure.matcher(line);
                         if (match.matches()) {
                             firstFailure = match.group(1);
                         }
@@ -363,7 +377,7 @@ public class CommandLineOutputHandler extends AbstractOutputHandler {
                         currentTreeNode.startFold(inputOutput);
                         addProjectFold = false;
                     }
-                    line = readLine();
+                    line = nextLine != null ? nextLine : readLine();
                 }
             } catch (IOException ex) {
                 java.util.logging.Logger.getLogger(CommandLineOutputHandler.class.getName()).log(java.util.logging.Level.FINE, null, ex);
