@@ -56,6 +56,7 @@ import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
@@ -136,6 +137,7 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
     private final transient ExplorerManager explorerManager = new ExplorerManager();
     
     private final BeanTreeView treeView;
+    private final Object PROJECT_LOCK = new Object();
     private NbMavenProject current;
     private Project currentP;
     private final TapPanel filtersPanel;
@@ -183,8 +185,10 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
     }
 
     void navigate(DataObject d) {
-        if (current != null) {
-            current.removePropertyChangeListener(pchadapter);
+        synchronized (PROJECT_LOCK) {
+            if (current != null) {
+                current.removePropertyChangeListener(pchadapter);
+            }
         }
         NbMavenProject n = null;
 
@@ -209,9 +213,11 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
             return;
         }
          
-        current = n;
-        currentP = p;
-        current.addPropertyChangeListener(pchadapter);
+        synchronized (PROJECT_LOCK) {
+            current = n;
+            currentP = p;
+            current.addPropertyChangeListener(pchadapter);
+        }
         showWaitNode();
         RequestProcessor.getDefault().post(this);
     }
@@ -220,11 +226,15 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
     public void run() {
         //#164852 somehow a folder dataobject slipped in, test mimetype to avoid that.
         // the root cause of the problem is unknown though
-        if (currentP != null ) { //NOI18N
+        Project cp;
+        synchronized(PROJECT_LOCK) {
+            cp = currentP;
+        }
+        if (cp != null ) { //NOI18N
          
-            NbMavenProject mpp = currentP.getLookup().lookup(NbMavenProject.class);
+            NbMavenProject mpp = cp.getLookup().lookup(NbMavenProject.class);
             if (mpp != null) {
-                final Children ch = Children.create(new PluginChildren(currentP), true);
+                final Children ch = Children.create(new PluginChildren(cp), true);
                 SwingUtilities.invokeLater(new Runnable() {
                     @Override
                     public void run() {
@@ -243,6 +253,7 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
             public void run() {
                 treeView.setRootVisible(false);
                 explorerManager.setRootContext(createEmptyNode());
+                treeView.expandAll(); // Force update view - see  bug 242567.
             }
         });
     }
@@ -251,16 +262,19 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
      * 
      */
     void release() {
-        if (current != null) {
-            current.removePropertyChangeListener(pchadapter);
+        synchronized(PROJECT_LOCK) {
+            if (current != null) {
+                current.removePropertyChangeListener(pchadapter);
+            }
+            current = null;
+            currentP = null;
         }
-        current = null;
-        currentP = null;
         SwingUtilities.invokeLater(new Runnable() {
             @Override
             public void run() {
                treeView.setRootVisible(false);
                explorerManager.setRootContext(createEmptyNode());
+               treeView.expandAll(); // Force update view - see  bug 242567.
             } 
         });
     }
@@ -376,7 +390,13 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
         protected @Override
         boolean createKeys(List<Mojo> toPopulate) {
             Set<Mojo> goals = new TreeSet<Mojo>();
-            MavenProject mp = prj.getLookup().lookup(NbMavenProject.class).getMavenProject();
+            NbMavenProject nbmp = prj.getLookup().lookup(NbMavenProject.class);
+            assert nbmp != null : "Project " + prj + " has no NbMavenProject in lookup.";
+            if(nbmp == null) {
+                LOG.log(Level.WARNING, "Project {0} has no NbMavenProject in lookup.", prj);
+                return true;
+            }
+            MavenProject mp = nbmp.getMavenProject();
             for (Artifact p : mp.getPluginArtifacts()) {
                 try {
 
@@ -572,7 +592,7 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
         
     }
     
-     @Messages("ACT_Execute_mod=Execute Goal With Modifiers...")
+    @Messages({"ACT_Execute_mod=Execute Goal With Modifiers...", "ACT_Execute_help=Show Documentation..."})
      private static class MojoNode extends AbstractNode {
         
  
@@ -594,12 +614,34 @@ public class GoalsPanel extends javax.swing.JPanel implements ExplorerManager.Pr
                     mapp.addProperty(p.property, "");
                 }
             }
+            
+            //
+            // Execute with modifiers 
+            //
             mapp.setGoals(Collections.singletonList(mojo.a.getGroupId() + ":" + mojo.a.getArtifactId() + ":" + mojo.a.getVersion() + ":" + mojo.goal));
-            Action a = ActionProviderImpl.createCustomMavenAction(mojo.prefix + ":" + mojo.goal, mapp, true, Lookup.EMPTY, project);
-            a.putValue(Action.NAME, ACT_Execute_mod());
+            Action runGoalWithModsAction = ActionProviderImpl.createCustomMavenAction(mojo.prefix + ":" + mojo.goal, mapp, true, Lookup.EMPTY, project);
+            runGoalWithModsAction.putValue(Action.NAME, ACT_Execute_mod());
+            
+            //
+            // Show Documentation
+            //
+            // f.e.: help:describe -Dcmd=org.codehaus.mojo:gwt-maven-plugin:1.2:debug -Ddetail
+            NetbeansActionMapping mappForHelpDesc = new NetbeansActionMapping();
+
+            mappForHelpDesc.setGoals(Collections.singletonList("help:describe"));
+            
+            HashMap<String, String> m = new HashMap<>();
+            m.put("cmd", String.format("%s:%s:%s:%s", mojo.a.getGroupId(), mojo.a.getArtifactId(), mojo.a.getVersion(), mojo.goal));
+            m.put("detail", "true");
+            mappForHelpDesc.setProperties(m);
+            Action runHelpDescAction = ActionProviderImpl.createCustomMavenAction(String.format("help:describe for %s:%s", mojo.prefix, mojo.goal), mappForHelpDesc, false, Lookup.EMPTY, project);
+            runHelpDescAction.putValue(Action.NAME, ACT_Execute_help());
+            
             return new Action[] {
                 new RunGoalAction(mojo, project),
-                a
+                runGoalWithModsAction,
+                null,
+                runHelpDescAction
             };
         }
 
