@@ -80,10 +80,15 @@ public final class MavenSettings  {
     private static final String PROP_MAVEN_RUNTIMES = "mavenRuntimes"; //NOI18N
     public static final String PROP_PROJECTNODE_NAME_PATTERN = "project.displayName"; //NOI18N
     private static final String PROP_ALWAYS_OUTPUT = "alwaysShowOutput";
+    private static final String PROP_SHOW_LOGGING_LEVEL = "showLoggingLevel"; //NOI18N
     private static final String PROP_REUSE_OUTPUT = "reuseOutputTabs";
     private static final String PROP_COLLAPSE_FOLDS = "collapseSuccessFolds";
     private static final String PROP_OUTPUT_TAB_CONFIG = "showConfigInOutputTab";
     private static final String PROP_OUTPUT_TAB_NAME = "showOutputTabAs";
+    private static final String PROP_EXPERIMENTAL_USE_BEST_MAVEN = "useBestMaven";
+    private static final String PROP_EXPERIMENTAL_USE_ALTERNATE_LOCATION = "useBestMavenAltLocation";
+    private static final String PROP_EXPERIMENTAL_ALTERNATE_LOCATION = "bestMavenAltLocation";
+    private static final String PROP_VM_OPTIONS_WRAP = "vmOptionsWrap";
 
     //these are from former versions (6.5) and are here only for conversion
     private static final String PROP_DEBUG = "showDebug"; // NOI18N
@@ -240,6 +245,13 @@ public final class MavenSettings  {
         }        
     }
     
+    public boolean isVMOptionsWrap() {
+        return getPreferences().getBoolean(PROP_VM_OPTIONS_WRAP, true);
+    }
+    
+    public void setVMOptionsWrap(boolean b) {
+        getPreferences().putBoolean(PROP_VM_OPTIONS_WRAP, b);
+    }
 
     public String getLastArchetypeGroupId() {
         return getPreferences().get(PROP_LAST_ARCHETYPE_GROUPID, Boolean.getBoolean("netbeans.full.hack") ? "test" : "com.mycompany"); //NOI18N
@@ -260,11 +272,19 @@ public final class MavenSettings  {
     public boolean isAlwaysShowOutput() {
         return getPreferences().getBoolean(PROP_ALWAYS_OUTPUT, true);
     }
-
+    
     public void setAlwaysShowOutput(boolean show) {
         getPreferences().putBoolean(PROP_ALWAYS_OUTPUT, show);
     }
     
+    public boolean isShowLoggingLevel() {
+        return getPreferences().getBoolean(PROP_SHOW_LOGGING_LEVEL, false);
+    }
+    
+    public void setShowLoggingLevel(boolean show) {
+        getPreferences().putBoolean(PROP_SHOW_LOGGING_LEVEL, show);
+    }
+    
     public boolean isReuseOutputTabs() {
         return getPreferences().getBoolean(PROP_REUSE_OUTPUT, true);
     }
@@ -293,6 +313,35 @@ public final class MavenSettings  {
         return getPreferences().get(PROP_PROJECTNODE_NAME_PATTERN, null); //NOI18N
     }
 
+    public boolean isUseBestMaven() {
+        return getPreferences().getBoolean(PROP_EXPERIMENTAL_USE_BEST_MAVEN, false);
+    }
+    
+    public void setUseBestMaven(boolean bestMaven) {
+        getPreferences().putBoolean(PROP_EXPERIMENTAL_USE_BEST_MAVEN, bestMaven);
+    }
+    
+    public boolean isUseBestMavenAltLocation() {
+        return getPreferences().getBoolean(PROP_EXPERIMENTAL_USE_ALTERNATE_LOCATION, false);
+    }
+    
+    public void setUseBestMavenAltLocation(boolean bestMavenAltLocation) {
+        getPreferences().putBoolean(PROP_EXPERIMENTAL_USE_ALTERNATE_LOCATION, bestMavenAltLocation);
+    }
+    
+    public void setBestMavenAltLocation(String location) {
+        if (null == location) {
+            getPreferences().remove(PROP_EXPERIMENTAL_ALTERNATE_LOCATION);
+        } else {
+            putProperty(PROP_EXPERIMENTAL_ALTERNATE_LOCATION, location);
+        }
+    }
+
+    public String getBestMavenAltLocation() {
+        return getPreferences().get(PROP_EXPERIMENTAL_ALTERNATE_LOCATION, null); //NOI18N
+    }
+    
+
     public boolean isCollapseSuccessFolds() {
         return getPreferences().getBoolean(PROP_COLLAPSE_FOLDS, false);
     }
@@ -325,7 +374,7 @@ public final class MavenSettings  {
             getPreferences().remove(PROP_OUTPUT_TAB_NAME);
         }
     }
-    
+
     public static enum OutputTabName {
         PROJECT_NAME,
         PROJECT_ID
@@ -470,8 +519,12 @@ public final class MavenSettings  {
                     continue;
                 }
 
-                mavenEnvDirs.add(path.substring(0,
+                if(path.equals("/bin") || path.equals("bin")) {
+                    mavenEnvDirs.add(path);
+                } else {
+                    mavenEnvDirs.add(path.substring(0,
                         path.length() - "bin".length() - File.pathSeparator.length()));
+                }
             }
         }
 
