@@ -51,7 +51,8 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
-import java.util.MissingResourceException;
+import java.util.concurrent.Callable;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
@@ -81,6 +82,7 @@ import static org.netbeans.modules.maven.problems.Bundle.*;
 import org.netbeans.spi.project.ProjectServiceProvider;
 import org.netbeans.spi.project.ui.ProjectProblemsProvider;
 import org.openide.filesystems.FileUtil;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.lookup.Lookups;
@@ -126,7 +128,7 @@ public class MavenModelProblemsProvider implements ProjectProblemsProvider {
 
     @Override
     public Collection<? extends ProjectProblem> getProblems() {
-        List<ProjectProblem> toRet = new ArrayList<ProjectProblem>();
+        final MavenProject prj = project.getLookup().lookup(NbMavenProject.class).getMavenProject();
         synchronized (this) {
             //lazy adding listener only when someone asks for the problems the first time
             if (projectListenerSet.compareAndSet(false, true)) {
@@ -136,7 +138,7 @@ public class MavenModelProblemsProvider implements ProjectProblemsProvider {
                 project.getLookup().lookup(NbMavenProject.class).addPropertyChangeListener(projectListener);
             
             }
-            MavenProject prj = project.getLookup().lookup(NbMavenProject.class).getMavenProject();
+            
             //for non changed project models, no need to recalculate, always return the cached value
             Object wasprocessed = prj.getContextValue(MavenModelProblemsProvider.class.getName());
             if (wasprocessed != null) {
@@ -145,18 +147,44 @@ public class MavenModelProblemsProvider implements ProjectProblemsProvider {
                     return cached;
                 }
             } 
-            MavenExecutionResult res = MavenProjectCache.getExecutionResult(prj);
-            if (res != null && res.hasExceptions()) {
-                toRet.addAll(reportExceptions(res));
+            Callable<Collection<? extends ProjectProblem>> c = new Callable<Collection<? extends ProjectProblem>>() {
+                @Override
+                public Collection<? extends ProjectProblem> call() throws Exception {
+                    Object wasprocessed = prj.getContextValue(MavenModelProblemsProvider.class.getName());
+                    if (wasprocessed != null) {
+                        Collection<ProjectProblem> cached = problemsCache.get();
+                        if (cached != null) {                            
+                            return Collections.EMPTY_LIST;
+                        }
+                    } 
+                    List<ProjectProblem> toRet = new ArrayList<>();
+                    MavenExecutionResult res = MavenProjectCache.getExecutionResult(prj);
+                    if (res != null && res.hasExceptions()) {
+                        toRet.addAll(reportExceptions(res));
+                    }
+                    //#217286 doArtifactChecks can call FileOwnerQuery and attempt to aquire the project mutex.
+                    toRet.addAll(doArtifactChecks(prj));
+                    //mark the project model as checked once and cached
+                    prj.setContextValue(MavenModelProblemsProvider.class.getName(), new Object());
+                    synchronized(MavenModelProblemsProvider.this) {
+                        problemsCache.set(toRet);
+                    }
+                    firePropertyChange();
+                    return toRet;
+                }                
+            };
+            if(Boolean.getBoolean("test.reload.sync")) {
+                try {
+                    return c.call();
+                } catch (Exception ex) {
+                    Exceptions.printStackTrace(ex);
+                }
+            } else {
+                RP.submit(c);
             }
-            //TODO if this is called from AWT, we might have a problem
-            //#217286 doArtifactChecks can call FileOwnerQuery and attempt to aquire the project mutex.
-            toRet.addAll(doArtifactChecks(prj));
-            //mark the project model as checked once and cached
-            prj.setContextValue(MavenModelProblemsProvider.class.getName(), new Object());
-            problemsCache.set(toRet);
         }
-        return toRet;
+        
+        return Collections.emptyList();
     }
 
     private void firePropertyChange() {
@@ -264,7 +292,8 @@ public class MavenModelProblemsProvider implements ProjectProblemsProvider {
         "TXT_Artifact_Resolution_problem=Artifact Resolution problem",
         "TXT_Artifact_Not_Found=Artifact Not Found",
         "TXT_Cannot_Load_Project=Unable to properly load project",
-        "TXT_Cannot_read_model=Error reading project model"
+        "TXT_Cannot_read_model=Error reading project model",
+        "TXT_NoMsg=Exception thrown while loading maven project at {0}. See messages.log for more information."
     })
     private Collection<ProjectProblem> reportExceptions(MavenExecutionResult res) {
         List<ProjectProblem> toRet = new ArrayList<ProjectProblem>();
@@ -296,8 +325,14 @@ public class MavenModelProblemsProvider implements ProjectProblemsProvider {
                     }
                 }
             } else {
-                LOG.log(Level.INFO, "Exception thrown while loading maven project at " + project.getProjectDirectory(), e); //NOI18N
-                toRet.add(ProjectProblem.createError(TXT_Cannot_read_model(), msg));
+                if(msg != null) {
+                    LOG.log(Level.INFO, "Exception thrown while loading maven project at " + project.getProjectDirectory(), e); //NOI18N
+                    toRet.add(ProjectProblem.createError(TXT_Cannot_read_model(), msg));
+                } else {
+                    String path = project.getProjectDirectory().getPath();
+                    toRet.add(ProjectProblem.createError(TXT_Cannot_read_model(), TXT_NoMsg(path)));
+                    LOG.log(Level.WARNING, "Exception thrown while loading maven project at " + path, e); //NOI18N
+                }
             }
         }
         return toRet;
