@@ -108,6 +108,7 @@ public class HgModuleConfig {
     private static final HgModuleConfig INSTANCE = new HgModuleConfig();
     private static final String KEY_SEARCH_ON_BRANCH = "searchOnBranch.enabled."; //NOI18N
     private static final String KEY_REMOVE_NEW_FILES_ON_REVERT = "removeNewFilesOnRevert"; //NOI18N
+    private static final String KEY_PULL_WITH_UPDATE = "pullWithUpdate"; //NOI18N
     
     private static String userName;
 
@@ -665,6 +666,14 @@ public class HgModuleConfig {
     public void setRemoveNewFilesOnRevertModifications (boolean flag) {
         getPreferences().putBoolean(KEY_REMOVE_NEW_FILES_ON_REVERT, flag);
     }
+
+    public boolean isPullWithUpdate () {
+        return getPreferences().getBoolean(KEY_PULL_WITH_UPDATE, true);
+    }
+
+    public void setPullWithUpdate (boolean pullWithUpdate) {
+        getPreferences().putBoolean(KEY_PULL_WITH_UPDATE, pullWithUpdate);
+    }
     
     synchronized Set<String> getCommitExclusions() {
         if (exclusions == null) {
