@@ -44,6 +44,7 @@
 package org.netbeans.modules.mercurial;
 
 import java.awt.Color;
+import java.awt.EventQueue;
 import org.netbeans.modules.mercurial.ui.menu.RecoverMenu;
 import org.netbeans.modules.versioning.spi.VCSAnnotator;
 import org.netbeans.modules.versioning.spi.VCSContext;
@@ -243,7 +244,9 @@ public class MercurialAnnotator extends VCSAnnotator implements PropertyChangeLi
         } else if (0 != (status & FileInformation.STATUS_VERSIONED_ADDEDLOCALLY)) {
             FileStatus fileStatus = mostImportantInfo.getStatus(mostImportantFile);
             if (fileStatus != null && fileStatus.isCopied()) {
-                statusText = getAnnotationProvider().COPIED_LOCALLY_FILE_TOOLTIP.getFormat().format(new Object[]{mostImportantInfo.getStatusText()});
+                statusText = (!EventQueue.isDispatchThread() && !fileStatus.getOriginalFile().exists()
+                        ? getAnnotationProvider().MOVED_LOCALY_FILE_TOOLTIP
+                        : getAnnotationProvider().COPIED_LOCALLY_FILE_TOOLTIP).getFormat().format(new Object[]{mostImportantInfo.getStatusText()});
             } else {
                 statusText = getAnnotationProvider().ADDED_LOCALLY_FILE_TOOLTIP.getFormat().format(new Object[]{mostImportantInfo.getStatusText()});
             }
@@ -469,7 +472,9 @@ public class MercurialAnnotator extends VCSAnnotator implements PropertyChangeLi
         } else if (0 != (status & FileInformation.STATUS_VERSIONED_ADDEDLOCALLY)) {
             FileStatus fileStatus = mostImportantInfo.getStatus(mostImportantFile);
             if (fileStatus != null && fileStatus.isCopied()) {
-                return getAnnotationProvider().COPIED_LOCALLY_FILE.getFormat().format(new Object [] { name, textAnnotation });
+                return (!EventQueue.isDispatchThread() && !fileStatus.getOriginalFile().exists()
+                        ? getAnnotationProvider().MOVED_LOCALY_FILE
+                        : getAnnotationProvider().COPIED_LOCALLY_FILE).getFormat().format(new Object [] { name, textAnnotation });
             } else {
                 return getAnnotationProvider().ADDED_LOCALLY_FILE.getFormat().format(new Object [] { name, textAnnotation });
             }
@@ -501,7 +506,9 @@ public class MercurialAnnotator extends VCSAnnotator implements PropertyChangeLi
         } else if (0 != (status & FileInformation.STATUS_VERSIONED_ADDEDLOCALLY)) {
             FileStatus fileStatus = mostImportantInfo.getStatus(null);
             if (fileStatus != null && fileStatus.isCopied()) {
-                return getAnnotationProvider().COPIED_LOCALLY_FILE.getActualColor();
+                return (!EventQueue.isDispatchThread() && !fileStatus.getOriginalFile().exists()
+                        ? getAnnotationProvider().MOVED_LOCALY_FILE
+                        : getAnnotationProvider().COPIED_LOCALLY_FILE).getActualColor();
             } else {
                 return getAnnotationProvider().ADDED_LOCALLY_FILE.getActualColor();
             }
