@@ -46,6 +46,7 @@ package org.netbeans.modules.mercurial;
 import java.util.Map;
 import org.netbeans.modules.versioning.spi.VCSInterceptor;
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import org.netbeans.modules.mercurial.util.HgCommand;
 import org.openide.util.RequestProcessor;
@@ -63,6 +64,7 @@ import java.util.Set;
 import java.util.concurrent.Callable;
 import org.netbeans.modules.mercurial.util.HgUtils;
 import java.util.concurrent.ConcurrentLinkedQueue;
+import org.netbeans.modules.mercurial.commands.StatusCommand;
 import org.netbeans.modules.mercurial.util.HgSearchHistorySupport;
 import org.netbeans.modules.versioning.spi.VersioningSupport;
 import org.netbeans.modules.versioning.util.DelayScanRegistry;
@@ -97,6 +99,12 @@ public class MercurialInterceptor extends VCSInterceptor {
     private final CommandUsageLogger commandLogger;
     private static final boolean AUTOMATIC_REFRESH_ENABLED = !"true".equals(System.getProperty("versioning.mercurial.autoRefreshDisabled", "false")); //NOI18N
     private final Mercurial hg;
+    private static final int STATUS_VCS_MODIFIED_ATTRIBUTE =
+            FileInformation.STATUS_NOTVERSIONED_NEWLOCALLY | 
+            FileInformation.STATUS_VERSIONED_ADDEDLOCALLY | 
+            FileInformation.STATUS_VERSIONED_CONFLICT | 
+            FileInformation.STATUS_VERSIONED_MERGE |
+            FileInformation.STATUS_VERSIONED_MODIFIEDLOCALLY;
 
     MercurialInterceptor(Mercurial hg, FileStatusCache cache) {
         this.cache = cache;
@@ -286,6 +294,10 @@ public class MercurialInterceptor extends VCSInterceptor {
     }
 
     @Override
+    @NbBundle.Messages({
+        "# {0} - file path",
+        "MSG_CopyFailed_NotExists=Copy failed because {0} does not exist"
+    })
     public void doCopy (final File from, final File to) throws IOException {
         Mercurial.LOG.log(Level.FINE, "doCopy {0}->{1}", new Object[]{from, to});
         if (from == null || to == null || to.exists()) return;
@@ -296,7 +308,13 @@ public class MercurialInterceptor extends VCSInterceptor {
         if (from.isDirectory()) {
             FileUtils.copyDirFiles(from, to);
         } else {
-            FileUtils.copyFile(from, to);
+            try {
+                FileUtils.copyFile(from, to);
+            } catch (FileNotFoundException ex) {
+                throw Exceptions.attachLocalizedMessage(ex, Bundle.MSG_CopyFailed_NotExists(from.getAbsolutePath()));
+            } catch (IOException ex) {
+                throw Exceptions.attachLocalizedMessage(ex, ex.getLocalizedMessage()); //NOI18N
+            }
         }
 
         if (root == null || HgUtils.isIgnored(to, false)) {
@@ -335,7 +353,7 @@ public class MercurialInterceptor extends VCSInterceptor {
             File root = hg.getRepositoryRoot(file);
             FileInformation info = null;
             try {
-                Map<File, FileInformation> statusMap = HgCommand.getStatus(root, Arrays.asList(file), null, null);
+                Map<File, FileInformation> statusMap = StatusCommand.create(root, Arrays.asList(file), false).setDetectConflicts(false).call();
                 info = statusMap != null ? statusMap.get(file) : null;
             } catch (HgException ex) {
                 Mercurial.LOG.log(Level.FINE, "beforeCreate(): getStatus failed for file: {0} {1}", new Object[]{file.getAbsolutePath(), ex.toString()}); // NOI18N
@@ -405,6 +423,15 @@ public class MercurialInterceptor extends VCSInterceptor {
             };
         } else if (SearchHistorySupport.PROVIDED_EXTENSIONS_SEARCH_HISTORY.equals(attrName)){
             return new HgSearchHistorySupport(file);
+        } else if ("ProvidedExtensions.VCSIsModified".equals(attrName)) {
+            File repoRoot = Mercurial.getInstance().getRepositoryRoot(file);
+            Boolean modified = null;
+            if (repoRoot != null) {
+                Set<File> coll = Collections.singleton(file);
+                cache.refreshAllRoots(Collections.<File, Set<File>>singletonMap(repoRoot, coll));
+                modified = cache.containsFileOfStatus(coll, STATUS_VCS_MODIFIED_ATTRIBUTE, true);
+            }
+            return modified;
         } else {
             return super.getAttribute(file, attrName);
         }
