@@ -109,20 +109,27 @@ import org.openide.util.ImageUtilities;
 import static java.awt.Component.BOTTOM_ALIGNMENT;
 import static java.awt.Component.CENTER_ALIGNMENT;
 import static java.awt.Component.LEFT_ALIGNMENT;
+import java.awt.event.KeyEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import javax.swing.Action;
 import static javax.swing.BorderFactory.createEmptyBorder;
 import static javax.swing.BoxLayout.X_AXIS;
 import static javax.swing.BoxLayout.Y_AXIS;
 import javax.swing.JComboBox;
+import javax.swing.KeyStroke;
 import static javax.swing.SwingConstants.SOUTH;
 import static javax.swing.SwingConstants.WEST;
 import static javax.swing.LayoutStyle.ComponentPlacement.RELATED;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.text.JTextComponent;
+import javax.swing.text.Keymap;
 import org.netbeans.modules.versioning.util.common.CommitMessageMouseAdapter;
 import org.openide.awt.TabbedPaneFactory;
+import org.openide.util.Lookup;
+import org.openide.util.Utilities;
+import org.openide.util.actions.CallbackSystemAction;
 
 /**
  *
@@ -612,6 +619,36 @@ public class CommitPanel extends AutoResizingPanel implements PreferenceChangeLi
             }
         }
     }
+    
+    @Override
+    protected boolean processKeyBinding(KeyStroke ks, KeyEvent e, int condition, boolean pressed) {
+        boolean ret = super.processKeyBinding(ks, e, condition, pressed);
+
+        // XXX #250546 Reason of overriding: to process global shortcut.
+        if ((JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT == condition) && (ret == false) && !e.isConsumed()) {
+
+            Keymap km = Lookup.getDefault().lookup(Keymap.class);
+            Action action = (km != null) ? km.getAction(ks) : null;
+
+            if (action == null) {
+                return false;
+            }
+
+            if (action instanceof CallbackSystemAction) {
+                CallbackSystemAction csAction = (CallbackSystemAction) action;
+                if (tabbedPane != null) {
+                    Action a = tabbedPane.getActionMap().get(csAction.getActionMapKey());
+                    if (a != null) {
+                        a.actionPerformed(new ActionEvent(this, ActionEvent.ACTION_PERFORMED, Utilities.keyToString(ks)));
+                        return true;
+                    }
+                }
+            }
+            return false;
+        } else {
+            return ret;
+        }
+    }
 
     void openDiff (HgFileNode[] nodes) {
         for (HgFileNode node : nodes) {
