@@ -64,6 +64,7 @@ import java.util.logging.Logger;
 import org.netbeans.modules.mercurial.FileInformation;
 import org.netbeans.modules.mercurial.FileStatusCache;
 import org.netbeans.modules.mercurial.HgException;
+import org.netbeans.modules.mercurial.HgModuleConfig;
 import org.netbeans.modules.mercurial.HgProgressSupport;
 import org.netbeans.modules.mercurial.Mercurial;
 import org.netbeans.modules.mercurial.OutputLogger;
@@ -538,6 +539,7 @@ public class PullAction extends ContextAction {
             OutputLogger logger = supp.getLogger();
             boolean bMergeNeeded = false;
             boolean updateNeeded = false;
+            boolean update = true;
             for (String s : list) {
                 logger.output(HgUtils.replaceHttpPassword(s));
                 if (HgCommand.isMergeNeededMsg(s)) {
@@ -563,13 +565,18 @@ public class PullAction extends ContextAction {
                     } catch (HgException ex) {
                         Mercurial.LOG.log(Level.FINE, null, ex);
                     }
+                    update = HgModuleConfig.getDefault().isPullWithUpdate();
                     if (currentBranch == null) {
                         supp.setDisplayName(Bundle.MSG_PullAction_progress_updating());
                     } else {
-                        supp.setDisplayName(Bundle.MSG_PullAction_progress_updatingBranch(currentBranch));
+                        if (update) {
+                            supp.setDisplayName(Bundle.MSG_PullAction_progress_updatingBranch(currentBranch));
+                        }
+                    }
+                    if (update) {
+                        list = HgCommand.doUpdateAll(root, false, currentBranch);
+                        logger.output(list);
                     }
-                    list = HgCommand.doUpdateAll(root, false, currentBranch);
-                    logger.output(list);
                 }
             }
             boolean finished = !bMergeNeeded;
@@ -611,8 +618,10 @@ public class PullAction extends ContextAction {
                     MergeAction.displayMergeWarning(branchHeads, logger, warnMoreHeads && !supp.isCanceled());
                 }
                 Mercurial.getInstance().historyChanged(root);
-                HgUtils.notifyUpdatedFiles(root, list);
-                HgUtils.forceStatusRefresh(root);
+                if (update) {
+                    HgUtils.notifyUpdatedFiles(root, list);
+                    HgUtils.forceStatusRefresh(root);
+                }
             }
         }
 
