@@ -761,6 +761,7 @@ public class InterceptorTest extends AbstractHgTestCase {
         File file = createFile(folder, "file1");
         commit(folder);
         
+        createFile(folder, "file2");
         deleteFO(file);
         assertFalse(file.exists());
         assertTrue(folder.exists());
@@ -772,6 +773,7 @@ public class InterceptorTest extends AbstractHgTestCase {
         File file = createFile(folder, "file1");
         commit(folder);
         
+        createFile(folder, "file2");
         deleteDO(file);
         assertFalse(file.exists());
         assertTrue(folder.exists());
@@ -805,6 +807,45 @@ public class InterceptorTest extends AbstractHgTestCase {
         assertEquals(FileInformation.STATUS_VERSIONED_REMOVEDLOCALLY, getCache().refresh(file1).getStatus());
         assertEquals(FileInformation.STATUS_VERSIONED_REMOVEDLOCALLY, getCache().refresh(file2).getStatus());
     }
+    
+    public void testIsModifiedAttributeFile () throws Exception {
+        // file is outside of versioned space, attribute should be unknown
+        File file = File.createTempFile("testIsModifiedAttributeFile", "txt");
+        file.deleteOnExit();
+        FileObject fo = FileUtil.toFileObject(FileUtil.normalizeFile(file));
+        String attributeModified = "ProvidedExtensions.VCSIsModified";
+        
+        Object attrValue = fo.getAttribute(attributeModified);
+        assertNull(attrValue);
+        
+        // file inside a git repo
+        file = new File(getWorkTreeDir(), "file");
+        write(file, "init");
+        fo = FileUtil.toFileObject(FileUtil.normalizeFile(file));
+        // new file, returns TRUE
+        attrValue = fo.getAttribute(attributeModified);
+        assertEquals(Boolean.TRUE, attrValue);
+        
+        HgCommand.doAdd(getWorkTreeDir(), file, NULL_LOGGER);
+        // added file, returns TRUE
+        attrValue = fo.getAttribute(attributeModified);
+        assertEquals(Boolean.TRUE, attrValue);
+        commit(file);
+        
+        // unmodified file, returns FALSE
+        attrValue = fo.getAttribute(attributeModified);
+        assertEquals(Boolean.FALSE, attrValue);
+        
+        write(file, "modification");
+        // modified file, returns TRUE
+        attrValue = fo.getAttribute(attributeModified);
+        assertEquals(Boolean.TRUE, attrValue);
+        
+        write(file, "init");
+        // back to up to date
+        attrValue = fo.getAttribute(attributeModified);
+        assertEquals(Boolean.FALSE, attrValue);
+    }
 
     private void moveDO (File from, File to) throws DataObjectNotFoundException, IOException {
         DataObject daoFrom = DataObject.find(FileUtil.toFileObject(from));
