@@ -444,7 +444,7 @@ public class ClientOptionsPanelGUI extends javax.swing.JPanel implements Documen
                 return groups[i];
             }
         }
-        return groups.length >= 0 ? groups[0] : null;
+        return groups.length > 0 ? groups[0] : null;
     }
     
     private ModelItem getPreselectedPackage( final ModelItem groupItem, final FileObject preselectedFolder ) {
