@@ -72,6 +72,7 @@ import org.eclipse.mylyn.internal.tasks.core.RepositoryQuery;
 import org.eclipse.mylyn.internal.tasks.core.TaskActivityManager;
 import org.eclipse.mylyn.internal.tasks.core.TaskContainerDelta;
 import org.eclipse.mylyn.internal.tasks.core.TaskList;
+import org.eclipse.mylyn.internal.tasks.core.TaskRepositoryDelta;
 import org.eclipse.mylyn.internal.tasks.core.TaskRepositoryManager;
 import org.eclipse.mylyn.internal.tasks.core.UnmatchedTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.data.ITaskDataManagerListener;
@@ -476,12 +477,17 @@ public class MylynSupport {
             ensureTaskListLoaded();
             assert taskRepositoryManager.getRepositoryConnector(repository.getConnectorKind()) != null
                 : "Did you forget to implement RepositoryConnectorProvider?";
-            for (ITask task : taskList.getAllTasks()) {
-                if (url.equals(task.getAttribute(ITasksCoreConstants.ATTRIBUTE_OUTGOING_NEW_REPOSITORY_URL))) {
-                    taskDataManager.refactorRepositoryUrl(task, task.getRepositoryUrl(), url);
-                } else if (oldUrl.equals(task.getRepositoryUrl())) {
-                    taskDataManager.refactorRepositoryUrl(task, url, url);
+            try {
+                for (ITask task : taskList.getAllTasks()) {
+                    if (url.equals(task.getAttribute(ITasksCoreConstants.ATTRIBUTE_OUTGOING_NEW_REPOSITORY_URL))) {
+                        taskDataManager.refactorRepositoryUrl(task, task.getRepositoryUrl(), url);
+                    } else if (oldUrl.equals(task.getRepositoryUrl())) {
+                        taskDataManager.refactorRepositoryUrl(task, url, url);
+                    }
                 }
+            } catch (Throwable t) {
+                // log, but set the rapository & co
+                LOG.log(Level.WARNING, null, t);
             }
             taskList.refactorRepositoryUrl(oldUrl, url);
             repository.setRepositoryUrl(url);
@@ -657,17 +663,18 @@ public class MylynSupport {
                         scheduleSave();
                     }
                     if (delta.getElement() instanceof ITask) {
-                        // task added to the tasklist
+                        // task added to the tasklist   
                         // new tasks (incoming_new) created long ago in the past
                         // should be marked as uptodate so when a repository is registener in the IDE
                         // it is not all green. Only fresh new tasks are relevant to the user
                         ITask task = (ITask) delta.getElement();
-                        if (task.getSynchronizationState() == ITask.SynchronizationState.INCOMING_NEW
-                                && task.getCreationDate() != null && task.getModificationDate() != null) {
+                        if ( (task.getSynchronizationState() == ITask.SynchronizationState.INCOMING_NEW 
+                              || task.getSynchronizationState() == ITask.SynchronizationState.INCOMING )
+                             && task.getCreationDate() != null && task.getModificationDate() != null) {
                             TaskRepository repository = taskRepositoryManager.getRepository(task.getConnectorKind(), task.getRepositoryUrl());
                             if (repository != null) {
                                 long time = getRepositoryCreationTime(repository.getRepositoryUrl());
-                                if (task.getCreationDate().getTime() < time) {
+                                if (task.getModificationDate().getTime() < time) {
                                     markTaskSeen(task, true);
                                     task.setAttribute(ATTR_TASK_INCOMING_NEW, Boolean.TRUE.toString());
                                 }
@@ -870,4 +877,8 @@ public class MylynSupport {
     void taskModified (ITask task) {
         taskList.notifyElementChanged(task);
     }
+
+    void notifyCredentialsChanged(TaskRepository repository) {
+        taskRepositoryManager.notifyRepositorySettingsChanged(repository, new TaskRepositoryDelta(TaskRepositoryDelta.Type.CREDENTIALS));
+    }
 }
