@@ -862,8 +862,10 @@ public class NbModuleSuite {
             modules.add("org.openide.filesystems");
             modules.add("org.openide.modules");
             modules.add("org.openide.util");
+            modules.add("org.openide.util.ui");
             modules.remove("org.netbeans.insane");
             modules.add("org.netbeans.core.startup");
+            modules.add("org.netbeans.core.startup.base");
             modules.add("org.netbeans.bootstrap");
             turnModules(ud, !config.honorAutoEager, modules, config.moduleRegExp, platform);
             if (config.enableClasspathModules) {
@@ -1064,11 +1066,15 @@ public class NbModuleSuite {
         }
         private static final Set<String> pseudoModules = new HashSet<String>(Arrays.asList(
                 "org.openide.util",
+                "org.openide.util.ui",
                 "org.openide.util.lookup",
                 "org.openide.modules",
                 "org.netbeans.bootstrap",
                 "org.openide.filesystems",
-                "org.netbeans.core.startup"));
+                "org.openide.filesystems.compat8",
+                "org.netbeans.core.startup",
+                "org.netbeans.core.startup.base",
+                "org.netbeans.libs.asm"));
         static void turnClassPathModules(File ud, ClassLoader loader) throws IOException {
             Enumeration<URL> en = loader.getResources("META-INF/MANIFEST.MF");
             while (en.hasMoreElements()) {
