@@ -54,6 +54,10 @@ import java.util.logging.LogRecord;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.junit.*;
+import org.openide.util.Exceptions;
+import org.openide.util.RequestProcessor;
+import org.openide.util.Task;
+import org.openide.util.TaskListener;
 
 public class RequestProcessorTest extends NbTestCase {
     static {
