@@ -46,6 +46,9 @@ package org.openide.util;
 
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import java.beans.PropertyVetoException;
+import java.beans.VetoableChangeListener;
+import java.beans.VetoableChangeSupport;
 import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
@@ -63,6 +66,7 @@ import java.util.prefs.NodeChangeListener;
 import java.util.prefs.PreferenceChangeEvent;
 import java.util.prefs.PreferenceChangeListener;
 import java.util.prefs.Preferences;
+import javax.swing.colorchooser.DefaultColorSelectionModel;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import org.netbeans.junit.NbTestCase;
@@ -174,12 +178,25 @@ public class WeakListenersTest extends NbTestCase {
         doTestReleaseOfListener (true);
     }
     
+    public void testReleaseOfPropNameListenerWithNullSource () throws Exception {
+        doTestReleaseOfListener (false, javax.swing.AbstractButton.TEXT_CHANGED_PROPERTY);
+    }
+    
+    public void testReleaseOfPropNameListenerWithSource () throws Exception {
+        doTestReleaseOfListener (true, javax.swing.AbstractButton.TEXT_CHANGED_PROPERTY);
+    }
+    
     private void doTestReleaseOfListener (final boolean source) throws Exception {   
+        doTestReleaseOfListener(source, null);
+    }
+    
+    private void doTestReleaseOfListener (final boolean source, final String propName) throws Exception {
         Listener l = new Listener ();
         
         class MyButton extends javax.swing.JButton {
             private Thread removedBy;
             private int cnt;
+            private int cntNamed;
             
             @Override
             public synchronized void removePropertyChangeListener (PropertyChangeListener l) {
@@ -203,6 +220,30 @@ public class WeakListenersTest extends NbTestCase {
                 cnt++;
                 notifyAll ();
             }
+
+            @Override
+            public synchronized void removePropertyChangeListener(String propertyName, PropertyChangeListener l) {
+                // notify prior
+                LOG.fine("removePropertyChangeListener("+propertyName+"): " + source + " cnt: " + cntNamed);
+                if (source && cntNamed == 0) {
+                    notifyAll ();
+                    try {
+                        // wait for 1
+                        LOG.fine("wait for 1");
+                        wait ();
+                        LOG.fine("wait for 1 over");
+                    } catch (InterruptedException ex) {
+                        fail ("Not happen");
+                    }
+                }
+                assertEquals(propName, propertyName);
+                LOG.fine("Super removePropertyChangeListener");
+                super.removePropertyChangeListener (propertyName, l);
+                LOG.fine("Super over removePropertyChangeListener");
+                removedBy = Thread.currentThread();
+                cntNamed++;
+                notifyAll ();
+            }
             
             public synchronized void waitListener () throws Exception {
                 int count = 0;
@@ -224,11 +265,24 @@ public class WeakListenersTest extends NbTestCase {
         
         MyButton button = new MyButton ();
         LOG.fine("Button is here");
-        java.beans.PropertyChangeListener weakL = WeakListeners.propertyChange (l, source ? button : null);
+        java.beans.PropertyChangeListener weakL;
+        if (propName == null) {
+            weakL = WeakListeners.propertyChange (l, source ? button : null);
+        } else {
+            weakL = WeakListeners.propertyChange (l, propName, source ? button : null);
+        }
         LOG.fine("WeakListeners created: " + weakL);
-        button.addPropertyChangeListener(weakL);
+        if (propName == null) {
+            button.addPropertyChangeListener(weakL);
+        } else {
+            button.addPropertyChangeListener(propName, weakL);
+        }
         LOG.fine("WeakListeners attached");
-        assertTrue ("Weak listener is there", Arrays.asList (button.getPropertyChangeListeners()).indexOf (weakL) >= 0);
+        if (propName == null) {
+            assertTrue ("Weak listener is there", Arrays.asList (button.getPropertyChangeListeners()).indexOf (weakL) >= 0);
+        } else {
+            assertTrue ("Weak listener is there", Arrays.asList (button.getPropertyChangeListeners(propName)).indexOf (weakL) >= 0);
+        }
         
         button.setText("Ahoj");
         LOG.fine("setText changed to ahoj");
@@ -272,9 +326,19 @@ public class WeakListenersTest extends NbTestCase {
             LOG.fine("Thread.sleep over");
         }
 
-        assertEquals ("Weak listener has been removed", -1, Arrays.asList (button.getPropertyChangeListeners()).indexOf (weakL));
+        if (propName == null) {
+            assertEquals ("Weak listener has been removed", -1, Arrays.asList (button.getPropertyChangeListeners()).indexOf (weakL));
+        } else {
+            assertEquals ("Weak listener has been removed", -1, Arrays.asList (button.getPropertyChangeListeners(propName)).indexOf (weakL));
+        }
         assertEquals ("Button released from a thread", "Active Reference Queue Daemon", button.removedBy.getName());
-        assertEquals ("Unregister called just once", 1, button.cnt);
+        if (propName == null) {
+            assertEquals ("Unregister called just once", 1, button.cnt);
+            assertEquals ("Unregister named not called", 0, button.cntNamed);
+        } else {
+            assertEquals ("Unregister called just once", 1, button.cntNamed);
+            assertEquals ("Unregister unnamed not called", 0, button.cnt);
+        }
         
         // and because it is not here, it can be GCed
         Reference<?> weakRef = new WeakReference<Object>(weakL);
@@ -283,6 +347,107 @@ public class WeakListenersTest extends NbTestCase {
         assertGC ("Weak listener can go away as well", weakRef);
     }
     
+    public void testNameListenersCombined() {
+        Logger WL_LOG = Logger.getLogger(WeakListenerImpl.class.getName());
+        class WLLogHandler extends Handler {
+            
+            private String warnings;
+
+            @Override
+            public void publish(LogRecord record) {
+                if (Level.WARNING.intValue() <= record.getLevel().intValue()) {
+                    if (warnings == null) {
+                        warnings = record.toString();
+                    } else {
+                        warnings += "\n" + record.toString();
+                    }
+                }
+            }
+
+            @Override
+            public void flush() {}
+
+            @Override
+            public void close() throws SecurityException {}
+            
+            String getWarnings() {
+                return warnings;
+            }
+            
+        }
+        WLLogHandler wlLogHandler = new WLLogHandler();
+        WL_LOG.addHandler(wlLogHandler);
+        VetoableChangeSupport vcs = new VetoableChangeSupport(this);
+        DefaultColorSelectionModel dcsm = new DefaultColorSelectionModel();
+        VListener v1 = new VListener ();
+        VListener v2 = new VListener ();
+        VListener v3 = new VListener ();
+        VListener v4 = new VListener ();
+        CListener c1 = new CListener();
+        CListener c2 = new CListener();
+        CListener c3 = new CListener();
+        CListener c4 = new CListener();
+        
+        vcs.addVetoableChangeListener (WeakListeners.vetoableChange(v1, vcs));
+        vcs.addVetoableChangeListener ("name", WeakListeners.vetoableChange (v2, "name", vcs));
+        vcs.addVetoableChangeListener ("name3", WeakListeners.vetoableChange (v3, "name3", vcs));
+        vcs.addVetoableChangeListener (WeakListeners.vetoableChange (v4, vcs));
+        dcsm.addChangeListener(WeakListeners.change(c1, dcsm));
+        dcsm.addChangeListener(WeakListeners.change(c2, dcsm));
+        dcsm.addChangeListener(WeakListeners.change(c3, dcsm));
+        dcsm.addChangeListener(WeakListeners.change(c4, dcsm));
+    
+        //System.err.println("V1:");
+        Reference<?> refV1 = new WeakReference<Object>(v1);
+        v1 = null;
+        assertGC ("Listener can be GC", refV1);
+        
+        //System.err.println("C1:");
+        Reference<?> refC1 = new WeakReference<Object>(c1);
+        c1 = null;
+        assertGC ("Listener can be GC", refC1);
+        
+        //System.err.println("V2:");
+        Reference<?> refV2 = new WeakReference<Object>(v2);
+        v2 = null;
+        assertGC ("Listener can be GC", refV2);
+        
+        //System.err.println("C2:");
+        Reference<?> refC2 = new WeakReference<Object>(c2);
+        c2 = null;
+        assertGC ("Listener can be GC", refC2);
+        
+        //System.err.println("V3:");
+        Reference<?> refV3 = new WeakReference<Object>(v3);
+        v3 = null;
+        assertGC ("Listener can be GC", refV3);
+        
+        //System.err.println("V4:");
+        Reference<?> refV4 = new WeakReference<Object>(v4);
+        v4 = null;
+        assertGC ("Listener can be GC", refV4);
+        
+        //System.err.println("C3:");
+        Reference<?> refC3 = new WeakReference<Object>(c3);
+        c3 = null;
+        assertGC ("Listener can be GC", refC3);
+        
+        //System.err.println("ALL:");
+        Reference<?> refVcs = new WeakReference<Object>(vcs);
+        vcs = null;
+        Reference<?> refDcsm = new WeakReference<Object>(dcsm);
+        dcsm = null;
+        
+        assertGC ("Source can be GC", refVcs);
+        assertGC ("Source can be GC", refDcsm);
+        
+        String warnings = wlLogHandler.getWarnings();
+        if (warnings != null) {
+            System.err.println(warnings);
+        }
+        assertNull(warnings, warnings);
+    }
+    
     
     public void testSourceCanBeGarbageCollected () {
         javax.swing.JButton b = new javax.swing.JButton ();
@@ -361,7 +526,7 @@ public class WeakListenersTest extends NbTestCase {
             l, 
             button,
             c,
-            Utilities.activeReferenceQueue()
+            BaseUtilities.activeReferenceQueue()
         };
         
         
@@ -511,6 +676,20 @@ public class WeakListenersTest extends NbTestCase {
         }
     } // end of Listener
     
+    private static final class VListener implements VetoableChangeListener {
+
+        @Override
+        public void vetoableChange(PropertyChangeEvent evt) throws PropertyVetoException {
+        }
+    }
+
+    private static final class CListener implements ChangeListener {
+
+        @Override
+        public void stateChanged(ChangeEvent e) {
+        }
+    }
+
     private static final class ImplEventContext extends javax.naming.InitialContext 
     implements javax.naming.event.EventContext {
         public javax.naming.event.NamingListener listener;
