@@ -43,8 +43,6 @@
 package org.netbeans.modules.parsing.api;
 
 import java.lang.ref.Reference;
-import java.lang.ref.ReferenceQueue;
-import java.lang.ref.SoftReference;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -52,10 +50,10 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.concurrent.Future;
 import org.netbeans.api.annotations.common.NonNull;
-
+import org.netbeans.api.editor.document.EditorMimeTypes;
 import org.netbeans.api.editor.mimelookup.MimeLookup;
 import org.netbeans.modules.parsing.impl.*;
-import org.netbeans.modules.parsing.lucene.support.LowMemoryWatcher;
+import org.netbeans.modules.parsing.spi.LowMemoryWatcher;
 import org.netbeans.modules.parsing.spi.ParseException;
 import org.netbeans.modules.parsing.spi.Parser;
 import org.netbeans.modules.parsing.spi.ParserFactory;
@@ -390,22 +388,73 @@ public final class ParserManager {
     }
 
     private static Parser findParser (final String mimeType) {
-        Parser p = null;
-        final Reference<Parser> ref = cachedParsers.get (mimeType);
-        if (ref != null) {
-            p = ref.get();
-        }
-        if (p == null) {
-            final Lookup lookup = MimeLookup.getLookup (mimeType);
-            final ParserFactory parserFactory = lookup.lookup (ParserFactory.class);
-            if (parserFactory == null) {
-                throw new IllegalArgumentException("No parser for mime type: " + mimeType);
-            }
-            p = parserFactory.createParser(Collections.<Snapshot>emptyList());
-            cachedParsers.put(mimeType, new SoftReference<Parser>(p));
-        }
-        return p;
+        return Utilities.getEnvFactory().findMimeParser(Lookup.getDefault(), mimeType);
     }
+    
+    /**
+     * Determines if the current execution is already called from the parsing
+     * system. If code is called by the parser, it should avoid blocking on a lock
+     * and must avoid blocking on other parsing results.
+     * 
+     * @return true, if the current thread executes code called from within the parser
+     * @since 9.2
+     */
+    public static boolean isParsing() {
+        return Utilities.holdsParserLock();
+    }
+
+    /**
+     * Determines if the MIME type can be parsed. Rejects unknown MIME types (must be amongst {@link #getAllMimeTypes}.
+     * Then accepts only text/* MIME type and specific hardcoded application/ MIME types.
+     * 
+     * @param mimeType the MIME type to check
+     * @return true, if the MIME type can be parsed.
+     * @since 9.2
+     */
+    public static boolean canBeParsed(String mimeType) {
+        if (mimeType == null ||
+            "content/unknown".equals(mimeType) ||    //NOI18N
+            !EditorMimeTypes.getDefault().getSupportedMimeTypes().contains(mimeType)) {
+            return false;
+        }
+
+        int slashIdx = mimeType.indexOf('/'); //NOI18N
+        assert slashIdx != -1 : "Invalid mimetype: '" + mimeType + "'"; //NOI18N
+
+        String type = mimeType.substring(0, slashIdx);
+        if (type.equals("application")) { //NOI18N
+            if (!mimeType.equals("application/x-httpd-eruby") && !mimeType.equals("application/xml-dtd")) { //NOI18N
+                return false;
+            }
+        } else if (!type.equals("text")) { //NOI18N
+            return false;
+        }
+
+//            if (allLanguagesParsersCount == -1) {
+//                Collection<? extends ParserFactory> allLanguagesParsers = MimeLookup.getLookup(MimePath.EMPTY).lookupAll(ParserFactory.class);
+//                allLanguagesParsersCount = allLanguagesParsers.size();
+//            }
+//            Collection<? extends ParserFactory> parsers = MimeLookup.getLookup(mimeType).lookupAll(ParserFactory.class);
+//            if (parsers.size() - allLanguagesParsersCount > 0) {
+//                return true;
+//            }
+//
+//            // Ideally we should check that there are EmbeddingProviders registered for the
+//            // mimeType, but let's assume that if there are TaskFactories they are either
+//            // ordinary scheduler tasks or EmbeddingProviders. The former would most likely
+//            // mean that there is also a Parser and would have been caught in the previous check.
+//            if (allLanguagesTasksCount == -1) {
+//                Collection<? extends TaskFactory> allLanguagesTasks = MimeLookup.getLookup(MimePath.EMPTY).lookupAll(TaskFactory.class);
+//                allLanguagesTasksCount = allLanguagesTasks.size();
+//            }
+//            Collection<? extends TaskFactory> tasks = MimeLookup.getLookup(mimeType).lookupAll(TaskFactory.class);
+//            if (tasks.size() - allLanguagesTasksCount > 0) {
+//                return true;
+//            }
+
+        return true;
+    }
+    
     //where
     private static Map<String,Reference<Parser>> cachedParsers = new HashMap<String,Reference<Parser>>();    
 }
