@@ -42,6 +42,7 @@
 
 package org.netbeans.modules.php.apigen.ui.customizer;
 
+import java.awt.EventQueue;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
@@ -62,6 +63,7 @@ import javax.swing.JPanel;
 import javax.swing.JRadioButton;
 import javax.swing.JTextField;
 import javax.swing.LayoutStyle.ComponentPlacement;
+import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import org.netbeans.modules.php.api.phpmodule.PhpModule;
@@ -70,37 +72,28 @@ import org.netbeans.modules.php.api.util.StringUtils;
 import org.netbeans.modules.php.apigen.ApiGenProvider;
 import org.netbeans.modules.php.apigen.commands.ApiGenScript;
 import org.netbeans.modules.php.apigen.ui.ApiGenPreferences;
-import org.netbeans.spi.project.ui.support.ProjectCustomizer.Category;
 import org.openide.awt.Mnemonics;
 import org.openide.filesystems.FileChooserBuilder;
 import org.openide.filesystems.FileUtil;
-import org.openide.util.HelpCtx;
+import org.openide.util.ChangeSupport;
 import org.openide.util.NbBundle;
 
-final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
+final class ApiGenPanel extends JPanel {
 
-    private static final long serialVersionUID = -54768321324347L;
+    private static final long serialVersionUID = -1547854687946312L;
 
     private static final String SEPARATOR = ","; // NOI18N
 
-    private final Category category;
     private final PhpModule phpModule;
+    private final ChangeSupport changeSupport = new ChangeSupport(this);
 
 
-    ApiGenPanel(Category category, PhpModule phpModule) {
-        assert category != null;
+    ApiGenPanel(PhpModule phpModule) {
+        assert EventQueue.isDispatchThread();
         assert phpModule != null;
 
-        this.category = category;
         this.phpModule = phpModule;
 
-        this.category.setStoreListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                storeData();
-            }
-        });
-
         initComponents();
         init();
     }
@@ -163,14 +156,14 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
 
         // enable/disable fields
         configEnabled(configRadioButton.isSelected());
-
-        // validate
-        validateData();
     }
 
-    @Override
-    public HelpCtx getHelpCtx() {
-        return new HelpCtx("org.netbeans.modules.php.apigen.ui.customizer.ApiGen"); // NOI18N
+    public void addChangeListener(ChangeListener listener) {
+        changeSupport.addChangeListener(listener);
+    }
+
+    public void removeChangeListener(ChangeListener listener) {
+        changeSupport.removeChangeListener(listener);
     }
 
     private boolean hasConfig() {
@@ -277,36 +270,37 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         configButton.setEnabled(enabled);
     }
 
-    void validateData() {
+    boolean isValidData() {
+        return getErrorMessage() == null;
+    }
+
+    public String getErrorMessage() {
         if (hasConfig()) {
-            validateConfigFile();
-        } else {
-            validateManualConfig();
+            return validateConfigFile(true);
         }
+        return validateManualConfig(true);
+    }
+
+    public String getWarningMessage() {
+        if (hasConfig()) {
+            return validateConfigFile(false);
+        }
+        return validateManualConfig(false);
     }
 
     @NbBundle.Messages("ApiGenPanel.warn.configNotNeon=Neon file is expected for configuration.")
-    private void validateConfigFile() {
-        // errors
+    private String validateConfigFile(boolean forErrors) {
         String config = getConfig();
-        String error = FileUtils.validateFile(config, false);
-        if (error != null) {
-            category.setErrorMessage(error);
-            category.setValid(false);
-            return;
+        if (forErrors) {
+            // errors
+            return FileUtils.validateFile(config, false);
         }
-
         // warnings
         File configFile = new File(config);
         if (!configFile.getName().endsWith(".neon")) { // NOI18N
-            category.setErrorMessage(Bundle.ApiGenPanel_warn_configNotNeon());
-            category.setValid(true);
-            return;
+            return Bundle.ApiGenPanel_warn_configNotNeon();
         }
-
-        // everything ok
-        category.setErrorMessage(null);
-        category.setValid(true);
+        return null;
     }
 
     @NbBundle.Messages({
@@ -319,74 +313,54 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         "# {0} - encoding",
         "ApiGenPanel.warn.missingCharset=Project encoding ''{0}'' nout found within specified charsets."
     })
-    private void validateManualConfig() {
-        // errors
-        // target
+    private String validateManualConfig(boolean forErrors) {
         String target = getTarget();
-        if (StringUtils.hasText(target)) {
-            File targetDir = new File(target);
-            if (targetDir.exists()) {
-                String error = FileUtils.validateDirectory(target, true);
-                if (error != null) {
-                    category.setErrorMessage(error);
-                    category.setValid(false);
-                    return;
-                }
-            } else {
-                if (!targetDir.isAbsolute()) {
-                    category.setErrorMessage(Bundle.ApiGenPanel_error_relativeTarget());
-                    category.setValid(false);
-                    return;
+        if (forErrors) {
+            // errors
+            // target
+            if (StringUtils.hasText(target)) {
+                File targetDir = new File(target);
+                if (targetDir.exists()) {
+                    return FileUtils.validateDirectory(target, true);
+                } else {
+                    if (!targetDir.isAbsolute()) {
+                        return Bundle.ApiGenPanel_error_relativeTarget();
+                    }
                 }
             }
+            // title
+            if (!StringUtils.hasText(getTitle())) {
+                return Bundle.ApiGenPanel_error_invalidTitle();
+            }
+            // charsets
+            if (getCharsets().isEmpty()) {
+                return Bundle.ApiGenPanel_error_invalidCharsets();
+            }
+            // access levels
+            if (!accessLevelPublicCheckBox.isSelected()
+                    && !accessLevelProtectedCheckBox.isSelected()
+                    && !accessLevelPrivateCheckBox.isSelected()) {
+                return Bundle.ApiGenPanel_error_invalidAccessLevels();
+            }
+            return null;
         }
-        // title
-        if (!StringUtils.hasText(getTitle())) {
-            category.setErrorMessage(Bundle.ApiGenPanel_error_invalidTitle());
-            category.setValid(false);
-            return;
-        }
-        // charsets
-        if (getCharsets().isEmpty()) {
-            category.setErrorMessage(Bundle.ApiGenPanel_error_invalidCharsets());
-            category.setValid(false);
-            return;
-        }
-        // access levels
-        if (!accessLevelPublicCheckBox.isSelected()
-                && !accessLevelProtectedCheckBox.isSelected()
-                && !accessLevelPrivateCheckBox.isSelected()) {
-            category.setErrorMessage(Bundle.ApiGenPanel_error_invalidAccessLevels());
-            category.setValid(false);
-            return;
-        }
-
         // warnings
         // charsets
         String defaultCharset = ApiGenPreferences.CHARSETS.getDefaultValue(phpModule);
         if (getCharsets().indexOf(defaultCharset) == -1) {
-            category.setErrorMessage(Bundle.ApiGenPanel_warn_missingCharset(defaultCharset));
-            category.setValid(true);
-            return;
+            return Bundle.ApiGenPanel_warn_missingCharset(defaultCharset);
         }
         // target
         if (!StringUtils.hasText(target)) {
-            category.setErrorMessage(Bundle.ApiGenPanel_warn_nbWillAskForDir());
-            category.setValid(true);
-            return;
+            return Bundle.ApiGenPanel_warn_nbWillAskForDir();
         }
         if (!new File(target).exists()) {
-            category.setErrorMessage(Bundle.ApiGenPanel_warn_targetDirWillBeCreated());
-            category.setValid(true);
-            return;
+            return Bundle.ApiGenPanel_warn_targetDirWillBeCreated();
         }
-
-        // everything ok
-        category.setErrorMessage(null);
-        category.setValid(true);
+        return null;
     }
 
-    void storeData() {
+    public void storeData() {
         ApiGenPreferences.putBoolean(phpModule, ApiGenPreferences.HAS_CONFIG, hasConfig());
         ApiGenPreferences.putTarget(phpModule, getTarget());
         ApiGenPreferences.put(phpModule, ApiGenPreferences.TITLE, getTitle());
@@ -403,6 +377,10 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         ApiGenPreferences.putBoolean(phpModule, ApiGenPreferences.SOURCE_CODE, getSourceCode());
     }
 
+    void fireChange() {
+        changeSupport.fireChange();
+    }
+
     /** This method is called from within the constructor to
      * initialize the form.
      * WARNING: Do NOT modify this code. The content of this method is
@@ -447,6 +425,7 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
 
         targetLabel.setLabelFor(targetTextField);
         Mnemonics.setLocalizedText(targetLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.targetLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(targetButton, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.targetButton.text")); // NOI18N
         targetButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
@@ -458,24 +437,35 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         Mnemonics.setLocalizedText(titleLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.titleLabel.text")); // NOI18N
 
         charsetsLabel.setLabelFor(charsetsTextField);
-
         Mnemonics.setLocalizedText(charsetsLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.charsetsLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(charsetsInfoLabel, "INFO"); // NOI18N
+
         Mnemonics.setLocalizedText(excludesLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.excludesLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(excludesInfoLabel, "INFO"); // NOI18N
 
         accessLevelLabel.setLabelFor(accessLevelPublicCheckBox);
-
         Mnemonics.setLocalizedText(accessLevelLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.accessLevelLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(accessLevelPublicCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.accessLevelPublicCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(accessLevelProtectedCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.accessLevelProtectedCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(accessLevelPrivateCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.accessLevelPrivateCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(internalCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.internalCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(phpCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.phpCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(treeCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.treeCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(deprecatedCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.deprecatedCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(todoCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.todoCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(downloadCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.downloadCheckBox.text")); // NOI18N
+
         Mnemonics.setLocalizedText(sourceCodeCheckBox, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.sourceCodeCheckBox.text")); // NOI18N
 
         configButtonGroup.add(configRadioButton);
@@ -483,6 +473,7 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
 
         configLabel.setLabelFor(configTextField);
         Mnemonics.setLocalizedText(configLabel, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.configLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(configButton, NbBundle.getMessage(ApiGenPanel.class, "ApiGenPanel.configButton.text")); // NOI18N
         configButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
@@ -492,19 +483,9 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
 
         GroupLayout layout = new GroupLayout(this);
         this.setLayout(layout);
-        layout.setHorizontalGroup(
-            layout.createParallelGroup(Alignment.LEADING)
+        layout.setHorizontalGroup(layout.createParallelGroup(Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
-                .addGap(145, 145, 145)
-                .addComponent(excludesTextField))
-            .addGroup(layout.createSequentialGroup()
-                .addGap(145, 145, 145)
-                .addComponent(charsetsTextField))
-            .addGroup(layout.createSequentialGroup()
-                .addGap(145, 145, 145)
-                .addComponent(titleTextField))
-            .addGroup(layout.createSequentialGroup()
-                .addGap(145, 145, 145)
+                .addGap(116, 116, 116)
                 .addComponent(targetTextField)
                 .addPreferredGap(ComponentPlacement.RELATED)
                 .addComponent(targetButton))
@@ -518,15 +499,18 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
             .addGroup(layout.createSequentialGroup()
                 .addGroup(layout.createParallelGroup(Alignment.LEADING)
                     .addComponent(noConfigRadioButton)
-                    .addComponent(configRadioButton)
+                    .addComponent(configRadioButton))
+                .addContainerGap())
+            .addGroup(layout.createSequentialGroup()
+                .addContainerGap()
+                .addGroup(layout.createParallelGroup(Alignment.LEADING)
+                    .addComponent(targetLabel)
+                    .addComponent(titleLabel)
+                    .addComponent(charsetsLabel)
+                    .addComponent(excludesLabel)
+                    .addComponent(accessLevelLabel))
+                .addGroup(layout.createParallelGroup(Alignment.LEADING)
                     .addGroup(layout.createSequentialGroup()
-                        .addContainerGap()
-                        .addGroup(layout.createParallelGroup(Alignment.LEADING)
-                            .addComponent(targetLabel)
-                            .addComponent(titleLabel)
-                            .addComponent(charsetsLabel)
-                            .addComponent(excludesLabel)
-                            .addComponent(accessLevelLabel))
                         .addPreferredGap(ComponentPlacement.RELATED)
                         .addGroup(layout.createParallelGroup(Alignment.LEADING)
                             .addComponent(accessLevelPublicCheckBox)
@@ -544,15 +528,18 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
                             .addComponent(accessLevelPrivateCheckBox)
                             .addComponent(sourceCodeCheckBox)))
                     .addGroup(layout.createSequentialGroup()
-                        .addGap(145, 145, 145)
-                        .addComponent(charsetsInfoLabel))
-                    .addGroup(layout.createSequentialGroup()
-                        .addGap(145, 145, 145)
-                        .addComponent(excludesInfoLabel)))
-                .addContainerGap())
+                        .addGap(8, 8, 8)
+                        .addGroup(layout.createParallelGroup(Alignment.LEADING)
+                            .addComponent(charsetsTextField)
+                            .addComponent(excludesTextField)
+                            .addGroup(layout.createSequentialGroup()
+                                .addGroup(layout.createParallelGroup(Alignment.LEADING)
+                                    .addComponent(excludesInfoLabel)
+                                    .addComponent(charsetsInfoLabel))
+                                .addGap(0, 242, Short.MAX_VALUE))
+                            .addComponent(titleTextField)))))
         );
-        layout.setVerticalGroup(
-            layout.createParallelGroup(Alignment.LEADING)
+        layout.setVerticalGroup(layout.createParallelGroup(Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
                 .addComponent(noConfigRadioButton)
                 .addPreferredGap(ComponentPlacement.RELATED)
@@ -685,7 +672,7 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         }
 
         private void processChange() {
-            validateData();
+            fireChange();
         }
 
     }
@@ -694,7 +681,7 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
 
         @Override
         public void actionPerformed(ActionEvent e) {
-            validateData();
+            fireChange();
         }
 
     }
@@ -704,7 +691,7 @@ final class ApiGenPanel extends JPanel implements HelpCtx.Provider {
         @Override
         public void itemStateChanged(ItemEvent e) {
             configEnabled(e.getStateChange() == ItemEvent.SELECTED);
-            validateData();
+            fireChange();
         }
 
     }
