@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -37,7 +37,7 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2012 Sun Microsystems, Inc.
+ * Portions Copyrighted 2015 Sun Microsystems, Inc.
  */
 package org.netbeans.modules.php.composer.commands;
 
@@ -49,15 +49,16 @@ import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.Future;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.extexecution.ExecutionDescriptor;
-import org.netbeans.api.extexecution.input.InputProcessor;
+import org.netbeans.api.extexecution.base.input.InputProcessor;
 import org.netbeans.modules.php.api.executable.InvalidPhpExecutableException;
 import org.netbeans.modules.php.api.executable.PhpExecutable;
 import org.netbeans.modules.php.api.executable.PhpExecutableValidator;
 import org.netbeans.modules.php.api.phpmodule.PhpModule;
-import org.netbeans.modules.php.api.util.FileUtils;
 import org.netbeans.modules.php.api.util.StringUtils;
 import org.netbeans.modules.php.api.util.UiUtils;
 import org.netbeans.modules.php.api.validation.ValidationResult;
@@ -66,6 +67,7 @@ import org.netbeans.modules.php.composer.options.ComposerOptionsValidator;
 import org.netbeans.modules.php.composer.output.model.SearchResult;
 import org.netbeans.modules.php.composer.output.parsers.Parsers;
 import org.netbeans.modules.php.composer.ui.options.ComposerOptionsPanelController;
+import org.netbeans.modules.php.composer.util.ComposerUtils;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -79,14 +81,16 @@ import org.openide.util.Utilities;
  */
 public final class Composer {
 
+    static final Logger LOGGER = Logger.getLogger(Composer.class.getName());
+
+    public static final String COMPOSER_FILENAME = "composer.json"; // NOI18N
+
     public static final List<String> COMPOSER_FILENAMES;
 
     private static final String COMPOSER = "composer"; // NOI18N
     private static final String COMPOSER_PHAR = COMPOSER + ".phar"; // NOI18N
     private static final String COMPOSER_BAT = COMPOSER + ".bat"; // NOI18N
 
-    private static final String COMPOSER_FILENAME = "composer.json"; // NOI18N
-
     // commands
     private static final String INIT_COMMAND = "init"; // NOI18N
     private static final String INSTALL_COMMAND = "install"; // NOI18N
@@ -162,24 +166,25 @@ public final class Composer {
 
     public Future<Integer> initIfNotPresent(PhpModule phpModule) {
         assert phpModule != null;
-        FileObject configFile = getComposerConfigFile(phpModule);
-        if (configFile != null && configFile.isValid()) {
+        FileObject composerJson = getComposerJson(phpModule);
+        if (composerJson != null
+                && composerJson.isValid()) {
             return null;
         }
         return init(phpModule);
     }
 
     @NbBundle.Messages({
-        "Composer.run.init=Composer (init)",
-        "Composer.file.exists=Composer config file already exists - overwrite it?",
+        "Composer.file.exists=Composer.json already exists - overwrite it?",
         "# {0} - project name",
-        "Composer.init.description=Description of project {0}."
+        "Composer.init.description=Description of project {0}.",
     })
     public Future<Integer> init(PhpModule phpModule) {
         assert phpModule != null;
-        // config file
-        FileObject configFile = getComposerConfigFile(phpModule);
-        if (configFile != null && configFile.isValid()) {
+        // composer.json
+        FileObject composerJson = getComposerJson(phpModule);
+        if (composerJson != null
+                && composerJson.isValid()) {
             // existing config
             if (!userConfirmation(phpModule.getDisplayName(), Bundle.Composer_file_exists())) {
                 return null;
@@ -199,7 +204,7 @@ public final class Composer {
                 String.format(NAME_PARAM, getInitName(options.getVendor(), phpModule.getName())),
                 String.format(AUTHOR_PARAM, options.getAuthorName(), options.getAuthorEmail()),
                 String.format(DESCRIPTION_PARAM, Bundle.Composer_init_description(phpModule.getDisplayName())));
-        return runCommand(phpModule, INIT_COMMAND, Bundle.Composer_run_init(), params);
+        return runCommand(phpModule, true, INIT_COMMAND, params);
     }
 
     private String getInitName(String vendor, String projectName) {
@@ -210,71 +215,58 @@ public final class Composer {
         return name.toString();
     }
 
-    @NbBundle.Messages("Composer.run.install=Composer (install)")
     public Future<Integer> install(PhpModule phpModule) {
         assert phpModule != null;
-        return runCommand(phpModule, INSTALL_COMMAND, Bundle.Composer_run_install());
+        return runCommand(phpModule, INSTALL_COMMAND);
     }
 
-    @NbBundle.Messages("Composer.run.installDev=Composer (install dev)")
     public Future<Integer> installDev(PhpModule phpModule) {
-        assert phpModule != null;
-        return runCommand(phpModule, INSTALL_COMMAND, Bundle.Composer_run_installDev(), Collections.singletonList(DEV_PARAM));
+        return install(phpModule);
     }
 
-    @NbBundle.Messages("Composer.run.installNoDev=Composer (install no-dev)")
     public Future<Integer> installNoDev(PhpModule phpModule) {
         assert phpModule != null;
-        return runCommand(phpModule, INSTALL_COMMAND, Bundle.Composer_run_installNoDev(), Collections.singletonList(NO_DEV_PARAM));
+        return runCommand(phpModule, INSTALL_COMMAND, Collections.singletonList(NO_DEV_PARAM));
     }
 
-    @NbBundle.Messages("Composer.run.update=Composer (update)")
     public Future<Integer> update(PhpModule phpModule) {
         assert phpModule != null;
-        return runCommand(phpModule, UPDATE_COMMAND, Bundle.Composer_run_update());
+        return runCommand(phpModule, UPDATE_COMMAND);
     }
 
-    @NbBundle.Messages("Composer.run.updateDev=Composer (update dev)")
     public Future<Integer> updateDev(PhpModule phpModule) {
-        assert phpModule != null;
-        return runCommand(phpModule, UPDATE_COMMAND, Bundle.Composer_run_updateDev(), Collections.singletonList(DEV_PARAM));
+        return update(phpModule);
     }
 
-    @NbBundle.Messages("Composer.run.updateNoDev=Composer (update no-dev)")
     public Future<Integer> updateNoDev(PhpModule phpModule) {
         assert phpModule != null;
-        return runCommand(phpModule, UPDATE_COMMAND, Bundle.Composer_run_updateNoDev(), Collections.singletonList(NO_DEV_PARAM));
+        return runCommand(phpModule, UPDATE_COMMAND, Collections.singletonList(NO_DEV_PARAM));
     }
 
-    @NbBundle.Messages("Composer.run.require=Composer (require)")
     public Future<Integer> require(PhpModule phpModule, String... packages) {
         assert phpModule != null;
-        return runCommand(phpModule, REQUIRE_COMMAND, Bundle.Composer_run_require(), Arrays.asList(packages));
+        return runCommand(phpModule, REQUIRE_COMMAND, Arrays.asList(packages));
     }
 
-    @NbBundle.Messages("Composer.run.requireDev=Composer (require dev)")
     public Future<Integer> requireDev(PhpModule phpModule, String... packages) {
         assert phpModule != null;
         List<String> params = new ArrayList<>(packages.length + 1);
         params.add(DEV_PARAM);
         params.addAll(Arrays.asList(packages));
-        return runCommand(phpModule, REQUIRE_COMMAND, Bundle.Composer_run_requireDev(), params);
+        return runCommand(phpModule, REQUIRE_COMMAND, params);
     }
 
-    @NbBundle.Messages("Composer.run.validate=Composer (validate)")
     public Future<Integer> validate(PhpModule phpModule) {
         assert phpModule != null;
-        return runCommand(phpModule, VALIDATE_COMMAND, Bundle.Composer_run_validate());
+        return runCommand(phpModule, VALIDATE_COMMAND);
     }
 
-    @NbBundle.Messages("Composer.run.selfUpdate=Composer (self-update)")
     public Future<Integer> selfUpdate() {
-        return runCommand(null, SELF_UPDATE_COMMAND, Bundle.Composer_run_selfUpdate());
+        return runCommand(null, SELF_UPDATE_COMMAND);
     }
 
-    @NbBundle.Messages("Composer.run.search=Composer (search)")
     public Future<Integer> search(@NullAllowed PhpModule phpModule, String token, boolean onlyName, final OutputProcessor<SearchResult> outputProcessor) {
-        PhpExecutable composer = getComposerExecutable(phpModule, Bundle.Composer_run_search());
+        PhpExecutable composer = getComposerExecutable(phpModule, false);
         if (composer == null) {
             return null;
         }
@@ -296,7 +288,7 @@ public final class Composer {
                 .frontWindow(false);
         // run
         return composer
-                .run(descriptor, new ExecutionDescriptor.InputProcessorFactory() {
+                .run(descriptor, new ExecutionDescriptor.InputProcessorFactory2() {
                     @Override
                     public InputProcessor newInputProcessor(InputProcessor defaultProcessor) {
                         return new OutputProcessorImpl(new OutputParser() {
@@ -311,9 +303,8 @@ public final class Composer {
                 });
     }
 
-    @NbBundle.Messages("Composer.run.show=Composer (show)")
     public Future<Integer> show(@NullAllowed PhpModule phpModule, String name, final OutputProcessor<String> outputProcessor) {
-        PhpExecutable composer = getComposerExecutable(phpModule, Bundle.Composer_run_show());
+        PhpExecutable composer = getComposerExecutable(phpModule, false);
         if (composer == null) {
             return null;
         }
@@ -330,7 +321,7 @@ public final class Composer {
                 .frontWindow(false);
         // run
         return composer
-                .run(descriptor, new ExecutionDescriptor.InputProcessorFactory() {
+                .run(descriptor, new ExecutionDescriptor.InputProcessorFactory2() {
                     @Override
                     public InputProcessor newInputProcessor(InputProcessor defaultProcessor) {
                         return new OutputProcessorImpl(new OutputParser() {
@@ -347,12 +338,16 @@ public final class Composer {
                 });
     }
 
-    private Future<Integer> runCommand(@NullAllowed PhpModule phpModule, String command, String title) {
-        return runCommand(phpModule, command, title, Collections.<String>emptyList());
+    private Future<Integer> runCommand(@NullAllowed PhpModule phpModule, String command) {
+        return runCommand(phpModule, command, Collections.<String>emptyList());
     }
 
-    private Future<Integer> runCommand(@NullAllowed PhpModule phpModule, String command, String title, List<String> commandParams) {
-        PhpExecutable composer = getComposerExecutable(phpModule, title);
+    private Future<Integer> runCommand(@NullAllowed PhpModule phpModule, String command, List<String> commandParams) {
+        return runCommand(phpModule, false, command, commandParams);
+    }
+
+    private Future<Integer> runCommand(@NullAllowed PhpModule phpModule, boolean forceProjectDir, String command, List<String> commandParams) {
+        PhpExecutable composer = getComposerExecutable(phpModule, forceProjectDir);
         if (composer == null) {
             return null;
         }
@@ -361,9 +356,14 @@ public final class Composer {
                 .run(getDescriptor(phpModule));
     }
 
+    @NbBundle.Messages({
+        "# {0} - project name",
+        "Composer.run.title=Composer ({0})",
+        "Composer.run.title.pure=Composer",
+    })
     @CheckForNull
-    private PhpExecutable getComposerExecutable(@NullAllowed PhpModule phpModule, String title) {
-        File dir = resolveWorkDir(phpModule);
+    private PhpExecutable getComposerExecutable(@NullAllowed PhpModule phpModule, boolean forceProjectDir) {
+        File dir = resolveWorkDir(phpModule, forceProjectDir);
         if (dir == null
                 && phpModule != null) {
             warnNoSources(phpModule.getDisplayName());
@@ -371,7 +371,7 @@ public final class Composer {
         }
         PhpExecutable composer = new PhpExecutable(composerPath)
                 .optionsSubcategory(ComposerOptionsPanelController.OPTIONS_SUBPATH)
-                .displayName(title);
+                .displayName(phpModule != null ? Bundle.Composer_run_title(phpModule.getDisplayName()) : Bundle.Composer_run_title_pure());
         if (dir != null) {
             composer.workDir(dir);
         }
@@ -415,18 +415,20 @@ public final class Composer {
                 new NotifyDescriptor.Message(Bundle.Composer_project_noSources(projectName), NotifyDescriptor.WARNING_MESSAGE));
     }
 
-    private FileObject getComposerConfigFile(PhpModule phpModule) {
+    @CheckForNull
+    private FileObject getComposerJson(PhpModule phpModule) {
         assert phpModule != null;
-        File dir = resolveWorkDir(phpModule);
-        if (dir == null) {
-            return null;
+        if (workDir != null) {
+            FileObject fo = FileUtil.toFileObject(workDir);
+            if (fo == null) {
+                // invalid workdir?
+                LOGGER.log(Level.INFO, "Valid workdir expected but invalid given: {0}", workDir);
+                return null;
+            }
+            return fo.getFileObject(COMPOSER_FILENAME);
         }
-        FileObject fo = FileUtil.toFileObject(dir);
-        if (fo == null) {
-            assert false : "FileObject should be found for file: " + dir;
-            return null;
-        }
-        return fo.getFileObject(COMPOSER_FILENAME);
+        return ComposerUtils.getComposerWorkDir(phpModule)
+                .getFileObject(COMPOSER_FILENAME);
     }
 
     private boolean userConfirmation(String title, String question) {
@@ -435,19 +437,23 @@ public final class Composer {
     }
 
     @CheckForNull
-    private File resolveWorkDir(PhpModule phpModule) {
+    private File resolveWorkDir(PhpModule phpModule, boolean forceProjectDir) {
         if (workDir != null) {
             return workDir;
         }
         if (phpModule == null) {
             return null;
         }
-        FileObject sourceDirectory = phpModule.getSourceDirectory();
-        if (sourceDirectory == null) {
+        FileObject composerJson = getComposerJson(phpModule);
+        if (composerJson != null) {
+            return FileUtil.toFile(composerJson.getParent());
+        }
+        FileObject dir = forceProjectDir ? phpModule.getProjectDirectory() : phpModule.getSourceDirectory();
+        if (dir == null) {
             // broken project
             return null;
         }
-        return FileUtil.toFile(sourceDirectory);
+        return FileUtil.toFile(dir);
     }
 
     public File getWorkDir() {
