@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -37,7 +37,7 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2008 Sun Microsystems, Inc.
+ * Portions Copyrighted 2015 Sun Microsystems, Inc.
  */
 
 package org.netbeans.modules.php.phpunit.commands;
@@ -62,9 +62,9 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.extexecution.ExecutionDescriptor;
-import org.netbeans.api.extexecution.input.InputProcessor;
-import org.netbeans.api.extexecution.input.InputProcessors;
-import org.netbeans.api.extexecution.input.LineProcessor;
+import org.netbeans.api.extexecution.base.input.InputProcessor;
+import org.netbeans.api.extexecution.base.input.InputProcessors;
+import org.netbeans.api.extexecution.base.input.LineProcessor;
 import org.netbeans.api.extexecution.print.LineConvertor;
 import org.netbeans.api.extexecution.print.LineConvertors;
 import org.netbeans.modules.php.api.executable.InvalidPhpExecutableException;
@@ -107,8 +107,6 @@ public final class PhpUnit {
     public static final String SCRIPT_NAME = "phpunit"; // NOI18N
     public static final String SCRIPT_NAME_LONG = SCRIPT_NAME + FileUtils.getScriptExtension(true);
     public static final String SCRIPT_NAME_PHAR = SCRIPT_NAME + ".phar"; // NOI18N
-    // for keeping log files to able to evaluate and fix issues
-    public static final boolean KEEP_LOGS = Boolean.getBoolean("nb.php.phpunit.keeplogs"); // NOI18N
     // test files suffix
     public static final String TEST_CLASS_SUFFIX = "Test"; // NOI18N
     private static final String TEST_FILE_SUFFIX = TEST_CLASS_SUFFIX + ".php"; // NOI18N
@@ -125,6 +123,7 @@ public final class PhpUnit {
     private static final String COVERAGE_LOG_PARAM = "--coverage-clover"; // NOI18N
     private static final String LIST_GROUPS_PARAM = "--list-groups"; // NOI18N
     private static final String GROUP_PARAM = "--group"; // NOI18N
+    private static final String PARAM_SEPARATOR = "--"; // NOI18N
     // bootstrap & config
     private static final String BOOTSTRAP_PARAM = "--bootstrap"; // NOI18N
     private static final String BOOTSTRAP_FILENAME = "bootstrap%s.php"; // NOI18N
@@ -255,7 +254,7 @@ public final class PhpUnit {
 
     @CheckForNull
     public Integer runTests(PhpModule phpModule, TestRunInfo runInfo) throws TestRunException {
-        PhpExecutable phpUnit = getExecutable(phpModule, getOutputTitle(runInfo, PhpUnitPreferences.isCustomSuiteEnabled(phpModule)));
+        PhpExecutable phpUnit = getExecutable(phpModule);
         if (phpUnit == null) {
             return null;
         }
@@ -321,6 +320,8 @@ public final class PhpUnit {
             // #218607 - hotfix
             //params.add(SUITE_NAME)
             params.add(getNbSuite().getAbsolutePath());
+            // #254276
+            params.add(PARAM_SEPARATOR);
             params.add(String.format(SUITE_RUN, joinPaths(runInfo.getStartFiles(), SUITE_PATH_DELIMITER)));
         }
 
@@ -338,7 +339,7 @@ public final class PhpUnit {
             return phpUnit.debug(startFiles.get(0), getDescriptor(), null);
         } catch (CancellationException ex) {
             // canceled
-            LOGGER.log(Level.FINE, "Test creating cancelled", ex);
+            LOGGER.log(Level.FINE, "Test running cancelled", ex);
         } catch (ExecutionException ex) {
             LOGGER.log(Level.INFO, null, ex);
             if (PhpUnitPreferences.isPhpUnitEnabled(phpModule)) {
@@ -352,10 +353,9 @@ public final class PhpUnit {
         return null;
     }
 
-    @NbBundle.Messages("PhpUnit.fetch.testGroups=PHPUnit (test-groups)")
     @CheckForNull
     private List<String> getTestGroups(PhpModule phpModule) throws TestRunException {
-        PhpExecutable phpUnit = getExecutable(phpModule, Bundle.PhpUnit_fetch_testGroups());
+        PhpExecutable phpUnit = getExecutable(phpModule);
         assert phpUnit != null;
 
         File workingDirectory = getWorkingDirectory(phpModule);
@@ -382,8 +382,8 @@ public final class PhpUnit {
             }
             return testGroupsProcessorFactory.getTestGroups();
         } catch (CancellationException ex) {
-            // canceled
-            LOGGER.log(Level.FINE, "Test creating cancelled", ex);
+            // cancelled
+            LOGGER.log(Level.FINE, "Test groups getting cancelled", ex);
         } catch (ExecutionException ex) {
             LOGGER.log(Level.INFO, null, ex);
             UiUtils.processExecutionException(ex, PhpUnitOptionsPanelController.OPTIONS_SUB_PATH);
@@ -392,8 +392,12 @@ public final class PhpUnit {
         return null;
     }
 
+    @NbBundle.Messages({
+        "# {0} - project name",
+        "PhpUnit.run.title=PHPUnit ({0})",
+    })
     @CheckForNull
-    private PhpExecutable getExecutable(PhpModule phpModule, String title) {
+    private PhpExecutable getExecutable(PhpModule phpModule) {
         FileObject sourceDirectory = phpModule.getSourceDirectory();
         if (sourceDirectory == null) {
             org.netbeans.modules.php.phpunit.ui.UiUtils.warnNoSources(phpModule.getDisplayName());
@@ -402,7 +406,7 @@ public final class PhpUnit {
 
         return new PhpExecutable(phpUnitPath)
                 .optionsSubcategory(PhpUnitOptionsPanelController.OPTIONS_SUB_PATH)
-                .displayName(title);
+                .displayName(Bundle.PhpUnit_run_title(phpModule.getDisplayName()));
     }
 
     private List<String> createParams(boolean withDefaults) {
@@ -455,44 +459,6 @@ public final class PhpUnit {
         return FileUtil.toFile(testDirectory);
     }
 
-    @NbBundle.Messages({
-        "PhpUnit.run.test.single=PHPUnit (test)",
-        "PhpUnit.run.test.single.custom=PHPUnit (test, custom)",
-        "PhpUnit.run.test.all=PHPUnit (test all)",
-        "PhpUnit.run.test.all.custom=PHPUnit (test all, custom)",
-        "PhpUnit.debug.single=PHPUnit (debug)",
-        "PhpUnit.debug.single.custom=PHPUnit (debug, custom)",
-        "PhpUnit.debug.all=PHPUnit (debug all)",
-        "PhpUnit.debug.all.custom=PHPUnit (debug all, custom)"
-    })
-    private String getOutputTitle(TestRunInfo runInfo, boolean customSuiteEnabled) {
-        boolean allTests = runInfo.allTests();
-        switch (runInfo.getSessionType()) {
-            case TEST:
-                if (allTests && customSuiteEnabled) {
-                    return Bundle.PhpUnit_run_test_all_custom();
-                } else if (allTests) {
-                    return Bundle.PhpUnit_run_test_all();
-                } else if (customSuiteEnabled) {
-                    return Bundle.PhpUnit_run_test_single_custom();
-                }
-                return Bundle.PhpUnit_run_test_single();
-                //break;
-            case DEBUG:
-                if (allTests && customSuiteEnabled) {
-                    return Bundle.PhpUnit_debug_all_custom();
-                } else if (allTests) {
-                    return Bundle.PhpUnit_debug_all();
-                } else if (customSuiteEnabled) {
-                    return Bundle.PhpUnit_debug_single_custom();
-                }
-                return Bundle.PhpUnit_debug_single();
-                //break;
-            default:
-                throw new IllegalStateException("Unknown session type: " + runInfo.getSessionType());
-        }
-    }
-
     void cleanupLogFiles() {
         if (PhpUnit.XML_LOG.exists()) {
             if (!PhpUnit.XML_LOG.delete()) {
@@ -763,7 +729,7 @@ public final class PhpUnit {
 
     }
 
-    private static final class TestGroupsOutputProcessorFactory implements ExecutionDescriptor.InputProcessorFactory {
+    private static final class TestGroupsOutputProcessorFactory implements ExecutionDescriptor.InputProcessorFactory2 {
 
         private final Pattern testGroupName = Pattern.compile("^\\s-\\s(.*)$"); // NOI18N
         private final List<String> testGroups = Collections.synchronizedList(new ArrayList<String>());
