@@ -74,9 +74,12 @@ import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.StaticResource;
 import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.classpath.GlobalPathRegistry;
+import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectInformation;
 import org.netbeans.api.project.ProjectManager;
+import org.netbeans.api.project.ProjectUtils;
+import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.queries.VisibilityQuery;
 import org.netbeans.api.search.SearchRoot;
 import org.netbeans.api.search.SearchScopeOptions;
@@ -85,6 +88,7 @@ import org.netbeans.api.search.provider.SearchInfoUtils;
 import org.netbeans.api.search.provider.SearchListener;
 import org.netbeans.modules.php.api.documentation.PhpDocumentations;
 import org.netbeans.modules.php.api.phpmodule.PhpModule;
+import org.netbeans.modules.php.api.util.FileUtils;
 import org.netbeans.modules.php.project.api.PhpSeleniumProvider;
 import org.netbeans.modules.php.project.api.PhpSourcePath;
 import org.netbeans.modules.php.project.classpath.BasePathSupport;
@@ -109,6 +113,7 @@ import org.netbeans.modules.php.spi.executable.DebugStarter;
 import org.netbeans.modules.php.spi.framework.PhpFrameworkProvider;
 import org.netbeans.modules.php.spi.framework.PhpModuleIgnoredFilesExtender;
 import org.netbeans.modules.php.spi.testing.PhpTestingProvider;
+import org.netbeans.modules.php.spi.testing.PhpTestingProviders;
 import org.netbeans.modules.web.browser.api.BrowserSupport;
 import org.netbeans.modules.web.browser.api.WebBrowser;
 import org.netbeans.modules.web.browser.api.BrowserUISupport;
@@ -142,6 +147,7 @@ import org.netbeans.spi.search.SearchInfoDefinition;
 import org.netbeans.spi.search.SearchInfoDefinitionFactory;
 import org.netbeans.spi.search.SubTreeSearchOptions;
 import org.openide.awt.HtmlBrowser;
+import org.openide.awt.NotificationDisplayer;
 import org.openide.filesystems.FileAttributeEvent;
 import org.openide.filesystems.FileChangeListener;
 import org.openide.filesystems.FileEvent;
@@ -286,7 +292,7 @@ public final class PhpProject implements Project {
                 .setTests(true)
                 .build();
         seleniumRoots = SourceRoots.Builder.create(updateHelper, eval, Bundle.PhpProject_sourceRoots_selenium())
-                .setProperties(PhpProjectProperties.SELENIUM_SRC_DIR)
+                .setPropertyNumericPrefix(PhpProjectProperties.SELENIUM_SRC_DIR)
                 .setTests(true)
                 .build();
 
@@ -305,6 +311,7 @@ public final class PhpProject implements Project {
             public void propertyChange(PropertyChangeEvent evt) {
                 removeSourceDirListener();
                 addSourceDirListener();
+                resetFrameworks();
             }
         });
         frameworksListener = new ChangeListener() {
@@ -414,6 +421,13 @@ public final class PhpProject implements Project {
         return testRoots.getRoots();
     }
 
+    /**
+     * @return selenium tests directory or <code>null</code>
+     */
+    FileObject[] getSeleniumDirectories() {
+        return seleniumRoots.getRoots();
+    }
+
     /**
      * @return selenium tests directory or <code>null</code>
      */
@@ -645,16 +659,6 @@ public final class PhpProject implements Project {
         fireIgnoredFilesChange();
     }
 
-    public boolean hasConfigFiles() {
-        final PhpModule phpModule = getPhpModule();
-        for (PhpFrameworkProvider frameworkProvider : getFrameworks()) {
-            if (frameworkProvider.getConfigurationFiles(phpModule).length > 0) {
-                return true;
-            }
-        }
-        return false;
-    }
-
     public List<PhpTestingProvider> getTestingProviders() {
         return testingProviders.getTestingProviders();
     }
@@ -748,15 +752,17 @@ public final class PhpProject implements Project {
                 new PhpLogicalViewProvider(this),
                 new CustomizerProviderImpl(this),
                 PhpSharabilityQuery.create(helper, getEvaluator(), getSourceRoots(), getTestRoots(), getSeleniumRoots()),
+                LookupProviderSupport.createSharabilityQueryMerger(),
                 new PhpProjectOperations(this) ,
                 phpProjectEncodingQueryImpl,
-                new TemplateAttributesProviderImpl(getHelper(), phpProjectEncodingQueryImpl),
+                new CreateFromTemplateAttributesImpl(getHelper(), phpProjectEncodingQueryImpl),
                 new PhpTemplates(),
                 new PhpSources(this, getHelper(), getEvaluator(), getSourceRoots(), getTestRoots(), getSeleniumRoots()),
                 getHelper(),
                 getEvaluator(),
                 PhpSearchInfo.create(this),
                 new PhpSubTreeSearchOptions(),
+                new PhpTestingProvidersImpl(testingProviders),
                 InternalWebServer.createForProject(this),
                 CssPreprocessors.getDefault().createProjectProblemsProvider(this),
                 ProjectPropertiesProblemProvider.createForProject(this),
@@ -766,6 +772,7 @@ public final class PhpProject implements Project {
                 ProjectBrowserProviderImpl.create(this),
                 new PhpVisibilityQuery.PhpVisibilityQueryImpl(this),
                 new UsageLogging(),
+                new ImportantFilesImpl(this),
                 // ?? getRefHelper()
         });
         return LookupProviderSupport.createCompositeLookup(base, "Projects/org-netbeans-modules-php-project/Lookup"); // NOI18N
@@ -860,6 +867,9 @@ public final class PhpProject implements Project {
                 jsTestingProvider.projectOpened(PhpProject.this);
             }
 
+            // autoconfigured?
+            checkAutoconfigured();
+
             // #187060 - exception in projectOpened => project IS NOT opened (so move it at the end of the hook)
             getCopySupport().projectOpened();
 
@@ -917,6 +927,30 @@ public final class PhpProject implements Project {
             getSeleniumRoots().getRoots();
         }
 
+        @NbBundle.Messages({
+            "# {0} - project name",
+            "PhpOpenedHook.notification.autoconfigured.title=Project {0} automatically configured",
+            "PhpOpenedHook.notification.autoconfigured.details=Review and correct important project settings detected by the IDE.",
+        })
+        private void checkAutoconfigured() {
+            PhpProjectProperties projectProperties = new PhpProjectProperties(PhpProject.this);
+            if (projectProperties.isAutoconfigured()) {
+                NotificationDisplayer.getDefault().notify(
+                        Bundle.PhpOpenedHook_notification_autoconfigured_title(ProjectUtils.getInformation(PhpProject.this).getDisplayName()),
+                        NotificationDisplayer.Priority.LOW.getIcon(),
+                        Bundle.PhpOpenedHook_notification_autoconfigured_details(),
+                        new ActionListener() {
+                            @Override
+                            public void actionPerformed(ActionEvent e) {
+                                PhpProjectUtils.openCustomizer(PhpProject.this, CompositePanelProviderImpl.SOURCES);
+                            }
+                        },
+                        NotificationDisplayer.Priority.LOW);
+                projectProperties.setAutoconfigured(false);
+                projectProperties.save();
+            }
+        }
+
     }
 
     private static final class ConfigPropertyProvider extends FilterPropertyProvider implements PropertyChangeListener {
@@ -966,6 +1000,75 @@ public final class PhpProject implements Project {
         public void runAllTests() {
             ConfigAction.get(ConfigAction.Type.SELENIUM, PhpProject.this).runProject();
         }
+
+        @Override
+        public boolean isSupportEnabled(FileObject[] activatedFOs) {
+            if (activatedFOs.length == 0) {
+                return false;
+            }
+
+            PhpProject onlyOneProjectAllowed = null;
+            for (FileObject fileObj : activatedFOs) {
+                if (fileObj == null) {
+                    return false;
+                }
+
+                // only php files or folders allowed
+                if (fileObj.isData() && !FileUtils.isPhpFile(fileObj)) {
+                    return false;
+                }
+
+                PhpProject phpProject = PhpProjectUtils.getPhpProject(fileObj);
+                if (phpProject == null) {
+                    return false;
+                }
+                if (PhpProjectValidator.isFatallyBroken(phpProject)) {
+                    return false;
+                }
+                if (onlyOneProjectAllowed == null) {
+                    onlyOneProjectAllowed = phpProject;
+                } else {
+                    if (!onlyOneProjectAllowed.equals(phpProject)) {
+                        // tests can be generated only for one project at one time
+                        return false;
+                    }
+                }
+
+                if (fileObj == phpProject.getProjectDirectory()) { // "Run Selenium Tests" action should be active for the project node
+                    return true;
+                }
+
+                FileObject sources = ProjectPropertiesSupport.getSourcesDirectory(phpProject);
+                if (sources == null || sources.equals(fileObj)) {
+                    return false;
+                }
+
+                if (!CommandUtils.isUnderSources(phpProject, fileObj)
+                        || CommandUtils.isUnderTests(phpProject, fileObj, false)
+                        || CommandUtils.isUnderSelenium(phpProject, fileObj, false)) {
+                    return false;
+                }
+            }
+            return true;
+        }
+
+        @Override
+        public List<Object> getTestSourceRoots(Collection<SourceGroup> createdSourceRoots, FileObject refFileObject) {
+            ArrayList<Object> folders = new ArrayList<>();
+            Project p = FileOwnerQuery.getOwner(refFileObject);
+            if (p != null && (p instanceof PhpProject)) {
+                List<FileObject> seleniumDirectories = ProjectPropertiesSupport.getSeleniumDirectories((PhpProject) p, true);
+                SourceGroup[] sourceGroups = PhpProjectUtils.getSourceGroups((PhpProject) p);
+                for (SourceGroup sg : sourceGroups) {
+                    if (!sg.contains(refFileObject)) {
+                        if (seleniumDirectories.contains(sg.getRootFolder())) {
+                            folders.add(sg);
+                        }
+                    }
+                }
+            }
+            return folders;
+        }
     }
 
     private final class ProjectPropertiesListener implements PropertyChangeListener {
@@ -1555,4 +1658,21 @@ public final class PhpProject implements Project {
 
     }
 
+    private static final class PhpTestingProvidersImpl implements PhpTestingProviders {
+
+        private final TestingProviders testingProviders;
+
+
+        public PhpTestingProvidersImpl(TestingProviders testingProviders) {
+            assert testingProviders != null;
+            this.testingProviders = testingProviders;
+        }
+
+        @Override
+        public List<PhpTestingProvider> getEnabledTestingProviders() {
+            return testingProviders.getTestingProviders();
+        }
+
+    }
+
 }
