@@ -49,7 +49,7 @@ import java.util.Collections;
 import java.util.List;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.annotations.common.CheckForNull;
-import org.netbeans.api.progress.ProgressUtils;
+import org.netbeans.api.progress.BaseProgressUtils;
 import org.netbeans.modules.php.api.PhpVersion;
 import org.netbeans.modules.php.api.executable.InvalidPhpExecutableException;
 import org.netbeans.modules.php.api.executable.PhpInterpreter;
@@ -179,6 +179,37 @@ public final class ProjectPropertiesSupport {
         return testsDirectory;
     }
 
+    
+
+    @NbBundle.Messages({
+        "ProjectPropertiesSupport.browse.selenium.test=Select a directory with project selenium test files.",
+    })
+    public static List<FileObject> getSeleniumDirectories(final PhpProject project, boolean showFileChooser) {
+        List<FileObject> testDirs = filterValid(project.getSeleniumDirectories());
+        if (!testDirs.isEmpty()) {
+            return testDirs;
+        }
+        if (!showFileChooser) {
+            return Collections.emptyList();
+        }
+        // show ui
+        BrowseTestSources panel = Mutex.EVENT.readAccess(new Mutex.Action<BrowseTestSources>() {
+            @Override
+            public BrowseTestSources run() {
+                return new BrowseTestSources(project, Bundle.ProjectPropertiesSupport_browse_selenium_test(),
+                        Bundle.ProjectPropertiesSupport_browse_tests_info());
+            }
+        });
+        if (!panel.open()) {
+            return Collections.emptyList();
+        }
+        File tests = new File(panel.getTestSources());
+        assert tests.isDirectory();
+        FileObject testsDirectory = FileUtil.toFileObject(tests);
+        saveTestSources(project, PhpProjectProperties.SELENIUM_SRC_DIR, tests);
+        return Collections.singletonList(testsDirectory);
+    }
+
     /**
      * @return selenium test sources directory or <code>null</code> (if not set up yet e.g.)
      */
@@ -298,7 +329,7 @@ public final class ProjectPropertiesSupport {
         if (value != null) {
             try {
                 return PhpVersion.valueOf(value);
-            } catch (IllegalArgumentException iae) {
+            } catch (Exception iae) {
                 // ignored
             }
         }
@@ -314,7 +345,7 @@ public final class ProjectPropertiesSupport {
         if (runAs != null) {
             try {
                 runAsType = PhpProjectProperties.RunAsType.valueOf(runAs);
-            } catch (IllegalArgumentException iae) {
+            } catch (Exception iae) {
                 // ignored
             }
         }
@@ -393,7 +424,7 @@ public final class ProjectPropertiesSupport {
         assert remoteUpload != null;
         try {
             uploadFiles = PhpProjectProperties.UploadFiles.valueOf(remoteUpload);
-        } catch (IllegalArgumentException iae) {
+        } catch (Exception iae) {
             // ignored
         }
         return uploadFiles;
@@ -529,7 +560,7 @@ public final class ProjectPropertiesSupport {
 
     @NbBundle.Messages("ProjectPropertiesSupport.project.metadata.saving=Saving project metadata...")
     private static void saveTestSources(final PhpProject project, final String propertyName, final File testDir) {
-        ProgressUtils.showProgressDialogAndRun(new Runnable() {
+        BaseProgressUtils.showProgressDialogAndRun(new Runnable() {
             @Override
             public void run() {
                 // XXX reference helper
