@@ -42,11 +42,13 @@
 
 package org.netbeans.modules.php.project.connections;
 
+import java.io.BufferedInputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.InvalidPathException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -60,6 +62,7 @@ import java.util.TreeSet;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.regex.Pattern;
+import org.netbeans.modules.php.api.util.FileUtils;
 import org.netbeans.modules.php.api.util.StringUtils;
 import org.netbeans.modules.php.project.PhpVisibilityQuery;
 import org.netbeans.modules.php.project.connections.common.RemoteUtils;
@@ -68,7 +71,6 @@ import org.netbeans.modules.php.project.connections.spi.RemoteConnectionProvider
 import org.netbeans.modules.php.project.connections.spi.RemoteFile;
 import org.netbeans.modules.php.project.connections.transfer.TransferFile;
 import org.netbeans.modules.php.project.connections.transfer.TransferInfo;
-import org.netbeans.modules.php.project.util.PhpProjectUtils;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.filesystems.FileAlreadyLockedException;
@@ -431,9 +433,8 @@ public final class RemoteClient implements Cancellable {
                 }
             }
             // XXX lock the file?
-            InputStream is = new FileInputStream(new File(new File(file.getBaseLocalDirectoryPath()), file.getLocalPath()));
             boolean success = false;
-            try {
+            try (InputStream is = new BufferedInputStream(new FileInputStream(new File(new File(file.getBaseLocalDirectoryPath()), file.getLocalPath())))) {
                 for (int i = 1; i <= TRIES_TO_TRANSFER; i++) {
                     boolean fileStored;
                     synchronized (this) {
@@ -452,7 +453,6 @@ public final class RemoteClient implements Cancellable {
                     }
                 }
             } finally {
-                is.close();
                 if (success) {
                     if (!properties.isUploadDirectly()) {
                         success = moveRemoteFile(tmpFileName, fileName);
@@ -905,7 +905,7 @@ public final class RemoteClient implements Cancellable {
             } finally {
                 lock.releaseLock();
             }
-        } catch (IOException ex) {
+        } catch (IOException | InvalidPathException ex) {
             LOGGER.log(Level.INFO, "Error while moving local file", ex);
             moved = false;
         } catch (DownloadSkipException ex) {
@@ -963,7 +963,7 @@ public final class RemoteClient implements Cancellable {
             return fo.lock();
         } catch (FileAlreadyLockedException lockedException) {
             if (warnChangedFile(fo)) {
-                PhpProjectUtils.saveFile(fo);
+                FileUtils.saveFile(fo);
                 // XXX remove once #213141 is fixed
                 try {
                     Thread.sleep(1000);
