@@ -223,8 +223,10 @@ public class SftpClient implements RemoteClient {
             Connector con = ConnectorFactory.getInstance().createConnector(ConnectorFactory.ConnectorKind.ANY);
             if (con != null) {
                 IdentityRepository irepo = new IdentityRepositoryImpl(con);
-                jsch.setIdentityRepository(irepo);
-                agentUsed = true;
+                if (irepo.getStatus() == IdentityRepository.RUNNING) {
+                    jsch.setIdentityRepository(irepo);
+                    agentUsed = true;
+                }
             }
         }
         if (!agentUsed) {
@@ -859,7 +861,8 @@ public class SftpClient implements RemoteClient {
 
         @Override
         public int getStatus() {
-            return connector.isAvailable() ? IdentityRepository.RUNNING : IdentityRepository.UNAVAILABLE;
+            return connector.isAvailable()
+                    && proxy.isRunning() ? IdentityRepository.RUNNING : IdentityRepository.UNAVAILABLE;
         }
 
         @Override
