@@ -56,10 +56,10 @@ import javax.swing.JComboBox;
 import javax.swing.JTextField;
 import javax.swing.MutableComboBoxModel;
 import javax.swing.UIManager;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.StaticResource;
 import org.netbeans.api.project.ProjectUtils;
-import org.netbeans.api.project.ui.ProjectProblems;
 import org.netbeans.modules.php.api.PhpVersion;
 import org.netbeans.modules.php.api.util.FileUtils;
 import org.netbeans.modules.php.api.util.StringUtils;
@@ -69,8 +69,6 @@ import org.netbeans.modules.php.project.PhpVisibilityQuery;
 import org.netbeans.modules.php.project.ProjectPropertiesSupport;
 import org.netbeans.modules.php.project.ui.options.PhpOptionsPanelController;
 import org.netbeans.spi.project.support.ant.PropertyUtils;
-import org.openide.DialogDisplayer;
-import org.openide.NotifyDescriptor;
 import org.openide.filesystems.FileChooserBuilder;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
@@ -99,22 +97,6 @@ public final class Utils {
     private Utils() {
     }
 
-    @NbBundle.Messages({
-        "# {0} - project name",
-        "Utils.metadata.corrupted=<html><b>Project {0} is corrupted.</b><br><br>Do you want to open Project Problems dialog?"
-    })
-    public static void warnInvalidSourcesDirectory(PhpProject project) {
-        String name = project.getName();
-        NotifyDescriptor descriptor = new NotifyDescriptor.Confirmation(
-                Bundle.Utils_metadata_corrupted(name),
-                name,
-                NotifyDescriptor.YES_NO_OPTION,
-                NotifyDescriptor.WARNING_MESSAGE);
-        if (DialogDisplayer.getDefault().notify(descriptor) == NotifyDescriptor.YES_OPTION) {
-            ProjectProblems.showCustomizer(project);
-        }
-    }
-
     // XXX use everywhere
     @NonNull
     public static Color getErrorForeground() {
@@ -592,6 +574,21 @@ public final class Utils {
     private static String browseSource(PhpProject project, String preselected, boolean selectDirectory) {
         FileObject rootFolder = ProjectPropertiesSupport.getSourcesDirectory(project);
         assert rootFolder != null;
+        return browseFolder(project, rootFolder, preselected, selectDirectory);
+    }
+
+    /**
+     * Browse for a directory from sources of a project and return the relative path or <code>null</code> if nothing selected.
+     * @param project project to get sources from.
+     * @param preselected the preselected value, can be null.
+     * @return the relative path to folder or <code>null</code> if nothing selected.
+     */
+    @CheckForNull
+    public static String browseFolder(PhpProject project, FileObject folder, String preselected) {
+        return browseFolder(project, folder, preselected, true);
+    }
+
+    private static String browseFolder(PhpProject project, FileObject rootFolder, String preselected, boolean selectDirectory) {
         FileObject selected = BrowseFolders.showDialog(PhpVisibilityQuery.forProject(project), new FileObject[] {rootFolder},
                 selectDirectory ? DataFolder.class : DataObject.class, securePreselected(preselected, !selectDirectory));
         if (selected != null) {
