@@ -43,7 +43,6 @@
 package org.netbeans.modules.php.project.ui.customizer;
 
 import java.awt.EventQueue;
-import java.io.File;
 import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -58,6 +57,7 @@ import javax.swing.JPanel;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.modules.editor.indent.project.api.Customizers;
+import org.netbeans.modules.php.api.documentation.PhpDocumentations;
 import org.netbeans.modules.php.api.framework.PhpFrameworks;
 import org.netbeans.modules.php.api.phpmodule.PhpModule;
 import org.netbeans.modules.php.api.testing.PhpTesting;
@@ -68,8 +68,6 @@ import org.netbeans.modules.php.project.ProjectPropertiesSupport;
 import org.netbeans.modules.php.spi.framework.PhpFrameworkProvider;
 import org.netbeans.modules.php.spi.framework.PhpModuleCustomizerExtender;
 import org.netbeans.modules.php.spi.testing.PhpTestingProvider;
-import org.netbeans.modules.web.clientproject.api.jslibs.JavaScriptLibraries;
-import org.netbeans.modules.web.clientproject.api.jslibs.JavaScriptLibrarySelectionPanel;
 import org.netbeans.modules.web.clientproject.api.jstesting.JsTestingProviders;
 import org.netbeans.modules.web.common.api.CssPreprocessors;
 import org.netbeans.spi.project.support.ant.ui.CustomizerUtilities;
@@ -90,6 +88,7 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
     public static final String IGNORE_PATH = "IgnorePath"; // NOI18N
     public static final String FRAMEWORKS = "Frameworks"; // NOI18N
     public static final String TESTING = PhpTesting.CUSTOMIZER_IDENT;
+    public static final String TESTING_SELENIUM = "SeleniumTesting"; // NOI18N
     public static final String LICENSE = "License"; // NOI18N
 
     private final String name;
@@ -113,6 +112,7 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
 
     @NbBundle.Messages({
         "CompositePanelProviderImpl.category.testing.title=Testing",
+        "CompositePanelProviderImpl.category.selenium.testing.title=Selenium Testing",
         "CompositePanelProviderImpl.category.browser.title=Browser",
         "CompositePanelProviderImpl.category.licenceHeaders.title=License Headers",
     })
@@ -174,6 +174,10 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
                     Bundle.CompositePanelProviderImpl_category_testing_title(),
                     null,
                     subcategories.toArray(new ProjectCustomizer.Category[subcategories.size()]));
+        } else if (TESTING_SELENIUM.equals(name)) {
+            toReturn = ProjectCustomizer.Category.create(TESTING_SELENIUM,
+                    Bundle.CompositePanelProviderImpl_category_selenium_testing_title(),
+                    null);
         } else if (LICENSE.equals(name)) {
             toReturn = ProjectCustomizer.Category.create(
                     LICENSE,
@@ -202,6 +206,8 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
             return new JPanel();
         } else if (TESTING.equals(nm)) {
             return new CustomizerTesting(category, uiProps, creatingTestingPanels());
+        } else if (TESTING_SELENIUM.equals(nm)) {
+            return new CustomizerSeleniumTesting(category, uiProps);
         } else if (LICENSE.equals(nm)) {
             CustomizerUtilities.LicensePanelContentHandler handler = new CustomizerUtilities.LicensePanelContentHandler() {
                 @Override
@@ -286,29 +292,6 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
         return new CompositePanelProviderImpl(BROWSER);
     }
 
-    @ProjectCustomizer.CompositeCategoryProvider.Registration(
-        projectType = UiUtils.CUSTOMIZER_PATH,
-        position = 190
-    )
-    public static ProjectCustomizer.CompositeCategoryProvider createJsFiles() {
-        return JavaScriptLibraries.createCustomizer(new JavaScriptLibraries.CustomizerSupport() {
-            @Override
-            public File getWebRoot(Lookup context) {
-                PhpProjectProperties projectProperties = context.lookup(PhpProjectProperties.class);
-                assert projectProperties != null;
-                return projectProperties.getResolvedWebRootFolder();
-            }
-            @Override
-            public void setLibrariesFolder(@NonNull Lookup context, String librariesFolder) {
-                // noop
-            }
-            @Override
-            public void setSelectedLibraries(@NonNull Lookup context, List<JavaScriptLibrarySelectionPanel.SelectedLibrary> selectedLibraries) {
-                // noop
-            }
-        });
-    }
-
     @ProjectCustomizer.CompositeCategoryProvider.Registration(
         projectType = UiUtils.CUSTOMIZER_PATH,
         position = 195
@@ -349,6 +332,14 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
         return new CompositePanelProviderImpl(TESTING);
     }
 
+    @ProjectCustomizer.CompositeCategoryProvider.Registration(
+            projectType = UiUtils.CUSTOMIZER_PATH,
+        position = 352
+    )
+    public static CompositePanelProviderImpl createSeleniumTesting() {
+        return new CompositePanelProviderImpl(TESTING_SELENIUM);
+    }
+
     @ProjectCustomizer.CompositeCategoryProvider.Registration(
             projectType = UiUtils.CUSTOMIZER_PATH,
             position = 351)
@@ -356,6 +347,13 @@ public class CompositePanelProviderImpl implements ProjectCustomizer.CompositeCa
         return JsTestingProviders.getDefault().createCustomizer();
     }
 
+    @ProjectCustomizer.CompositeCategoryProvider.Registration(
+            projectType = UiUtils.CUSTOMIZER_PATH,
+            position = 360)
+    public static ProjectCustomizer.CompositeCategoryProvider createPhpDocumentation() {
+        return PhpDocumentations.createCustomizer();
+    }
+
     @ProjectCustomizer.CompositeCategoryProvider.Registration(
         projectType = UiUtils.CUSTOMIZER_PATH,
         position = 900
