@@ -58,6 +58,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.TreeMap;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import javax.swing.DefaultListModel;
 import javax.swing.ListCellRenderer;
 import org.netbeans.api.annotations.common.CheckForNull;
@@ -92,6 +94,9 @@ import org.openide.util.Utilities;
  * @author Tomas Mysik, Radek Matous
  */
 public final class PhpProjectProperties implements ConfigManager.ConfigProvider {
+
+    private static final Logger LOGGER = Logger.getLogger(PhpProjectProperties.class.getName());
+
     public static final int DEFAULT_DEBUG_PROXY_PORT = 9001;
 
     public static final String SRC_DIR = "src.dir"; // NOI18N
@@ -135,6 +140,7 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
     public static final String LICENSE_NAME = "project.license";
     public static final String LICENSE_PATH = "project.licensePath";
     public static final String TESTING_PROVIDERS = "testing.providers";
+    public static final String AUTOCONFIGURED = "autoconfigured";
 
     public static final String DEBUG_PATH_MAPPING_SEPARATOR = "||NB||"; // NOI18N
     public static final String TESTING_PROVIDERS_SEPARATOR = ";"; // NOI18N
@@ -227,6 +233,7 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
     private final IncludePathSupport includePathSupport;
     private final IgnorePathSupport ignorePathSupport;
     private final TestDirectoriesPathSupport testDirectoriesPathSupport;
+    private final SeleniumTestDirectoriesPathSupport seleniumTestDirectoriesPathSupport;
 
     // all these fields don't have to be volatile - this ensures request processor
     // CustomizerSources
@@ -264,6 +271,9 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
     // Testing
     private DefaultListModel<BasePathSupport.Item> testDirectoriesListModel = null;
     private ListCellRenderer<BasePathSupport.Item> testDirectoriesListRenderer = null;
+    // Selenium Testing
+    private DefaultListModel<BasePathSupport.Item> seleniumTestDirectoriesListModel = null;
+    private ListCellRenderer<BasePathSupport.Item> seleniumTestDirectoriesListRenderer = null;
 
     // license
     private String licenseNameValue;
@@ -272,19 +282,22 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
     private boolean licensePathChanged = false;
     private String changedLicensePathContent;
 
+    private volatile Boolean autoconfigured = null;
+
 
     public PhpProjectProperties(PhpProject project) {
-        this(project, null, null, null);
+        this(project, null, null, null, null);
     }
 
     public PhpProjectProperties(PhpProject project, IncludePathSupport includePathSupport, IgnorePathSupport ignorePathSupport,
-            TestDirectoriesPathSupport testDirectoriesPathSupport) {
+            TestDirectoriesPathSupport testDirectoriesPathSupport, SeleniumTestDirectoriesPathSupport seleniumTestDirectoriesPathSupport) {
         assert project != null;
 
         this.project = project;
         this.includePathSupport = includePathSupport;
         this.ignorePathSupport = ignorePathSupport;
         this.testDirectoriesPathSupport = testDirectoriesPathSupport;
+        this.seleniumTestDirectoriesPathSupport = seleniumTestDirectoriesPathSupport;
 
         runConfigs = readRunConfigs();
         String currentConfig = ProjectPropertiesSupport.getPropertyEvaluator(project).getProperty("config"); // NOI18N
@@ -407,6 +420,11 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
         return srcDir;
     }
 
+    public void setSrcDir(String srcDir) {
+        assert srcDir != null;
+        this.srcDir = srcDir;
+    }
+
     public String getUrl() {
         if (url == null) {
             url = ProjectPropertiesSupport.getPropertyEvaluator(project).getProperty(URL);
@@ -494,7 +512,14 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
             List<String> values = new ArrayList<>();
             EditableProperties properties = project.getHelper().getProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH);
             for (String property : project.getTestRoots().getRootProperties()) {
-                values.add(properties.getProperty(property));
+                String value = properties.getProperty(property);
+                if (value != null) {
+                    values.add(value);
+                } else {
+                    // #250401
+                    LOGGER.log(Level.INFO, "Value must be found for property: {0}", property);
+                    assert false : String.valueOf(properties);
+                }
             }
             testDirectoriesListModel = PathUiSupport.createListModel(testDirectoriesPathSupport.itemsIterator(
                     values.toArray(new String[values.size()])));
@@ -510,6 +535,34 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
         return testDirectoriesListRenderer;
     }
 
+    public DefaultListModel<BasePathSupport.Item> getSeleniumTestDirectoriesListModel() {
+        if (seleniumTestDirectoriesListModel == null) {
+            List<String> values = new ArrayList<>();
+            EditableProperties properties = project.getHelper().getProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH);
+            for (String property : project.getSeleniumRoots().getRootProperties()) {
+                String value = properties.getProperty(property);
+                if (value != null) {
+                    values.add(value);
+                } else {
+                    // #250401
+                    LOGGER.log(Level.INFO, "Value must be found for property: {0}", property);
+                    assert false : String.valueOf(properties);
+                }
+            }
+            seleniumTestDirectoriesListModel = PathUiSupport.createListModel(seleniumTestDirectoriesPathSupport.itemsIterator(
+                    values.toArray(new String[values.size()])));
+        }
+        return seleniumTestDirectoriesListModel;
+    }
+
+    public ListCellRenderer<BasePathSupport.Item> getSeleniumTestDirectoriesListRenderer() {
+        if (seleniumTestDirectoriesListRenderer == null) {
+            seleniumTestDirectoriesListRenderer = new PathUiSupport.ClassPathListCellRenderer(ProjectPropertiesSupport.getPropertyEvaluator(project),
+                project.getProjectDirectory());
+        }
+        return seleniumTestDirectoriesListRenderer;
+    }
+
     public void addCustomizerExtender(PhpModuleCustomizerExtender customizerExtender) {
         if (customizerExtenders == null) {
             customizerExtenders = new HashSet<>();
@@ -563,6 +616,17 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
         this.testingProviders = testingProviders;
     }
 
+    public boolean isAutoconfigured() {
+        if (autoconfigured == null) {
+            autoconfigured = Boolean.parseBoolean(ProjectPropertiesSupport.getPropertyEvaluator(project).getProperty(AUTOCONFIGURED));
+        }
+        return autoconfigured;
+    }
+
+    public void setAutoconfigured(boolean autoconfigured) {
+        this.autoconfigured = autoconfigured;
+    }
+
     public void save() {
         try {
             // store properties
@@ -649,11 +713,20 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
             testDirs = testDirectoriesPathSupport.encodeToStrings(PathUiSupport.getIterator(testDirectoriesListModel), true, false);
         }
 
+        // selenium testing
+        String[] seleniumTestDirs = null;
+        if (seleniumTestDirectoriesListModel != null) {
+            seleniumTestDirs = seleniumTestDirectoriesPathSupport.encodeToStrings(PathUiSupport.getIterator(seleniumTestDirectoriesListModel), true, false);
+        }
+
         // get properties
         EditableProperties projectProperties = helper.getProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH);
         EditableProperties privateProperties = helper.getProperties(AntProjectHelper.PRIVATE_PROPERTIES_PATH);
 
         // sources
+        if (srcDir != null) {
+            projectProperties.setProperty(SRC_DIR, srcDir);
+        }
         if (copySrcFiles != null) {
             privateProperties.setProperty(COPY_SRC_FILES, copySrcFiles);
         }
@@ -719,6 +792,24 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
                 i++;
             }
         }
+        // selenium testing
+        if (seleniumTestDirs != null) {
+            // first, remove all current test dirs
+            for (String property : project.getSeleniumRoots().getRootProperties()) {
+                projectProperties.remove(property);
+            }
+            // set new ones
+            int i = 1;
+            for (String seleniumTestDir : seleniumTestDirs) {
+                String propertyName = SELENIUM_SRC_DIR;
+                if (i > 1) {
+                    // backward compatibility
+                    propertyName += i;
+                }
+                projectProperties.setProperty(propertyName, seleniumTestDir);
+                i++;
+            }
+        }
 
         // license
         if (licensePathValue != null) {
@@ -757,6 +848,14 @@ public final class PhpProjectProperties implements ConfigManager.ConfigProvider
             projectProperties.setProperty(TESTING_PROVIDERS, StringUtils.implode(testingProviders, TESTING_PROVIDERS_SEPARATOR));
         }
 
+        if (autoconfigured != null) {
+            if (autoconfigured) {
+                privateProperties.put(AUTOCONFIGURED, Boolean.TRUE.toString());
+            } else {
+                privateProperties.remove(AUTOCONFIGURED);
+            }
+        }
+
         // configs
         storeRunConfigs(projectProperties, privateProperties);
         EditableProperties ep = helper.getProperties(CONFIG_PRIVATE_PROPERTIES_PATH);
