@@ -59,18 +59,21 @@ import javax.swing.event.ChangeListener;
 import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.project.Project;
+import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
+import org.netbeans.api.project.Sources;
+import org.netbeans.api.templates.CreateDescriptor;
+import org.netbeans.modules.php.api.util.FileUtils;
+import org.netbeans.modules.php.api.util.UiUtils;
 import org.netbeans.modules.php.project.PhpProject;
 import org.netbeans.modules.php.project.PhpProjectValidator;
 import org.netbeans.modules.php.project.ProjectPropertiesSupport;
 import org.netbeans.modules.php.project.SourceRoots;
-import org.netbeans.modules.php.project.ui.Utils;
 import org.netbeans.modules.php.project.util.PhpProjectUtils;
 import org.netbeans.spi.project.ui.templates.support.Templates;
 import org.openide.WizardDescriptor;
 import org.openide.WizardDescriptor.Panel;
 import org.openide.filesystems.FileObject;
-import org.openide.loaders.CreateFromTemplateHandler;
 import org.openide.loaders.DataFolder;
 import org.openide.loaders.DataObject;
 import org.openide.util.RequestProcessor;
@@ -142,7 +145,7 @@ public final class NewFileWizardIterator implements WizardDescriptor.Asynchronou
 
         // #187374
         try {
-            PhpProjectUtils.reformatFile(createdFile);
+            FileUtils.reformatFile(createdFile);
         } catch (IOException exc) {
             LOGGER.log(Level.WARNING, exc.getMessage(), exc);
         }
@@ -152,7 +155,7 @@ public final class NewFileWizardIterator implements WizardDescriptor.Asynchronou
 
     private Map<String, Object> getTemplateParams() {
         Map<String, Object> params = new HashMap<>();
-        params.put(CreateFromTemplateHandler.FREE_FILE_EXTENSION, true);
+        params.put(CreateDescriptor.FREE_FILE_EXTENSION, true);
         params.put("namespace", wizard.getProperty(NewFileNamespacePanel.NAMESPACE)); // NOI18N
         return params;
     }
@@ -185,7 +188,7 @@ public final class NewFileWizardIterator implements WizardDescriptor.Asynchronou
             return;
         }
         if (PhpProjectValidator.isFatallyBroken(phpProject)) {
-            Utils.warnInvalidSourcesDirectory(phpProject);
+            UiUtils.warnBrokenProject(phpProject.getPhpModule());
         }
     }
 
@@ -211,6 +214,7 @@ public final class NewFileWizardIterator implements WizardDescriptor.Asynchronou
             return null;
         }
         if (!(project instanceof PhpProject)) {
+            // XXX check convertor project
             LOGGER.log(Level.WARNING, "PHP project expected but found {0}", project.getClass().getName());
             return null;
         }
@@ -339,6 +343,11 @@ public final class NewFileWizardIterator implements WizardDescriptor.Asynchronou
                 groups = PhpProjectUtils.getSourceGroups(project);
             }
         }
+        // fallback (e.g. convertor project)
+        if (groups.length == 0) {
+            // XXX check convertor project?
+            groups = ProjectUtils.getSources(project).getSourceGroups(Sources.TYPE_GENERIC);
+        }
         final BottomPanel bottomPanelForPhpProject = getBottomPanelForPhpProject();
         Templates.SimpleTargetChooserBuilder targetChooserBuilder = Templates.buildSimpleTargetChooser(project, groups);
         if (bottomPanelForPhpProject != null) {
