@@ -60,9 +60,9 @@ import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.netbeans.api.extexecution.ExecutionDescriptor;
-import org.netbeans.api.extexecution.input.InputProcessor;
-import org.netbeans.api.extexecution.input.InputProcessors;
-import org.netbeans.api.extexecution.input.LineProcessor;
+import org.netbeans.api.extexecution.base.input.InputProcessor;
+import org.netbeans.api.extexecution.base.input.InputProcessors;
+import org.netbeans.api.extexecution.base.input.LineProcessor;
 import org.netbeans.modules.php.api.executable.InvalidPhpExecutableException;
 import org.netbeans.modules.php.api.executable.PhpExecutable;
 import org.netbeans.modules.php.api.executable.PhpExecutableValidator;
@@ -171,7 +171,7 @@ public class SymfonyScript {
 
     public void runCommand(PhpModule phpModule, List<String> parameters, Runnable postExecution) {
         createPhpExecutable(phpModule)
-                .displayName(getDisplayName(phpModule, parameters.get(0)))
+                .displayName(getDisplayName(phpModule))
                 .additionalParameters(getAllParams(parameters))
                 .run(getDescriptor(postExecution));
     }
@@ -189,7 +189,7 @@ public class SymfonyScript {
 
         try {
             Future<Integer> result = createPhpExecutable(phpModule)
-                    .displayName(getDisplayName(phpModule, allParams.get(0)))
+                    .displayName(getDisplayName(phpModule))
                     .additionalParameters(getAllParams(allParams))
                     .warnUser(false)
                     .run(getDescriptor(null));
@@ -214,7 +214,7 @@ public class SymfonyScript {
         allParams.addAll(Arrays.asList(params));
 
         createPhpExecutable(phpModule)
-                .displayName(getDisplayName(phpModule, allParams.get(0)))
+                .displayName(getDisplayName(phpModule))
                 .additionalParameters(getAllParams(allParams))
                 .warnUser(false)
                 .run(getDescriptor(null));
@@ -229,7 +229,7 @@ public class SymfonyScript {
 
         HelpLineProcessor lineProcessor = new HelpLineProcessor();
         Future<Integer> result = createPhpExecutable(phpModule)
-                .displayName(getDisplayName(phpModule, allParams.get(0)))
+                .displayName(getDisplayName(phpModule))
                 .additionalParameters(getAllParams(allParams))
                 .run(getSilentDescriptor(), getOutProcessorFactory(lineProcessor));
         try {
@@ -274,11 +274,10 @@ public class SymfonyScript {
 
     @NbBundle.Messages({
         "# {0} - project name",
-        "# {1} - command",
-        "SymfonyScript.command.title={0} ({1})"
+        "SymfonyScript.command.title=Symfony ({0})"
     })
-    private String getDisplayName(PhpModule phpModule, String command) {
-        return Bundle.SymfonyScript_command_title(phpModule.getDisplayName(), command);
+    private String getDisplayName(PhpModule phpModule) {
+        return Bundle.SymfonyScript_command_title(phpModule.getDisplayName());
     }
 
     private ExecutionDescriptor getDescriptor(Runnable postExecution) {
@@ -290,8 +289,8 @@ public class SymfonyScript {
         return executionDescriptor;
     }
 
-    private ExecutionDescriptor.InputProcessorFactory getOutProcessorFactory(final LineProcessor lineProcessor) {
-        return new ExecutionDescriptor.InputProcessorFactory() {
+    private ExecutionDescriptor.InputProcessorFactory2 getOutProcessorFactory(final LineProcessor lineProcessor) {
+        return new ExecutionDescriptor.InputProcessorFactory2() {
             @Override
             public InputProcessor newInputProcessor(InputProcessor defaultProcessor) {
                 return InputProcessors.ansiStripping(InputProcessors.bridge(lineProcessor));
