@@ -43,11 +43,13 @@ package org.netbeans.modules.profiler.nbimpl.actions;
 
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Objects;
 import java.util.logging.Logger;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.lib.profiler.ProfilerLogger;
+import org.netbeans.lib.profiler.common.AttachSettings;
 import org.netbeans.lib.profiler.common.ProfilingSettings;
 import org.netbeans.lib.profiler.common.SessionSettings;
 import org.netbeans.lib.profiler.common.integration.IntegrationUtils;
@@ -55,30 +57,170 @@ import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.global.Platform;
 import org.netbeans.modules.profiler.HeapDumpWatch;
 import org.netbeans.modules.profiler.actions.ProfilingSupport;
+import org.netbeans.modules.profiler.api.GestureSubmitter;
 import org.netbeans.modules.profiler.api.JavaPlatform;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
 import org.netbeans.modules.profiler.api.ProfilerIDESettings;
+import org.netbeans.modules.profiler.api.ProjectUtilities;
 import org.netbeans.modules.profiler.api.project.ProjectProfilingSupport;
 import org.netbeans.modules.profiler.nbimpl.NetBeansProfiler;
 import org.netbeans.modules.profiler.nbimpl.providers.JavaPlatformManagerImpl;
 import org.netbeans.modules.profiler.spi.JavaPlatformProvider;
+import org.netbeans.modules.profiler.utilities.ProfilerUtils;
 import org.netbeans.modules.profiler.utils.IDEUtils;
+import org.netbeans.modules.profiler.v2.ProfilerSession;
 import org.netbeans.spi.project.ActionProvider;
 import org.netbeans.spi.project.LookupProvider.Registration.ProjectType;
 import org.netbeans.spi.project.ProjectServiceProvider;
 import org.openide.filesystems.FileObject;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.lookup.ServiceProvider;
 
 /**
  *
  * @author Jaroslav Bachorik
+ * @author Jiri Sedlacek
  */
+@NbBundle.Messages({
+    "ProfilerLauncher_unsupportedProject=Profiling not supported for {0}",
+    "ProfilerLauncher_noFeature=<html><b>No profiling feature selected.</b><br><br>Please select at least one profiling feature for the session.</html>"
+})
 public class ProfilerLauncher {
     final private static Logger LOG = Logger.getLogger(ProfilerLauncher.class.getName());
     
     final private static String AGENT_ARGS = "agent.jvmargs"; // NOI18N
     final private static String LINUX_THREAD_TIMER_KEY = "-XX:+UseLinuxPosixThreadCPUClocks"; // NOI18N
+    
+    public static final class Command {
+        private final String command;
+        public Command(String command) { this.command = command; }
+        String get() { return command; }
+    }
+    
+    @ServiceProvider(service=ProfilerSession.Provider.class)
+    public static final class SessionProvider extends ProfilerSession.Provider {
+        public ProfilerSession createSession(Lookup context) {
+            return new ProfilerSessionImpl(context);
+        }
+    }
+    
+    final private static class ProfilerSessionImpl extends ProfilerSession {
+        
+        ProfilerSessionImpl(Lookup _context) {
+            super(NetBeansProfiler.getDefaultNB(), _context);
+        }
+
+        public boolean start() {
+            final NetBeansProfiler profiler = (NetBeansProfiler)getProfiler();
+            
+            Project project = (Project)getProject();
+            profiler.setProfiledProject(project, getFile());
+            
+            final ProfilingSettings pSettings = getProfilingSettings();
+            if (pSettings == null) { // #250237 ?
+                ProfilerDialogs.displayError(Bundle.ProfilerLauncher_noFeature());
+                return false;
+            }
+            
+            if (isAttach()) {
+                final AttachSettings aSettings = getAttachSettings();
+                
+                // Log profiler usage
+                if (project == null) GestureSubmitter.logAttachExternal(pSettings, aSettings);
+                else GestureSubmitter.logAttachApp(project, pSettings, aSettings);
+                
+                ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
+                    public void run() { profiler.attachToApp(pSettings, aSettings); }
+                });
+            } else {
+                String command = normalizedCommand(getContext());
+                
+                if (!ProjectSensitivePerformer.supportsProfileProject(command, project) &&
+                    !FileSensitivePerformer.supportsProfileFile(command, getFile())) {
+                    ProfilerDialogs.displayError(Bundle.ProfilerLauncher_unsupportedProject(ProjectUtilities.getDisplayName(project)));
+                    return false;
+                }
+                
+                // Log profiler usage
+                GestureSubmitter.logProfileApp(project, pSettings);
+                
+                final Session s = newSession(command, getContext());
+                if (s != null) {
+                    s.setProfilingSettings(pSettings);
+                    s.run();
+                    
+                    // Not sure at this point if the profiling session will be started
+                    // or not (main class may be missing etc.). Let's say starting the
+                    // session has been cancelled if it's not running after 1200 ms.
+                    //
+                    // If it actually becomes alive after that time, the Profile button
+                    // will be correctly pressed again so it won't hurt user experience.
+                    int aliveCheck = Integer.getInteger("profiler.nbimpl.aliveCheck", 1200); // NOI18N
+                    profiler.checkAliveAfter(aliveCheck); // #247826 ?
+                } else {
+                    return false;
+                }
+            }
+            return true;
+        }
+
+        public boolean modify() {
+            ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
+                public void run() {
+                    getProfiler().modifyCurrentProfiling(getProfilingSettings());
+                }
+            });
+            return true;
+        }
+
+        public boolean stop() {
+            ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
+                public void run() {
+                    if (isAttach()) getProfiler().detachFromApp();
+                    else getProfiler().stopApp();
+                }
+            });
+            return true;
+        }
+        
+        protected synchronized boolean isCompatibleContext(Lookup _context) {
+            // Compare projects
+            Project _project = _context.lookup(Project.class);
+            if (!Objects.equals(getProject(), _project)) return false;
+            
+            // Command and/or file can be changed if not profiling
+            if (!inProgress()) return true;
+            
+            // Compare commands
+            String c = normalizedCommand(getContext());
+            String _c = normalizedCommand(_context);
+            if (!Objects.equals(c, _c)) return false;
+            
+            // Compare files
+            FileObject f = getContext().lookup(FileObject.class);
+            FileObject _f = _context.lookup(FileObject.class);
+            if (!Objects.equals(f, _f)) return false;
+            
+            return true;
+        }
+        
+        public Lookup.Provider getProject() {
+            return getContext().lookup(Project.class);
+        }
+        
+        public FileObject getFile() {
+            return getContext().lookup(FileObject.class);
+        }
+        
+        // Handles no command from context action in editor/navigator
+        private static String normalizedCommand(Lookup context) {
+            Command command = context.lookup(Command.class);
+            String _command = command == null ? null : command.get();
+            return _command == null ? ActionProvider.COMMAND_PROFILE : _command;
+        }
+        
+    }
 
     final public static class Session  {
         private SessionSettings ss;
@@ -194,15 +336,16 @@ public class ProfilerLauncher {
         
         public boolean configure() {
             if (ss == null || ss.getJavaExecutable() == null) return false; // No platform defined; fail
+            if (ps == null) return false; // Unsupported workflow (lazy settings not supported in this version)
             
             final ProjectProfilingSupport pSupport = ProjectProfilingSupport.get(project);
 
             NetBeansProfiler.getDefaultNB().setProfiledProject(project, fo);
 
-            // ** display select task panel
-            ProfilingSettings ps = ProfilingSupport.getDefault().selectTaskForProfiling(project, ss, fo, true);;
-            if (ps != null) {
-                this.ps = ps;
+//            // ** display select task panel
+//            ProfilingSettings ps = ProfilingSupport.getDefault().selectTaskForProfiling(project, ss, fo, true);;
+//            if (ps != null) {
+//                this.ps = ps;
                 this.ps.store(props);
                 
                 setupAgentEnv(platform, ss, ProfilerIDESettings.getInstance(), ps, project, props);
@@ -210,7 +353,7 @@ public class ProfilerLauncher {
 
                 rerun = false;
                 configured = true;
-            }
+//            }
             return configured;
         }
         
@@ -331,7 +474,7 @@ public class ProfilerLauncher {
         }
         if (project == null) return; // sanity check; we need project here
         
-        if (ProfilingSupport.getDefault().checkProfilingInProgress()) {
+        if (ProfilingSupport.checkProfilingInProgress()) {
             return;
         }
         
