@@ -49,7 +49,6 @@ import org.netbeans.lib.profiler.client.ClientUtils;
 import org.netbeans.lib.profiler.common.Profiler;
 import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
 import org.netbeans.modules.profiler.LoadedSnapshot;
-import org.netbeans.modules.profiler.ProfilerControlPanel2;
 import org.netbeans.modules.profiler.ResultsManager;
 import org.netbeans.modules.profiler.ppoints.ui.TriggeredTakeSnapshotCustomizer;
 import org.netbeans.modules.profiler.ppoints.ui.ValidityAwarePanel;
@@ -77,9 +76,10 @@ import javax.swing.SwingUtilities;
 import javax.swing.border.TitledBorder;
 import org.netbeans.lib.profiler.ui.UIUtils;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
-import org.netbeans.modules.profiler.api.project.ProjectStorage;
+import org.netbeans.modules.profiler.api.ProfilerStorage;
 import org.netbeans.modules.profiler.api.ProjectUtilities;
 import org.netbeans.modules.profiler.ppoints.ui.ProfilingPointReport;
+import org.netbeans.modules.profiler.v2.SnapshotsWindow;
 import org.openide.util.Lookup;
 import org.openide.ErrorManager;
 
@@ -504,7 +504,7 @@ public final class TriggeredTakeSnapshotProfilingPoint extends TriggeredGlobalPr
     // ---
     FileObject getSnapshotDirectory() throws IOException {
         if (snapshotTarget.equals(TARGET_PROJECT_KEY)) {
-            return ProjectStorage.getSettingsFolder(getProject(), true);
+            return ProfilerStorage.getProjectFolder(getProject(), true);
         } else {
             File f = new File(snapshotFile);
             f.mkdirs();
@@ -614,11 +614,14 @@ public final class TriggeredTakeSnapshotProfilingPoint extends TriggeredGlobalPr
         }
 
         if (heapdumpTaken) {
-            if (ProfilerControlPanel2.hasDefault())
-                ProfilerControlPanel2.getDefault().refreshSnapshotsList();
+//            if (ProfilerControlPanel2.hasDefault())
+//                ProfilerControlPanel2.getDefault().refreshSnapshotsList();
 
             try {
-                return new File(dumpFileName).toURI().toURL().toExternalForm();
+                File file = new File(dumpFileName);
+                FileObject folder = FileUtil.toFileObject(file.getParentFile());
+                SnapshotsWindow.instance().refreshFolder(folder, true);
+                return file.toURI().toURL().toExternalForm();
             } catch (MalformedURLException ex) {
                 ProfilerLogger.log(ex);
 
