@@ -44,6 +44,7 @@
 
 package org.netbeans.modules.project.libraries;
 
+import org.netbeans.spi.project.libraries.WritableLibraryProvider;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.io.CharConversionException;
@@ -52,6 +53,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.URL;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
@@ -60,6 +62,7 @@ import java.util.ResourceBundle;
 import java.util.Set;
 import java.util.StringTokenizer;
 import java.util.TreeSet;
+import java.util.concurrent.Callable;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.event.ChangeEvent;
@@ -138,6 +141,7 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
         try {
             return FileUtil.createFolder(FileUtil.getConfigRoot(), LIBRARIES_REPOSITORY);
         } catch (IOException e) {
+            Exceptions.printStackTrace(e);
             return null;
         }
     }
@@ -183,7 +187,7 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
                             }
                             librariesByFileNames.put(descriptorFile.getPath(),impl);
                             libraries.put (impl.getName(),impl);
-                            Util.registerSource(impl, descriptorFile);
+                            LibrariesModule.registerSource(impl, descriptorFile);
                         }
                     }
                 } catch (SAXException e) {
@@ -212,6 +216,8 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
         }
     }
 
+    @NonNull
+    @SuppressWarnings("NestedAssignment")
     private Libs initStorage (final boolean reset) {
         synchronized (this) {
             if (!initialized) {
@@ -231,8 +237,9 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
             }
         }
         boolean success = false;
-        final Map<String,LibraryImplementation> libraries = new HashMap<String, LibraryImplementation>();
-        final Map<String,LibraryImplementation> librariesByFileNames = new HashMap<String, LibraryImplementation>();
+        final Map<String,LibraryImplementation> libraries = new HashMap<>();
+        final Map<String,LibraryImplementation> librariesByFileNames = new HashMap<>();
+        Libs res;
         try {
             this.loadFromStorage(libraries, librariesByFileNames);
             success = true;
@@ -242,11 +249,13 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
                     inchange = false;
                 }
                 if (success) {
-                    this.libs = new Libs(libraries,librariesByFileNames);
+                    res = this.libs = new Libs(libraries,librariesByFileNames);
+                } else {
+                    res = new Libs(Collections.<String, LibraryImplementation>emptyMap(),Collections.<String, LibraryImplementation>emptyMap());
                 }
-                return libs;
             }
         }
+        return res;
     }
 
     private static LibraryImplementation readLibrary (FileObject descriptorFile) throws SAXException, ParserConfigurationException, IOException{
@@ -259,20 +268,36 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
         final LibraryDeclarationParser parser = new LibraryDeclarationParser(handler,convertor);
         handler.setLibrary (impl);
         readLibrary (descriptorFile, parser);
-        Util.registerSource(impl, descriptorFile);
+        LibrariesModule.registerSource(impl, descriptorFile);
         return handler.getLibrary();
     }
 
-    private static void readLibrary (FileObject descriptorFile, LibraryDeclarationParser parser) throws SAXException, ParserConfigurationException, IOException {
-        final URL baseURL = descriptorFile.toURL();
-        InputSource input = new InputSource(baseURL.toExternalForm());        
-        try (InputStream in = descriptorFile.getInputStream()) {
-            input.setByteStream(in); // #33554 workaround
-            parser.parse(input);
-        } catch (SAXException e) {
-            throw Exceptions.attachMessage(e, "From: " + baseURL);  //NOI18N
-        } catch (IOException e) {
-            throw Exceptions.attachMessage(e, "From: " + baseURL);  //NOI18N
+    private static void readLibrary (
+            @NonNull final FileObject descriptorFile,
+            @NonNull final LibraryDeclarationParser parser) throws SAXException, ParserConfigurationException, IOException {
+        try {
+            FileLockManager.getDefault().readAction(
+                descriptorFile,
+                new Callable<Void>() {
+                    @Override
+                    public Void call() throws IOException, ParserConfigurationException, SAXException {
+                        final URL baseURL = descriptorFile.toURL();
+                        final InputSource input = new InputSource(baseURL.toExternalForm());
+                        try (InputStream in = descriptorFile.getInputStream()) {
+                            input.setByteStream(in); // #33554 workaround
+                            parser.parse(input);
+                        } catch (SAXException e) {
+                            throw Exceptions.attachMessage(e, "From: " + baseURL);  //NOI18N
+                        } catch (IOException e) {
+                            throw Exceptions.attachMessage(e, "From: " + baseURL);  //NOI18N
+                        }
+                        return null;
+                    }
+                });
+        } catch (IOException | ParserConfigurationException | SAXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw new RuntimeException(e);
         }
     }
 
@@ -326,14 +351,15 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
 
 
     @Override
-    public void addLibrary (LibraryImplementation library) throws IOException {
+    public boolean addLibrary (LibraryImplementation library) throws IOException {
         this.initStorage(false);
         assert this.storage != null : "Storage is not initialized";
         writeLibrary(this.storage,library);
+        return true;
     }
 
     @Override
-    public void removeLibrary (LibraryImplementation library) throws IOException {
+    public boolean removeLibrary (LibraryImplementation library) throws IOException {
         final Libs data = this.initStorage(false);
         assert this.storage != null : "Storage is not initialized";
         final String path = data.findPath(library);
@@ -342,11 +368,13 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
             if (fo != null) {
                 fo.delete();
             }
+            return true;
         }
+        return false;
     }
 
     @Override
-    public void updateLibrary(final LibraryImplementation oldLibrary, final LibraryImplementation newLibrary) throws IOException {
+    public boolean updateLibrary(final LibraryImplementation oldLibrary, final LibraryImplementation newLibrary) throws IOException {
         final Libs data = this.initStorage(false);
         assert this.storage != null : "Storage is not initialized";
         final String path = data.findPath(oldLibrary);
@@ -357,17 +385,19 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
                 final LibraryTypeProvider libraryTypeProvider = ltRegistry.getLibraryTypeProvider (libraryType);
                 if (libraryTypeProvider == null) {
                     LOG.warning("LibrariesStorageL Cannot store library, the library type is not recognized by any of installed LibraryTypeProviders.");	//NOI18N
-                    return;
-                }
-                this.storage.getFileSystem().runAtomicAction(
-                        new FileSystem.AtomicAction() {
-                            public void run() throws IOException {
-                                LibraryDeclarationParser.writeLibraryDefinition (fo, newLibrary, libraryTypeProvider);
+                } else {
+                    this.storage.getFileSystem().runAtomicAction(
+                            new FileSystem.AtomicAction() {
+                                public void run() throws IOException {
+                                    LibraryDeclarationParser.writeLibraryDefinition (fo, newLibrary, libraryTypeProvider);
+                                }
                             }
-                        }
-                );
+                    );
+                }
+                return true;
             }
         }
+        return false;
     }
 
 
@@ -490,13 +520,8 @@ implements WritableLibraryProvider<LibraryImplementation>, ChangeListener {
                 FileObject parent = storage.getParent();
                 FileObject timeStampFile = FileUtil.createData(parent,TIME_STAMPS_FILE);
                 FileLock lock = timeStampFile.lock();
-                try {
-                    OutputStream out = timeStampFile.getOutputStream(lock);
-                    try {
-                        timeStamps.store (out, null);
-                    } finally {
-                        out.close();
-                    }
+                try (final OutputStream out = timeStampFile.getOutputStream(lock)) {
+                    timeStamps.store (out, null);
                 } finally {
                     lock.releaseLock();
                 }
