@@ -52,15 +52,16 @@ import java.net.URI;
 import java.net.URL;
 import java.util.List;
 import java.util.Map;
-import java.util.Properties;
 import java.util.Stack;
+import java.util.concurrent.Callable;
 import java.util.concurrent.atomic.AtomicBoolean;
 import javax.xml.parsers.ParserConfigurationException;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.annotations.common.NullAllowed;
-import org.netbeans.modules.project.libraries.ui.LibrariesModel;
 import org.netbeans.spi.project.libraries.LibraryImplementation;
 import org.netbeans.spi.project.libraries.LibraryTypeProvider;
+import org.netbeans.spi.project.libraries.support.LibrariesSupport;
+import org.openide.filesystems.FileLock;
 import org.openide.filesystems.FileObject;
 import org.openide.xml.XMLUtil;
 import org.w3c.dom.Document;
@@ -249,7 +250,7 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
         final String here = (String) ctx[0];
         final String ns = (String) ctx[1];
         Attributes attrs = (Attributes) ctx[2];
-        if (!expectedNS.equals(ns)) {
+        if (expectedNS == null || !expectedNS.equals(ns)) {
             throw new SAXException("Invalid librray descriptor namespace"); // NOI18N
         }
         if (DESCRIPTION.equals(here)) {
@@ -352,16 +353,30 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
             final @NonNull LibraryImplementation library,
             final @NonNull LibraryTypeProvider libraryTypeProvider) throws IOException {
         validateLibraryContent(library, libraryTypeProvider);
-        final Document doc = Util.supportsDisplayName(library) ?
-                (Util.supportsProperties(library) ?
+        final Document doc = LibrariesSupport.supportsDisplayName(library) ?
+                (LibrariesSupport.supportsProperties(library) ?
                     createLibraryDefinition3(library, libraryTypeProvider) :
                     createLibraryDefinition2(library, libraryTypeProvider)) :
                 createLibraryDefinition1(library, libraryTypeProvider);
-        final OutputStream os = definitionFile.getOutputStream();
         try {
-            XMLUtil.write(doc, os, "UTF-8"); // NOI18N
-        } finally {
-            os.close();
+            FileLockManager.getDefault().writeAction(
+                definitionFile,
+                new Callable<Void>() {
+                    @Override
+                    public Void call() throws IOException {
+                        final FileLock lck = definitionFile.lock();
+                        try (OutputStream os = definitionFile.getOutputStream(lck)) {
+                            XMLUtil.write(doc, os, "UTF-8"); // NOI18N
+                        } finally {
+                            lck.releaseLock();
+                        }
+                        return null;
+                    }
+                });
+        } catch (IOException ioe) {
+            throw ioe;
+        } catch (Exception e) {
+            throw new RuntimeException(e);
         }
     }
 
@@ -376,7 +391,9 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
             @NonNull final LibraryImplementation library,
             @NonNull final LibraryTypeProvider libraryTypeProvider) {
         for (String vtype : libraryTypeProvider.getSupportedVolumeTypes()) {
-            LibrariesModel.convertURLsToURIs(library.getContent(vtype));
+            LibrariesSupport.convertURLsToURIs(
+                library.getContent(vtype),
+                LibrariesSupport.ConversionMode.FAIL);
         }
     }
 
@@ -398,7 +415,7 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
         if (localizingBundle != null && localizingBundle.length() > 0) {
             libraryE.appendChild(doc.createElement(BUNDLE)).appendChild(doc.createTextNode(localizingBundle)); // NOI18N
         }
-        String displayname = Util.getDisplayName(library);
+        String displayname = LibrariesSupport.getDisplayName(library);
         if (displayname != null) {
             libraryE.appendChild(doc.createElement(DISPLAY_NAME)).appendChild(doc.createTextNode(displayname)); // NOI18N
         }
@@ -432,7 +449,7 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
         if (localizingBundle != null && localizingBundle.length() > 0) {
             libraryE.appendChild(doc.createElementNS(LIBRARY_NS2, BUNDLE)).appendChild(doc.createTextNode(localizingBundle)); // NOI18N
         }
-        String displayname = Util.getDisplayName(library);
+        String displayname = LibrariesSupport.getDisplayName(library);
         if (displayname != null) {
             libraryE.appendChild(doc.createElementNS(LIBRARY_NS2, DISPLAY_NAME)).appendChild(doc.createTextNode(displayname)); // NOI18N
         }
@@ -465,7 +482,7 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
         if (localizingBundle != null && localizingBundle.length() > 0) {
             libraryE.appendChild(doc.createElementNS(LIBRARY_NS3, BUNDLE)).appendChild(doc.createTextNode(localizingBundle)); // NOI18N
         }
-        String displayname = Util.getDisplayName(library);
+        String displayname = LibrariesSupport.getDisplayName(library);
         if (displayname != null) {
             libraryE.appendChild(doc.createElementNS(LIBRARY_NS3, DISPLAY_NAME)).appendChild(doc.createTextNode(displayname)); // NOI18N
         }
@@ -479,7 +496,7 @@ public class LibraryDeclarationParser implements ContentHandler, EntityResolver
                 }
             }
         }
-        final Map<String,String> properties = Util.getProperties(library);
+        final Map<String,String> properties = LibrariesSupport.getProperties(library);
         assert properties != null : "LibraryImplementation: " + library + " returned null properties."; //NOI18N
         final Element propertiesNode = (Element) libraryE.appendChild(doc.createElementNS(LIBRARY_NS3, PROPERTIES));
         for (Map.Entry<String,String> e : properties.entrySet()) {
