@@ -51,6 +51,7 @@ import java.io.CharConversionException;
 import java.io.IOException;
 import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
+import java.net.URI;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -66,6 +67,9 @@ import java.util.logging.Logger;
 import javax.swing.Action;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.netbeans.api.annotations.common.CheckForNull;
+import org.netbeans.api.annotations.common.NonNull;
+import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.annotations.common.StaticResource;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
@@ -75,7 +79,9 @@ import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
 import org.netbeans.spi.project.ActionProvider;
+import org.netbeans.spi.project.FileOwnerQueryImplementation;
 import org.netbeans.spi.project.ui.LogicalViewProvider;
+import org.netbeans.spi.project.ui.support.ProjectConvertors;
 import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileChangeListener;
 import org.openide.filesystems.FileEvent;
@@ -84,6 +90,7 @@ import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileStatusEvent;
 import org.openide.filesystems.FileStatusListener;
 import org.openide.filesystems.FileSystem;
+import org.openide.filesystems.FileUIUtils;
 import org.openide.filesystems.FileUtil;
 import org.openide.nodes.AbstractNode;
 import org.openide.nodes.Children;
@@ -100,6 +107,7 @@ import org.openide.util.WeakListeners;
 import org.openide.util.WeakSet;
 import org.openide.util.lookup.Lookups;
 import org.openide.util.lookup.ProxyLookup;
+import org.openide.util.lookup.ServiceProvider;
 import org.openide.xml.XMLUtil;
 
 /** Root node for list of open projects
@@ -171,16 +179,20 @@ public class ProjectsRootNode extends AbstractNode {
 
         assert ((ch.type == LOGICAL_VIEW) || (ch.type == PHYSICAL_VIEW));
         // Speed up search in case we have an owner project - look in its node first.
-        Project ownerProject = FileOwnerQuery.getOwner(target);
-        for (int lookOnlyInOwnerProject = (ownerProject != null) ? 0 : 1; lookOnlyInOwnerProject < 2; lookOnlyInOwnerProject++) {
-            for (Node node : ch.getNodes(true)) {
-                Project p = node.getLookup().lookup(Project.class);
-                assert p != null : "Should have had a Project in lookup of " + node;
-                if (lookOnlyInOwnerProject == 0 && p != ownerProject) {
-                    continue; // but try again (in next outer loop) as a fallback
-                }
-                Node n = null;
-                if (ch.type == LOGICAL_VIEW) {
+        Project ownerProject = findProject(target);
+        final SelectInProjectFileOwnerQueryImpl foq = SelectInProjectFileOwnerQueryImpl.getInstance();
+        if (foq != null) {
+            foq.setCurrentProject(target, ownerProject);
+        }
+        try {
+            for (int lookOnlyInOwnerProject = (ownerProject != null) ? 0 : 1; lookOnlyInOwnerProject < 2; lookOnlyInOwnerProject++) {
+                for (Node node : ch.getNodes(true)) {
+                    Project p = node.getLookup().lookup(Project.class);
+                    assert p != null : "Should have had a Project in lookup of " + node;
+                    if (lookOnlyInOwnerProject == 0 && p != ownerProject) {
+                        continue; // but try again (in next outer loop) as a fallback
+                    }
+                    Node n = null;
                     LogicalViewProvider lvp = p.getLookup().lookup(LogicalViewProvider.class);
                     if (lvp != null) {
                         // XXX (cf. #63554): really should be calling this on DataObject usually, since
@@ -188,15 +200,20 @@ public class ProjectsRootNode extends AbstractNode {
                         // ...but it is not clear who has implemented findPath to assume FileObject!
                         n = lvp.findPath(node, target);
                     }
-                } else if (ch.type == PHYSICAL_VIEW){
-                    PhysicalView.PathFinder pf = node.getLookup().lookup(PhysicalView.PathFinder.class);
-                    if ( pf != null ) {
-                        n = pf.findPath(node, target);
+                    if (n == null && ch.type == PHYSICAL_VIEW) {
+                        PhysicalView.PathFinder pf = node.getLookup().lookup(PhysicalView.PathFinder.class);
+                        if ( pf != null ) {
+                            n = pf.findPath(node, target);
+                        }
+                    }
+                    if ( n != null ) {
+                        return n;
                     }
                 }
-                if ( n != null ) {
-                    return n;
-                }
+            }
+        } finally {
+            if (foq != null) {
+                foq.clearCurrentProject();
             }
         }
         return null;
@@ -220,7 +237,24 @@ public class ProjectsRootNode extends AbstractNode {
             }
         }
     }
-    
+
+    @CheckForNull
+    private static Project findProject(@NonNull final FileObject target) {
+        Project owner = FileOwnerQuery.getOwner(target);
+        if (owner != null && ProjectConvertors.isConvertorProject(owner)) {
+            FileObject dir = owner.getProjectDirectory().getParent();
+            while (dir != null) {
+                Project p = FileOwnerQuery.getOwner(dir);
+                if (p != null && !ProjectConvertors.isConvertorProject(p)) {
+                    owner = p;
+                    break;
+                }
+                dir = dir.getParent();
+            }
+        }
+        return owner;
+    }
+
     private static class Handle implements Node.Handle {
 
         private static final long serialVersionUID = 78374332058L;
@@ -739,7 +773,7 @@ public class ProjectsRootNode extends AbstractNode {
             String original = super.getDisplayName();
             if (files != null && files.iterator().hasNext()) {
                 try {
-                    original = files.iterator().next().getFileSystem().getStatus().annotateName(original, files);
+                    original = files.iterator().next().getFileSystem().getDecorator().annotateName(original, files);
                 } catch (FileStateInvalidException e) {
                     LOG.log(Level.INFO, null, e);
                 }
@@ -752,7 +786,7 @@ public class ProjectsRootNode extends AbstractNode {
             String original = super.getDisplayName();
             if (files != null && files.iterator().hasNext()) {
                 try {
-                    original = files.iterator().next().getFileSystem().getStatus().annotateName(original, files);
+                    original = files.iterator().next().getFileSystem().getDecorator().annotateName(original, files);
                 } catch (FileStateInvalidException e) {
                     LOG.log(Level.INFO, null, e);
                 }
@@ -781,13 +815,10 @@ public class ProjectsRootNode extends AbstractNode {
             }
             if (files != null && files.iterator().hasNext()) {
                 try {
-                    FileSystem.Status stat = files.iterator().next().getFileSystem().getStatus();
-                    if (stat instanceof FileSystem.HtmlStatus) {
-                        FileSystem.HtmlStatus hstat = (FileSystem.HtmlStatus) stat;
-                        String annotatedMagic = hstat.annotateNameHtml(MAGIC, files);
-                        if (annotatedMagic != null) {
-                            htmlName = annotatedMagic.replace(MAGIC, htmlName);
-                        }
+                    String annotatedMagic = files.iterator().next().getFileSystem().
+                            getDecorator().annotateNameHtml(MAGIC, files);
+                    if (annotatedMagic != null) {
+                        htmlName = annotatedMagic.replace(MAGIC, htmlName);
                     }
                 } catch (FileStateInvalidException e) {
                     LOG.log(Level.INFO, null, e);
@@ -809,7 +840,7 @@ public class ProjectsRootNode extends AbstractNode {
                 if (files != null && files.iterator().hasNext()) {
                     try {
                         FileObject fo = files.iterator().next();
-                        img = fo.getFileSystem().getStatus().annotateIcon(img, type, files);
+                        img = FileUIUtils.getImageDecorator(fo.getFileSystem()).annotateIcon(img, type, files);
                     } catch (FileStateInvalidException e) {
                         LOG.log(Level.INFO, null, e);
                     }
@@ -918,4 +949,63 @@ public class ProjectsRootNode extends AbstractNode {
             return getLookups().length > 1;
         }
     } // end of BadgingLookup
+
+    /**
+     * The {@link FileOwnerQueryImplementation} returning the first non artificial project owner
+     * for {@link LogicalViewProvider#findPath}.
+     * This {@link FileOwnerQueryImplementation} removes a need for {@link Project}'s {@link LogicalViewProvider}s
+     * to ignore the artificial projects as done in {@link ProjectsRootNode#findProject}.
+     * Needs to have the higher priority than the SimpleFileOwnerQueryImplementation.
+     */
+    @ServiceProvider(service = FileOwnerQueryImplementation.class, position = 10)
+    public static final class SelectInProjectFileOwnerQueryImpl implements FileOwnerQueryImplementation {
+
+        private final ThreadLocal<Object[]> current = new ThreadLocal<Object[]>();
+
+        @Override
+        @CheckForNull
+        public Project getOwner(final URI file) {
+            final Object[] currentTuple = current.get();
+            if (currentTuple != null) {
+                Object currentUri = currentTuple[1];
+                if (currentUri == null) {
+                     currentTuple[1] = currentUri = ((FileObject)currentTuple[0]).toURI();
+                }
+                if (currentUri.equals(file)) {
+                    return (Project) currentTuple[2];
+                }
+            }
+            return null;
+        }
+
+        @Override
+        public Project getOwner(final FileObject file) {
+            final Object[] currentTuple = current.get();
+            if (currentTuple != null && currentTuple[0].equals(file)) {
+                return (Project) currentTuple[2];
+            }
+            return null;
+        }
+
+        private void setCurrentProject(
+                @NonNull final FileObject fo,
+                @NullAllowed final Project prj) {
+            assert fo != null;
+            current.set(new Object[]{fo, null, prj});
+        }
+
+        private void clearCurrentProject() {
+            current.remove();
+        }
+
+        @CheckForNull
+        private static SelectInProjectFileOwnerQueryImpl getInstance() {
+            for (FileOwnerQueryImplementation impl : Lookup.getDefault().lookupAll(FileOwnerQueryImplementation.class)) {
+                if (SelectInProjectFileOwnerQueryImpl.class == impl.getClass()) {
+                    return SelectInProjectFileOwnerQueryImpl.class.cast(impl);
+                }
+            }
+            return null;
+        }
+    }
 }
