@@ -682,7 +682,8 @@ public class PropertiesOpen extends CloneableOpenSupport
                     dataObj = (PropertiesDataObject) evt.getSource();
                 }
                 if (dataObj != null) {
-                    if (dataObj.getCookieSet0().getCookie(OpenCookie.class) != dataObj.getOpenSupport()) {
+                    OpenCookie cookie = dataObj.getCookieSet0().getCookie(OpenCookie.class);
+                    if (cookie != dataObj.getOpenSupport()) {
                         PropertyChangeListener l = weakEnvPropListeners.remove(dataObj);
                         VetoableChangeListener v = weakEnvVetoListeners.remove(dataObj);
                         if (l!=null) {
@@ -691,6 +692,10 @@ public class PropertiesOpen extends CloneableOpenSupport
                         if (v!=null) {
                             dataObj.removeVetoableChangeListener(v);
                         }
+                        // remove old open cookie
+                        if (cookie != null) {
+                            dataObj.getCookieSet0().remove(cookie);
+                        }
                         //Adds new OpenCookie to this dataObj
                         dataObj.getCookieSet0().add(dataObj.getOpenSupport());
                         if (dataObj.getBundleStructure().getEntryCount()>1) {
@@ -707,7 +712,8 @@ public class PropertiesOpen extends CloneableOpenSupport
                     dataObj = (PropertiesDataObject) evt.getSource();
                 }
                 if (dataObj != null) {
-                    if (dataObj.getCookieSet0().getCookie(OpenCookie.class) != dataObj.getOpenSupport()) {
+                    OpenCookie cookie = dataObj.getCookieSet0().getCookie(OpenCookie.class);
+                    if (cookie != dataObj.getOpenSupport()) {
                         PropertyChangeListener l = weakEnvPropListeners.remove(dataObj);
                         VetoableChangeListener v = weakEnvVetoListeners.remove(dataObj);
                         if (l!=null) {
@@ -716,6 +722,10 @@ public class PropertiesOpen extends CloneableOpenSupport
                         if (v!=null) {
                             dataObj.removeVetoableChangeListener(v);
                         }
+                        // remove old open cookie
+                        if (cookie != null) {
+                            dataObj.getCookieSet0().remove(cookie);
+                        }
                         //Adds new OpenCookie to this dataObj
                         dataObj.getCookieSet0().add(dataObj.getOpenSupport());
                         if (dataObj.getBundleStructure().getEntryCount()>1) {
