@@ -178,7 +178,7 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
             ui.getRefactoring().addProgressListener(fuListener = new FUListener());
         }
         initialize();
-        updateFilters();
+        updateFilters(false);
         refresh(false);
     }
     
@@ -245,6 +245,25 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
         validate();
         inited=true;
     }
+    
+    @Override
+    public boolean requestFocusInWindow() {
+        boolean value = super.requestFocusInWindow();
+        if(this.tree != null) {
+            return this.tree.requestFocusInWindow();
+        } else {
+            return value;
+        }
+    }
+
+    //#41258: In the SDI, requestFocus is called rather than requestFocusInWindow:
+    @Override
+    public void requestFocus() {
+        super.requestFocus();
+        if(this.tree != null) {
+            this.tree.requestFocus();
+        }
+    }
 
     /**
      * Returns the toolbar. In this default implementation, toolbar is
@@ -655,10 +674,12 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
     private void refresh(final boolean showParametersPanel) {
         checkEventThread();
         boolean scanning = IndexingManager.getDefault().isIndexing();
+        boolean resetFilters = showParametersPanel;
         if (showParametersPanel) {
             // create parameters panel for refactoring
             if (parametersPanel == null) {
                 parametersPanel = new ParametersPanel(ui);
+                resetFilters = false;
             }
             // show parameters dialog
             RefactoringSession tempSession = parametersPanel.showDialog();
@@ -692,7 +713,7 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
         final AtomicBoolean sizeIsApproximate = new AtomicBoolean();
         initialize();
         if(showParametersPanel) {
-            updateFilters();
+            updateFilters(resetFilters);
         }
 
         cancelRequest.set(false);
@@ -748,12 +769,10 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
                         setupInstantTree(root, showParametersPanel);
                     }
                     
-                    if (isQuery) {
-                        if (!showParametersPanel) {
-                            progressHandle.start();
-                        }
-                    } else {
+                    if (!isQuery) {
                         progressHandle.start(elements.size()/10);
+                    } else {
+                        progressHandle.start();
                     }
 
                     int i=0;
@@ -762,12 +781,11 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
                         //[retouche]                    JavaModel.getJavaRepository().beginTrans(false);
                         try {
                             // ui.getRefactoring().setClassPath();
-                            boolean progressStarted = false;
                             for (Iterator it = elements.iterator(); it.hasNext();i++) {
                                 final RefactoringElement e = (RefactoringElement) it.next();
                                 TreeElement treeElement = null;
                                 if(callback != null || // #217986, not really nice
-                                        e.include(filtersManager)) {
+                                        filtersManager == null || e.include(filtersManager)) {
                                     treeElement = TreeElementFactory.getTreeElement(e);
                                     createNode(treeElement, nodes, root);
                                 } else {
@@ -783,10 +801,6 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
                                     }
                                     final boolean finished = session!= null? APIAccessor.DEFAULT.isFinished(session) : true;
                                     final boolean last = !it.hasNext();
-                                    if (!progressStarted && (finished || last)) {
-                                        progressStarted = true;
-                                        progressHandle.start();
-                                    }
                                     if ((occurrences % 10 == 0 && !finished) || last) {
                                         SwingUtilities.invokeLater(new Runnable() {
                                             @Override
@@ -833,7 +847,7 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
                                 stopButton.setVisible(false);
                                 refreshButton.setVisible(true);
                                 if(showParametersPanel) {
-                                    updateFilters();
+                                    updateFilters(false);
                                 }
                             }
                         });
@@ -1112,7 +1126,7 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
         prefs.putInt(PREF_VIEW_TYPE, currentView);
     }
 
-    private void updateFilters() {
+    private void updateFilters(boolean reset) {
         if(!ui.isQuery() || callback != null) {
             if(filterBar != null) {
                 toolbars.remove(filterBar);
@@ -1127,7 +1141,11 @@ public class RefactoringPanel extends JPanel implements FiltersManagerImpl.Filte
             filterBar = null;
             filtersManager = null;
         }
-        final FiltersDescription desc = APIAccessor.DEFAULT.getFiltersDescription(ui.getRefactoring());
+        AbstractRefactoring refactoring = ui.getRefactoring();
+        if(reset) {
+            APIAccessor.DEFAULT.resetFiltersDescription(refactoring);
+        }
+        final FiltersDescription desc = APIAccessor.DEFAULT.getFiltersDescription(refactoring);
         filtersManager = FiltersManagerImpl.create(desc == null? new FiltersDescription() : desc);
         filterBar = filtersManager.getComponent();
         toolbars.add(filterBar, BorderLayout.EAST);
