@@ -416,14 +416,31 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
         for (int i = 0; i < pi.length; i++) {
             int originalIndex = pi[i].getOriginalIndex();
             VariableTree vt;
+            boolean isVarArgs = i == pi.length -1 && pi[i].getType().endsWith("..."); // NOI18N
+            String newType = isVarArgs? pi[i].getType().replace("...", "") : pi[i].getType(); //NOI18N
             if (originalIndex < 0) {
-                boolean isVarArgs = i == pi.length -1 && pi[i].getType().endsWith("..."); // NOI18N
                 vt = make.Variable(make.Modifiers(Collections.<Modifier>emptySet()),
                         pi[i].getName(),
-                        skipType? null : make.Identifier(isVarArgs? pi[i].getType().replace("...", "") : pi[i].getType()), // NOI18N
+                        skipType? null : make.Identifier(newType), // NOI18N
                         null);
             } else {
                 vt = currentParameters.get(originalIndex);
+                if(!skipType) {
+                    Tree typeTree = null;
+                    if (origMethod != null) {
+                        if (!pi[i].getType().equals(origMethod.getParameters().get(originalIndex).getType().toString())) {
+                            typeTree = make.Identifier(newType);
+                        }
+                    } else {
+                        typeTree = make.Identifier(newType);
+                    }
+                    if(typeTree != null) {
+                        vt = make.Variable(vt.getModifiers(),
+                                vt.getName(),
+                                typeTree,
+                                vt.getInitializer());
+                    }
+                }
             }
             arguments.add(vt);
         }
@@ -580,6 +597,22 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
             List<? extends VariableTree> currentParameters = current.getParameters();
             List<VariableTree> newParameters = new ArrayList<VariableTree>(paramInfos.length);
             
+            boolean renameParams = !fromIntroduce;
+            
+            ExecutableElement oMethod = (ExecutableElement) el;
+            ExecutableElement refMethod = (ExecutableElement) elementToFind;
+            
+            if(oMethod != refMethod) {
+                List<? extends VariableElement> oParams = oMethod.getParameters();
+                List<? extends VariableElement> rParams = refMethod.getParameters();
+                for (int i = 0; i < oParams.size(); i++) {
+                    if(!oParams.get(i).getSimpleName().contentEquals(rParams.get(i).getSimpleName())) {
+                        renameParams = false;
+                        break;
+                    }
+                }
+            }
+            
             ParameterInfo[] p = paramInfos;
             for (int i=0; i<p.length; i++) {
                 int originalIndex = p[i].getOriginalIndex();
@@ -606,7 +639,7 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
                         typeTree = make.Identifier(newType); // NOI18N
                     }
                     vt = make.Variable(originalVt.getModifiers(),
-                            fromIntroduce? originalVt.getName() : p[i].getName(),
+                            renameParams? p[i].getName() : originalVt.getName(),
                             typeTree,
                             originalVt.getInitializer());
                 }
@@ -676,7 +709,7 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
                     }
                 }
             }
-            final BlockTree body = translateBody(current.getBody(), current.getParameters(), (ExecutableElement)el);
+            final BlockTree body = translateBody(current.getBody(), current.getParameters(), (ExecutableElement)el, renameParams);
 
             MethodTree nju = make.Method(
                     make.Modifiers(modifiers, current.getModifiers().getAnnotations()),
@@ -734,7 +767,7 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
                 DocCommentTree newDoc = make.DocComment(Collections.EMPTY_LIST, Collections.EMPTY_LIST, tags);
                 rewrite(synthConstructor? nju : tree, null, newDoc);
             }
-            rewrite(tree, nju);
+            rewrite(tree, make.asReplacementOf(nju, tree));
         }
     }
 
@@ -769,30 +802,31 @@ public class ChangeParamsTransformer extends RefactoringVisitor {
         return false;
     }
     
-    private BlockTree translateBody(BlockTree blockTree,  final List<? extends VariableTree> parameters, ExecutableElement p) {
+    private BlockTree translateBody(BlockTree blockTree,  final List<? extends VariableTree> parameters, ExecutableElement p, boolean renameParams) {
         final Map<ExpressionTree, ExpressionTree> original2Translated = new HashMap<ExpressionTree, ExpressionTree>();
         boolean changed = false;
         do {
             original2Translated.clear();
-            TreeScanner<Void, Void> idScan = new TreeScanner<Void, Void>() {
-                @Override
-                public Void visitIdentifier(IdentifierTree node, Void p) {
-                    String name = node.getName().toString();
-                    if (getCurrentPath().getParentPath().getLeaf().getKind() != Kind.MEMBER_SELECT){
-                        for (int i = 0; i < paramInfos.length; i++) {
-                            ParameterInfo parameterInfo = paramInfos[i];
-                            if(parameterInfo.getOriginalIndex() >= 0 &&
-                                    parameters.get(parameterInfo.getOriginalIndex()).getName().contentEquals(name)) {
-                                original2Translated.put(node, make.Identifier(parameterInfo.getName()));
+            if(renameParams) {
+                TreeScanner<Void, Void> idScan = new TreeScanner<Void, Void>() {
+                    @Override
+                    public Void visitIdentifier(IdentifierTree node, Void p) {
+                        String name = node.getName().toString();
+                        if (getCurrentPath().getParentPath().getLeaf().getKind() != Kind.MEMBER_SELECT){
+                            for (int i = 0; i < paramInfos.length; i++) {
+                                ParameterInfo parameterInfo = paramInfos[i];
+                                if(parameterInfo.getOriginalIndex() >= 0 &&
+                                        parameters.get(parameterInfo.getOriginalIndex()).getName().contentEquals(name)) {
+                                    original2Translated.put(node, make.Identifier(parameterInfo.getName()));
+                                }
                             }
                         }
+                        return super.visitIdentifier(node, p);
                     }
-                    return super.visitIdentifier(node, p);
-                }
-            };
-            idScan.scan(blockTree, null);
-            blockTree = (BlockTree) workingCopy.getTreeUtilities().translate(blockTree, original2Translated);
-            
+                };
+                idScan.scan(blockTree, null);
+                blockTree = (BlockTree) workingCopy.getTreeUtilities().translate(blockTree, original2Translated);
+            }
             original2Translated.clear();
             TreeScanner<Boolean, ExecutableElement> methodScanner = new TreeScanner<Boolean, ExecutableElement>() {
                 @Override
