@@ -86,7 +86,7 @@ import org.openide.util.Lookup;
  * @author  Pavel Flaska
  */
 public class RenamePanel extends JPanel implements CustomRefactoringPanel {
-
+    private static final Logger LOG = Logger.getLogger(RenamePanel.class.getName());
     private final transient String oldName;
     private final transient ChangeListener parent;
     private final transient TreePathHandle handle;
@@ -146,8 +146,12 @@ public class RenamePanel extends JPanel implements CustomRefactoringPanel {
                 public void run(CompilationController info) throws Exception {
                     if(handle.getElementHandle().getKind() == ElementKind.FIELD) {
                         VariableElement element = (VariableElement) handle.resolveElement(info);
+                        if(element == null) {
+                            LOG.log(Level.WARNING, "Cannot resolve ElementHandle {0} {1}", new Object[] {handle, info.getClasspathInfo()});
+                            return;
+                        }
                         TypeElement parent = (TypeElement) element.getEnclosingElement();
-                    boolean hasGetters = false;
+                        boolean hasGetters = false;
                         for (ExecutableElement method : ElementFilter.methodsIn(parent.getEnclosedElements())) {
                             if (RefactoringUtils.isGetter(info, method, element) || RefactoringUtils.isSetter(info, method, element)) {
                                 hasGetters = true;
@@ -168,6 +172,10 @@ public class RenamePanel extends JPanel implements CustomRefactoringPanel {
                     
                     if(handle.getElementHandle().getKind() == ElementKind.CLASS || handle.getElementHandle().getKind() == ElementKind.METHOD) {
 			final Element methodElement = handle.resolveElement(info);
+                        if(methodElement == null) {
+                            LOG.log(Level.WARNING, "Cannot resolve ElementHandle {0} {1}", new Object[] {handle, info.getClasspathInfo()});
+                            return;
+                        }
                         final FileObject fileObject = handle.getFileObject();
                         Collection<? extends TestLocator> testLocators = Lookup.getDefault().lookupAll(TestLocator.class);
                         for (final TestLocator testLocator : testLocators) {
@@ -323,6 +331,11 @@ public class RenamePanel extends JPanel implements CustomRefactoringPanel {
 
         nameField.setText(oldName);
         nameField.selectAll();
+        nameField.addFocusListener(new java.awt.event.FocusAdapter() {
+            public void focusLost(java.awt.event.FocusEvent evt) {
+                nameFieldFocusLost(evt);
+            }
+        });
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
         gridBagConstraints.weightx = 1.0;
@@ -371,7 +384,13 @@ public class RenamePanel extends JPanel implements CustomRefactoringPanel {
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
         add(updateReferencesCheckBox, gridBagConstraints);
 
+        renameGettersAndCheckersCheckBox.setSelected(((Boolean) RefactoringModule.getOption("gettersAndSetters.rename", Boolean.FALSE)).booleanValue());
         org.openide.awt.Mnemonics.setLocalizedText(renameGettersAndCheckersCheckBox, org.openide.util.NbBundle.getMessage(RenamePanel.class, "RenamePanel.renameGettersAndCheckersCheckBox.text")); // NOI18N
+        renameGettersAndCheckersCheckBox.addItemListener(new java.awt.event.ItemListener() {
+            public void itemStateChanged(java.awt.event.ItemEvent evt) {
+                renameGettersAndCheckersCheckBoxItemStateChanged(evt);
+            }
+        });
         renameGettersAndCheckersCheckBox.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 renameGettersAndCheckersCheckBoxActionPerformed(evt);
@@ -428,12 +447,23 @@ public class RenamePanel extends JPanel implements CustomRefactoringPanel {
     }//GEN-LAST:event_renameGettersAndCheckersCheckBoxActionPerformed
 
 private void renameTestClassCheckBoxStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_renameTestClassCheckBoxStateChanged
-    parent.stateChanged(null);
+        parent.stateChanged(null);
 }//GEN-LAST:event_renameTestClassCheckBoxStateChanged
 
     private void renameTestClassMethodCheckBoxStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_renameTestClassMethodCheckBoxStateChanged
         parent.stateChanged(null);
     }//GEN-LAST:event_renameTestClassMethodCheckBoxStateChanged
+
+    private void renameGettersAndCheckersCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_renameGettersAndCheckersCheckBoxItemStateChanged
+        // used for change default value for gettersAndSetters check-box.                                                  
+        // The value is persisted and then used as default in next IDE run.
+        Boolean b = evt.getStateChange() == ItemEvent.SELECTED ? Boolean.TRUE : Boolean.FALSE;
+        RefactoringModule.setOption("gettersAndSetters.rename", b); // NOI18N
+    }//GEN-LAST:event_renameGettersAndCheckersCheckBoxItemStateChanged
+
+    private void nameFieldFocusLost(java.awt.event.FocusEvent evt) {//GEN-FIRST:event_nameFieldFocusLost
+        parent.stateChanged(null);
+    }//GEN-LAST:event_nameFieldFocusLost
                                                              
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.JPanel jPanel1;
