@@ -72,6 +72,72 @@ public class ChangeParametersTest extends RefactoringTestBase {
         JavacParser.DISABLE_SOURCE_LEVEL_DOWNGRADE = true;
     }
     
+    public void test255269() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                        + "public interface A {\n"
+                        + "    boolean test(int a);\n"
+                        + "\n"
+                        + "    public static void m() {\n"
+                        + "        A f2 = (int c) -> true;\n"
+                        + "    }\n"
+                        + "}\n"));
+        ParameterInfo[] paramTable = {new ParameterInfo(0, "a", "Object", null)};
+        performChangeParameters(null, null, null, paramTable, Javadoc.NONE, 0, false, new Problem(false, "WRN_isNotAssignable"));
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                        + "public interface A {\n"
+                        + "    boolean test(Object a);\n"
+                        + "\n"
+                        + "    public static void m() {\n"
+                        + "        A f2 = (Object c) -> true;\n"
+                        + "    }\n"
+                        + "}\n"));
+    }
+    
+    public void test250047() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t; public class A {\n"
+                        + "    /**\n"
+                        + "     * \n"
+                        + "     * @param x the value of x\n"
+                        + "     */\n"
+                        + "    public void testMethod(int a, int x) {\n"
+                        + "         System.out.println(x);\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public static void main(string[] args) {\n"
+                        + "        testMethod(2, 1);\n"
+                        + "    }\n"
+                        + "}\n"),
+                new File("t/B.java", "package t; public class B extends A {\n"
+                        + "    public void testMethod(int a, int b) {\n"
+                        + "         int x = a;\n"
+                        + "    }\n"
+                        + "}\n"));
+        ParameterInfo[] paramTable = new ParameterInfo[]{new ParameterInfo(0, "b", "int", null), new ParameterInfo(1, "x", "int", null)};
+        performChangeParameters(null, null, null, paramTable, Javadoc.NONE, 1, false);
+        verifyContent(src,
+                new File("t/A.java", "package t; public class A {\n"
+                        + "    /**\n"
+                        + "     * \n"
+                        + "     * @param x the value of x\n"
+                        + "     */\n"
+                        + "    public void testMethod(int b, int x) {\n"
+                        + "         System.out.println(x);\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public static void main(string[] args) {\n"
+                        + "        testMethod(2, 1);\n"
+                        + "    }\n"
+                        + "}\n"),
+                new File("t/B.java", "package t; public class B extends A {\n"
+                        + "    public void testMethod(int a, int b) {\n"
+                        + "         int x = a;\n"
+                        + "    }\n"
+                        + "}\n"));
+    }
+    
     public void test239300() throws Exception {
         writeFilesAndWaitForScan(src,
                 new File("t/A.java", "package t; public class A {\n"
