@@ -71,6 +71,41 @@ public class InlineTest extends RefactoringTestBase {
         JavacParser.DISABLE_SOURCE_LEVEL_DOWNGRADE = true;
     }
     
+    public void test216817() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    String greet = \"\";\n"
+                        + "    public static void main(String[] args) {\n"
+                        + "        new A().foo(\"\");\n"
+                        + "    }\n"
+                        + "    private void foo(String msg) {\n"
+                        + "        System.out.println(msg + greet);\n"
+                        + "    }\n"
+                        + "    private class Inner {\n"
+                        + "        public void bar() {\n"
+                        + "            foo(\"\");\n"
+                        + "        }\n"
+                        + "    }\n"
+                        + "}\n"));
+        final InlineRefactoring[] r = new InlineRefactoring[1];
+        createInlineMethodRefactoring(src.getFileObject("t/A.java"), 3, r);
+        performRefactoring(r);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    String greet = \"\";\n"
+                        + "    public static void main(String[] args) {\n"
+                        + "        System.out.println(\"\" + new A().greet);\n"
+                        + "    }\n"
+                        + "    private class Inner {\n"
+                        + "        public void bar() {\n"
+                        + "            System.out.println(\"\" + greet);\n"
+                        + "        }\n"
+                        + "    }\n"
+                        + "}\n"));
+    }
+    
     public void test242995() throws Exception {
         writeFilesAndWaitForScan(src,
                 new File("t/A.java", "package t;\n"
@@ -954,6 +989,31 @@ public class InlineTest extends RefactoringTestBase {
                 + "    }\n"
                 + "}"));
     }
+    
+    public void testInlineTempComments() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public void testMethod() {\n"
+                + "        // my Text\n"
+                + "        String text = \"text\";\n"
+                + "        System.out.println(text);\n"
+                + "    }\n"
+                + "}"));
+
+        InlineRefactoring[] r = new InlineRefactoring[1];
+        createInlineTempRefactoring(src.getFileObject("t/A.java"), 0, r);
+        performRefactoring(r);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public void testMethod() {\n"
+                + "        System.out.println(\n"
+                + "                           // my Text\n"
+                + "                           \"text\");\n"
+                + "    }\n"
+                + "}"));
+    }
 
     public void testInlineTempa() throws Exception {
         writeFilesAndWaitForScan(src,
@@ -1827,6 +1887,36 @@ public class InlineTest extends RefactoringTestBase {
         createInlineMethodRefactoring(src.getFileObject("t/A.java"), 1, r);
         performRefactoring(r, new Problem(true, "ERR_InlineMethodMultipleReturn"));
     }
+    
+    public void testCanInlineMethodMultipleReturn() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    private String getGreeting(String name) {\n"
+                + "        if(name.length() > 3)\n"
+                + "            return name;\n"
+                + "        else\n"
+                + "            return name + \"...\";\n"
+                + "    }\n"
+                + "    public static String testMethod() {\n"
+                + "        return getGreeting(\"World\");\n"
+                + "    }\n"
+                + "}"));
+        final InlineRefactoring[] r = new InlineRefactoring[1];
+        createInlineMethodRefactoring(src.getFileObject("t/A.java"), 1, r);
+        performRefactoring(r);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public static String testMethod() {\n"
+                + "        if (\"World\".length() > 3) {\n"
+                + "            return \"World\";\n"
+                + "        } else {\n"
+                + "            return \"World\" + \"...\";\n"
+                + "        }\n"
+                + "    }\n"
+                + "}"));
+    }
 
     public void testCannotInlineMethodNoLastReturn() throws Exception {
         writeFilesAndWaitForScan(src,
@@ -1862,6 +1952,61 @@ public class InlineTest extends RefactoringTestBase {
         createInlineMethodRefactoring(src.getFileObject("t/A.java"), 1, r2);
         performRefactoring(r2, new Problem(true, "ERR_InlineMethodNoLastReturn"));
     }
+    
+    public void testCanInlineMethodNoLastReturn() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    private String getGreeting(String name) {\n"
+                + "        throw new UnsupportedOperationException(\"Not yet implemented\");\n"
+                + "    }\n"
+                + "    public static void testMethod() {\n"
+                + "        getGreeting(\"World\");\n"
+                + "    }\n"
+                + "}"));
+        final InlineRefactoring[] r = new InlineRefactoring[1];
+        createInlineMethodRefactoring(src.getFileObject("t/A.java"), 1, r);
+        performRefactoring(r);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    public static void testMethod() {\n"
+                        + "        throw new UnsupportedOperationException(\"Not yet implemented\");\n"
+                        + "    }\n"
+                        + "}"));
+        
+        
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    private String getGreeting(String name) {\n"
+                + "        try {\n"
+                + "            System.out.println(\"Hello World!\");\n"
+                + "        }\n"
+                + "        finally {\n"
+                + "            return \"Hello Finally\";\n"
+                + "        }\n"
+                + "    }\n"
+                + "    public static void testMethod() {\n"
+                + "        getGreeting(\"World\");\n"
+                + "    }\n"
+                + "}"));
+        final InlineRefactoring[] r2 = new InlineRefactoring[1];
+        createInlineMethodRefactoring(src.getFileObject("t/A.java"), 1, r2);
+        performRefactoring(r2);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public static void testMethod() {\n"
+                + "        try {\n"
+                + "            System.out.println(\"Hello World!\");\n"
+                + "        }\n"
+                + "        finally {\n"
+                + "            return \"Hello Finally\";\n"
+                + "        }\n"
+                + "    }\n"
+                + "}"));
+    }
 
     public void testCannotInlineMethodNoAccessors() throws Exception {
         writeFilesAndWaitForScan(src,
