@@ -54,6 +54,101 @@ public class MoveMethodTest extends MoveBaseTest {
         super(name);
     }
     
+    public void test236877() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/SourceClass.java", "package t;\n"
+                + "public class SourceClass {\n"
+                + "    public void movedMethod(SourceClass a) {\n"
+                + "    }\n"
+                + "}\n"),
+                new File("u/TargetClass.java", "package u;\n"
+                + "public class TargetClass {\n"
+                + "}\n"));
+        performMove(src.getFileObject("t/SourceClass.java"), new int[]{1}, src.getFileObject("u/TargetClass.java"), Visibility.PUBLIC, false);
+        verifyContent(src,
+                new File("t/SourceClass.java", "package t;\n"
+                + "public class SourceClass {\n"
+                + "}\n"),
+                new File("u/TargetClass.java", "package u;\n"
+                + "import t.SourceClass;\n"
+                + "public class TargetClass {\n"
+                + "    public void movedMethod(SourceClass a) {\n"
+                + "    }\n"
+                + "}\n"));
+    }
+    
+    public void testMoveComments() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    public void doStuff() {\n"
+                        + "        // do stuff dude!\n"
+                        + "        //more stuff\n"
+                        + "        int i = 2 + 2;\n"
+                        + "        assert i == 4;\n"
+                        + "        // more stuff\n"
+                        + "        // do stuff dude!\n"
+                        + "        //more stuff\n"
+                        + "        i = 2 + 2;\n"
+                        + "        assert i == 4;\n"
+                        + "        // more stuff\n"
+                        + "        // do stuff dude!\n"
+                        + "        //more stuff\n"
+                        + "        i = 2 + 2;\n"
+                        + "        assert i == 4;\n"
+                        + "        // more stuff\n"
+                        + "        // do stuff dude!\n"
+                        + "        //more stuff\n"
+                        + "        i = 2 + 2;\n"
+                        + "        assert i == 4;\n"
+                        + "        // more stuff\n"
+                        + "        // do stuff dude!\n"
+                        + "        //more stuff\n"
+                        + "        i = 2 + 2;\n"
+                        + "        assert i == 4;\n"
+                        + "        // more stuff\n"
+                        + "    }\n"
+                        + "}\n"),
+                new File("t/B.java", "package t;\n"
+                + "public class B {\n"
+                + "}\n"));
+        performMove(src.getFileObject("t/A.java"), new int[]{1}, src.getFileObject("t/B.java"), Visibility.PUBLIC, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "}\n"),
+                new File("t/B.java", "package t;\n"
+                + "public class B {\n"
+                + "    public void doStuff() {\n"
+                + "        // do stuff dude!\n"
+                + "        //more stuff\n"
+                + "        int i = 2 + 2;\n"
+                + "        assert i == 4;\n"
+                + "        // more stuff\n"
+                + "        // do stuff dude!\n"
+                + "        //more stuff\n"
+                + "        i = 2 + 2;\n"
+                + "        assert i == 4;\n"
+                + "        // more stuff\n"
+                + "        // do stuff dude!\n"
+                + "        //more stuff\n"
+                + "        i = 2 + 2;\n"
+                + "        assert i == 4;\n"
+                + "        // more stuff\n"
+                + "        // do stuff dude!\n"
+                + "        //more stuff\n"
+                + "        i = 2 + 2;\n"
+                + "        assert i == 4;\n"
+                + "        // more stuff\n"
+                + "        // do stuff dude!\n"
+                + "        //more stuff\n"
+                + "        i = 2 + 2;\n"
+                + "        assert i == 4;\n"
+                + "        // more stuff\n"
+                + "    }\n"
+                + "}\n"));
+    }
+    
     public void testMoveGenericReturn() throws Exception {
         writeFilesAndWaitForScan(src,
                 new File("t/A.java", "package t;\n"
@@ -95,6 +190,42 @@ public class MoveMethodTest extends MoveBaseTest {
                 + "}\n"));
     }
     
+    public void testMoveKeepOld() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public static String param = \"a\";\n"
+                + "    \n"
+                + "    public static void movedMethod(String p) {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    public void test() {\n"
+                + "        movedMethod(param);\n"
+                + "    }\n"
+                + "}\n"),
+                new File("t/B.java", "package t;\n"
+                + "public class B {\n"
+                + "}\n"));
+        performMove(src.getFileObject("t/A.java"), new int[]{2}, src.getFileObject("t/B.java"), Visibility.ASIS, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public static String param = \"a\";\n"
+                + "    \n"
+                + "    public void test() {\n"
+                + "        B.movedMethod(param);\n"
+                + "    }\n"
+                + "}\n"),
+                new File("t/B.java", "package t;\n"
+                + "public class B {\n"
+                + "    \n"
+                + "    public static void movedMethod(String p) {\n"
+                + "        \n"
+                + "    }\n"
+                + "}\n"));
+    }
+    
     public void test232604() throws Exception {
         writeFilesAndWaitForScan(src,
                 new File("t/A.java", "package t;\n"
