@@ -59,6 +59,7 @@ import org.netbeans.modules.refactoring.api.RefactoringSession;
 import org.netbeans.modules.refactoring.java.RefactoringUtils;
 import org.netbeans.modules.refactoring.java.api.MemberInfo;
 import org.netbeans.modules.refactoring.java.api.PullUpRefactoring;
+import org.netbeans.modules.refactoring.spi.impl.UndoManager;
 import org.openide.filesystems.FileObject;
 
 /**
@@ -465,6 +466,157 @@ public class PullUpTest extends RefactoringTestBase {
                 + "\n"
                 + "}"));
     }
+    
+    public void testPullUpMethodUndo() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("pullup/PullUpBaseClass.java", "package pullup;\n"
+                + "\n"
+                + "import java.io.Serializable;\n"
+                + "\n"
+                + "public class PullUpBaseClass extends PullUpSuperClass implements Serializable {\n"
+                + "     \n"
+                + "    public String field;\n"
+                + "    \n"
+                + "    public void method() {\n"
+                + "        //method body\n"
+                + "        System.out.println(\"Hello\");\n"
+                + "    }\n"
+                + "    \n"
+                + "    public class InnerClass {\n"
+                + "        //class body\n"
+                + "        public void method() {\n"
+                + "            \n"
+                + "        }\n"
+                + "    }\n"
+                + "   \n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void localyReferenced() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void reference() {\n"
+                + "        localyReferenced();\n"
+                + "    }\n"
+                + "}"),
+                new File("pullup/PullUpSuperClass.java", "package pullup;\n"
+                + "\n"
+                + "public class PullUpSuperClass {\n"
+                + "    \n"
+                + "    public void m2() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    final String field2 = \"const\";\n"
+                + "\n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "\n"
+                + "}"));
+        performPullUp(src.getFileObject("pullup/PullUpBaseClass.java"), 2, Boolean.FALSE);
+        verifyContent(src,
+                new File("pullup/PullUpBaseClass.java", "package pullup;\n"
+                + "\n"
+                + "import java.io.Serializable;\n"
+                + "\n"
+                + "public class PullUpBaseClass extends PullUpSuperClass implements Serializable {\n"
+                + "     \n"
+                + "    public String field;\n"
+                + "    \n"
+                + "    public class InnerClass {\n"
+                + "        //class body\n"
+                + "        public void method() {\n"
+                + "            \n"
+                + "        }\n"
+                + "    }\n"
+                + "   \n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void localyReferenced() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void reference() {\n"
+                + "        localyReferenced();\n"
+                + "    }\n"
+                + "}"),
+                new File("pullup/PullUpSuperClass.java", "package pullup;\n"
+                + "\n"
+                + "public class PullUpSuperClass {\n"
+                + "    \n"
+                + "    public void m2() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    final String field2 = \"const\";\n"
+                + "\n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    public void method() {\n"
+                + "        //method body\n"
+                + "        System.out.println(\"Hello\");\n"
+                + "    }\n"
+                + "    \n"
+                + "\n"
+                + "}"));
+        UndoManager undoManager = UndoManager.getDefault();
+        undoManager.setAutoConfirm(true);
+        undoManager.undo(null);
+        verifyContent(src,
+                new File("pullup/PullUpBaseClass.java", "package pullup;\n"
+                + "\n"
+                + "import java.io.Serializable;\n"
+                + "\n"
+                + "public class PullUpBaseClass extends PullUpSuperClass implements Serializable {\n"
+                + "     \n"
+                + "    public String field;\n"
+                + "    \n"
+                + "    public void method() {\n"
+                + "        //method body\n"
+                + "        System.out.println(\"Hello\");\n"
+                + "    }\n"
+                + "    \n"
+                + "    public class InnerClass {\n"
+                + "        //class body\n"
+                + "        public void method() {\n"
+                + "            \n"
+                + "        }\n"
+                + "    }\n"
+                + "   \n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void localyReferenced() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    private void reference() {\n"
+                + "        localyReferenced();\n"
+                + "    }\n"
+                + "}"),
+                new File("pullup/PullUpSuperClass.java", "package pullup;\n"
+                + "\n"
+                + "public class PullUpSuperClass {\n"
+                + "    \n"
+                + "    public void m2() {\n"
+                + "        \n"
+                + "    }\n"
+                + "    \n"
+                + "    final String field2 = \"const\";\n"
+                + "\n"
+                + "    public void existing() {\n"
+                + "        \n"
+                + "    }\n"
+                + "\n"
+                + "}"));
+    }
 
     public void testPullUpAllComments() throws Exception { // #210915 - Refactoring Pull Up Leaves Single Comment in Sub Class
         writeFilesAndWaitForScan(src, new File("t/SuperClass.java",
