@@ -70,9 +70,340 @@ public class RenameTest extends RefactoringTestBase {
         super(name);
     }
     
+    public void testMethodChainInTest() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/SampleClass.java", "package t;\n"
+                        + "\n"
+                        + "import java.math.BigDecimal;\n"
+                        + "\n"
+                        + "public class SampleClass {\n"
+                        + "\n"
+                        + "  public static final class Builder {\n"
+                        + "\n"
+                        + "    private Builder() {\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public static Builder create() {\n"
+                        + "      return new Builder();\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public Builder sampleMethod1(BigDecimal bd) {\n"
+                        + "      return this;\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public Builder sampleMethod2() {\n"
+                        + "      return this;\n"
+                        + "    }\n"
+                        + "  }\n"
+                        + "\n"
+                        + "}"));
+        writeFilesAndWaitForScan(test,
+                new File("t/SampleClassTest.java", "package t;\n"
+                        + "\n"
+                        + "import static java.math.BigDecimal.*;\n"
+                        + "import static t.BigDecimalConstants.*;\n"
+                        + "\n"
+                        + "public class SampleClassTest {\n"
+                        + "\n"
+                        + "  public void testSomeMethod() {\n"
+                        + "    SampleClass.Builder.create()\n"
+                        + "            .sampleMethod1(ONE)\n"
+                        + "            .sampleMethod1(FIVE)\n"
+                        + "            .sampleMethod2();\n"
+                        + "  }\n"
+                        + "\n"
+                        + "}"),
+                new File("t/BigDecimalConstants.java", "package t;\n"
+                        + "\n"
+                        + "import java.math.BigDecimal;\n"
+                        + "\n"
+                        + "public interface BigDecimalConstants {\n"
+                        + "\n"
+                        + "  public static final BigDecimal FIVE = new BigDecimal(\"5.00\");\n"
+                        + "\n"
+                        + "}\n"
+                        + ""));
+        JavaRenameProperties props = new JavaRenameProperties();
+        performRename(src.getFileObject("t/SampleClass.java"), 1, 3, "sampleMethod3", props, true);
+        verifyContent(src,
+                new File("t/SampleClass.java", "package t;\n"
+                        + "\n"
+                        + "import java.math.BigDecimal;\n"
+                        + "\n"
+                        + "public class SampleClass {\n"
+                        + "\n"
+                        + "  public static final class Builder {\n"
+                        + "\n"
+                        + "    private Builder() {\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public static Builder create() {\n"
+                        + "      return new Builder();\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public Builder sampleMethod1(BigDecimal bd) {\n"
+                        + "      return this;\n"
+                        + "    }\n"
+                        + "\n"
+                        + "    public Builder sampleMethod3() {\n"
+                        + "      return this;\n"
+                        + "    }\n"
+                        + "  }\n"
+                        + "\n"
+                        + "}"));
+        verifyContent(test,
+                new File("t/SampleClassTest.java", "package t;\n"
+                        + "\n"
+                        + "import static java.math.BigDecimal.*;\n"
+                        + "import static t.BigDecimalConstants.*;\n"
+                        + "\n"
+                        + "public class SampleClassTest {\n"
+                        + "\n"
+                        + "  public void testSomeMethod() {\n"
+                        + "    SampleClass.Builder.create()\n"
+                        + "            .sampleMethod1(ONE)\n"
+                        + "            .sampleMethod1(FIVE)\n"
+                        + "            .sampleMethod3();\n"
+                        + "  }\n"
+                        + "\n"
+                        + "}"),
+                new File("t/BigDecimalConstants.java", "package t;\n"
+                        + "\n"
+                        + "import java.math.BigDecimal;\n"
+                        + "\n"
+                        + "public interface BigDecimalConstants {\n"
+                        + "\n"
+                        + "  public static final BigDecimal FIVE = new BigDecimal(\"5.00\");\n"
+                        + "\n"
+                        + "}\n"
+                        + ""));
+    }
+    
+    public void testStaticImport() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "\n"
+                + "import java.util.Collection;\n"
+                + "import java.util.Arrays;\n"
+                + "import static t.A.Length.of;\n"
+                + "\n"
+                + "public class A {\n"
+                + "    static class Length {\n"
+                + "        static int of(String in) {\n"
+                + "            return in.length();\n"
+                + "        }\n"
+                + "\n"
+                + "        static int of(Collection<?> collection) {\n"
+                + "            return collection.size();\n"
+                + "        }\n"
+                + "    }\n"
+                + "\n"
+                + "    public static void main(final String[] args) {\n"
+                + "        int i = of(\"jfgdksjgfkds\");\n"
+                + "        int j = of(Arrays.asList(\"a\", \"b\"));\n"
+                + "    }"
+                + "}"));
+        JavaRenameProperties props = new JavaRenameProperties();
+        performRename(src.getFileObject("t/A.java"), 1, 2, "fooBar", props, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "\n"
+                + "import java.util.Collection;\n"
+                + "import java.util.Arrays;\n"
+                + "import static t.A.Length.fooBar;\n"
+                + "import static t.A.Length.of;\n"
+                + "\n"
+                + "public class A {\n"
+                + "    static class Length {\n"
+                + "        static int of(String in) {\n"
+                + "            return in.length();\n"
+                + "        }\n"
+                + "\n"
+                + "        static int fooBar(Collection<?> collection) {\n"
+                + "            return collection.size();\n"
+                + "        }\n"
+                + "    }\n"
+                + "\n"
+                + "    public static void main(final String[] args) {\n"
+                + "        int i = of(\"jfgdksjgfkds\");\n"
+                + "        int j = fooBar(Arrays.asList(\"a\", \"b\"));\n"
+                + "    }"
+                + "}"));
+    }
+    
+    public void testStaticImport2() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "\n"
+                + "import java.util.Collection;\n"
+                + "import java.util.Arrays;\n"
+                + "import static t.A.Length.of;\n"
+                + "\n"
+                + "public class A {\n"
+                + "    static class Length {\n"
+                + "        static int of(Collection<?> collection) {\n"
+                + "            return collection.size();\n"
+                + "        }\n"
+                + "    }\n"
+                + "\n"
+                + "    public static void main(final String[] args) {\n"
+                + "        int j = of(Arrays.asList(\"a\", \"b\"));\n"
+                + "    }"
+                + "}"));
+        JavaRenameProperties props = new JavaRenameProperties();
+        performRename(src.getFileObject("t/A.java"), 1, 1, "fooBar", props, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "\n"
+                + "import java.util.Collection;\n"
+                + "import java.util.Arrays;\n"
+                + "import static t.A.Length.fooBar;\n"
+                + "\n"
+                + "public class A {\n"
+                + "    static class Length {\n"
+                + "        static int fooBar(Collection<?> collection) {\n"
+                + "            return collection.size();\n"
+                + "        }\n"
+                + "    }\n"
+                + "\n"
+                + "    public static void main(final String[] args) {\n"
+                + "        int j = fooBar(Arrays.asList(\"a\", \"b\"));\n"
+                + "    }"
+                + "}"));
+    }
+    
+    public void testJavadocMethodRef() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public void foo() {\n"
+                + "    }\n"
+                + "    \n"
+                + "    /**\n"
+                + "     * Not {@link #bar}.\n"
+                + "     * @see #foo() we just call method foo()\n"
+                + "     */\n"
+                + "    public static void main() {\n"
+                + "        new A().foo();\n"
+                + "    }\n"
+                + "}"));
+        performRename(src.getFileObject("t/A.java"), 1, -1, "fooBar", null, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public class A {\n"
+                + "    public void fooBar() {\n"
+                + "    }\n"
+                + "    \n"
+                + "    /**\n"
+                + "     * Not {@link #bar}.\n"
+                + "     * @see #fooBar() we just call method foo()\n"
+                + "     */\n"
+                + "    public static void main() {\n"
+                + "        new A().fooBar();\n"
+                + "    }\n"
+                + "}"));
+    }
+    
+    public void testJavadocClassRef() throws Exception { // #250415 - Refactor Rename ... Class should rename Class in @see or @link Class#member javadoc
+        writeFilesAndWaitForScan(src,
+                new File("t/B.java", "package t;\n"
+                        + "/**\n"
+                        + " * Extends {@link A} with own main method\n"
+                        + " * implemented using the BaseClass {@link A#main main} method.\n"
+                        + " * \n"
+                        + " * @see A\n"
+                        + " */\n"
+                        + "public class B extends A {\n"
+                        + "  /**\n"
+                        + "   * Calls {@link A#main}.\n"
+                        + "   * @see A#main\n"
+                        + "   */\n"
+                        + "  public static void main(String[] parameters) {\n"
+                        + "    A.main(new B(), parameters);\n"
+                        + "  }\n"
+                        + "}"),
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    public static void main(A base, String[] parameters) {\n"
+                        + "    }\n"
+                        + "}"));
+        performRename(src.getFileObject("t/A.java"), -1, -1, "C", null, false);
+        verifyContent(src,
+                new File("t/B.java", "package t;\n"
+                        + "/**\n"
+                        + " * Extends {@link C} with own main method\n"
+                        + " * implemented using the BaseClass {@link C#main main} method.\n"
+                        + " * \n"
+                        + " * @see C\n"
+                        + " */\n"
+                        + "public class B extends C {\n"
+                        + "  /**\n"
+                        + "   * Calls {@link C#main}.\n"
+                        + "   * @see C#main\n"
+                        + "   */\n"
+                        + "  public static void main(String[] parameters) {\n"
+                        + "    C.main(new B(), parameters);\n"
+                        + "  }\n"
+                        + "}"),
+                new File("t/A.java", "package t;\n"
+                        + "public class C {\n"
+                        + "    public static void main(C base, String[] parameters) {\n"
+                        + "    }\n"
+                        + "}"));
+    }
+    
+    public void test236868() throws Exception {
+        String source;
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", source = "package t;\n"
+                        + "public class A {\n"
+                        + "    public int x;\n"
+                        + "        public void method(int x) {\n"
+                        + "        LABEL:\n"
+                        + "        while (x > 0) {\n"
+                        + "            LABEL2:\n"
+                        + "            for (int i = 0; i < 10; i++) {\n"
+                        + "                if (x == 1) {\n"
+                        + "                    break LABEL;\n"
+                        + "                }\n"
+                        + "                if (x == 2) {\n"
+                        + "                    continue LABEL;\n"
+                        + "                }\n"
+                        + "                if (x == 3) {\n"
+                        + "                    break LABEL2;\n"
+                        + "                }\n"
+                        + "            }\n"
+                        + "        }\n"
+                        + "    }"
+                        + "}"));
+        performRename(src.getFileObject("t/A.java"), source.indexOf("LABEL") + 1, "LABEL1", null, false);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                        + "public class A {\n"
+                        + "    public int x;\n"
+                        + "        public void method(int x) {\n"
+                        + "        LABEL1:\n"
+                        + "        while (x > 0) {\n"
+                        + "            LABEL2:\n"
+                        + "            for (int i = 0; i < 10; i++) {\n"
+                        + "                if (x == 1) {\n"
+                        + "                    break LABEL1;\n"
+                        + "                }\n"
+                        + "                if (x == 2) {\n"
+                        + "                    continue LABEL1;\n"
+                        + "                }\n"
+                        + "                if (x == 3) {\n"
+                        + "                    break LABEL2;\n"
+                        + "                }\n"
+                        + "            }\n"
+                        + "        }\n"
+                        + "    }"
+                        + "}"));
+    }
+    
     public void test238268() throws Exception {
         String source;
-        writeFilesAndWaitForScan(src, new File("t/A.java", source = "pacakge t;\n"
+        writeFilesAndWaitForScan(src, new File("t/A.java", source = "package t;\n"
                 + "public class Calculator {\n"
                 + "\n"
                 + "    interface IntegerMath {\n"
@@ -96,7 +427,7 @@ public class RenameTest extends RefactoringTestBase {
                 + "    }\n"
                 + "}"));
         performRename(src.getFileObject("t/A.java"), source.indexOf('x') + 1, "a", null, true);
-        verifyContent(src, new File("t/A.java", "pacakge t;\n"
+        verifyContent(src, new File("t/A.java", "package t;\n"
                 + "public class Calculator {\n"
                 + "\n"
                 + "    interface IntegerMath {\n"
@@ -508,6 +839,57 @@ public class RenameTest extends RefactoringTestBase {
 
     }
     
+    public void test253063() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public enum A implements ATest {\n"
+                + "    AAA { void foo() { } }\n"
+                + "}"),
+                new File("t/ATest.java", "package t;\n"
+                + "\n"
+                + "public interface ATest {\n"
+                + "    void foo();\n"
+                + "}"));
+        JavaRenameProperties props = new JavaRenameProperties();
+        performRename(src.getFileObject("t/ATest.java"), 0, -1, "foos", props, false, new Problem(false, "ERR_IsOverridden"));
+        verifyContent(src,
+                new File("t/A.java", "package t;\n"
+                + "public enum A implements ATest {\n"
+                + "    AAA { void foos() { } }\n"
+                + "}"),
+                new File("t/ATest.java", "package t;\n"
+                + "\n"
+                + "public interface ATest {\n"
+                + "    void foos();\n"
+                + "}"));
+    }
+    
+    public void test234094() throws Exception {
+        writeFilesAndWaitForScan(src,
+                new File("t/A.java", "package t;\n"
+                + "public enum A {\n"
+                + "}"));
+        writeFilesAndWaitForScan(test,
+                new File("t/ATest.java", "package t;\n"
+                + "import junit.framework.TestCase;\n"
+                + "\n"
+                + "public class ATest extends TestCase {\n"
+                + "}"));
+        JavaRenameProperties props = new JavaRenameProperties();
+        props.setIsRenameTestClass(true);
+        performRename(src.getFileObject("t/A.java"), -1, -1, "B", props, true);
+        verifyContent(src,
+                new File("t/A.java", "package t;\n" // XXX: Why use old filename, is it not renamed?
+                + "public enum B {\n"
+                + "}"));
+        verifyContent(test,
+                new File("t/BTest.java", "package t;\n"
+                + "import junit.framework.TestCase;\n"
+                + "\n"
+                + "public class BTest extends TestCase {\n"
+                + "}"));
+    }
+    
     public void test200224() throws Exception {
         writeFilesAndWaitForScan(src,
                 new File("t/A.java", "package t;\n"
