@@ -289,7 +289,7 @@ public final class KeyboardPopupSwitcher implements WindowFocusListener {
         pTable = new SwitcherTable(items);
         // Compute coordinates for popup to be displayed in center of screen
         Dimension popupDim = pTable.getPreferredSize();
-        Rectangle screen = Utilities.getUsableScreenBounds();
+        Rectangle screen = WindowManager.getDefault().getMainWindow().getBounds();
         this.x = screen.x + ((screen.width / 2) - (popupDim.width / 2));
         this.y = screen.y + ((screen.height / 2) - (popupDim.height / 2));
         // Set initial selection if there are at least two items in table
