@@ -51,9 +51,11 @@ import java.beans.PropertyChangeSupport;
 import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedList;
+import java.util.List;
 import java.util.Map;
 import java.util.Queue;
 import java.util.Set;
@@ -62,13 +64,16 @@ import java.util.logging.Logger;
 import javax.swing.JEditorPane;
 import javax.swing.JRootPane;
 import javax.swing.SwingUtilities;
+import javax.swing.text.AbstractDocument;
 import javax.swing.text.Caret;
 import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.StyledDocument;
 import org.netbeans.api.editor.EditorRegistry;
+import org.netbeans.api.lexer.LanguagePath;
+import org.netbeans.api.lexer.TokenHierarchy;
+import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.modules.editor.NbEditorUtilities;
-
 import org.openide.cookies.EditorCookie;
 import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileChangeListener;
@@ -151,7 +156,7 @@ public final class EditorContextDispatcher {
     private final Map<String, PropertyChangeSupport> pcsByMIMEType = new HashMap<String, PropertyChangeSupport>();
     
     private String lastFiredMIMEType = null;
-    private Map<String, Object> lastMIMETypeEvents = new HashMap<String, Object>();
+    private Map<String, Reference<Object>> lastMIMETypeEvents = new HashMap<String, Reference<Object>>();
 
     private static final Reference<FileObject> NO_FILE = new WeakReference<FileObject>(null);
     private static final Reference<JTextComponent> NO_TEXT_COMPONENT = new WeakReference<JTextComponent>(null);
@@ -289,6 +294,90 @@ public final class EditorContextDispatcher {
         }
     }
     
+    /**
+     * Get a list of MIME types of languages found on the current line.
+     * @return A set of MIME types.
+     * @since 2.50
+     */
+    public Set<String> getMIMETypesOnCurrentLine() {
+        Line line = getCurrentLine();
+        if (line == null) {
+            return Collections.EMPTY_SET;
+        }
+        return getMIMETypesOnLine(line);
+    }
+    
+    /**
+     * Get a list of MIME types of languages found on a line.
+     * @param line The line to search for the MIME types.
+     * @return A set of MIME types.
+     * @since 2.50
+     */
+    public Set<String> getMIMETypesOnLine(Line line) {
+        EditorCookie editorCookie = line.getLookup().lookup(EditorCookie.class);
+        if (editorCookie == null) {
+            DataObject dobj = line.getLookup().lookup(DataObject.class);
+            if (dobj != null) {
+                editorCookie = dobj.getLookup().lookup(EditorCookie.class);
+            }
+            if (editorCookie == null) {
+                return Collections.emptySet();
+            }
+        }
+        StyledDocument document = editorCookie.getDocument();
+        if (document == null) {
+            return Collections.emptySet();
+        }
+        Set<String> mimeTypes = null;
+        ((AbstractDocument) document).readLock();
+        try {
+            TokenHierarchy<Document> th = TokenHierarchy.get((Document) document);
+            int ln = line.getLineNumber();
+            int offset = NbDocument.findLineOffset(document, ln);
+            int maxOffset = document.getLength() - 1;
+            int maxLine = NbDocument.findLineNumber(document, maxOffset);
+            int offset2;
+            if (ln + 1 > maxLine) {
+                offset2 = maxOffset;
+            } else {
+                offset2 = NbDocument.findLineOffset(document, ln+1) - 1;
+            }
+            // The line has offsets <offset, offset2>
+            Set<LanguagePath> languagePaths = th.languagePaths();
+            for (LanguagePath lp : languagePaths) {
+                List<TokenSequence<?>> tsl = th.tokenSequenceList(lp, offset, offset2);
+                for (TokenSequence ts : tsl) {
+                    if (ts.moveNext()) {
+                        //int to = ts.offset();
+                        //if (!(offset <= to && to < offset2)) {
+                        //    continue;
+                        //}
+                        TokenSequence ets;
+                        ets = ts.embedded();
+                        if (ets != null) {
+                            ts = ets;
+                        }
+                        String mimeType = ts.language().mimeType();
+                        if (mimeType != null) {
+                            if (mimeTypes == null) {
+                                mimeTypes = Collections.singleton(mimeType);
+                            } else {
+                                if (mimeTypes.size() == 1) {
+                                    mimeTypes = new HashSet<String>(mimeTypes);
+                                }
+                                mimeTypes.add(mimeType);
+                            }
+                        }
+                    }
+                }
+            }
+        } finally {
+            ((AbstractDocument) document).readUnlock();
+        }
+        return (mimeTypes != null) ? mimeTypes : Collections.<String>emptySet();
+        
+    }
+    
     /**
      * Get the most recent active file. This returns the active file if there's
      * one, or a file, that was most recently active.
@@ -503,7 +592,7 @@ public final class EditorContextDispatcher {
             // registered for a particular MIME type:
             if (oldMIMEType != null && !oldMIMEType.equals(newMIMEType) && pcsMIMEOld != null) {
                 String lastMIMEType;
-                Map<String, Object> lastEvents;
+                Map<String, Reference<Object>> lastEvents;
                 synchronized (this) {
                     lastMIMEType = lastFiredMIMEType;
                     lastEvents = new HashMap(lastMIMETypeEvents);
@@ -516,7 +605,7 @@ public final class EditorContextDispatcher {
                 }
                 if (lastEvents != null) {
                     for (String property : lastEvents.keySet()) {
-                        pcsMIMEOld.firePropertyChange(property, lastEvents.get(property), null);
+                        pcsMIMEOld.firePropertyChange(property, lastEvents.get(property).get(), null);
                     }
                 }
             }
@@ -534,7 +623,8 @@ public final class EditorContextDispatcher {
             synchronized (this) {
                 if (pcsMIME != null) {
                     lastFiredMIMEType = preferredMIMEType;
-                    lastMIMETypeEvents.put(evt.getPropertyName(), evt.getNewValue());
+                    // evt.getNewValue() may be a JEditorPane instance which disables its GC
+                    lastMIMETypeEvents.put(evt.getPropertyName(), new WeakReference<Object>(evt.getNewValue()));
                 } else {
                     lastFiredMIMEType = null;
                     lastMIMETypeEvents.clear();
@@ -616,6 +706,9 @@ public final class EditorContextDispatcher {
                 } else {
                     newFile = findPrimary(fos);
                 }
+                if (newFile != null && !newFile.isData()) {
+                    newFile = null;
+                }
                 synchronized (EditorContextDispatcher.this) {
                     oldFile = currentFile.get();
                     //System.err.println("\nCURRENT FILES = "+fos+"\n");
