@@ -102,6 +102,7 @@ import org.netbeans.spi.java.hints.Hint;
 import org.netbeans.api.java.source.matching.Matcher;
 import org.netbeans.api.java.source.matching.Occurrence;
 import org.netbeans.api.java.source.matching.Pattern;
+import org.netbeans.spi.java.hints.TriggerOptions;
 import org.openide.util.Exceptions;
 
 /**
@@ -556,9 +557,16 @@ public class HintsInvoker {
 
                     Set<String> suppressedWarnings = new HashSet<String>(Utilities.findSuppressedWarnings(info, candidate));
                     Occurrence verifiedVariables = verified.next();
+                    
+                    boolean guarded = isInGuarded(info, candidate);
 
                     for (HintDescription hd : patternHints.get(d)) {
                         HintMetadata hm = hd.getMetadata();
+                        // skip guarded sections
+                        if (guarded && !hd.getTrigger().hasOption(TriggerOptions.PROCESS_GUARDED)) {
+                            continue;
+                        }
+                        
                         HintContext c = SPIAccessor.getINSTANCE().createHintContext(info, settings, hm, candidate, verifiedVariables.getVariables(), verifiedVariables.getMultiVariables(), verifiedVariables.getVariables2Names(), constraints, problems, bulkMode, cancel, caret);
 
                         if (!Collections.disjoint(suppressedWarnings, hm.suppressWarnings))
@@ -639,11 +647,15 @@ public class HintsInvoker {
         }
 
         private void runAndAdd(TreePath path, List<HintDescription> rules, Map<HintDescription, List<ErrorDescription>> d) {
-            if (rules != null && !isInGuarded(info, path)) {
+            if (rules != null) {
+                boolean guarded = isInGuarded(info, path);
                 OUTER: for (HintDescription hd : rules) {
                     if (isCanceled()) {
                         return ;
                     }
+                    if (guarded && !hd.getTrigger().hasOption(TriggerOptions.PROCESS_GUARDED)) {
+                        continue;
+                    }
 
                     HintMetadata hm = hd.getMetadata();
 
