@@ -47,6 +47,8 @@ package org.netbeans.modules.tasklist.todo.settings;
 import java.awt.Component;
 import java.awt.Graphics;
 import java.awt.Rectangle;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -113,6 +115,18 @@ class ToDoCustomizer extends javax.swing.JPanel implements DocumentListener{
                 enableButtons();
             }
         });
+        table.addPropertyChangeListener(new PropertyChangeListener() {
+            @Override
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("tableCellEditor".equals(evt.getPropertyName())) { //NOI18N
+                    if (!table.isEditing()) { //  A cell has stopped editing
+                        fireChanged();
+                        firePropertyChange(OptionsPanelController.PROP_CHANGED, new Boolean(changed), Boolean.TRUE);
+                        firePropertyChange(OptionsPanelController.PROP_VALID, null, null);
+                    }
+                }
+            }
+        });
         jScrollPane1.getViewport().setOpaque( false );
         enableButtons();
     }
@@ -447,7 +461,7 @@ class ToDoCustomizer extends javax.swing.JPanel implements DocumentListener{
             FileObject[] children = factoriesFO.getChildren();
             for (FileObject child : children) {
                 String childName = child.getNameExt();
-                String displayName = filesystem.getStatus().annotateName(childName, Collections.singleton(child));
+                String displayName = filesystem.getDecorator().annotateName(childName, Collections.singleton(child));
                 if (!childName.equals(displayName)) {
                     return displayName;
                 }
@@ -800,7 +814,7 @@ private void btnChangeActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIR
         editor.addCellEditorListener( new CellEditorListener() {
             public void editingStopped(ChangeEvent e) {
                 editor.removeCellEditorListener( this );
-                table.setValueAt(editor.getCellEditorValue(), model.getRowCount() - 1, 0);
+                model.setValueAt(editor.getCellEditorValue(), model.getRowCount() - 1, 0);
                 fireChanged();
                 firePropertyChange( OptionsPanelController.PROP_CHANGED, new Boolean(wasChanged), Boolean.TRUE);
                 firePropertyChange(OptionsPanelController.PROP_VALID, null, null);
