@@ -47,13 +47,17 @@ package org.netbeans.modules.terminal.ioprovider;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
+import java.awt.Dialog;
 import java.awt.Dimension;
 import java.awt.Point;
 import java.awt.datatransfer.Clipboard;
+import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.StringSelection;
+import java.awt.datatransfer.Transferable;
+import java.awt.datatransfer.UnsupportedFlavorException;
 import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.awt.event.InputEvent;
-import java.awt.event.KeyEvent;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseWheelEvent;
@@ -63,30 +67,32 @@ import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.beans.PropertyVetoException;
 import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.PrintStream;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.StringTokenizer;
-import java.util.logging.Level;
-import java.util.logging.Logger;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.prefs.Preferences;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.ActionMap;
+import javax.swing.Icon;
+import javax.swing.ImageIcon;
 import javax.swing.InputMap;
-import javax.swing.JCheckBoxMenuItem;
+import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JPopupMenu;
-import javax.swing.JSeparator;
 import javax.swing.KeyStroke;
 import javax.swing.SwingUtilities;
+import javax.swing.TransferHandler;
 import javax.swing.event.PopupMenuEvent;
 import javax.swing.event.PopupMenuListener;
 import javax.swing.text.AttributeSet;
 import javax.swing.text.Keymap;
-import org.openide.NotifyDescriptor.InputLine;
 import org.openide.filesystems.FileAttributeEvent;
 import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileRenameEvent;
@@ -117,15 +123,26 @@ import org.netbeans.lib.terminalemulator.ActiveRegion;
 import org.netbeans.lib.terminalemulator.ActiveTermListener;
 import org.netbeans.lib.terminalemulator.Extent;
 import org.netbeans.lib.terminalemulator.TermListener;
+import org.netbeans.lib.terminalemulator.TermStream;
+import org.netbeans.modules.terminal.actions.ActionFactory;
+import org.netbeans.modules.terminal.actions.PinTabAction;
 import org.netbeans.modules.terminal.api.IOResizable;
+import org.netbeans.modules.terminal.support.TerminalPinSupport;
+import org.netbeans.modules.terminal.support.TerminalPinSupport.DetailsStateListener;
+import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
-import org.openide.NotifyDescriptor;
 import org.openide.cookies.InstanceCookie;
 import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.loaders.DataObject;
+import org.openide.util.ContextAwareAction;
 import org.openide.util.Exceptions;
+import org.openide.util.ImageUtilities;
+import org.openide.util.NbBundle;
+import org.openide.util.Utilities;
+import org.openide.util.WeakListeners;
+import org.openide.util.datatransfer.MultiTransferObject;
 import org.openide.windows.InputOutput;
 import org.openide.windows.OutputEvent;
 import org.openide.windows.OutputListener;
@@ -194,6 +211,9 @@ public final class Terminal extends JComponent {
     // properties managed by IOvisibility
     private boolean closable = true;
 
+    private boolean pinned = false;
+    private String cwd;
+
     private boolean closedUnconditionally;
 
     private class TermOptionsPCL implements PropertyChangeListener {
@@ -260,23 +280,42 @@ public final class Terminal extends JComponent {
      * Adapter to forward Term size change events as property changes.
      */
     private class MyTermListener implements TermListener {
+
+	private final static int MAX_TITLE_LENGTH = 35;
+	private final static String PREFIX = "..."; // NOI18N
+	private final static String INFIX = " - "; // NOI18N
+
 	@Override
 	public void sizeChanged(Dimension cells, Dimension pixels) {
 	    IOResizable.Size size = new IOResizable.Size(cells, pixels);
 	    tio.pcs().firePropertyChange(IOResizable.PROP_SIZE, null, size);
 	}
 
-	private final static int MAX_TITLE_LENGTH = 40;
+	@Override
+	public void cwdChanged(String cwd) {
+	    if (!customTitle) {
+		int newLength = PREFIX.length() + INFIX.length() + cwd.length();
+		String newTitle = name.concat(INFIX).concat(cwd);
+		updateTooltopText(newTitle);
+		if (newLength > MAX_TITLE_LENGTH) {
+		    newTitle = name
+			    .concat(INFIX)
+			    .concat(PREFIX)
+			    .concat(cwd.substring(newLength - MAX_TITLE_LENGTH));
+		}
+		updateName(newTitle);
+	    }
+	}
 
 	@Override
 	public void titleChanged(String title) {
 	    if (!customTitle) {
-		final String prefix = "...";			// NOI18N
-		final int currentLength = prefix.length() + title.length();
-		if (currentLength > MAX_TITLE_LENGTH) {
-		    title = prefix + title.substring(currentLength - MAX_TITLE_LENGTH);
+		String newTitle = title;
+		updateTooltopText(newTitle);
+		if (title.length() > MAX_TITLE_LENGTH) {
+		    newTitle = PREFIX.concat(title.substring(title.length() - MAX_TITLE_LENGTH));
 		}
-		updateName(title);
+		updateName(newTitle);
 	    }
 	}
     }
@@ -320,18 +359,70 @@ public final class Terminal extends JComponent {
         term.setHistorySize(4000);
         term.setRenderingHints(getRenderingHints());
 	
+		term.addListener(new TermListener() {
+
+	    @Override
+	    public void sizeChanged(Dimension cells, Dimension pixels) {
+	    }
+
+	    @Override
+	    public void titleChanged(String title) {
+	    }
+
+	    @Override
+	    public void cwdChanged(String aCwd) {
+		cwd = aCwd;
+	    }
+	});
+	
 	shortcutsDir.addFileChangeListener(shortcutsListener);
         termOptions.addPropertyChangeListener(termOptionsPCL);
         applyTermOptions(true);
-
+	
 	final Set<Action> actions = new HashSet<Action>();
+	final Set<Action> awareActions = new HashSet<Action>();
 	actions.add(copyAction);
 	actions.add(pasteAction);
 	actions.add(findAction);
 	actions.add(wrapAction);
+	actions.add(largerFontAction);
+	actions.add(smallerFontAction);
+	actions.add(setTitleAction);
+	actions.add(pinTabAction);
 	actions.add(clearAction);
+	actions.add(dumpSequencesAction);
 	actions.add(closeAction);
-	setupKeymap(actions);
+	
+	for (Action action : actions) {
+	    if (action instanceof ContextAwareAction) {
+		action = ((ContextAwareAction) action).createContextAwareInstance(Lookups.fixed(this));
+	    }
+	    awareActions.add(action);
+	}
+	
+	final TerminalPinSupport support = TerminalPinSupport.getDefault();
+	TerminalPinSupport.DetailsStateListener listener = new TerminalPinSupport.DetailsStateListener() {
+
+	    @Override
+	    public void detailsAdded(Term notifiedTerm) {
+		if (notifiedTerm != term) {
+		    return;
+		}
+		TerminalPinSupport.TerminalPinningDetails pinDetails = support.findPinningDetails(notifiedTerm);
+		if (pinDetails != null) {
+		    boolean customTitle = pinDetails.isCustomTitle();
+		    setCustomTitle(customTitle);
+		    if (customTitle) {
+			setTitle(pinDetails.getTitle());
+		    }
+		    pin(true);
+		}
+	    }
+	};
+
+	support.addDetailsStateListener(WeakListeners.create(DetailsStateListener.class, listener, support));
+	
+	setupKeymap(awareActions);
 
         mouseAdapter = new MouseAdapter() {
             @Override
@@ -359,8 +450,18 @@ public final class Terminal extends JComponent {
 
 	};
         term.getScreen().addMouseListener(mouseAdapter);
-	
-	term.getScreen().addMouseWheelListener(new MouseWheelListener() {
+
+        term.getScreen().getActionMap().put("org.openide.actions.PopupAction", new AbstractAction() { //NOI18N
+
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                Point p = getPopupPosition();
+                postPopupMenu(p);
+            }
+        }
+        );
+
+        term.getScreen().addMouseWheelListener(new MouseWheelListener() {
 
 	    @Override
 	    public void mouseWheelMoved(final MouseWheelEvent e) {
@@ -369,11 +470,15 @@ public final class Terminal extends JComponent {
 		    changeFontSizeBy(change);
 		    e.consume();
 		}
-	    }
+	    }	
 	});
 
 	termListener = new MyTermListener();
 	term.addListener(termListener);
+	
+//	final SupportStream supportStream = new SupportStream();
+//	term.pushStream(supportStream);
+//	term.setTransferHandler(new TransferHandlerImpl(supportStream));
 
         // Set up to convert clicks on active regions, created by OutputWriter.
         // println(), to outputLineAction notifications.
@@ -518,6 +623,10 @@ public final class Terminal extends JComponent {
     public ActiveTerm term() {
         return term;
     }
+    
+    public String getCwd() {
+	return cwd;
+    }
 
     public void setTitle(String title) {
 	customTitle = true;
@@ -530,32 +639,14 @@ public final class Terminal extends JComponent {
     }
 
     public String getTitle() {
-        return title == null ? name : title;
+        return title;
     }
 
-    FindState getFindState() {
+    public FindState getFindState() {
         return findState;
     }
 
-    private final class ClearAction extends AbstractAction {
-        public ClearAction() {
-            super(Catalog.get("CTL_Clear"));	// NOI18N
-	    /* OLD
-            KeyStroke accelerator = KeyStroke.getKeyStroke(KeyEvent.VK_E,
-                                                           InputEvent.ALT_MASK);
-            putValue(ACCELERATOR_KEY, accelerator);
-	    */
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-            term.clear();
-        }
-    }
-    
-    private void changeFontSizeBy(final int d) {
+    public void changeFontSizeBy(final int d) {
 	int oldFontSize = termOptions.getFontSize();
 	
 	int newFontSze = oldFontSize + d;
@@ -567,216 +658,23 @@ public final class Terminal extends JComponent {
 	
 	TermOptions.getDefault(prefs).setFontSize(newFontSze);
     }
-    
-    private final class LargerFontAction extends AbstractAction{
 
-	public LargerFontAction() {
-	    super(Catalog.get("CTL_LargerFont")); //NOI18N
-	}
+    public boolean isPinned() {
+	return pinned;
+    }
 
-	@Override
-	public void actionPerformed(final ActionEvent e) {
-	    changeFontSizeBy(+1);
-	}
+    public void setPinned(boolean pinned) {
+	this.pinned = pinned;
     }
     
-    private final class SmallerFontAction extends AbstractAction{
-
-	public SmallerFontAction() {
-	    super(Catalog.get("CTL_SmallerFont")); //NOI18N
-	}
-
-	@Override
-	public void actionPerformed(final ActionEvent e) {
-	    changeFontSizeBy(-1);
-	}
-    }
-    
-
-    private final class CloseAction extends AbstractAction {
-        public CloseAction() {
-            super(Catalog.get("CTL_Close"));	// NOI18N
-            KeyStroke accelerator = KeyStroke.getKeyStroke(KeyEvent.VK_W,
-                                                           InputEvent.CTRL_MASK | InputEvent.SHIFT_MASK);
-            putValue(ACCELERATOR_KEY, accelerator);
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-            close();
-        }
-
-	@Override
-	public boolean isEnabled() {
-	    return closable;
-	}
-    }
-    
-        private final class DumpSequencesAction extends AbstractAction {
-        public DumpSequencesAction() {
-            super("Dump Sequences");	// NOI18N
-        }
-
-        private void dump(String title, Set<String> set) {
-            File file = new File(String.format("/tmp/term-sequences-%s", title)); // NOI18N
-            PrintStream ps;
-            try {
-                ps = new PrintStream(file);
-            } catch (FileNotFoundException ex) {
-                Logger.getLogger(Terminal.class.getName()).log(Level.SEVERE, null, ex);
-                return;
-            }
-
-            if (set != null) {
-                for (String s : set) {
-                    ps.printf("%s\n", s); // NOI18N
-		}
-            }
-
-            ps.close();
-        }
-
-        @Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled()) {
-		return;
-	    }
-            dump("completed", term.getCompletedSequences()); // NOI18N
-            dump("unrecognized", term.getUnrecognizedSequences()); // NOI18N
-        }
+    public boolean isCustomTitle() {
+	return customTitle;
     }
 
-    private final class SetTitleAction extends AbstractAction {
-
-	public SetTitleAction() {
-	    super(Catalog.get("CTL_SetTitle"));	// NOI18N
-	}
-
-	@Override
-	public void actionPerformed(ActionEvent e) {
-	    InputLine inputLine = new NotifyDescriptor.InputLine(Catalog.get("LBL_Title"), Catalog.get("LBL_SetTitle"));// NOI18N
-	    String title = getTitle();
-	    inputLine.setInputText(title);
-	    if (DialogDisplayer.getDefault().notify(inputLine) == NotifyDescriptor.OK_OPTION) {
-		String newTitle = inputLine.getInputText().trim();
-		if (!newTitle.equals(title)) {
-		    if (!newTitle.isEmpty()) {
-			setTitle(newTitle);
-		    } else {
-			resetTitle();
-		    }
-		}
-	    }
-	}
+    public void setCustomTitle(boolean customTitle) {
+	this.customTitle = customTitle;
     }
 
-    private final class CopyAction extends AbstractAction {
-        public CopyAction() {
-            super(Catalog.get("CTL_Copy"));	// NOI18N
-            KeyStroke accelerator = KeyStroke.getKeyStroke(KeyEvent.VK_C,
-                                                           InputEvent.CTRL_MASK | InputEvent.SHIFT_MASK);
-            // System.out.printf("Accelerator for Copy: %s\n", accelerator);
-            putValue(ACCELERATOR_KEY, accelerator);
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-            term.copyToClipboard();
-        }
-    }
-
-    private final class PasteAction extends AbstractAction {
-        public PasteAction() {
-            super(Catalog.get("CTL_Paste"));	// NOI18N
-            KeyStroke accelerator = KeyStroke.getKeyStroke(KeyEvent.VK_V,
-                                                           InputEvent.CTRL_MASK | InputEvent.SHIFT_MASK);
-            // System.out.printf("Accelerator for Paste: %s\n", accelerator);
-            putValue(ACCELERATOR_KEY, accelerator);
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-            term.pasteFromClipboard();
-        }
-    }
-
-    private final class FindAction extends AbstractAction {
-        public FindAction() {
-            super(Catalog.get("CTL_Find"));	// NOI18N
-	    /* LATER
-            KeyStroke accelerator = KeyStroke.getKeyStroke(KeyEvent.VK_F,
-                                                           InputEvent.ALT_MASK);
-            putValue(ACCELERATOR_KEY, accelerator);
-	    */
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-
-	    // OLD ioContainer.find(Terminal.this);
-	    // the following is code that used to be in TerminalContainer.find():
-	    FindState findState = getFindState();
-	    if (findState.isVisible()) {
-		return;
-	    }
-	    findState.setVisible(true);
-	    /* LATER
-	    findBar.setState(findState);
-	    add(findBar, BorderLayout.SOUTH);
-	    validate();
-	     */
-        }
-    }
-
-    private static final String BOOLEAN_STATE_ACTION_KEY = "boolean_state_action";	// NOI18N
-    private static final String BOOLEAN_STATE_ENABLED_KEY = "boolean_state_enabled";	// NOI18N
-
-    private final class WrapAction extends AbstractAction {
-        public WrapAction() {
-            super(Catalog.get("CTL_Wrap"));	// NOI18N
-            // LATER KeyStroke accelerator = Utilities.stringToKey("A-R");
-            putValue(BOOLEAN_STATE_ACTION_KEY, true);
-        }
-
-	@Override
-        public void actionPerformed(ActionEvent e) {
-            if (!isEnabled())
-                return;
-            boolean hs = term.isHorizontallyScrollable();
-            term.setHorizontallyScrollable(!hs);
-        }
-
-        @Override
-        public Object getValue(String key) {
-            if (key.equals(BOOLEAN_STATE_ENABLED_KEY))
-                return ! term.isHorizontallyScrollable();
-            else
-                return super.getValue(key);
-
-        }
-    }
-
-    private final Action copyAction = new CopyAction();
-    private final Action setTitleAction = new SetTitleAction();
-    private final Action pasteAction = new PasteAction();
-    private final Action findAction = new FindAction();
-    private final Action wrapAction = new WrapAction();
-    private final Action clearAction = new ClearAction();
-    private final Action closeAction = new CloseAction();
-    private final Action largerFontAction = new LargerFontAction();
-    private final Action smallerFontAction = new SmallerFontAction();
-    private final Action dumpSequencesAction = new DumpSequencesAction();
-
-
-
     // Ideally IOContainer.remove() would be unconditional and we could check
     // the isClosable() and vetoing here. However, Closing a tab via it's 'X'
     // is internal to IOContainer implementation and it calls IOCOntainer.remove()
@@ -800,8 +698,96 @@ public final class Terminal extends JComponent {
     }
 
     public void close() {
-	if (!isVisibleInContainer())
+	if (!isVisibleInContainer()) {
 	    return;
+	}
+
+	if (isPinnable()) {
+	    /* Will be enabled after delegating actions from TerminalContainerTabber will 
+	     * be implemented. Enabling this now will cause inconsistensy or copy-pasting.
+	     */
+	    final AtomicBoolean canceled = new AtomicBoolean(false);
+	    if (pinned && !closedUnconditionally) {
+		final int CLOSE_AND_UNPIN = 0;
+		final int CLOSE = 1;
+		final int CANCEL = 2;
+
+		final String CMD_CLOSE_AND_UNPIN = "CloseAndUnpin"; //NOI18N
+		final String CMD_CLOSE = "Close"; //NOI18N
+		final String CMD_CANCEL = "Cancel"; //NOI18N
+
+		JButton[] options = new JButton[]{
+		    new JButton(NbBundle.getMessage(Terminal.class, "TXT_CloseAndUnpin", getTitle())),
+		    new JButton(NbBundle.getMessage(Terminal.class, "TXT_Close")),
+		    new JButton(NbBundle.getMessage(Terminal.class, "TXT_Cancel"))
+		};
+
+		ActionListener commandListener = new ActionListener() {
+
+		    @Override
+		    public void actionPerformed(ActionEvent e) {
+			String command = e.getActionCommand();
+
+			if (CMD_CLOSE_AND_UNPIN.equals(command)) {
+			    Action pinTabAction = ActionFactory.forID(ActionFactory.PIN_TAB_ACTION_ID);
+			    if (pinTabAction != null) {
+				pinTabAction.actionPerformed(null);
+			    }
+			} else if (CMD_CANCEL.equals(command)) {
+			    canceled.set(true);
+			    return;
+			} else if (CMD_CLOSE.equals(command)){
+			    return;
+			}
+		    }
+		};
+
+		options[CLOSE_AND_UNPIN].setActionCommand(CMD_CLOSE_AND_UNPIN);
+		options[CLOSE].setActionCommand(CMD_CLOSE);
+		options[CANCEL].setActionCommand(CMD_CANCEL);
+
+		options[CLOSE_AND_UNPIN].addActionListener(commandListener);
+		options[CLOSE].addActionListener(commandListener);
+		options[CANCEL].addActionListener(commandListener);
+
+		String message = NbBundle.getMessage(Terminal.class, "LBL_CloseTerminal", getTitle());
+
+		DialogDescriptor dd = new DialogDescriptor(
+			message,
+			NbBundle.getMessage(Terminal.class, "TXT_CloseTerminalTitle"),
+			true,
+			options,
+			options[CLOSE_AND_UNPIN],
+			DialogDescriptor.DEFAULT_ALIGN,
+			null,
+			null
+		);
+
+		dd.setClosingOptions(options); // all are closing
+
+		Dialog dialog = DialogDisplayer.getDefault().createDialog(dd);
+
+		try {
+		    dialog.setVisible(true);
+		} catch (Throwable th) {
+		    if (!(th.getCause() instanceof InterruptedException)) {
+			throw new RuntimeException(th);
+		    }
+		    dd.setValue(options[CANCEL]);
+		} finally {
+		    dialog.dispose();
+		}
+
+		if (dd.getValue().equals(DialogDescriptor.DEFAULT_OPTION)) {
+		    canceled.set(true);
+		}
+	    }
+
+	    if (canceled.get()) {
+		return;
+	    }
+	}
+
 	ioContainer.remove(this);
     }
 
@@ -879,26 +865,74 @@ public final class Terminal extends JComponent {
 	Task task = new Task.UpdateName(ioContainer, this);
 	task.post();
     }
+    
+    private void updateTooltopText(String text) {
+	Task task = new Task.SetToolTipText(ioContainer, this, text);
+	task.post();
+    }
+
+    private void setIcon(Icon icon) {
+	Task task = new Task.SetIcon(ioContainer, this, icon);
+	task.post();
+    }
+        
+    private final ImageIcon icon = ImageUtilities.loadImageIcon("org/netbeans/modules/terminal/support/pin.png", false); //NOI18N
+
+    public void pin(boolean newState) {
+	if (newState) {
+	    setIcon(icon);
+	} else {
+	    setIcon(null);
+	}
+	TerminalPinSupport.getDefault().findPinningDetails(term).setPinned(newState);
+
+	setPinned(newState);
+	
+	pinTabAction.putValue("Name", PinTabAction.getMessage(newState)); //NOI18N
+    }
+    
+    private boolean isPinnable() {
+	Object clientProperty = this.getClientProperty("pinAction"); //NOI18N
+	return clientProperty != null && clientProperty.equals("enabled"); //NOI18N
+    }
+
+    /*
+    private static final String BOOLEAN_STATE_ACTION_KEY = "boolean_state_action";	// NOI18N
+    private static final String BOOLEAN_STATE_ENABLED_KEY = "boolean_state_enabled";	// NOI18N
 
     private boolean isBooleanStateAction(Action a) {
-        Boolean isBooleanStateAction = (Boolean) a.getValue(BOOLEAN_STATE_ACTION_KEY);	//
-        return isBooleanStateAction != null && isBooleanStateAction;
+	Boolean isBooleanStateAction = (Boolean) a.getValue(BOOLEAN_STATE_ACTION_KEY);	//
+	return isBooleanStateAction != null && isBooleanStateAction;
     }
 
+    // not used
     private void addMenuItem(JPopupMenu menu, Object o) {
-        if (o instanceof JSeparator) {
-            menu.add((JSeparator) o);
-        } else if (o instanceof Action) {
-            Action a = (Action) o;
-            if (isBooleanStateAction(a)) {
-                JCheckBoxMenuItem item = new JCheckBoxMenuItem(a);
-                item.setSelected((Boolean) a.getValue(BOOLEAN_STATE_ENABLED_KEY));
-                menu.add(item);
-            } else {
-                menu.add((Action) o);
-            }
-        }
+	if (o instanceof JSeparator) {
+	    menu.add((JSeparator) o);
+	} else if (o instanceof Action) {
+	    Action a = (Action) o;
+	    if (isBooleanStateAction(a)) {
+		JCheckBoxMenuItem item = new JCheckBoxMenuItem(a);
+		item.setSelected((Boolean) a.getValue(BOOLEAN_STATE_ENABLED_KEY));
+		menu.add(item);
+	    } else {
+		menu.add((Action) o);
+	    }
+	}
     }
+    */
+    
+    private Action copyAction = ActionFactory.forID(ActionFactory.COPY_ACTION_ID);
+    private Action pasteAction = ActionFactory.forID(ActionFactory.PASTE_ACTION_ID);
+    private Action findAction = ActionFactory.forID(ActionFactory.FIND_ACTION_ID);
+    private Action wrapAction = ActionFactory.forID(ActionFactory.WRAP_ACTION_ID);
+    private Action largerFontAction = ActionFactory.forID(ActionFactory.LARGER_FONT_ACTION_ID);
+    private Action smallerFontAction = ActionFactory.forID(ActionFactory.SMALLER_FONT_ACTION_ID);
+    private Action setTitleAction = ActionFactory.forID(ActionFactory.SET_TITLE_ACTION_ID);
+    private Action pinTabAction = ActionFactory.forID(ActionFactory.PIN_TAB_ACTION_ID);
+    private Action clearAction = ActionFactory.forID(ActionFactory.CLEAR_ACTION_ID);
+    private Action dumpSequencesAction = ActionFactory.forID(ActionFactory.DUMP_SEQUENCE_ACTION_ID);
+    private Action closeAction = ActionFactory.forID(ActionFactory.CLOSE_ACTION_ID);
 
     private void setupKeymap(Set<Action> actions) {
 	// We need to do two things.
@@ -935,7 +969,7 @@ public final class Terminal extends JComponent {
 	System.out.printf("Terminal.setupKeymap() ... lookup returns %d hits\n", c.size());
 	Keymap globalKeymap = Lookup.getDefault().lookup(Keymap.class);
 	if (globalKeymap == null) {
-	    System.out.printf("\tCouldn't find keymap\n");
+	    System.out.printf("\tCouldn't findPinningDetails keymap\n");
 	} else {
 	    KeyStroke[] keyStrokes = globalKeymap.getBoundKeyStrokes();
 	    for (KeyStroke ks : keyStrokes) {
@@ -953,10 +987,41 @@ public final class Terminal extends JComponent {
         term.setKeyStrokeSet((HashSet) passKeystrokes);
     }
 
+    private Point getPopupPosition() {
+        final int offset = 25;
+
+        return new Point(offset, offset);
+    }
+
     private void postPopupMenu(Point p) {
-        JPopupMenu menu = new JPopupMenu();
+	findAction.setEnabled(!findState.isVisible());
+
+	// TMP Find is not operation so keep it disabled
+	// TODO IG fix
+	findAction.setEnabled(false);
+	
+	JPopupMenu menu = Utilities.actionsToPopup(
+		new Action[]{
+		    copyAction,
+		    pasteAction,
+		    null,
+		    /*
+		    findAction,
+		    null,*/
+		    wrapAction,
+		    largerFontAction,
+		    smallerFontAction,
+		    null,
+		    setTitleAction,
+		    isPinnable() ? pinTabAction : null, //NOI18N
+		    null,
+		    clearAction,
+		    isClosable() ? closeAction : null, // it's ok to have null as last element,
+		    (System.getProperty("Term.debug") != null) ? dumpSequencesAction : null
+		}, Lookups.fixed(this)
+	);
 	menu.putClientProperty("container", ioContainer); // NOI18N
-        menu.putClientProperty("component", this);             // NOI18N
+	menu.putClientProperty("component", this);             // NOI18N
 
 	/* LATER?
 	 * NB IO APIS don't add sidebar actions to menu
@@ -970,30 +1035,7 @@ public final class Terminal extends JComponent {
                 menu.add(new JSeparator());
         }
 	 */
-        addMenuItem(menu, copyAction);
-        addMenuItem(menu, pasteAction);
-        addMenuItem(menu, new JSeparator());
-        addMenuItem(menu, findAction);
-        addMenuItem(menu, new JSeparator());
-        addMenuItem(menu, wrapAction);
-        addMenuItem(menu, largerFontAction);
-        addMenuItem(menu, smallerFontAction);
-	addMenuItem(menu, new JSeparator());
-	addMenuItem(menu, setTitleAction);
-        addMenuItem(menu, new JSeparator());
-        addMenuItem(menu, clearAction);
-	if (isClosable())
-	    addMenuItem(menu, closeAction);
-
-	if (System.getProperty("Term.debug") != null) {
-            addMenuItem(menu, dumpSequencesAction);
-        }
-
-        findAction.setEnabled(! findState.isVisible());
-
-	// TMP Find is not operation so keep it disabled
-	findAction.setEnabled(false);
-
+	
         menu.addPopupMenuListener(new PopupMenuListener() {
 	    @Override
             public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
@@ -1134,4 +1176,160 @@ public final class Terminal extends JComponent {
 	    }
 	}
     }
+    
+    private static class SupportStream extends TermStream {
+
+	@Override
+	public void flush() {
+	    if (toDCE == toDTE) {
+		toDCE.flush();
+	    } else {
+		toDTE.flush();
+		toDCE.flush();
+	    }
+	}
+
+	@Override
+	public void putChar(char c) {
+	    toDTE.putChar(c);
+	}
+
+	@Override
+	public void putChars(char[] buf, int offset, int count) {
+	    toDTE.putChars(buf, offset, count);
+	}
+
+	@Override
+	public void sendChar(char c) {
+	    toDCE.sendChar(c);
+	}
+
+	@Override
+	public void sendChars(char[] c, int offset, int count) {
+	    toDCE.sendChars(c, offset, count);
+	}
+
+    }
+
+    private static class TransferHandlerImpl extends TransferHandler {
+
+	private DataFlavor dataObjectDnd = null;
+	private DataFlavor multiTransferObject = null;
+	private final SupportStream stream;
+
+	public TransferHandlerImpl(SupportStream stream) {
+	    /*
+	     * Trying to load data flavor for drag'n'drop operations . 
+	     * So in this case just don't enable drag'n'drop feature for FileObjects.
+	     */
+	    try {
+		this.dataObjectDnd = new DataFlavor("application/x-java-openide-dataobjectdnd;class=org.openide.loaders.DataObject;mask={0}");//NOI18N
+	    } catch (ClassNotFoundException ex) {
+	    }
+	    try {
+		this.multiTransferObject = new DataFlavor("application/x-java-openide-multinode;class=org.openide.util.datatransfer.MultiTransferObject;mask={0}");//NOI18N
+	    } catch (ClassNotFoundException ex) {
+	    }
+	    
+	    this.stream = stream;
+	}
+
+	private void display(List<String> strings) {
+	    StringBuilder sb = new StringBuilder();
+	    for (String string : strings) {
+		sb.append('\'');
+		sb.append(string);
+		sb.append('\'');
+		sb.append(' ');
+	    }
+
+	    final String str = sb.toString();
+	    SwingUtilities.invokeLater(new Runnable() {
+
+		@Override
+		public void run() {
+		    stream.sendChars(str.toCharArray(), 0, str.length());
+		    }
+	    });
+	}
+
+	@Override
+	public boolean canImport(TransferHandler.TransferSupport support) {
+	    boolean canHandleDO = (dataObjectDnd != null && support.isDataFlavorSupported(dataObjectDnd));
+	    boolean canHandleMTO = (multiTransferObject != null && support.isDataFlavorSupported(multiTransferObject));
+	    boolean canHandleList = support.isDataFlavorSupported(DataFlavor.javaFileListFlavor);
+	    
+	    if (canHandleDO || canHandleList) {
+		return true;
+	    } else if (canHandleMTO) {
+		try {
+		    MultiTransferObject mto = (MultiTransferObject) support.getTransferable().getTransferData(multiTransferObject);
+		    for (int i = 0; i < mto.getCount(); i++) {
+			if (mto.isDataFlavorSupported(i, dataObjectDnd)) {
+			    return true;
+			}
+		    }
+		} catch (UnsupportedFlavorException ex) {
+		} catch (IOException ex) {
+		}
+	    }
+
+	    return false;
+	}
+
+	/**
+	 * Drops a list of objects to the Terminal, single quoted, space as
+	 * a delimiter. Terminal TC won't gain focus.
+	 * Order: 
+	 * 1. List of FileObject 
+	 * 2. Single FileObject 
+	 * 3. List of File. 
+	 * FO stands before File because list of RemoteFO is recognized as list 
+	 * of File but can't be correctly handled.
+	 *
+	 */
+	@Override
+	public boolean importData(TransferHandler.TransferSupport support) {
+	    Transferable transferable = support.getTransferable();
+
+	    try {
+		if (multiTransferObject != null && support.isDataFlavorSupported(multiTransferObject)) {
+		    MultiTransferObject mto = (MultiTransferObject) transferable.getTransferData(multiTransferObject);
+		    List<String> strings = new ArrayList<String>();
+		    for (int i = 0; i < mto.getCount(); i++) {
+			if (mto.isDataFlavorSupported(i, dataObjectDnd)) {
+			    DataObject dObj = (DataObject) mto.getTransferData(i, dataObjectDnd);
+			    FileObject fObj = dObj.getLookup().lookup(FileObject.class);
+			    if (fObj != null) {
+				strings.add(fObj.getPath());
+			    }
+			}
+		    }
+		    display(strings);
+		    return true;
+		} else if (dataObjectDnd != null && support.isDataFlavorSupported(dataObjectDnd)) {
+		    DataObject dObj = (DataObject) transferable.getTransferData(dataObjectDnd);
+		    FileObject fObj = dObj.getLookup().lookup(FileObject.class);
+		    if (fObj != null) {
+			String str = fObj.getPath();
+			display(Arrays.asList(str));
+			return true;
+		    }
+		} else if (support.isDataFlavorSupported(DataFlavor.javaFileListFlavor)) {
+		    List<File> list = (List<File>) transferable.getTransferData(DataFlavor.javaFileListFlavor);
+		    List<String> strings = new ArrayList<String>();
+		    for (File file : list) {
+			strings.add(file.getAbsolutePath());
+		    }
+
+		    display(strings);
+		    return true;
+		}
+	    } catch (UnsupportedFlavorException ex) {
+	    } catch (IOException ex) {
+	    }
+
+	    return false;
+	}
+    }
 }
