@@ -238,7 +238,7 @@ public class TomcatManager implements DeploymentManager {
             }
         }
         if (checkResponse) {
-            return Utils.pingTomcat(getServerPort(), timeout); // is tomcat responding?
+            return Utils.pingTomcat(getServerPort(), timeout, getServerHeader(), getPlainUri()); // is tomcat responding?
         } else {
             return false; // cannot resolve the state
         }
@@ -463,40 +463,45 @@ public class TomcatManager implements DeploymentManager {
         return tomEEVersion;
     }
 
-    public synchronized void loadTomEEInfo() {
-        if (tomEEChecked) {
-            LOGGER.log(Level.INFO, "TomEE version {0}, type {1}", new Object[] {tomEEVersion, tomEEType});
-            return;
-        }
-        assert tomEEWarListener == null;
-
-        tomEEChecked = true;
-        tomEEVersion = TomcatFactory.getTomEEVersion(tp.getCatalinaHome(), tp.getCatalinaBase());
-        tomEEType = tomEEVersion == null ? null : TomcatFactory.getTomEEType(tp.getCatalinaHome(), tp.getCatalinaBase());
-        if (tomEEVersion == null) {
-            tomEEWarListener = new TomEEWarListener(tp, new TomEEWarListener.RefreshHook() {
-
-                @Override
-                public void refresh(TomEEVersion version, TomEEType type) {
-                    synchronized (TomcatManager.this) {
-                        tomEEVersion = version;
-                        tomEEType = type;
-                    }
-                    getTomcatPlatform().notifyLibrariesChanged();
-                }
-            });
-            File listenFile;
-            if (tp.getCatalinaBase() != null) {
-                listenFile = new File(tp.getCatalinaBase(), "webapps"); // NOI18N
-            } else {
-                listenFile = new File(tp.getCatalinaHome(), "webapps"); // NOI18N
+    public void loadTomEEInfo() {
+        boolean fireListener = false;
+        synchronized (this) {
+            if (tomEEChecked) {
+                LOGGER.log(Level.INFO, "TomEE version {0}, type {1}", new Object[] {tomEEVersion, tomEEType});
+                return;
             }
+            assert tomEEWarListener == null;
 
-            FileUtil.addFileChangeListener(tomEEWarListener, listenFile);
+            tomEEChecked = true;
+            tomEEVersion = TomcatFactory.getTomEEVersion(tp.getCatalinaHome(), tp.getCatalinaBase());
+            tomEEType = tomEEVersion == null ? null : TomcatFactory.getTomEEType(tp.getCatalinaHome(), tp.getCatalinaBase());
+            if (tomEEVersion == null) {
+                tomEEWarListener = new TomEEWarListener(tp, new TomEEWarListener.RefreshHook() {
+
+                    @Override
+                    public void refresh(TomEEVersion version, TomEEType type) {
+                        synchronized (TomcatManager.this) {
+                            tomEEVersion = version;
+                            tomEEType = type;
+                        }
+                        getTomcatPlatform().notifyLibrariesChanged();
+                    }
+                });
+                File listenFile;
+                if (tp.getCatalinaBase() != null) {
+                    listenFile = new File(tp.getCatalinaBase(), "webapps"); // NOI18N
+                } else {
+                    listenFile = new File(tp.getCatalinaHome(), "webapps"); // NOI18N
+                }
+
+                FileUtil.addFileChangeListener(tomEEWarListener, listenFile);
+                fireListener = true;
+            }
+            LOGGER.log(Level.INFO, "TomEE version {0}, type {1}", new Object[] {tomEEVersion, tomEEType});
+        }
+        if (fireListener) {
             tomEEWarListener.checkAndRefresh();
         }
-
-        LOGGER.log(Level.INFO, "TomEE version {0}, type {1}", new Object[] {tomEEVersion, tomEEType});
     }
 
 // --- DeploymentManager interface implementation ----------------------
@@ -764,16 +769,21 @@ public class TomcatManager implements DeploymentManager {
     /** Return server port defined in the server.xml file, this value may differ
      * from the actual port Tomcat is currently running on @see #getCurrentServerPort(). */
     public int getServerPort() {
-        ensurePortsUptodate();
+        ensureConnectionInfoUptodate();
         return tp.getServerPort();
     }
 
     public int getShutdownPort() {
-        ensurePortsUptodate();
+        ensureConnectionInfoUptodate();
         return tp.getShutdownPort();
     }
+
+    public String getServerHeader() {
+        ensureConnectionInfoUptodate();
+        return tp.getServerHeader();
+    }
     
-    private void ensurePortsUptodate() {
+    private void ensureConnectionInfoUptodate() {
         File serverXml = tp.getServerXml();
         long timestamp = -1;
         if (serverXml.exists()) {
@@ -793,6 +803,7 @@ public class TomcatManager implements DeploymentManager {
                     tp.setTimestamp(timestamp);
                     tp.setServerPort(Integer.parseInt(TomcatInstallUtil.getPort(server)));
                     tp.setShutdownPort(Integer.parseInt(TomcatInstallUtil.getShutdownPort(server)));
+                    tp.setServerHeader(TomcatInstallUtil.getServerHeader(server));
                 } catch (IOException ioe) {
                     LOGGER.log(Level.INFO, null, ioe);
                 } catch (NumberFormatException nfe) {
