@@ -53,10 +53,12 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Collections;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.regex.Pattern;
 import javax.enterprise.deploy.shared.ActionType;
 import javax.enterprise.deploy.shared.CommandType;
 import javax.enterprise.deploy.shared.StateType;
@@ -134,10 +136,18 @@ public final class StartTomcat extends StartServer implements ProgressObject {
     
     /** For how long should we keep trying to get response from the server. */
     private static final long TIMEOUT_DELAY = 180000;
+
+    private static final Pattern WINDOWS_ESCAPED_JAVA_OPTS = Pattern.compile("^set\\s\"JAVA_OPTS.*$");
     
     private static final Logger LOGGER = Logger.getLogger(StartTomcat.class.getName());
         
     private TomcatManager tm;
+
+    // GuardedBy("this")
+    private boolean javaOptsEscaped;
+
+    // GuardedBy("this")
+    private Date lastCheckedStart;
     
     private ProgressEventSupport pes;
     private int currentServerPort; // current server port Tomcat is running on
@@ -386,13 +396,20 @@ public final class StartTomcat extends StartServer implements ProgressObject {
                 };
                 boolean isWindows = Utilities.isWindows();
                 for (String prop : PROXY_PROPS) {
-                    if (javaOpts.indexOf(prop) == -1) {
+                    if (!javaOpts.contains(prop)) {
                         String value = System.getProperty(prop);
                         if (value != null) {
-                            if ((isWindows || tm.isTomcat70() || tm.isTomcat80()) && "http.nonProxyHosts".equals(prop)) { // NOI18N
-                                // enclose in double quotes to escape the pipes separating the hosts on windows
-                                // or on unix - tomcat 7 use eval instead of exec
-                                value = "\"" + value + "\""; // NOI18N
+                            if ("http.nonProxyHosts".equals(prop)) { // NOI18N
+                                if (isWindows) {
+                                    boolean javaOptsEscaped = isJavaOptsEscaped();
+                                    if (javaOptsEscaped) {
+                                        value = value.replaceAll("\\|", "^|"); // NOI18N
+                                    } else {
+                                        value = "\"" + value + "\""; // NOI18N
+                                    }
+                                } else if (tm.isTomcat70() || tm.isTomcat80()) {
+                                    value = "\"" + value + "\""; // NOI18N
+                                }
                             }
                             sb.append(" -D").append(prop).append("=").append(value); // NOI18N
                         }
@@ -651,7 +668,7 @@ public final class StartTomcat extends StartServer implements ProgressObject {
             }
         } else {
             int timeout = tm.getTomcatProperties().getRunningCheckTimeout();
-            return !Utils.pingTomcat(tm.getServerPort(), timeout);
+            return !Utils.pingTomcat(tm.getServerPort(), timeout, tm.getServerHeader(), tm.getPlainUri());
         }
     }
     
@@ -770,7 +787,39 @@ public final class StartTomcat extends StartServer implements ProgressObject {
         }
         return platform;
     }
-    
+
+    private boolean isJavaOptsEscaped() {
+        if (Utilities.isUnix()) {
+            return false;
+        }
+
+        FileObject start = FileUtil.toFileObject(FileUtil.normalizeFile(getStartupScript()));
+        if (start == null) {
+            return false;
+        }
+
+        synchronized (this) {
+            if (lastCheckedStart != null && !start.lastModified().after(lastCheckedStart)) {
+                return javaOptsEscaped;
+            }
+
+            javaOptsEscaped = false;
+            lastCheckedStart = start.lastModified();
+            try {
+                for (String line : start.asLines("UTF-8")) { // NOI18N
+                    if (WINDOWS_ESCAPED_JAVA_OPTS.matcher(line).matches()) {
+                        javaOptsEscaped = true;
+                        break;
+                    }
+                }
+            } catch (IOException ex) {
+                LOGGER.log(Level.INFO, null, ex);
+            }
+
+            return javaOptsEscaped;
+        }
+    }
+
     /** enable/disable ${catalina.home}/common/endorsed/*.jar in the catalina class
      loader in the catalina.properties file */
     private void patchCatalinaProperties(File catalinaBase, final boolean endorsedEnabled) {
