@@ -213,10 +213,6 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
     
     private VersioningManager() {
         providersLookupResult = Lookup.getDefault().lookupResult(VCSSystemProvider.class);
-        Collection<? extends VCSSystemProvider> providers = providersLookupResult.allInstances();
-        for (VCSSystemProvider p : providers) {
-            p.addChangeListener(this);
-        }
     }
     
     private void init() {
@@ -224,8 +220,14 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
             // initialize VCSContext which in turn initializes SPIAccessor
             // before any other thread touches SPIAccessor
             VCSContext ctx = VCSContext.EMPTY;
-            // do not fire events under lock but asynchronously
-            refreshVersioningSystems(true);
+            synchronized (versioningSystems) {
+                Collection<? extends VCSSystemProvider> providers = providersLookupResult.allInstances();
+                for (VCSSystemProvider p : providers) {
+                    p.addChangeListener(this);
+                }
+                // do not fire events under lock but asynchronously
+                refreshVersioningSystems(true);
+            }
             VersioningSupport.getPreferences().addPreferenceChangeListener(this);
         } finally {
             initialized = true;                                    
@@ -380,10 +382,14 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
         }
         if (owner != null) {
             if (owner == NULL_OWNER) {
-                LOG.log(Level.FINE, " cached NULL_OWNER of {0}", new Object[] { file });
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, " cached NULL_OWNER of {0}", new Object[] { file });
+                }
                 return null;
             }
-            LOG.log(Level.FINE, " cached owner {0} of {1}", new Object[] { owner.getClass().getName(), file });
+            if (LOG.isLoggable(Level.FINE)) {
+                LOG.log(Level.FINE, " cached owner {0} of {1}", new Object[] { owner.getClass().getName(), file });
+            }
             return owner;
         }
 
@@ -406,7 +412,9 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
 
         if (owner == null && VersioningSupport.isExcluded(folder)) {
             // the owner is not known yet and the folder is excluded/unversioned
-            LOG.log(Level.FINE, " caching NULL_OWNER of excluded {0}", new Object[] { file }); //NOI18N
+            if (LOG.isLoggable(Level.FINE)) {
+                LOG.log(Level.FINE, " caching NULL_OWNER of excluded {0}", new Object[] { file }); //NOI18N
+            }
             if (isFile) {
                 synchronized(fileOwners) {
                     fileOwners.put(folder, NULL_OWNER);
@@ -418,14 +426,20 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
             return null;
         } else if (owner != null) {
             synchronized(fileOwners) {
-                LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, file }) ;
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, file }) ;
+                }
                 fileOwners.put(file, owner != null ? owner : NULL_OWNER);            
             }           
             if (owner == NULL_OWNER) {
-                LOG.log(Level.FINE, " cached NULL_OWNER of {0}", new Object[] { folder });
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, " cached NULL_OWNER of {0}", new Object[] { folder });
+                }
                 return null;
             }            
-            LOG.log(Level.FINE, " cached owner {0} of {1}", new Object[] { owner.getClass().getName(), folder });                         
+            if (LOG.isLoggable(Level.FINE)) {
+                LOG.log(Level.FINE, " cached owner {0} of {1}", new Object[] { owner.getClass().getName(), folder });
+            }
             return owner;
         }        
         
@@ -436,14 +450,20 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
         for (VersioningSystem system : vs) {
             if (system != localHistory) {    // currently, local history is never an owner of a file
                 VCSFileProxy topmost = system.getTopmostManagedAncestor(folder);
-                LOG.log(Level.FINE, " {0} returns {1} ", new Object[] { system.getClass().getName(), topmost }) ;
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, " {0} returns {1} ", new Object[] { system.getClass().getName(), topmost }) ;
+                }
                 if (topmost != null && (closestParent == null || Utils.isAncestorOrEqual(closestParent, topmost))) {
                     if (VersioningConfig.getDefault().isDisconnected(system, topmost)) {
                         // repository root is disconnected from this vcs
-                        LOG.log(Level.FINE, " skipping disconnected owner = {0} for {1}", new Object[] { 
-                            system.getClass().getName(), topmost }) ;
+                        if (LOG.isLoggable(Level.FINE)) {
+                            LOG.log(Level.FINE, " skipping disconnected owner = {0} for {1}", new Object[] { 
+                                system.getClass().getName(), topmost }) ;
+                        }
                     } else {
-                        LOG.log(Level.FINE, " owner = {0}", new Object[] { system.getClass().getName() }) ;
+                        if (LOG.isLoggable(Level.FINE)) {
+                            LOG.log(Level.FINE, " owner = {0}", new Object[] { system.getClass().getName() }) ;
+                        }
                         owner = system;
                         closestParent = topmost;
                     }
@@ -453,22 +473,30 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
                 
         synchronized(folderOwners) {
             if (owner != null) {
-                LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, folder }) ;
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, folder }) ;
+                }
                 folderOwners.put(folder, owner);
             } else {
                 // nobody owns the folder => all parents aren't owned
                 while(folder != null) {
-                    LOG.log(Level.FINE, " caching unversioned folder {0}", new Object[] { folder }) ;
+                    if (LOG.isLoggable(Level.FINE)) {
+                        LOG.log(Level.FINE, " caching unversioned folder {0}", new Object[] { folder }) ;
+                    }
                     folderOwners.put(folder, NULL_OWNER);
                     folder = folder.getParentFile();
                 }
             }
         }
         synchronized(fileOwners) {
-            LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, file }) ;
+            if (LOG.isLoggable(Level.FINE)) {
+                LOG.log(Level.FINE, " caching owner {0} of {1}", new Object[] { owner != null ? owner.getClass().getName() : null, file }) ;
+            }
             fileOwners.put(file, owner != null ? owner : NULL_OWNER);            
         }
-        LOG.log(Level.FINE, "owner = {0}", new Object[] { owner != null ? owner.getClass().getName() : null }) ;
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.log(Level.FINE, "owner = {0}", new Object[] { owner != null ? owner.getClass().getName() : null }) ;
+        }
         return owner;
     }
     
@@ -624,7 +652,9 @@ public class VersioningManager implements PropertyChangeListener, ChangeListener
                 return ret;
             }
         } finally {
-            LOG.log(Level.FINE, "needsLocalHistory method [{0}] returns {1}", new Object[] {methodName, ret});
+            if (LOG.isLoggable(Level.FINE)) {
+                LOG.log(Level.FINE, "needsLocalHistory method [{0}] returns {1}", new Object[] {methodName, ret});
+            }
         }
     }
 
