@@ -41,6 +41,7 @@
  */
 package org.netbeans.modules.versioning.core.api;
 
+import java.awt.EventQueue;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
@@ -53,6 +54,7 @@ import org.netbeans.api.extexecution.ProcessBuilder;
 import org.netbeans.api.fileinfo.NonRecursiveFolder;
 import org.netbeans.modules.versioning.core.APIAccessor;
 import org.netbeans.modules.versioning.core.FlatFolder;
+import org.netbeans.modules.versioning.core.Utils;
 import org.netbeans.modules.versioning.core.filesystems.VCSFileProxyOperations;
 import org.openide.filesystems.FileAttributeEvent;
 import org.openide.filesystems.FileChangeListener;
@@ -126,7 +128,21 @@ public final class VCSFileProxy {
      * @return a VCSFileProxy representing the a file given by the parent and child values
      */
     public static VCSFileProxy createFileProxy(VCSFileProxy parent, String child) {
-        return new VCSFileProxy(parent.getPath() + "/" + child, parent.proxy);   // NOI18N
+        File parentFile = parent.toFile();
+        if (parentFile != null) {
+            return createFileProxy(new File(parentFile, child));
+        } else {
+            final String p = parent.getPath();
+            if (p.endsWith("/")) {   // NOI18N
+                return new VCSFileProxy(p + child, parent.proxy);
+            } else {
+                if (p.isEmpty() && child.startsWith("/")) {
+                    return new VCSFileProxy(child, parent.proxy);   // NOI18N
+                } else {
+                    return new VCSFileProxy(p + "/" + child, parent.proxy);   // NOI18N
+                }
+            }
+        }
     }
     
     static VCSFileProxy createFileProxy(String path) {
@@ -134,7 +150,7 @@ public final class VCSFileProxy {
     }
     
     static VCSFileProxy createFileProxy(VCSFileProxy parent, String child, boolean isDirectory) {
-        VCSFileProxy file = new VCSFileProxy(parent.getPath() + "/" + child, parent.proxy); // NOI18N
+        VCSFileProxy file = createFileProxy(parent, child);
         file.isDirectory = isDirectory;
         return file;
     }
@@ -161,7 +177,7 @@ public final class VCSFileProxy {
      * @return a VCSFileProxy representing the given file or null if the given 
      * FileObject-s Filesystem isn't supported - e.g. jar filesystem. 
      */
-    public static VCSFileProxy createFileProxy(FileObject fileObject) {        
+    public static VCSFileProxy createFileProxy(final FileObject fileObject) {        
         try {
             VCSFileProxyOperations fileProxyOperations = getFileProxyOperations(fileObject.getFileSystem());
             if (fileProxyOperations == null) {
@@ -179,7 +195,18 @@ public final class VCSFileProxy {
                         @Override public void fileRenamed(FileRenameEvent fe) { }
                         @Override public void fileAttributeChanged(FileAttributeEvent fe) { }
                     };
-                    fileObject.addFileChangeListener(WeakListeners.create(FileChangeListener.class, p.fileChangeListener, fileObject));
+                    Runnable run = new Runnable() {
+
+                        @Override
+                        public void run () {
+                            fileObject.addFileChangeListener(WeakListeners.create(FileChangeListener.class, p.fileChangeListener, fileObject));
+                        }
+                    };
+                    if (EventQueue.isDispatchThread()) {
+                        Utils.postParallel(run);
+                    } else {
+                        run.run();
+                    }
                     return p;
                 } else {
                     return null; // e.g. FileObject from a jar filesystem
