@@ -48,6 +48,7 @@ import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import javax.lang.model.element.Element;
 import javax.lang.model.element.TypeElement;
@@ -635,7 +636,7 @@ public class AlternativeTest extends CommonTestCase {
     }
     
     protected void checkMixed1( VariableElement element, WebBeansModel model ) {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -690,7 +691,7 @@ public class AlternativeTest extends CommonTestCase {
     }
     
     protected void checkMixed2( VariableElement element, WebBeansModel model ) {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -720,7 +721,7 @@ public class AlternativeTest extends CommonTestCase {
     protected void checkProduction1( VariableElement element,
             WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -750,7 +751,7 @@ public class AlternativeTest extends CommonTestCase {
     protected void checkProduction2( VariableElement element,
             WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -807,7 +808,7 @@ public class AlternativeTest extends CommonTestCase {
     protected void checkProduction3( VariableElement element,
             WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -836,7 +837,7 @@ public class AlternativeTest extends CommonTestCase {
     protected void checkProduction4( VariableElement element,
             WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -863,7 +864,7 @@ public class AlternativeTest extends CommonTestCase {
 
     private void check2( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -933,7 +934,7 @@ public class AlternativeTest extends CommonTestCase {
     
     private void check1( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -989,7 +990,7 @@ public class AlternativeTest extends CommonTestCase {
     
     private void check3( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -1045,7 +1046,7 @@ public class AlternativeTest extends CommonTestCase {
     
     private void checkEnabled1( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -1080,7 +1081,7 @@ public class AlternativeTest extends CommonTestCase {
     
     private void checkEnabled2( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
@@ -1142,7 +1143,7 @@ public class AlternativeTest extends CommonTestCase {
     
     private void checkEnabled3( VariableElement element, WebBeansModel model )
     {
-        DependencyInjectionResult result = model.lookupInjectables(element, null);
+        DependencyInjectionResult result = model.lookupInjectables(element, null, new AtomicBoolean(false));
         
         assertNotNull( result );
         
