@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -37,15 +37,17 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2012 Sun Microsystems, Inc.
+ * Portions Copyrighted 2015 Sun Microsystems, Inc.
  */
 package org.netbeans.modules.web.clientproject.ui;
 
+import java.awt.EventQueue;
 import java.awt.Image;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.CharConversionException;
 import java.io.File;
+import java.net.URL;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
@@ -58,21 +60,26 @@ import java.util.logging.Logger;
 import javax.swing.Action;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.netbeans.api.annotations.common.CheckForNull;
+import org.netbeans.api.annotations.common.StaticResource;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectInformation;
 import org.netbeans.api.project.ProjectUtils;
+import org.netbeans.api.project.Sources;
 import org.netbeans.api.queries.VisibilityQuery;
 import org.netbeans.modules.gsf.codecoverage.api.CoverageActionFactory;
 import org.netbeans.modules.web.clientproject.ClientSideProject;
-import org.netbeans.modules.web.clientproject.ClientSideProjectConstants;
+import org.netbeans.modules.web.clientproject.api.BadgeIcon;
+import org.netbeans.modules.web.clientproject.api.build.BuildTools;
 import org.netbeans.modules.web.clientproject.api.jstesting.JsTestingProvider;
 import org.netbeans.modules.web.clientproject.api.jstesting.JsTestingProviders;
+import org.netbeans.modules.web.clientproject.api.platform.PlatformProvider;
 import org.netbeans.modules.web.clientproject.api.remotefiles.RemoteFilesNodeFactory;
+import org.netbeans.modules.web.clientproject.env.Values;
 import org.netbeans.modules.web.clientproject.spi.platform.ClientProjectEnhancedBrowserImplementation;
 import org.netbeans.modules.web.clientproject.util.ClientSideProjectUtilities;
 import org.netbeans.spi.project.ActionProvider;
-import org.netbeans.spi.project.support.ant.PropertyEvaluator;
 import org.netbeans.spi.project.ui.LogicalViewProvider;
 import org.netbeans.spi.project.ui.ProjectProblemsProvider;
 import org.netbeans.spi.project.ui.support.CommonProjectActions;
@@ -86,9 +93,6 @@ import org.openide.actions.ToolsAction;
 import org.openide.awt.ActionID;
 import org.openide.awt.ActionReference;
 import org.openide.awt.ActionReferences;
-import org.openide.filesystems.FileChangeAdapter;
-import org.openide.filesystems.FileChangeListener;
-import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.loaders.DataFolder;
@@ -121,7 +125,7 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 
     static final Logger LOGGER = Logger.getLogger(ClientSideProjectLogicalView.class.getName());
 
-    static final RequestProcessor RP = new RequestProcessor(ClientSideProjectLogicalView.class);
+    static final RequestProcessor RP = new RequestProcessor(ClientSideProjectLogicalView.class.getName(), 2);
 
     private final ClientSideProject project;
 
@@ -167,14 +171,27 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
                 return node;
             } else if (FileUtil.isParentOf(kid, fo)) {
                 Node found = findNode(node, kid, fo);
-                if (found != null && hasObject(found, target)) {
+                if (found == null) {
+                    return null;
+                }
+                if (hasObject(found, target)) {
                     return found;
                 }
+                // #252446 ?
+                Node[] nodes = found.getParentNode().getChildren().getNodes(true);
+                for (Node child : nodes) {
+                    if (child.getName().equals(fo.getName())
+                            && hasObject(child, fo)) {
+                        return child;
+                    }
+                }
             }
         }
         return null;
     }
 
+
+    @CheckForNull
     private static Node findNode(Node node, FileObject root, FileObject fo) {
         String relPath = FileUtil.getRelativePath(root, fo);
 
@@ -227,9 +244,18 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 /** This is the node you actually see in the project tab for the project */
     private static final class ClientSideProjectNode extends AbstractNode implements ChangeListener, PropertyChangeListener {
 
+        @StaticResource
+        private static final String HTML5_BADGE_ICON = "org/netbeans/modules/web/clientproject/ui/resources/html5-badge.png"; // NOI18N
+        @StaticResource
+        private static final String JS_LIBRARY_BADGE_ICON = "org/netbeans/modules/web/clientproject/ui/resources/js-library-badge.png"; // NOI18N
+        @StaticResource
+        private static final String PLACEHOLDER_BADGE_ICON = "org/netbeans/modules/web/clientproject/ui/resources/placeholder-badge.png"; // NOI18N
+        private static final URL PLACEHOLDER_BADGE_URL = ClientSideProjectNode.class.getResource(PLACEHOLDER_BADGE_ICON);
+        private static final String ICON_TOOLTIP = "<img src=\"%s\">&nbsp;%s"; // NOI18N
+
         private final ClientSideProject project;
         private final ProjectInformation projectInfo;
-        private final PropertyEvaluator evaluator;
+        private final Values evaluator;
         private final ProjectProblemsProvider problemsProvider;
 
 
@@ -314,14 +340,14 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
         @Override
         public Action[] getActions(boolean arg0) {
             List<Action> actions = new LinkedList<>(Arrays.asList(CommonProjectActions.forType("org-netbeans-modules-web-clientproject"))); // NOI18N
-            addGruntActions(actions);
+            addBuildActions(actions);
             addCodeCoverageAction(actions);
             return actions.toArray(new Action[actions.size()]);
         }
 
         @Override
         public Image getIcon(int type) {
-            return ImageUtilities.loadImage(ClientSideProject.PROJECT_ICON);
+            return annotateImage(ImageUtilities.loadImage(ClientSideProject.HTML5_PROJECT_ICON));
         }
 
         @Override
@@ -329,6 +355,30 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
             return getIcon(type);
         }
 
+        private Image annotateImage(Image image) {
+            Image icon = image;
+            boolean badged = false;
+            // platform providers
+            for (PlatformProvider provider : project.getPlatformProviders()) {
+                BadgeIcon badgeIcon = provider.getBadgeIcon();
+                if (badgeIcon != null) {
+                    icon = ImageUtilities.addToolTipToImage(icon, String.format(ICON_TOOLTIP, badgeIcon.getUrl(), provider.getDisplayName()));
+                    if (!badged) {
+                        icon = ImageUtilities.mergeImages(icon, badgeIcon.getImage(), 0, 0);
+                        badged = true;
+                    }
+                } else {
+                    icon = ImageUtilities.addToolTipToImage(icon, String.format(ICON_TOOLTIP, PLACEHOLDER_BADGE_URL, provider.getDisplayName()));
+                }
+            }
+            // project type, only if no platform
+            if (!badged) {
+                Image projectBadge = ImageUtilities.loadImage(project.isJsLibrary() ? JS_LIBRARY_BADGE_ICON : HTML5_BADGE_ICON);
+                icon = ImageUtilities.mergeImages(icon, projectBadge, 0, 0);
+            }
+            return icon;
+        }
+
         @Override
         public String getName() {
             // i would expect getName() here but see #222588
@@ -343,18 +393,24 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
             } catch (CharConversionException ex) {
                 return dispName;
             }
-            return ClientSideProjectUtilities.isBroken(project)
+            return ClientSideProjectUtilities.hasErrors(project)
                     ? "<font color=\"#" + Integer.toHexString(ClientSideProjectUtilities.getErrorForeground().getRGB() & 0xffffff) + "\">" + dispName + "</font>" // NOI18N
                     : null;
         }
 
         @NbBundle.Messages({
             "# {0} - project directory",
-            "ClientSideProjectNode.description=HTML5 application in {0}"
+            "ClientSideProjectNode.project.description=HTML5 application in {0}",
+            "# {0} - project directory",
+            "ClientSideProjectNode.library.description=JavaScript library in {0}",
         })
         @Override
         public String getShortDescription() {
-            return Bundle.ClientSideProjectNode_description(FileUtil.getFileDisplayName(project.getProjectDirectory()));
+            String projectDirName = FileUtil.getFileDisplayName(project.getProjectDirectory());
+            if (project.isJsLibrary()) {
+                return Bundle.ClientSideProjectNode_library_description(projectDirName);
+            }
+            return Bundle.ClientSideProjectNode_project_description(projectDirName);
         }
 
         @Override
@@ -394,13 +450,14 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
             RP.post(new Runnable() {
                 @Override
                 public void run() {
+                    fireIconChange();
                     fireNameChange(null, null);
                     fireDisplayNameChange(null, null);
                 }
             });
         }
 
-        private void addGruntActions(List<Action> actions) {
+        private void addBuildActions(List<Action> actions) {
             ClientProjectEnhancedBrowserImplementation cfg = project.getEnhancedBrowserImpl();
             if (cfg == null) {
                 return;
@@ -410,10 +467,13 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
                 return;
             }
             Set<String> supportedActions = new HashSet<>(Arrays.asList(actionProvider.getSupportedActions()));
-            boolean grunt = project.getProjectDirectory().getFileObject("Gruntfile.js") !=null;
-            boolean buildSupported = supportedActions.contains(ActionProvider.COMMAND_BUILD) || grunt;
-            boolean rebuildSupported = supportedActions.contains(ActionProvider.COMMAND_REBUILD) || grunt;
-            boolean cleanSupported = supportedActions.contains(ActionProvider.COMMAND_CLEAN) || grunt;
+            boolean hasBuildTools = BuildTools.getDefault().hasBuildTools(project);
+            boolean buildSupported = hasBuildTools
+                    || supportedActions.contains(ActionProvider.COMMAND_BUILD);
+            boolean rebuildSupported = hasBuildTools
+                    || supportedActions.contains(ActionProvider.COMMAND_REBUILD);
+            boolean cleanSupported = hasBuildTools
+                    || supportedActions.contains(ActionProvider.COMMAND_CLEAN);
             int index = 1; // right after New... action
             if (buildSupported
                     || rebuildSupported
@@ -455,7 +515,10 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 
     private static enum BasicNodes {
         Sources,
+        SiteRoot,
+        SourcesAndSiteRoot,
         Tests,
+        TestsSelenium,
     }
 
     // TODO: all three nodes are registered at the same time - could be refactored and
@@ -472,7 +535,7 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 
     }
 
-    @NodeFactory.Registration(projectType="org-netbeans-modules-web-clientproject",position=537)
+    @NodeFactory.Registration(projectType="org-netbeans-modules-web-clientproject",position=900)
     public static NodeFactory createRemoteFiles() {
         return RemoteFilesNodeFactory.createRemoteFilesNodeFactory();
     }
@@ -482,19 +545,21 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
         return JsTestingProviders.getDefault().createJsTestingProvidersNodeFactory();
     }
 
-    private static class ClientProjectNodeList implements NodeList<Key> {
+    private static final class ClientProjectNodeList implements NodeList<Key>, ChangeListener {
 
-        private ChangeSupport changeSupport = new ChangeSupport(this);
+        private final ChangeSupport changeSupport = new ChangeSupport(this);
         private final ClientSideProject project;
         private final FileObject nbprojectFolder;
-        private final Listener listener;
-        private List<Key> keysCache = new ArrayList<>();
+        final Sources projectSources;
+        final ChangeListener changeListener;
 
-        public ClientProjectNodeList(ClientSideProject p) {
+
+        private ClientProjectNodeList(ClientSideProject p) {
             this.project = p;
             nbprojectFolder = p.getProjectDirectory().getFileObject("nbproject"); // NOI18N
             assert nbprojectFolder != null : "Folder nbproject must exist for project " + project.getName();
-            listener = new Listener();
+            projectSources = ProjectUtils.getSources(p);
+            changeListener = WeakListeners.change(this, projectSources);
         }
 
         @Override
@@ -509,121 +574,61 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 
         @Override
         public void addNotify() {
-            // #230378 - use weak listeners otherwise project is not garbage collected
-            project.getEvaluator().addPropertyChangeListener(
-                    WeakListeners.propertyChange(listener, project.getEvaluator()));
-            addFsListeners();
+            RP.post(new Runnable() {
+                @Override
+                public void run() {
+                    // #230378 - use weak listeners otherwise project is not garbage collected
+                    // #237407 - do it in a background thread
+                    projectSources.addChangeListener(changeListener);
+                }
+            });
         }
 
         @Override
         public void removeNotify() {
-            // #230378 - weak listeners are used so no need to call "removeListener"
+            // #230378 - weak listeners are used so in fact, no need to call "removeListener"
         }
 
-        private void addFsListeners() {
-            FileObject projectDirectory = project.getProjectDirectory();
-            projectDirectory.addRecursiveListener(
-                    WeakListeners.create(FileChangeListener.class, listener, projectDirectory));
-            addTestsListeners();
-        }
-
-        private void addTestsListeners() {
-            FileObject projectDirectory = project.getProjectDirectory();
-            FileObject testsFolder = project.getTestsFolder(false);
-            if (testsFolder != null
-                    && !projectDirectory.equals(testsFolder)
-                    && !FileUtil.isParentOf(projectDirectory, testsFolder)) {
-                testsFolder.addRecursiveListener(
-                        WeakListeners.create(FileChangeListener.class, listener, testsFolder));
-            }
-        }
-
-        private class Listener extends FileChangeAdapter implements PropertyChangeListener {
-
-            private volatile boolean sourcesNodeHidden;
-            private volatile boolean testsNodeHidden;
-
-            public Listener() {
-                sourcesNodeHidden = isNodeHidden(BasicNodes.Sources);
-                testsNodeHidden = isNodeHidden(BasicNodes.Tests);
-            }
-
-            @Override
-            public void fileFolderCreated(FileEvent fe) {
-                updateNodesVisibility();
-            }
-
-            @Override
-            public void fileDataCreated(FileEvent fe) {
-                updateNodesVisibility();
-            }
-
-
-            @Override
-            public void fileDeleted(FileEvent fe) {
-                updateNodesVisibility();
-            }
-
-            @Override
-            public void propertyChange(PropertyChangeEvent evt) {
-                if (ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER.equals(evt.getPropertyName())) {
-                    sourcesNodeHidden = isNodeHidden(BasicNodes.Sources);
-                    refreshKey(BasicNodes.Sources);
-                } else if (ClientSideProjectConstants.PROJECT_TEST_FOLDER.equals(evt.getPropertyName())) {
-                    testsNodeHidden = isNodeHidden(BasicNodes.Tests);
-                    refreshKey(BasicNodes.Tests);
-                    addTestsListeners();
-                }
-            }
-
-            private void updateNodesVisibility() {
-                boolean nodeHidden = isNodeHidden(BasicNodes.Sources);
-                if (nodeHidden != sourcesNodeHidden) {
-                    sourcesNodeHidden = nodeHidden;
-                    refreshKey(BasicNodes.Sources);
-                }
-                nodeHidden = isNodeHidden(BasicNodes.Tests);
-                if (nodeHidden != testsNodeHidden) {
-                    testsNodeHidden = nodeHidden;
-                    refreshKey(BasicNodes.Tests);
-                }
-            }
-
-        }
-
-        private void refreshKey(final BasicNodes type) {
-            // force key refresh:
-            removeKey(type);
+        void fireChange() {
             changeSupport.fireChange();
         }
 
-        private synchronized void removeKey(final BasicNodes type) {
-            for (int i = 0; i < keysCache.size(); i++) {
-                if (type.equals(keysCache.get(i).getNode())) {
-                    keysCache.remove(i);
-                    break;
+        @Override
+        public void stateChanged(ChangeEvent e) {
+            EventQueue.invokeLater(new Runnable() {
+                @Override
+                public void run() {
+                    fireChange();
                 }
-            }
+            });
         }
 
         @Override
-        public Node node(Key k) {
-            switch (k.getNode()) {
+        public Node node(Key key) {
+            BasicNodes node = key.getNode();
+            switch (node) {
                 case Sources:
+                case SiteRoot:
+                case SourcesAndSiteRoot:
                 case Tests:
-                    return createNodeForFolder(k.getNode());
+                case TestsSelenium:
+                    return createNodeForFolder(key);
                 default:
+                    assert false : "Unknown node type: " + node;
                     return null;
             }
         }
 
         // #218736
         private List<File> getIgnoredFiles(BasicNodes basicNodes) {
-            List<File> ignoredFiles = new ArrayList<File>();
+            List<File> ignoredFiles = new ArrayList<>();
             FileObject buildFolder = project.getProjectDirectory().getFileObject("build"); // NOI18N
             switch (basicNodes) {
                 case Sources:
+                case SiteRoot:
+                case SourcesAndSiteRoot:
                 case Tests:
+                case TestsSelenium:
                     addIgnoredFile(ignoredFiles, nbprojectFolder);
                     addIgnoredFile(ignoredFiles, buildFolder);
                     break;
@@ -643,74 +648,65 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
             }
         }
 
-        private boolean isNodeHidden(BasicNodes type) {
-            if (type == BasicNodes.Sources) {
-                return false;
-            }
-            FileObject root = getRootForNode(type);
-            return root == null
-                    || !root.isValid()
-                    || root.getChildren().length == 0;
-        }
-
         private FileObject getRootForNode(BasicNodes node) {
+            FileObject sources = project.getSourcesFolder();
+            FileObject siteRoot = project.getSiteRootFolder();
             switch (node) {
-                case Tests: return project.getTestsFolder(false);
-                case Sources: return project.getSiteRootFolder();
+                case Sources:
+                    if (sources == null) {
+                        return null;
+                    }
+                    if (sources.equals(siteRoot)) {
+                        return null;
+                    }
+                    return sources;
+                case SiteRoot:
+                    if (siteRoot == null) {
+                        return null;
+                    }
+                    if (siteRoot.equals(sources)) {
+                        return null;
+                    }
+                    return siteRoot;
+                case SourcesAndSiteRoot:
+                    if (sources == null
+                            || siteRoot == null) {
+                        return null;
+                    }
+                    if (sources.equals(siteRoot)) {
+                        return sources;
+                    }
+                    return null;
+                case Tests:
+                    return project.getTestsFolder(false);
+                case TestsSelenium:
+                    return project.getTestsSeleniumFolder(false);
                 default:
                     assert false : "Unknown node: " + node;
                     return null;
             }
         }
 
-        // the same logic as createNodeForFolder() bellow but prevents calling
-        // getNodeDelegate() from background thread (see eg. issue 230580)
-        private boolean canCreateNodeFor(BasicNodes type) {
-            FileObject root = getRootForNode(type);
-            if (root != null && root.isValid()) {
-                if (!isNodeHidden(type)) {
-                    return true;
-                }
-            }
-            return false;
-        }
-
-        private Node createNodeForFolder(BasicNodes type) {
-            FileObject root = getRootForNode(type);
-            if (root != null && root.isValid()) {
-                DataFolder df = DataFolder.findFolder(root);
-                if (!isNodeHidden(type)) {
-                    return new FolderFilterNode(type, df.getNodeDelegate().cloneNode(), getIgnoredFiles(type));
-                }
-            }
-            // missing root should be solved by project problems
-            return null;
+        private Node createNodeForFolder(Key key) {
+            BasicNodes node = key.getNode();
+            FileObject root = key.getRoot();
+            assert root != null;
+            assert root.isValid() : root;
+            DataFolder df = DataFolder.findFolder(root);
+            return new FolderFilterNode(node, df.getNodeDelegate().cloneNode(), getIgnoredFiles(node));
         }
 
         @Override
         public List<Key> keys() {
-            // in order to resolve #225877 the only way to refresh a node in NodeList
-            // is to add it or remove it. There is nothing like Children.Keys.refreshKey(...).
-            // Hence I have to create a new key instance here as a workaround:
-            ArrayList<Key> keys = new ArrayList<>();
-            if (canCreateNodeFor(BasicNodes.Sources)) {
-                keys.add(getKey(BasicNodes.Sources));
-            }
-            if (canCreateNodeFor(BasicNodes.Tests)) {
-                keys.add(getKey(BasicNodes.Tests));
-            }
-            return keys;
-        }
-
-        private synchronized Key getKey(BasicNodes n) {
-            for (Key k : keysCache) {
-                if (n.equals(k.getNode())) {
-                    return k;
+            BasicNodes[] allNodes = BasicNodes.values();
+            ArrayList<Key> keys = new ArrayList<>(allNodes.length);
+            for (BasicNodes node : allNodes) {
+                FileObject root = getRootForNode(node);
+                if (root != null && root.isValid()) {
+                    keys.add(new Key(node, root));
                 }
             }
-            Key k = new Key(n);
-            keysCache.add(k);
-            return k;
+            return keys;
         }
 
     }
@@ -721,24 +717,32 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
      * was reconfigured.
      */
     private static class Key {
-        private BasicNodes node;
-        private int timestamp;
-        private static int counter = 0;
 
-        public Key(BasicNodes node) {
+        private final BasicNodes node;
+        private final FileObject root;
+
+
+        public Key(BasicNodes node, FileObject root) {
+            assert node != null;
+            assert root != null;
             this.node = node;
-            this.timestamp = ++counter;
+            this.root = root;
         }
 
+
         public BasicNodes getNode() {
             return node;
         }
 
+        public FileObject getRoot() {
+            return root;
+        }
+
         @Override
         public int hashCode() {
             int hash = 7;
-            hash = 67 * hash + (this.node != null ? this.node.hashCode() : 0);
-            hash = hash + this.timestamp * 67;
+            hash = 89 * hash + Objects.hashCode(this.node);
+            hash = 89 * hash + Objects.hashCode(this.root);
             return hash;
         }
 
@@ -754,26 +758,25 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
             if (this.node != other.node) {
                 return false;
             }
-            if (this.timestamp != other.timestamp) {
+            if (!Objects.equals(this.root, other.root)) {
                 return false;
             }
             return true;
         }
 
-        @Override
-        public String toString() {
-            return "Key{" + "node=" + node + ", timestamp=" + timestamp + ", hash="+ hashCode()+"}";
-        }
-
     }
 
     private static final class FolderFilterNode extends FilterNode {
 
-        private BasicNodes nodeType;
-        private Node iconDelegate;
-        private Node delegate;
-        private static final Image SOURCES_FILES_BADGE = ImageUtilities.loadImage("org/netbeans/modules/web/clientproject/ui/resources/sources-badge.gif", true); // NOI18N
-        private static final Image TESTS_FILES_BADGE = ImageUtilities.loadImage("org/netbeans/modules/web/clientproject/ui/resources/tests-badge.gif", true); // NOI18N
+        @StaticResource
+        private static final String SOURCES_FILES_BADGE = "org/netbeans/modules/web/clientproject/ui/resources/sources-badge.gif"; // NOI18N
+        @StaticResource
+        private static final String SITE_ROOT_FILES_BADGE = "org/netbeans/modules/web/clientproject/ui/resources/siteroot-badge.gif"; // NOI18N
+
+        private final BasicNodes nodeType;
+        private final Node iconDelegate;
+        private final Node delegate;
+
 
         public FolderFilterNode(BasicNodes nodeType, Node folderNode, List<File> ignoreList) {
             super(folderNode, folderNode.isLeaf() ? Children.LEAF :
@@ -817,21 +820,24 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
 
         private Image computeIcon(BasicNodes node, boolean opened, int type) {
             Image image;
-            Image badge = null;
+            String badge = null;
             switch (nodeType) {
                 case Sources:
+                case Tests:
+                case TestsSelenium:
                     badge = SOURCES_FILES_BADGE;
                     break;
-                case Tests:
-                    badge = TESTS_FILES_BADGE;
+                case SiteRoot:
+                case SourcesAndSiteRoot:
+                    badge = SITE_ROOT_FILES_BADGE;
                     break;
                 default:
-                    assert false;
+                    assert false : "Unknown nodeType: " + nodeType;
             }
 
             image = opened ? iconDelegate.getOpenedIcon(type) : iconDelegate.getIcon(type);
             if (badge != null) {
-                image = ImageUtilities.mergeImages(image, badge, 7, 7);
+                image = ImageUtilities.mergeImages(image, ImageUtilities.loadImage(badge, false), 7, 7);
             }
 
             return image;
@@ -841,9 +847,15 @@ public class ClientSideProjectLogicalView implements LogicalViewProvider {
         public String getDisplayName() {
             switch (nodeType) {
                 case Sources:
+                    return java.util.ResourceBundle.getBundle("org/netbeans/modules/web/clientproject/ui/Bundle").getString("SOURCES");
+                case SiteRoot:
                     return java.util.ResourceBundle.getBundle("org/netbeans/modules/web/clientproject/ui/Bundle").getString("SITE_ROOT");
+                case SourcesAndSiteRoot:
+                    return java.util.ResourceBundle.getBundle("org/netbeans/modules/web/clientproject/ui/Bundle").getString("SOURCES_SITE_ROOT");
                 case Tests:
                     return java.util.ResourceBundle.getBundle("org/netbeans/modules/web/clientproject/ui/Bundle").getString("UNIT_TESTS");
+                case TestsSelenium:
+                    return java.util.ResourceBundle.getBundle("org/netbeans/modules/web/clientproject/ui/Bundle").getString("SELENIUM_TESTS");
                 default:
                     throw new AssertionError(nodeType.name());
             }
