@@ -41,12 +41,12 @@
  */
 package org.netbeans.modules.web.clientproject.ui.customizer;
 
+import org.netbeans.modules.web.clientproject.env.Licenses;
 import java.awt.EventQueue;
+import java.beans.PropertyChangeEvent;
 import java.io.File;
 import java.io.IOException;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.api.annotations.common.CheckForNull;
@@ -54,16 +54,18 @@ import org.netbeans.api.project.ProjectManager;
 import org.netbeans.modules.web.browser.api.WebBrowser;
 import org.netbeans.modules.web.clientproject.ClientSideProject;
 import org.netbeans.modules.web.clientproject.ClientSideProjectConstants;
-import org.netbeans.modules.web.clientproject.api.jslibs.JavaScriptLibrarySelectionPanel;
-import org.netbeans.modules.web.clientproject.api.jslibs.JavaScriptLibrarySelectionPanel.SelectedLibrary;
+import org.netbeans.modules.web.clientproject.api.platform.PlatformProvider;
+import org.netbeans.modules.web.clientproject.api.platform.PlatformProviders;
+import org.netbeans.modules.web.clientproject.env.CommonProjectHelper;
+import org.netbeans.modules.web.clientproject.env.Env;
 import org.netbeans.modules.web.clientproject.spi.platform.ClientProjectEnhancedBrowserImplementation;
 import org.netbeans.modules.web.clientproject.util.ClientSideProjectUtilities;
-import org.netbeans.spi.project.support.ant.AntProjectHelper;
-import org.netbeans.spi.project.support.ant.EditableProperties;
 import org.openide.filesystems.FileUtil;
+import org.openide.util.EditableProperties;
 import org.openide.util.Mutex;
 import org.openide.util.MutexException;
 import org.openide.util.NbBundle;
+import org.openide.util.RequestProcessor;
 
 /**
  *
@@ -73,69 +75,33 @@ public final class ClientSideProjectProperties {
 
     private static final Logger LOGGER = Logger.getLogger(ClientSideProjectProperties.class.getName());
 
-    final ClientSideProject project;
-    private final List<JavaScriptLibrarySelectionPanel.SelectedLibrary> newJsLibraries = new CopyOnWriteArrayList<JavaScriptLibrarySelectionPanel.SelectedLibrary>();
+    private static final RequestProcessor RP = new RequestProcessor(ClientSideProjectProperties.class);
 
-    private volatile String siteRootFolder = null;
-    private volatile String testFolder = null;
+    final ClientSideProject project;
+
+    private volatile AtomicReference<String> sourceFolder = null;
+    private volatile AtomicReference<String> siteRootFolder = null;
+    private volatile AtomicReference<String> testFolder = null;
+    private volatile AtomicReference<String> testSeleniumFolder = null;
     private volatile String jsLibFolder = null;
     private volatile String encoding = null;
+    private volatile Boolean runBrowser = null;
+    private volatile AtomicReference<String> runAs = null;
     private volatile String startFile = null;
     private volatile String selectedBrowser = null;
     private volatile String webRoot = null;
     private volatile String projectUrl = null;
     private volatile ProjectServer projectServer = null;
     private volatile ClientProjectEnhancedBrowserImplementation enhancedBrowserSettings = null;
+    private volatile Boolean autoconfigured = null;
 
     //customizer license headers
-    private LicensePanelSupport licenseSupport;
-    private volatile boolean isSiteRootModified;
-    private volatile boolean isTestFolderModified;
+    private Licenses licenseSupport;
 
     public ClientSideProjectProperties(ClientSideProject project) {
         this.project = project;
     }
 
-    /**
-     * Add or replace project and/or private properties.
-     * <p>
-     * This method cannot be called in the UI thread.
-     * @param projectProperties project properties to be added to (replaced in) the current project properties
-     * @param privateProperties private properties to be added to (replaced in) the current private properties
-     */
-    public void save(final Map<String, String> projectProperties, final Map<String, String> privateProperties) {
-        assert !EventQueue.isDispatchThread();
-        assert !projectProperties.isEmpty() || !privateProperties.isEmpty() : "Neither project nor private properties to be saved";
-        try {
-            // store properties
-            ProjectManager.mutex().writeAccess(new Mutex.ExceptionAction<Void>() {
-                @Override
-                public Void run() throws IOException {
-                    AntProjectHelper helper = project.getProjectHelper();
-
-                    mergeProperties(helper, AntProjectHelper.PROJECT_PROPERTIES_PATH, projectProperties);
-                    mergeProperties(helper, AntProjectHelper.PRIVATE_PROPERTIES_PATH, privateProperties);
-
-                    ProjectManager.getDefault().saveProject(project);
-                    return null;
-                }
-
-                private void mergeProperties(AntProjectHelper helper, String path, Map<String, String> properties) {
-                    if (properties.isEmpty()) {
-                        return;
-                    }
-                    EditableProperties currentProperties = helper.getProperties(path);
-                    for (Map.Entry<String, String> entry : properties.entrySet()) {
-                        currentProperties.put(entry.getKey(), entry.getValue());
-                    }
-                    helper.putProperties(path, currentProperties);
-                }
-            });
-        } catch (MutexException e) {
-            LOGGER.log(Level.WARNING, null, e.getException());
-        }
-    }
-
     public void save() {
         assert !EventQueue.isDispatchThread();
         try {
@@ -150,6 +116,12 @@ public final class ClientSideProjectProperties {
                     return null;
                 }
             });
+            RP.post(new Runnable() {
+                @Override
+                public void run() {
+                    firePropertyChanges();
+                }
+            }, 100);
         } catch (MutexException | IOException e) {
             LOGGER.log(Level.WARNING, null, e);
         }
@@ -157,27 +129,60 @@ public final class ClientSideProjectProperties {
 
     void saveProperties() {
         // first, create possible foreign file references
-        String siteRootFolderReference = createForeignFileReference(siteRootFolder);
-        String testFolderReference = null;
-        if (isTestFolderModified
-                && !testFolder.trim().isEmpty()) {
-            testFolderReference = createForeignFileReference(testFolder);
-        }
+        String sourceFolderReference = createForeignFileReference(sourceFolder, true);
+        String siteRootFolderReference = createForeignFileReference(siteRootFolder, true);
+        String testFolderReference = createForeignFileReference(testFolder, false);
+        String testSeleniumFolderReference = createForeignFileReference(testSeleniumFolder, false);
         // save properties
-        EditableProperties privateProperties = project.getProjectHelper().getProperties(AntProjectHelper.PRIVATE_PROPERTIES_PATH);
-        EditableProperties projectProperties = project.getProjectHelper().getProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH);
+        EditableProperties privateProperties = project.getProjectHelper().getProperties(CommonProjectHelper.PRIVATE_PROPERTIES_PATH);
+        EditableProperties projectProperties = project.getProjectHelper().getProperties(CommonProjectHelper.PROJECT_PROPERTIES_PATH);
 
-        if (isSiteRootModified) {
-            putProperty(projectProperties, ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER, siteRootFolderReference);
-            isSiteRootModified = false;
+        if (sourceFolder != null) {
+            if (sourceFolderReference != null) {
+                putProperty(projectProperties, ClientSideProjectConstants.PROJECT_SOURCE_FOLDER, sourceFolderReference);
+            } else {
+                // source dir removed
+                projectProperties.remove(ClientSideProjectConstants.PROJECT_SOURCE_FOLDER);
+            }
         }
-        if (testFolderReference != null) {
-            putProperty(projectProperties, ClientSideProjectConstants.PROJECT_TEST_FOLDER, testFolderReference);
-        } else if (isTestFolderModified) {
-            // tests dir removed
-            projectProperties.remove(ClientSideProjectConstants.PROJECT_TEST_FOLDER);
+        if (siteRootFolder != null) {
+            if (siteRootFolderReference != null) {
+                // do not overwrite site root if target folder does not exist (issue #248174)
+                File siteRootF = project.getProjectHelper().resolveFile(siteRootFolder.get());
+                if (siteRootF != null && siteRootF.exists()) {
+                    putProperty(projectProperties, ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER, siteRootFolderReference);
+                }
+            } else {
+                // siteroot dir removed
+                projectProperties.remove(ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER);
+            }
+        }
+        if (testFolder != null) {
+            if (testFolderReference != null) {
+                putProperty(projectProperties, ClientSideProjectConstants.PROJECT_TEST_FOLDER, testFolderReference);
+            } else {
+                // tests dir removed
+                projectProperties.remove(ClientSideProjectConstants.PROJECT_TEST_FOLDER);
+            }
+        }
+        if (testSeleniumFolder != null) {
+            if (testSeleniumFolderReference != null) {
+                putProperty(projectProperties, ClientSideProjectConstants.PROJECT_TEST_SELENIUM_FOLDER, testSeleniumFolderReference);
+            } else {
+                // tests dir removed
+                projectProperties.remove(ClientSideProjectConstants.PROJECT_TEST_SELENIUM_FOLDER);
+            }
         }
         putProperty(projectProperties, ClientSideProjectConstants.PROJECT_ENCODING, encoding);
+        if (runAs != null) {
+            String runAsValue = runAs.get();
+            if (runAsValue != null) {
+                putProperty(projectProperties, ClientSideProjectConstants.PROJECT_RUN_AS, runAsValue);
+            } else {
+                projectProperties.remove(ClientSideProjectConstants.PROJECT_RUN_AS);
+            }
+        }
+        putProperty(projectProperties, ClientSideProjectConstants.PROJECT_RUN_BROWSER, runBrowser);
         putProperty(projectProperties, ClientSideProjectConstants.PROJECT_START_FILE, startFile);
         // #227995: store PROJECT_SELECTED_BROWSER in private.properties:
         projectProperties.remove(ClientSideProjectConstants.PROJECT_SELECTED_BROWSER);
@@ -192,8 +197,15 @@ public final class ClientSideProjectProperties {
         putProperty(privateProperties, ClientSideProjectConstants.PROJECT_PROJECT_URL, projectUrl);
         putProperty(projectProperties, ClientSideProjectConstants.PROJECT_WEB_ROOT, webRoot);
         getLicenseSupport().updateProperties(projectProperties);
-        project.getProjectHelper().putProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH, projectProperties);
-        project.getProjectHelper().putProperties(AntProjectHelper.PRIVATE_PROPERTIES_PATH, privateProperties);
+        if (autoconfigured != null) {
+            if (autoconfigured) {
+                privateProperties.put(ClientSideProjectConstants.PROJECT_AUTOCONFIGURED, Boolean.TRUE.toString());
+            } else {
+                privateProperties.remove(ClientSideProjectConstants.PROJECT_AUTOCONFIGURED);
+            }
+        }
+        project.getProjectHelper().putProperties(CommonProjectHelper.PROJECT_PROPERTIES_PATH, projectProperties);
+        project.getProjectHelper().putProperties(CommonProjectHelper.PRIVATE_PROPERTIES_PATH, privateProperties);
     }
 
     void saveEnhancedBrowserConfiguration() {
@@ -203,6 +215,14 @@ public final class ClientSideProjectProperties {
         }
     }
 
+    void firePropertyChanges() {
+        if (runAs != null) {
+            String runAsValue = runAs.get();
+            PlatformProviders.getDefault().notifyPropertyChanged(project,
+                    new PropertyChangeEvent(project, PlatformProvider.PROP_RUN_CONFIGURATION, null, runAsValue));
+        }
+    }
+
     ClientProjectEnhancedBrowserImplementation createEnhancedBrowserSettings(WebBrowser wb) {
         enhancedBrowserSettings =
                 ClientSideProject.createEnhancedBrowserImpl(project, wb);
@@ -213,32 +233,59 @@ public final class ClientSideProjectProperties {
         return project;
     }
 
-    public String getSiteRootFolder() {
+    public boolean isAutoconfigured() {
+        if (autoconfigured == null) {
+            autoconfigured = Boolean.parseBoolean(getProjectProperty(ClientSideProjectConstants.PROJECT_AUTOCONFIGURED, Boolean.FALSE.toString()));
+        }
+        return autoconfigured;
+    }
+
+    public void setAutoconfigured(boolean autoconfigured) {
+        this.autoconfigured = autoconfigured;
+    }
+
+    public AtomicReference<String> getSourceFolder() {
+        if (sourceFolder == null) {
+            sourceFolder = new AtomicReference<>(getProjectProperty(ClientSideProjectConstants.PROJECT_SOURCE_FOLDER, null));
+        }
+        return sourceFolder;
+    }
+
+    public void setSourceFolder(String sourceFolder) {
+        this.sourceFolder = new AtomicReference<>(sourceFolder);
+    }
+
+    public AtomicReference<String> getSiteRootFolder() {
         if (siteRootFolder == null) {
-            siteRootFolder = getProjectProperty(ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER, ""); // NOI18N
+            siteRootFolder = new AtomicReference<>(getProjectProperty(ClientSideProjectConstants.PROJECT_SITE_ROOT_FOLDER, null));
         }
         return siteRootFolder;
     }
 
     public void setSiteRootFolder(String siteRootFolder) {
-        isSiteRootModified = true;
-        this.siteRootFolder = siteRootFolder;
+        this.siteRootFolder = new AtomicReference<>(siteRootFolder);
     }
 
-    public String getTestFolder() {
+    public AtomicReference<String> getTestFolder() {
         if (testFolder == null) {
-            testFolder = getProjectProperty(ClientSideProjectConstants.PROJECT_TEST_FOLDER, ""); // NOI18N
+            testFolder = new AtomicReference<>(getProjectProperty(ClientSideProjectConstants.PROJECT_TEST_FOLDER, null));
         }
         return testFolder;
     }
 
     public void setTestFolder(String testFolder) {
-        isTestFolderModified = true;
-        if (testFolder == null) {
-            // we need to find out that some value was set ("no value" in this case)
-            testFolder = ""; // NOI18N
+        this.testFolder = new AtomicReference<>(testFolder);
+    }
+
+    public AtomicReference<String> getTestSeleniumFolder() {
+        if (testSeleniumFolder == null) {
+            testSeleniumFolder = new AtomicReference<>(getProjectProperty(ClientSideProjectConstants.PROJECT_TEST_SELENIUM_FOLDER, null));
         }
-        this.testFolder = testFolder;
+        return testSeleniumFolder;
+    }
+
+    public void setTestSeleniumFolder(String testSeleniumFolder) {
+        this.testSeleniumFolder = new AtomicReference<>(testSeleniumFolder);
     }
 
     public String getEncoding() {
@@ -252,6 +299,28 @@ public final class ClientSideProjectProperties {
         this.encoding = encoding;
     }
 
+    public AtomicReference<String> getRunAs() {
+        if (runAs == null) {
+            runAs = new AtomicReference<>(getProjectProperty(ClientSideProjectConstants.PROJECT_RUN_AS, null));
+        }
+        return runAs;
+    }
+
+    public void setRunAs(String runAs) {
+        this.runAs = new AtomicReference<>(runAs);
+    }
+
+    public boolean isRunBrowser() {
+        if (runBrowser == null) {
+            runBrowser = project.isRunBrowser();
+        }
+        return runBrowser;
+    }
+
+    public void setRunBrowser(boolean runBrowser) {
+        this.runBrowser = runBrowser;
+    }
+
     public String getStartFile() {
         if (startFile == null) {
             startFile = project.getStartFile();
@@ -315,34 +384,6 @@ public final class ClientSideProjectProperties {
         this.projectServer = projectServer;
     }
 
-    public void setNewJsLibraries(List<SelectedLibrary> newJsLibraries) {
-        assert newJsLibraries != null;
-        // not needed to be locked, called always by just one caller
-        this.newJsLibraries.clear();
-        this.newJsLibraries.addAll(newJsLibraries);
-    }
-
-    List<SelectedLibrary> getNewJsLibraries() {
-        return newJsLibraries;
-    }
-
-    public static String createListOfJsLibraries(List<SelectedLibrary> libs) {
-        StringBuilder sb = new StringBuilder(200);
-        List<SelectedLibrary> selectedLibraries = libs;
-        for (SelectedLibrary lib : selectedLibraries) {
-            if (lib.isDefault()) {
-                continue;
-            }
-            if (sb.length() > 0) {
-                sb.append("|"); // NOI18N
-            }
-            JavaScriptLibrarySelectionPanel.LibraryVersion libraryVersion = lib.getLibraryVersion();
-            assert libraryVersion != null;
-            sb.append(libraryVersion.getLibrary().getName());
-        }
-        return sb.toString();
-    }
-
     public void setJsLibFolder(String jsLibFolder) {
         assert jsLibFolder != null;
         this.jsLibFolder = jsLibFolder;
@@ -352,17 +393,28 @@ public final class ClientSideProjectProperties {
         return jsLibFolder;
     }
 
+    @CheckForNull
+    public File getResolvedSourceFolder() {
+        return resolveFile(getSourceFolder().get());
+    }
+
+    @CheckForNull
     public File getResolvedSiteRootFolder() {
-        File resolvedFile = resolveFile(getSiteRootFolder());
-        if (resolvedFile != null) {
-            return resolvedFile;
-        }
-        return FileUtil.toFile(project.getProjectDirectory());
+        return resolveFile(getSiteRootFolder().get());
+    }
+
+    @CheckForNull
+    public File getResolvedTestFolder() {
+        return resolveFile(getTestFolder().get());
     }
 
     @CheckForNull
     public File getResolvedStartFile() {
-        return resolveFile(getSiteRootFolder() + (getSiteRootFolder().isEmpty() ? "" : "/") + getStartFile()); // NOI18N
+        String siteRoot = getSiteRootFolder().get();
+        if (siteRoot == null) {
+            return null;
+        }
+        return resolveFile(siteRoot + (siteRoot.isEmpty() ? "" : "/") + getStartFile()); // NOI18N
     }
 
     private String getProjectProperty(String property, String defaultValue) {
@@ -379,14 +431,30 @@ public final class ClientSideProjectProperties {
         }
     }
 
-    private String createForeignFileReference(String filePath) {
+    private void putProperty(EditableProperties properties, String property, Boolean value) {
+        if (value != null) {
+            properties.put(property, value.toString());
+        }
+    }
+
+    private String createForeignFileReference(AtomicReference<String> filePath, boolean storeEmptyPath) {
+        if (filePath == null) {
+            return null;
+        }
+        return createForeignFileReference(filePath.get(), storeEmptyPath);
+    }
+
+    private String createForeignFileReference(String filePath, boolean storeEmptyPath) {
         if (filePath == null) {
             // not set at all
             return null;
         }
         if (filePath.isEmpty()) {
-            // empty value will be saved
-            return ""; // NOI18N
+            if (storeEmptyPath) {
+                // empty value will be saved
+                return ""; // NOI18N
+            }
+            return null;
         }
         File file = project.getProjectHelper().resolveFile(filePath);
         return project.getReferenceHelper().createForeignFileReference(file, null);
@@ -394,17 +462,21 @@ public final class ClientSideProjectProperties {
 
     @CheckForNull
     private File resolveFile(String path) {
-        if (path == null || path.isEmpty()) {
+        if (path == null) {
             return null;
         }
+        if (path.isEmpty()) {
+            return FileUtil.toFile(project.getProjectDirectory());
+        }
         return project.getProjectHelper().resolveFile(path);
     }
 
-    public LicensePanelSupport getLicenseSupport() {
+    public Licenses getLicenseSupport() {
         if (licenseSupport == null) {
-            licenseSupport = new LicensePanelSupport(project.getEvaluator(), project.getProjectHelper(),
-                getProjectProperty(LicensePanelSupport.LICENSE_PATH, null),
-                getProjectProperty(LicensePanelSupport.LICENSE_NAME, null));
+            Env is = project.is;
+            licenseSupport = is.newLicensePanelSupport(project.getEvaluator(), project.getProjectHelper(),
+                getProjectProperty(Licenses.LICENSE_PATH, null),
+                getProjectProperty(Licenses.LICENSE_NAME, null));
         }
         return licenseSupport;
     }
