@@ -57,6 +57,7 @@ import javax.swing.SwingConstants;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
+import org.netbeans.modules.web.clientproject.api.util.StringUtilities;
 import org.netbeans.modules.web.clientproject.util.ClientSideProjectUtilities;
 import org.netbeans.modules.web.clientproject.api.util.ValidationUtilities;
 import org.openide.awt.Mnemonics;
@@ -70,27 +71,23 @@ import org.openide.util.NbBundle;
  */
 public class ExistingClientSideProject extends JPanel {
 
-    private static final long serialVersionUID = -4683211573157747L;
-
     private final ChangeSupport changeSupport = new ChangeSupport(this);
 
     // @GuardedBy("EDT")
     boolean fireChanges = true;
     // @GuardedBy("EDT")
     String lastSiteRoot = ""; // NOI18N
-    // @GuardedBy("EDT")
-    String lastProjectName = ""; // NOI18N
     volatile String testDir = null;
 
 
     public ExistingClientSideProject() {
         initComponents();
-        initSiteRoot();
-        initProjectName();
-        initProjectDirectory();
+        init();
     }
 
-    private void initSiteRoot() {
+    private void init() {
+        DocumentListener defaultDocumentListener = new DefaultDocumentListener();
+        // site root
         siteRootTextField.getDocument().addDocumentListener(new DefaultDocumentListener(new Runnable() {
             @Override
             public void run() {
@@ -103,29 +100,22 @@ public class ExistingClientSideProject extends JPanel {
                 fireChanges = true;
             }
         }));
-    }
-
-    private void initProjectName() {
-        projectNameTextField.getDocument().addDocumentListener(new DefaultDocumentListener(new Runnable() {
-            @Override
-            public void run() {
-                assert EventQueue.isDispatchThread();
-                fireChanges = false;
-                updateProjectDirectoryName();
-                lastProjectName = getProjectName();
-                fireChanges = true;
-            }
-        }));
-    }
-
-    private void initProjectDirectory() {
-        projectDirectoryTextField.getDocument().addDocumentListener(new DefaultDocumentListener());
+        // sources
+        sourcesTextField.getDocument().addDocumentListener(defaultDocumentListener);
+        // project name
+        projectNameTextField.getDocument().addDocumentListener(defaultDocumentListener);
+        // project dir
+        projectDirectoryTextField.getDocument().addDocumentListener(defaultDocumentListener);
     }
 
     public String getSiteRoot() {
         return siteRootTextField.getText().trim();
     }
 
+    public String getSources() {
+        return sourcesTextField.getText().trim();
+    }
+
     public String getProjectName() {
         return projectNameTextField.getText().trim();
     }
@@ -146,8 +136,23 @@ public class ExistingClientSideProject extends JPanel {
         changeSupport.removeChangeListener(listener);
     }
 
+    @NbBundle.Messages({
+        "ExistingClientSideProject.siteRoot.label=Site Root",
+        "ExistingClientSideProject.sources.label=Source folder",
+        "ExistingClientSideProject.error.noFolder=Site Root or/and Source folder must be selected.",
+    })
     public String getErrorMessage() {
-        String error = validateSiteRoot();
+        String siteRoot = getSiteRoot();
+        String sources = getSources();
+        if (!StringUtilities.hasText(siteRoot)
+                && !StringUtilities.hasText(sources)) {
+            return Bundle.ExistingClientSideProject_error_noFolder();
+        }
+        String error = validateFolder(siteRoot, Bundle.ExistingClientSideProject_siteRoot_label());
+        if (error != null) {
+            return error;
+        }
+        error = validateFolder(sources, Bundle.ExistingClientSideProject_sources_label());
         if (error != null) {
             return error;
         }
@@ -163,20 +168,20 @@ public class ExistingClientSideProject extends JPanel {
     }
 
     @NbBundle.Messages({
-        "ExistingClientSideProject.error.siteRoot.empty=Site root must be selected.",
-        "ExistingClientSideProject.error.siteRoot.invalid=Site root is not a valid path.",
-        "ExistingClientSideProject.error.siteRoot.nbproject=Site root is already NetBeans project (maybe only in memory)."
+        "# {0} - folder name",
+        "ExistingClientSideProject.error.folder.invalid={0} is not a valid path.",
+        "# {0} - folder name",
+        "ExistingClientSideProject.error.folder.nbproject={0} is already NetBeans project (maybe only in memory).",
     })
-    private String validateSiteRoot() {
-        String siteRoot = getSiteRoot();
-        if (siteRoot.isEmpty()) {
-            return Bundle.ExistingClientSideProject_error_siteRoot_empty();
+    private String validateFolder(String folder, String folderName) {
+        if (!StringUtilities.hasText(folder)) {
+            return null;
         }
-        File siteRootDir = FileUtil.normalizeFile(new File(siteRoot).getAbsoluteFile());
-        if (!siteRootDir.isDirectory()) {
-            return Bundle.ExistingClientSideProject_error_siteRoot_invalid();
-        } else if (ClientSideProjectUtilities.isProject(siteRootDir)) {
-            return Bundle.ExistingClientSideProject_error_siteRoot_nbproject();
+        File folderDir = FileUtil.normalizeFile(new File(folder).getAbsoluteFile());
+        if (!folderDir.isDirectory()) {
+            return Bundle.ExistingClientSideProject_error_folder_invalid(folderName);
+        } else if (ClientSideProjectUtilities.isProject(folderDir)) {
+            return Bundle.ExistingClientSideProject_error_folder_nbproject(folderName);
         }
         return null;
     }
@@ -205,14 +210,7 @@ public class ExistingClientSideProject extends JPanel {
         if (ClientSideProjectUtilities.isProject(projDir)) {
             return Bundle.ExistingClientSideProject_error_projectDirectory_alreadyProject();
         }
-        File siteRoot = FileUtil.normalizeFile(new File(getSiteRoot()).getAbsoluteFile());
-        if (projDir.isDirectory()) {
-            if (projDir.equals(siteRoot)) {
-                // same as site root, do nothing
-                return null;
-            }
-            // XXX ideally warn about possibly non-empty directory
-        } else {
+        if (!projDir.isDirectory()) {
             // not existing directory
             if (!ValidationUtilities.isValidFilename(projDir)) {
                 return Bundle.ExistingClientSideProject_error_projectDirectory_invalid();
@@ -240,29 +238,14 @@ public class ExistingClientSideProject extends JPanel {
         assert EventQueue.isDispatchThread();
         String projectDirectory = getProjectDirectory();
         if (!lastSiteRoot.isEmpty() && projectDirectory.equals(lastSiteRoot)) {
-            // project directory in site root => do nothing
+            // project directory is site root => do nothing
             return;
         }
         projectDirectoryTextField.setText(getSiteRoot());
     }
 
-    void updateProjectDirectoryName() {
-        String projectDirectory = getProjectDirectory();
-        if (projectDirectory.equals(getSiteRoot())) {
-            // project directory in site root => do nothing
-            return;
-        }
-        if (!lastProjectName.isEmpty()
-                && !projectDirectory.equals(lastProjectName)
-                && projectDirectory.endsWith(lastProjectName)) {
-            // yes, project directory follows project name
-            String newProjDir = projectDirectory.substring(0, projectDirectory.length() - lastProjectName.length()) + getProjectName();
-            projectDirectoryTextField.setText(newProjDir);
-        }
-    }
-
-    void detectClientSideProject(String siteRoot) {
-        ClientSideProjectDetector detector = new ClientSideProjectDetector(new File(siteRoot));
+    void detectClientSideProject(String folder) {
+        ClientSideProjectDetector detector = new ClientSideProjectDetector(new File(folder));
         if (detector.detected()) {
             projectNameTextField.setText(detector.getName());
             projectDirectoryTextField.setText(detector.getProjectDirPath());
@@ -287,6 +270,9 @@ public class ExistingClientSideProject extends JPanel {
         siteRootLabel = new JLabel();
         siteRootTextField = new JTextField();
         siteRootBrowseButton = new JButton();
+        sourcesLabel = new JLabel();
+        sourcesTextField = new JTextField();
+        sourcesBrowseButton = new JButton();
         projectNameLabel = new JLabel();
         projectNameTextField = new JTextField();
         projectDirectoryLabel = new JLabel();
@@ -295,6 +281,7 @@ public class ExistingClientSideProject extends JPanel {
 
         siteRootLabel.setLabelFor(siteRootTextField);
         Mnemonics.setLocalizedText(siteRootLabel, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.siteRootLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(siteRootBrowseButton, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.siteRootBrowseButton.text")); // NOI18N
         siteRootBrowseButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
@@ -302,11 +289,21 @@ public class ExistingClientSideProject extends JPanel {
             }
         });
 
+        Mnemonics.setLocalizedText(sourcesLabel, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.sourcesLabel.text")); // NOI18N
+
+        Mnemonics.setLocalizedText(sourcesBrowseButton, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.sourcesBrowseButton.text")); // NOI18N
+        sourcesBrowseButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                sourcesBrowseButtonActionPerformed(evt);
+            }
+        });
+
         projectNameLabel.setLabelFor(projectNameTextField);
         Mnemonics.setLocalizedText(projectNameLabel, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.projectNameLabel.text")); // NOI18N
 
         projectDirectoryLabel.setLabelFor(projectDirectoryTextField);
         Mnemonics.setLocalizedText(projectDirectoryLabel, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.projectDirectoryLabel.text")); // NOI18N
+
         Mnemonics.setLocalizedText(projectDirectoryBrowseButton, NbBundle.getMessage(ExistingClientSideProject.class, "ExistingClientSideProject.projectDirectoryBrowseButton.text")); // NOI18N
         projectDirectoryBrowseButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
@@ -316,40 +313,46 @@ public class ExistingClientSideProject extends JPanel {
 
         GroupLayout layout = new GroupLayout(this);
         this.setLayout(layout);
-        layout.setHorizontalGroup(
-            layout.createParallelGroup(Alignment.LEADING)
+        layout.setHorizontalGroup(layout.createParallelGroup(Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
                 .addGroup(layout.createParallelGroup(Alignment.LEADING)
                     .addComponent(projectDirectoryLabel)
+                    .addComponent(projectNameLabel)
                     .addComponent(siteRootLabel)
-                    .addComponent(projectNameLabel))
+                    .addComponent(sourcesLabel))
                 .addPreferredGap(ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(Alignment.LEADING)
+                    .addComponent(projectNameTextField)
                     .addGroup(layout.createSequentialGroup()
-                        .addGroup(layout.createParallelGroup(Alignment.LEADING)
-                            .addComponent(siteRootTextField)
-                            .addComponent(projectDirectoryTextField))
+                        .addGroup(layout.createParallelGroup(Alignment.TRAILING)
+                            .addComponent(sourcesTextField)
+                            .addComponent(siteRootTextField, Alignment.LEADING)
+                            .addComponent(projectDirectoryTextField, Alignment.LEADING))
                         .addPreferredGap(ComponentPlacement.RELATED)
                         .addGroup(layout.createParallelGroup(Alignment.LEADING)
                             .addComponent(siteRootBrowseButton, Alignment.TRAILING)
-                            .addComponent(projectDirectoryBrowseButton, Alignment.TRAILING)))
-                    .addComponent(projectNameTextField)))
+                            .addComponent(projectDirectoryBrowseButton, Alignment.TRAILING)
+                            .addComponent(sourcesBrowseButton, Alignment.TRAILING)))))
         );
 
-        layout.linkSize(SwingConstants.HORIZONTAL, new Component[] {projectDirectoryBrowseButton, siteRootBrowseButton});
+        layout.linkSize(SwingConstants.HORIZONTAL, new Component[] {projectDirectoryBrowseButton, siteRootBrowseButton, sourcesBrowseButton});
 
-        layout.setVerticalGroup(
-            layout.createParallelGroup(Alignment.LEADING)
+        layout.setVerticalGroup(layout.createParallelGroup(Alignment.LEADING)
             .addGroup(layout.createSequentialGroup()
                 .addGroup(layout.createParallelGroup(Alignment.BASELINE)
-                    .addComponent(siteRootLabel)
                     .addComponent(siteRootTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
-                    .addComponent(siteRootBrowseButton))
+                    .addComponent(siteRootBrowseButton)
+                    .addComponent(siteRootLabel))
+                .addPreferredGap(ComponentPlacement.RELATED)
+                .addGroup(layout.createParallelGroup(Alignment.BASELINE)
+                    .addComponent(sourcesTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
+                    .addComponent(sourcesLabel)
+                    .addComponent(sourcesBrowseButton))
                 .addPreferredGap(ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                     .addComponent(projectNameTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
                     .addComponent(projectNameLabel))
-                .addPreferredGap(ComponentPlacement.UNRELATED)
+                .addPreferredGap(ComponentPlacement.RELATED)
                 .addGroup(layout.createParallelGroup(Alignment.BASELINE)
                     .addComponent(projectDirectoryLabel)
                     .addComponent(projectDirectoryTextField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
@@ -357,12 +360,14 @@ public class ExistingClientSideProject extends JPanel {
         );
     }// </editor-fold>//GEN-END:initComponents
 
-    @NbBundle.Messages("ExistingClientSideProject.siteRoot.dialog.title=Select Site Root")
+    @NbBundle.Messages({
+        "ExistingClientSideProject.siteRoot.dialog.title=Select Site Root",
+    })
     private void siteRootBrowseButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_siteRootBrowseButtonActionPerformed
-        File siteRoot = browseFile(".siteRoot", Bundle.ExistingClientSideProject_siteRoot_dialog_title(), //NOI18N
+        File folder = browseFile(".siteRoot", Bundle.ExistingClientSideProject_siteRoot_dialog_title(), //NOI18N
                 getSiteRoot());
-        if (siteRoot != null) {
-            siteRootTextField.setText(FileUtil.normalizeFile(siteRoot).getAbsolutePath());
+        if (folder != null) {
+            siteRootTextField.setText(FileUtil.normalizeFile(folder).getAbsolutePath());
         }
     }//GEN-LAST:event_siteRootBrowseButtonActionPerformed
 
@@ -371,16 +376,21 @@ public class ExistingClientSideProject extends JPanel {
         File projectDirectory = browseFile(".projectDirectory", Bundle.ExistingClientSideProject_projectDirectory_dialog_title(), // NOI18N
                 getProjectDirectory());
         if (projectDirectory != null) {
-            File result = FileUtil.normalizeFile(projectDirectory);
-            File[] children = result.listFiles();
-            if (children != null && children.length > 0) {
-                // non-empty dir is not allowed, preselect directory with project name
-                result = new File(result, getProjectName());
-            }
-            projectDirectoryTextField.setText(result.getAbsolutePath());
+            projectDirectoryTextField.setText(FileUtil.normalizeFile(projectDirectory).getAbsolutePath());
         }
     }//GEN-LAST:event_projectDirectoryBrowseButtonActionPerformed
 
+    @NbBundle.Messages({
+        "ExistingClientSideProject.sources.dialog.title=Select Source Folder",
+    })
+    private void sourcesBrowseButtonActionPerformed(ActionEvent evt) {//GEN-FIRST:event_sourcesBrowseButtonActionPerformed
+        File folder = browseFile(".sources", Bundle.ExistingClientSideProject_sources_dialog_title(), //NOI18N
+                getSources());
+        if (folder != null) {
+            sourcesTextField.setText(FileUtil.normalizeFile(folder).getAbsolutePath());
+        }
+    }//GEN-LAST:event_sourcesBrowseButtonActionPerformed
+
     private File browseFile(String dirKey, String title, String currentDirectory) {
         File workDir = null;
         if (currentDirectory != null && !currentDirectory.isEmpty()) {
@@ -389,7 +399,7 @@ public class ExistingClientSideProject extends JPanel {
                 workDir = currDir;
             }
         }
-        FileChooserBuilder builder = new FileChooserBuilder(NewClientSideProject.class.getName() + dirKey)
+        FileChooserBuilder builder = new FileChooserBuilder(ExistingClientSideProject.class.getName() + dirKey)
                 .setTitle(title)
                 .setDirectoriesOnly(true);
         if (workDir != null) {
@@ -408,6 +418,9 @@ public class ExistingClientSideProject extends JPanel {
     private JButton siteRootBrowseButton;
     private JLabel siteRootLabel;
     private JTextField siteRootTextField;
+    private JButton sourcesBrowseButton;
+    private JLabel sourcesLabel;
+    private JTextField sourcesTextField;
     // End of variables declaration//GEN-END:variables
 
     //~ Inner classes
