@@ -49,10 +49,12 @@ import java.io.IOException;
 import java.net.InetAddress;
 import java.net.MalformedURLException;
 import java.net.NetworkInterface;
+import java.net.SocketException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLDecoder;
+import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.List;
@@ -63,8 +65,10 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.ImageIcon;
 import org.netbeans.api.editor.mimelookup.MimePath;
+import org.netbeans.api.project.Project;
 import org.netbeans.modules.parsing.api.Embedding;
 import org.netbeans.modules.parsing.api.ResultIterator;
+import org.netbeans.modules.web.common.spi.ProjectWebRootProvider;
 import org.netbeans.modules.web.common.spi.ProjectWebRootQuery;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
@@ -548,9 +552,26 @@ public class WebUtils {
                 }
             }
             return localHost;
-        } catch (Exception ex) {
+        } catch (UnknownHostException uhex) {
+            throw new IllegalStateException("Cannot resolve local host address, please check your network configuration.", uhex); // NOI18N
+        } catch (SocketException ex) {
             throw new IllegalStateException(ex);
         }
     }
 
+    /**
+     * Checks whether the given project has web root.
+     * @param project project to be checked
+     * @return {@code true} if the given project has web root, {@code false} otherwise
+     * @since 1.78
+     */
+    public static boolean hasWebRoot(Project project) {
+        Parameters.notNull("project", project); // NOI18N
+        ProjectWebRootProvider webRootProvider = project.getLookup().lookup(ProjectWebRootProvider.class);
+        if (webRootProvider == null) {
+            return false;
+        }
+        return !webRootProvider.getWebRoots().isEmpty();
+    }
+
 }
