@@ -52,8 +52,8 @@ import javax.swing.text.BadLocationException;
 import javax.swing.text.StyledDocument;
 import org.netbeans.modules.css.model.api.Model;
 import org.netbeans.modules.web.common.api.LexerUtils;
-import org.netbeans.modules.web.inspect.sourcemap.Mapping;
-import org.netbeans.modules.web.inspect.sourcemap.SourceMap;
+import org.netbeans.modules.web.common.sourcemap.Mapping;
+import org.netbeans.modules.web.common.sourcemap.SourceMap;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.cookies.EditorCookie;
