@@ -432,9 +432,9 @@ public abstract class CssStylesPanelProviderImpl extends JPanel implements CssSt
             return Bundle.CTL_CssStylesProviderImpl_selection_view_title();
         }
 
-        Lookup lookup;
-        Lookup.Result<FileObject> result;
-        LookupListener listener;
+        private Lookup lookup;
+        private Lookup.Result<FileObject> result;
+        private LookupListener listener;
 
         @Override
         public JComponent getContent(Lookup lookup) {
@@ -497,6 +497,9 @@ public abstract class CssStylesPanelProviderImpl extends JPanel implements CssSt
                         if (file != null) {
                             try {
                                 Source source = Source.create(file);
+                                if (source == null) {
+                                    return;
+                                }
                                 ParserManager.parse(Collections.singleton(source), new UserTask() {
                                     @Override
                                     public void run(ResultIterator resultIterator) throws Exception {
