@@ -59,18 +59,23 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.JToolBar;
 import org.netbeans.api.project.Project;
+import org.netbeans.modules.web.browser.spi.EnhancedBrowser;
+import org.netbeans.modules.web.common.api.UsageLogger;
 import org.netbeans.modules.web.inspect.CSSUtils;
 import org.netbeans.modules.web.inspect.PageModel;
 import org.netbeans.modules.web.inspect.actions.Resource;
 import org.netbeans.modules.web.inspect.files.Files;
 import org.netbeans.modules.web.inspect.webkit.ui.CSSStylesPanel;
-import org.netbeans.modules.web.webkit.debugging.api.dom.DOM;
 import org.netbeans.modules.web.webkit.debugging.api.WebKitDebugging;
 import org.netbeans.modules.web.webkit.debugging.api.css.CSS;
 import org.netbeans.modules.web.webkit.debugging.api.css.StyleSheetHeader;
 import org.netbeans.modules.web.webkit.debugging.api.debugger.RemoteObject;
+import org.netbeans.modules.web.webkit.debugging.api.dom.DOM;
 import org.netbeans.modules.web.webkit.debugging.api.dom.Node;
+import org.openide.DialogDisplayer;
+import org.openide.NotifyDescriptor;
 import org.openide.util.Lookup;
+import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
 /**
@@ -491,6 +496,30 @@ public class WebKitPageModel extends PageModel {
             }
         }
 
+        @Override
+        public void shadowRootPushed(Node host, Node shadowRoot) {
+            synchronized(WebKitPageModel.this) {
+                int hostId = host.getNodeId();
+                updateNodes(shadowRoot);
+                DOMNode domNode = nodes.get(hostId);
+                if (domNode != null) {
+                    domNode.updateChildren(host, shadowRoot);
+                }
+            }
+        }
+
+        @Override
+        public void shadowRootPopped(Node host, Node shadowRoot) {
+            synchronized(WebKitPageModel.this) {
+                int hostId = host.getNodeId();
+                DOMNode domNode = nodes.get(hostId);
+                if (domNode != null) {
+                    domNode.updateChildren(host);
+                }
+                nodes.remove(shadowRoot.getNodeId());
+            }
+        }
+
     }
 
     /**
@@ -539,12 +568,20 @@ public class WebKitPageModel extends PageModel {
         if (domNode == null) {
             domNode = new DOMNode(this, node);
             nodes.put(nodeId, domNode);
+            if (nodes.size() > MAX_NODES) { // Check page size
+                showPageSizeWarning();
+            }
         }
         boolean updateChildren = false;
         List<Node> subNodes = node.getChildren();
         if (subNodes == null) {
             int nodeType = node.getNodeType();
-            if (nodeType == org.w3c.dom.Node.ELEMENT_NODE || nodeType == org.w3c.dom.Node.DOCUMENT_NODE) {
+            if (nodeType == org.w3c.dom.Node.ELEMENT_NODE
+                    || nodeType == org.w3c.dom.Node.DOCUMENT_NODE
+                    || nodeType == org.w3c.dom.Node.DOCUMENT_FRAGMENT_NODE) {
+                if (node.getChildrenCount() > MAX_CHILD_NODES) {
+                    showPageSizeWarning();
+                }
                 webKit.getDOM().requestChildNodes(nodeId);
             }
         } else {
@@ -553,6 +590,10 @@ public class WebKitPageModel extends PageModel {
             }
             updateChildren = true;
         }
+        for (Node shadowRoot : node.getShadowRoots()) {
+            updateNodes(shadowRoot);
+            updateChildren = true;
+        }
         final Node contentDocument = node.getContentDocument();
         if (contentDocument != null) {
             updateNodes(contentDocument);
@@ -580,13 +621,50 @@ public class WebKitPageModel extends PageModel {
         return domNode;
     }
 
+    /** Maximum number of elements in a page for safe inspection. */
+    private static final int MAX_NODES = 100000;
+    /** Maximum number of child nodes of one node for safe inspection. */
+    private static final int MAX_CHILD_NODES = 20000;
+    /** Determines whether a warning about the size of the page was shown. */
+    private boolean pageSizeWarningShown = false;
+    
+    /**
+     * Checks if the current information that we have about the inspected
+     * page is too large to continue with the page inspection safely.
+     */
+    @NbBundle.Messages({
+        "WebKitPageModel.pageSizeWarningTitle=Page Too Large",
+        "WebKitPageModel.pageSizeWarningMessage="
+                + "The page is too large to inspect it in NetBeans safely. "
+                + "You may run out of memory if you continue with the inspection. "
+                + "Do you what to close this page and stop its inspection?"
+    })
+    private void showPageSizeWarning() {
+        if (!pageSizeWarningShown) {
+            pageSizeWarningShown = true;
+            NotifyDescriptor descriptor = new NotifyDescriptor.Confirmation(
+                    Bundle.WebKitPageModel_pageSizeWarningMessage(),
+                    Bundle.WebKitPageModel_pageSizeWarningTitle(),
+                    NotifyDescriptor.YES_NO_OPTION,
+                    NotifyDescriptor.WARNING_MESSAGE
+            );
+            DialogDisplayer.getDefault().notify(descriptor);
+            if (descriptor.getValue() == NotifyDescriptor.YES_OPTION) {
+                EnhancedBrowser browser = pageContext.lookup(EnhancedBrowser.class);
+                if (browser != null) {
+                    browser.close(true);
+                }
+            }
+        }
+    }
+
     /**
      * Returns {@code DOMNode} with the specified ID.
      *
      * @param nodeId ID of the requested {@code DOMNode}.
      * @return {@code DOMNode} with the specified ID.
      */
-    DOMNode getNode(int nodeId) {
+    public DOMNode getNode(int nodeId) {
         return nodes.get(nodeId);
     }
 
@@ -599,6 +677,7 @@ public class WebKitPageModel extends PageModel {
             }
             selectedNodes = knownNodes(nodes);
         }
+        logPageInspectionUsage();
         firePropertyChange(PROP_SELECTED_NODES, null, null);
     }
 
@@ -621,6 +700,16 @@ public class WebKitPageModel extends PageModel {
         return knownNodes;
     }
 
+    private static final UsageLogger USAGE_LOGGER = new UsageLogger.Builder("org.netbeans.ui.metrics.web.inspect")  // NOI18N
+            .firstMessageOnly(true)
+            .message(WebKitPageModel.class, "USG_PAGE_INSPECTION") // NOI18N
+            .create();
+
+    /** Logs the usage of page inspection. */
+    private void logPageInspectionUsage() {
+        USAGE_LOGGER.log();
+    }
+
     @Override
     public List<org.openide.nodes.Node> getSelectedNodes() {
         synchronized (this) {
@@ -851,6 +940,9 @@ public class WebKitPageModel extends PageModel {
                     }
                 }
             }
+        } else if (type == org.w3c.dom.Node.DOCUMENT_FRAGMENT_NODE) {
+            // Shadow root => highlight/select the host
+            result = node.getParent();
         }
         return result;
     }
