@@ -41,6 +41,7 @@
  */
 package org.netbeans.modules.web.javascript.debugger.breakpoints;
 
+import java.awt.Image;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.net.URL;
@@ -67,10 +68,12 @@ import org.netbeans.modules.web.webkit.debugging.api.Debugger;
 import org.netbeans.modules.web.webkit.debugging.api.WebKitDebugging;
 import org.netbeans.modules.web.webkit.debugging.api.debugger.CallFrame;
 import org.netbeans.modules.web.webkit.debugging.api.dom.Node;
+import org.netbeans.modules.web.webkit.debugging.api.dom.NodeAnnotator;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.URLMapper;
 import org.openide.text.Line;
+import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
@@ -84,6 +87,7 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
     protected final Debugger d;
     private final Breakpoint b;
     private static final RequestProcessor rp = new RequestProcessor(WebKitBreakpointManager.class);
+    private static final Image DOM_BREAKPOINT_BADGE = ImageUtilities.loadImage("org/netbeans/modules/web/javascript/debugger/resources/DOMBreakpoint.png", false); // NOI18N
 
     protected WebKitBreakpointManager(Debugger d, Breakpoint b) {
         this.d = d;
@@ -177,7 +181,7 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
                 url = reformatFileURL(url);
                 org.netbeans.modules.web.webkit.debugging.api.debugger.Breakpoint br = null;
                 try {
-                    br = d.addLineBreakpoint(url, lb.getLine().getLineNumber(), 0);
+                    br = d.addLineBreakpoint(url, lb.getLine().getLineNumber(), null, lb.getCondition());
                 } catch (BreakpointException bex) {
                     JSBreakpointStatus.setInvalid(lb, bex.getLocalizedMessage());
                 }
@@ -236,6 +240,15 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
         }
         
         private void resubmit() {
+            if (SwingUtilities.isEventDispatchThread()) {
+                rp.post(new Runnable() {
+                    @Override
+                    public void run() {
+                        resubmit();
+                    }
+                });
+                return ;
+            }
             org.netbeans.modules.web.webkit.debugging.api.debugger.Breakpoint brkpt;
             synchronized (brkptLock) {
                 brkpt = b;
@@ -248,7 +261,7 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
                     url = reformatFileURL(url);
                     resubmitting.set(false);
                     try {
-                        brkpt = d.addLineBreakpoint(url, lb.getLine().getLineNumber(), 0);
+                        brkpt = d.addLineBreakpoint(url, lb.getLine().getLineNumber(), null, lb.getCondition());
                     } catch (BreakpointException bex) {
                         brkpt = null;
                         JSBreakpointStatus.setInvalid(lb, bex.getLocalizedMessage());
@@ -292,6 +305,10 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
             }
         }
 
+        @Override
+        public void enabled(boolean enabled) {
+        }
+        
         @Override
         public void propertyChange(PropertyChangeEvent event) {
             String propertyName = event.getPropertyName();
@@ -301,6 +318,8 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
                     return ;
                 }
                 resubmit();
+            } else if (JSLineBreakpoint.PROP_CONDITION.equals(propertyName)) {
+                resubmit();
             } else if (JSLineBreakpoint.PROP_LINE_NUMBER.equals(propertyName) ||
                        JSLineBreakpoint.PROP_FILE.equals(propertyName)) {
                 lineChanged.set(true);
@@ -500,6 +519,7 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
             } else {
                 db.setInvalid(Bundle.MSG_DOM_BRKP_Unresolved());
             }
+            NodeAnnotator.getDefault().annotate(node, DOM_BREAKPOINT_BADGE);
         }
 
         @Override
@@ -533,6 +553,7 @@ abstract class WebKitBreakpointManager implements PropertyChangeListener {
                 db.resetValidity();
             }
             bps = null;
+            NodeAnnotator.getDefault().annotate(theNode, null);
         }
 
         @Override
