@@ -60,7 +60,8 @@ import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.netbeans.modules.web.javascript.debugger.ViewModelSupport;
+import org.netbeans.api.annotations.common.StaticResource;
+import org.netbeans.modules.javascript2.debug.models.ViewModelSupport;
 import org.netbeans.modules.web.javascript.debugger.eval.EvaluatorService;
 import org.netbeans.modules.web.webkit.debugging.api.Debugger;
 import org.netbeans.modules.web.webkit.debugging.api.debugger.CallFrame;
@@ -89,9 +90,12 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
         TableModel, Debugger.Listener, PropertyChangeListener {
 
     private static final Logger LOGGER = Logger.getLogger(VariablesModel.class.getName());
+    //@StaticResource(searchClasspath = true)
     public static final String LOCAL = "org/netbeans/modules/debugger/resources/localsView/local_variable_16.png"; // NOI18N
-    public static final String GLOBAL = "org/netbeans/modules/web/javascript/debugger/resources/global_variable_16.png"; // NOI18N
-    public static final String PROTO = "org/netbeans/modules/web/javascript/debugger/resources/proto_variable_16.png"; // NOI18N
+    @StaticResource(searchClasspath = true)
+    public static final String GLOBAL = "org/netbeans/modules/javascript2/debug/resources/global_variable_16.png"; // NOI18N
+    @StaticResource(searchClasspath = true)
+    public static final String PROTO = "org/netbeans/modules/javascript2/debug/resources/proto_variable_16.png"; // NOI18N
     
     protected final Debugger debugger;
     protected final EvaluatorService evaluator;
@@ -174,6 +178,9 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
                 if (i != 0) {
                     return i;
                 } else {
+                    if (o1.isArrayElement() && o2.isArrayElement()) {
+                        return Long.signum(o1.getArrayIndex() - o2.getArrayIndex());
+                    }
                     return o1.getObjectName().compareToIgnoreCase(o2.getObjectName());
                 }
             }
@@ -199,8 +206,17 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
         res = new ArrayList<ScopedRemoteObject>();
         variablesCache.put(prop, res);
         if (prop.getType() == RemoteObject.Type.OBJECT) {
+            RemoteObject.SubType subType = prop.getSubType();
+            boolean isArray = RemoteObject.SubType.ARRAY.equals(subType);
             for (PropertyDescriptor desc : prop.getProperties()) {
-                res.add(new ScopedRemoteObject(desc.getValue(), desc.getName(), scope, parentNameID));
+                long arrayIndex = -1;
+                if (isArray) {
+                    try {
+                        arrayIndex = Long.parseLong(desc.getName());
+                    } catch (NumberFormatException nfex) {}
+                }
+                ScopedRemoteObject sro = new ScopedRemoteObject(desc.getValue(), desc.getName(), scope, parentNameID, arrayIndex);
+                res.add(sro);
             }
         }
         return sortVariables(res);
@@ -213,6 +229,10 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
         } else if (node instanceof ScopedRemoteObject) {
             RemoteObject var = ((ScopedRemoteObject) node).getRemoteObject();
             if (var != null && var.getType() == RemoteObject.Type.OBJECT) {
+                if (RemoteObject.SubType.ERROR.equals(var.getSubType())) {
+                    // Do not expand errors
+                    return true;
+                }
                 if (var.hasFetchedProperties()) {
                     return var.getProperties().isEmpty();
                 } else {
@@ -429,6 +449,10 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
     public void reset() {
     }
 
+    @Override
+    public void enabled(boolean enabled) {
+    }
+    
     @Override
     public void propertyChange(PropertyChangeEvent evt) {
         String propertyName = evt.getPropertyName();
@@ -448,12 +472,9 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
         private ViewScope scope;
         private String objectName;
         private String parentNameID;
+        private long arrayElementIndex; // an array index, or -1 when not an array element.
 
-        public ScopedRemoteObject(RemoteObject var, String name) {
-            this(var, name, ViewScope.DEFAULT);
-        }
-
-        public ScopedRemoteObject(RemoteObject var, Scope sc) {
+        ScopedRemoteObject(RemoteObject var, Scope sc) {
             this.var = var;
             if (sc.isLocalScope()) {
                 this.scope = ViewScope.LOCAL;
@@ -481,14 +502,15 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
         }
 
         public ScopedRemoteObject(RemoteObject var, String name, ViewScope scope) {
-            this(var, name, scope, null);
+            this(var, name, scope, null, -1);
         }
         
-        public ScopedRemoteObject(RemoteObject var, String name, ViewScope scope, String parentNameID) {
+        ScopedRemoteObject(RemoteObject var, String name, ViewScope scope, String parentNameID, long arrayElementIndex) {
             this.var = var;
             this.scope = scope;
             this.objectName = name;
             this.parentNameID = parentNameID;
+            this.arrayElementIndex = arrayElementIndex;
         }
 
         public ViewScope getScope() {
@@ -506,6 +528,14 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
             return objectName;
         }
 
+        boolean isArrayElement() {
+            return arrayElementIndex >= 0;
+        }
+        
+        long getArrayIndex() {
+            return arrayElementIndex;
+        }
+
         @Override
         public boolean equals(Object obj) {
             if (!(obj instanceof ScopedRemoteObject)) {
@@ -566,7 +596,7 @@ public class VariablesModel extends ViewModelSupport implements TreeModel, Exten
             String parent = (parentNameID != null) ? ", parent = '"+parentNameID+"'" : "";  // NOI18N
             return "ScopedRemoteObject["+scope+", "+objectName+", "+var+parent+"]";         // NOI18N
         }
-        
+
     }
 
     public static enum ViewScope {
