@@ -487,6 +487,9 @@ public class CompositeComponentModel extends JsfPageModel {
                 case '=':
                     out.append("\\e");
                     break;
+                case ';':
+                    out.append("\\m");
+                    break;
                 case '\\':
                     out.append("\\s");
                     break;
@@ -512,6 +515,9 @@ public class CompositeComponentModel extends JsfPageModel {
                     case 'e':
                         out.append('=');
                         break;
+                    case 'm':
+                        out.append(';');
+                        break;
                     case 's':
                         out.append('\\');
                         break;
