@@ -43,6 +43,7 @@ package org.netbeans.modules.web.webkit.debugging.api;
 
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -147,12 +148,16 @@ public final class Debugger {
             webkit.getPage().enable();
             webkit.getNetwork().enable();
             webkit.getConsole().enable();
+            webkit.getDOM().enable();
             webkit.getCSS().enable();
 
             enabled = true;
         }
         
         setBreakpointsActive(lastBreakpointsActive);
+        for (Listener l : listeners ) {
+            l.enabled(true);
+        }
         
         return true;
     }
@@ -187,6 +192,7 @@ public final class Debugger {
             webkit.getNetwork().disable();
             webkit.getConsole().disable();
             webkit.getCSS().disable();
+            webkit.getDOM().disable();
             transport.sendCommand(new Command(COMMAND_DISABLE));
             enabled = false;
             suspended = false;
@@ -194,6 +200,9 @@ public final class Debugger {
             currentCallFrame = null;
             initDOMLister = true;
         }
+        for (Listener l : listeners ) {
+            l.enabled(false);
+        }
     }
 
     public void stepOver() {
@@ -371,21 +380,30 @@ public final class Debugger {
     }*/
     
     @SuppressWarnings("unchecked")    
-    public Breakpoint addLineBreakpoint(String url, int lineNumber, int columnNumber) throws BreakpointException {
+    public Breakpoint addLineBreakpoint(String url, int lineNumber, Integer columnNumber, String condition) throws BreakpointException {
         if (inLiveHTMLMode) {
             // ignore line breakpoints when in Live HTML mode
             return null;
         }
         JSONObject params = new JSONObject();
         params.put("lineNumber", lineNumber);
-        params.put("url", url.replaceAll("/", "\\/")); //  XXX: not sure why but using backslash is necesssary here
-        params.put("columnNumber", columnNumber);
+        params.put("urlRegex", createURLRegex(url));
+        if (columnNumber != null) {
+            params.put("columnNumber", columnNumber);
+        }
+        if (condition != null) {
+            params.put("condition", condition);
+        }
         Response resp = transport.sendBlockingCommand(new Command(COMMAND_SET_BRKP_BY_URL, params));
         if (resp != null) {
             if (resp.getException() != null) {
                 // transport is broken
                 String message;
-                Object error = resp.getResponse().get("error");
+                JSONObject response = resp.getResponse();
+                Object error = null;
+                if (response != null) {
+                    error = response.get("error");
+                }
                 if (error instanceof String) {
                     message = parseError((String) error);
                 } else {
@@ -406,6 +424,40 @@ public final class Debugger {
         return null;
     }
 
+    private String createURLRegex(String url) {
+        String baseURL;
+        try {
+            URL u = new URL(url);
+            baseURL = u.getProtocol()+":"+
+                ((u.getAuthority() != null && u.getAuthority().length() > 0) ?
+                    "//"+u.getAuthority() : "")+
+                ((u.getPath() != null) ?
+                    u.getPath() : "");
+        } catch (MalformedURLException ex) {
+            baseURL = url;
+            int i = url.indexOf('?');
+            if (i > 0) {
+                baseURL = baseURL.substring(0, i);
+            }
+            i = url.indexOf('#');
+            if (i > 0) {
+                baseURL = baseURL.substring(0, i);
+            }
+        }
+        // Escape regex special characters:
+        baseURL = baseURL.replace("\\", "\\\\");
+        baseURL = baseURL.replace(".", "\\.");
+        baseURL = baseURL.replace("*", "\\*");
+        baseURL = baseURL.replace("+", "\\+");
+        baseURL = baseURL.replace("(", "\\(");
+        baseURL = baseURL.replace(")", "\\)");
+        baseURL = baseURL.replace("{", "\\{");
+        baseURL = baseURL.replace("}", "\\}");
+        baseURL = baseURL.replace("|", "\\|");
+        //System.err.println("Escaped baseURL = '"+baseURL+"'");
+        return "^"+baseURL+".*";
+    }
+
     @SuppressWarnings("unchecked")    
     public void removeLineBreakpoint(Breakpoint b) {
         JSONObject params = new JSONObject();
@@ -674,6 +726,13 @@ public final class Debugger {
          * Object state was reset due to page reload.
          */
         void reset();
+        
+        /**
+         * Debugger was enabled or disabled.
+         * @param enabled <code>true</code> when the debugger was enabled,
+         *                <code>false</code> when disabled.
+         */
+        void enabled(boolean enabled);
     }
     
 }
