@@ -62,8 +62,13 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.UIManager;
 import org.netbeans.api.project.Project;
+import org.netbeans.api.project.ProjectUtils;
+import org.netbeans.api.project.SourceGroup;
+import org.netbeans.api.project.Sources;
+import org.netbeans.modules.web.clientproject.api.WebClientProjectConstants;
 import org.netbeans.modules.web.common.api.RemoteFileCache;
 import org.netbeans.modules.web.common.api.ServerURLMapping;
+import org.netbeans.modules.web.common.api.WebUtils;
 import org.netbeans.modules.web.webkit.debugging.api.console.Console;
 import org.netbeans.modules.web.webkit.debugging.api.console.ConsoleMessage;
 import org.openide.cookies.LineCookie;
@@ -207,6 +212,9 @@ public class BrowserConsoleLogger implements Console.Listener {
     }
     
     private boolean shouldLogMessage(ConsoleMessage msg) {
+        if (msg == null) {
+            return false; // Issue 250389
+        }
         String level = msg.getLevel();
         String source = msg.getSource();
         // Ignore CSS warnings
@@ -549,8 +557,8 @@ public class BrowserConsoleLogger implements Console.Listener {
         }
 
         FileObject fileObject = null;
-        if (filePath.startsWith("http:") || filePath.startsWith("https:")) {    // NOI18N
-            try {
+        try {
+            if (filePath.startsWith("http:") || filePath.startsWith("https:")) {    // NOI18N
                 URL url;
                 try {
                     url = new URI(filePath).toURL();
@@ -564,17 +572,33 @@ public class BrowserConsoleLogger implements Console.Listener {
                 if (fileObject == null) {
                     fileObject = RemoteFileCache.getRemoteFile(url);
                 }
-            } catch (IOException ex) {
-                Exceptions.printStackTrace(ex);
-            }
-        } else {
-            File file;
-            if (filePath.startsWith("file:/")) {                                // NOI18N
-                file = Utilities.toFile(URI.create(filePath));
             } else {
-                file = new File(filePath);
+                File file;
+                if (filePath.startsWith("file:/")) {                                // NOI18N
+                    URI uri;
+                    try {
+                        // Issue 255536
+                        uri = new URI(filePath);
+                    } catch (URISyntaxException usex) {
+                        uri = null;
+                    }
+                    if (uri == null || uri.getQuery() != null || uri.getFragment() != null) {
+                        // Remove the query and/or fragment
+                        uri = WebUtils.stringToUrl(WebUtils.urlToString(new URL(filePath), true)).toURI();
+                    }
+                    file = Utilities.toFile(uri);
+                } else {
+                    file = new File(filePath);
+                    if (!file.isAbsolute() && project != null) {
+                        fileObject = findFileInProjecSources(project, filePath);
+                    }
+                }
+                if (fileObject == null) {
+                    fileObject = FileUtil.toFileObject(FileUtil.normalizeFile(file));
+                }
             }
-            fileObject = FileUtil.toFileObject(FileUtil.normalizeFile(file));
+        } catch (IOException | URISyntaxException ex) {
+            Exceptions.printStackTrace(ex);
         }
         if (fileObject == null) {
             LOG.log(Level.FINE, "Cannot resolve \"{0}\"", filePath);
@@ -597,6 +621,25 @@ public class BrowserConsoleLogger implements Console.Listener {
             }
         }
     }
+    
+    private static final String[] KNOWN_SOURCE_TYPES = {Sources.TYPE_GENERIC,
+                                                        WebClientProjectConstants.SOURCES_TYPE_HTML5_SITE_ROOT,
+                                                        WebClientProjectConstants.SOURCES_TYPE_HTML5_TEST,
+                                                        WebClientProjectConstants.SOURCES_TYPE_HTML5_TEST_SELENIUM };
+    private static FileObject findFileInProjecSources(Project project, String filePath) {
+        Sources sources = ProjectUtils.getSources(project);
+        for (String sourceType : KNOWN_SOURCE_TYPES) {
+            SourceGroup[] sourceGroups = sources.getSourceGroups(sourceType);
+            for (SourceGroup sourceGroup : sourceGroups) {
+                FileObject rootFolder = sourceGroup.getRootFolder();
+                FileObject fileObject = rootFolder.getFileObject(filePath);
+                if (fileObject != null) {
+                    return fileObject;
+                }
+            }
+        }
+        return null;
+    }
 
     public static LineCookie getLineCookie(final FileObject fo) {
         LineCookie result = null;
